% File src/library/base/man/Quotes.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Quotes}
\alias{Quotes}
\alias{backtick}
\alias{backquote}
\alias{'}%'
\alias{"}%"
\alias{`}%`
\concept{quotes}
\concept{backslash}
\title{Quotes}
\description{
  \R に於ける様々な引用化の使用法の説明．
}
\details{
  三種類のタイプの引用化が \R の構文の一部分である：一重と二重引用符そして
バックチック(また逆引用符 \samp{`}) である．加えて，
バックスラッシュが文字定数中で以下の文字をエスケープ化するのに使われる．
}
\section{文字定数}{
一重と二重引用符は文字列定数を区切る．それらは同じように使用できるが
二重引用符の方が好ましい(そして文字定数は二重引用符を使ってプリントされる)ので，
一重引用符は普通二重引用符を含む文字定数を区切る時だけ使われる．

バックスラッシュは文字定数中でエスケープ列を開始するのに使われる．
以下の表中に無い文字のエスケープ化はエラーになる．

一重引用符で区切られた文字定数中の一重引用符と
二重引用符で区切られた文字定数中の二重引用符はバックスラッシュでエスケープ化
する必要がある．

  \tabular{ll}{
    \samp{\\n}\tab 新行\cr
    \samp{\\r}\tab キャリッジリターン\cr
    \samp{\\t}\tab タブ\cr
    \samp{\\b}\tab バックスペース\cr
    \samp{\\a}\tab 警告(ベル)\cr
    \samp{\\f}\tab フォームフィード\cr
    \samp{\\v}\tab 垂直タブ\cr
    \samp{\\\\}\tab バックスラッシュ \samp{\\}\cr
    \samp{\\'}\tab ASCII アポストロフ \samp{'}\cr
    \samp{\\"}\tab ASCII 引用符 \samp{"}\cr
    \samp{\\`}\tab ASCII グレーブアクセント(バックチック) \samp{`}\cr
    \samp{\\nnn}\tab 与えられた8進法コード(1, 2または3つの数字)の文字列\cr
    \samp{\\xnn}\tab 与えられた16進法コード(1または2つの数字)の文字列\cr
    \samp{\\unnnn}\tab 与えられたコード(1から4つの数字)のユニコード文字列\cr
    \samp{\\Unnnnnnnn}\tab 与えられたコード(1から8つの16進数字)のユニコード文字列\cr
  }
最後の二つの別の形式は \samp{\\u\{nnnn\}} と \samp{\\U\{nnnnnnnn\}} である．
ユニコードのエスケープ列を除く全ては，もし \code{allowEscapes = TRUE} ならば，
文字列を  \code{\link{scan}} と \code{\link{read.table}} で読み込む際にも
使える．ユニコードのエスケープは現在のロケールの文字列に無いユニコード文字の
入力にも使える(文字列が内部的に UTF-8 で保管される時)．

構文解析器は単一の文字列中の8進/16進数とユニコードエスケープの双方の使用を
認めない．

これらの形式はプリント不可能な文字セット(バックスラッシュを含む)のプリント
の際に \code{\link{print.default}} で使える．

埋め込みヌルは文字列中に許されないので，文字列中でヌル
(\samp{\\0} のような)を使うと文字列はその箇所で切り詰められる
(普通警告が出る)．
}
\section{名前と識別子}{
識別子は文字，数字，ピリオッド(\code{.})そしてアンダスコアの系列からなる．
数字やアンダスコアから始まってはならないし，数字の後にピリオッドが
アッてはならない．予約語 \link{Reserved} は適正な識別子ではない．

\emph{文字} の定義は現在のロケールに依存するが，
アスキー数字だけが数字とされる．

そうした識別子はまた \emph{構文名} として知られ，\R のコード中で
直接使うことが出来る．
引用化すればほとんどいつも他の名前も使うことが出来る．
好ましい引用符はバックチック(\samp{`})であり，構文逆解析 \code{\link{deparse}} は
普通それを使う．しかし多くの状況で一重・二重引用符による引用化も使うことが出来る
(文字定数はしばしば名前に変換されるように)．バックチックが本質的な一つの場合は
公式中で変数名を区切る時である：\code{\link{formula}} を見よ．
}
\seealso{
  構文の他の様相については \code{\link{Syntax}}．

  英語のテキストの引用化については \code{\link{sQuote}}．

  OS 命令の引用化については \code{\link{shQuote}}．

  マニュアル \sQuote{R Language Definition}．
}
\keyword{documentation}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Quotes.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Quotes}
%\alias{Quotes}
%\alias{backtick}
%\alias{backquote}
%\alias{'}%'
%\alias{"}%"
%\alias{`}%`
%\concept{quotes}
%\concept{backslash}
%\title{Quotes}
%\description{
%  Descriptions of the various uses of quoting in \R.
%}
%\details{
%  Three types of quotes are part of the syntax of \R: single and double
%  quotation marks and the backtick (or back quote, \samp{`}).  In
%  addition, backslash is used to escape the following character
%  inside character constants.
%}
%\section{Character constants}{
%  Single and double quotes delimit character constants.  They can be used
%  interchangeably but double quotes are preferred (and character
%  constants are printed using double quotes), so single quotes are
%  normally only used to delimit character constants containing double
%  quotes.
%
%  Backslash is used to start an escape sequence inside character
%  constants.  Escaping a character not in the following table is an
%  error.
%
%  Single quotes need to be escaped by backslash in single-quoted
%  strings, and double quotes in double-quoted strings.
%
%  \tabular{ll}{
%    \samp{\\n}\tab newline\cr
%    \samp{\\r}\tab carriage return\cr
%    \samp{\\t}\tab tab\cr
%    \samp{\\b}\tab backspace\cr
%    \samp{\\a}\tab alert (bell)\cr
%    \samp{\\f}\tab form feed\cr
%    \samp{\\v}\tab vertical tab\cr
%    \samp{\\\\}\tab backslash \samp{\\}\cr
%    \samp{\\'}\tab ASCII apostrophe \samp{'}\cr
%    \samp{\\"}\tab ASCII quotation mark \samp{"}\cr
%    \samp{\\`}\tab ASCII grave accent (backtick) \samp{`}\cr
%    \samp{\\nnn}\tab character with given octal code (1, 2 or 3 digits)\cr
%    \samp{\\xnn}\tab character with given hex code (1 or 2 hex digits)\cr
%    \samp{\\unnnn}\tab Unicode character with given code (1--4 hex digits)\cr
%    \samp{\\Unnnnnnnn}\tab Unicode character with given code (1--8 hex digits)\cr
%  }
%  Alternative forms for the last two are \samp{\\u\{nnnn\}} and
%  \samp{\\U\{nnnnnnnn\}}.  All except the Unicode escape sequences are
%  also supported when reading character strings by \code{\link{scan}}
%  and \code{\link{read.table}} if \code{allowEscapes = TRUE}.  Unicode
%  escapes can be used to enter Unicode characters not in the current
%  locale's charset (when the string will be stored internally in UTF-8).
%
%  The parser does not allow the use of both octal/hex and Unicode
%  escapes in a single string.
%
%  These forms will also be used by \code{\link{print.default}}
%  when outputting non-printable characters (including backslash).
%
%  Embedded nuls are not allowed in character strings, so using escapes
%  (such as \samp{\\0}) for a nul will result in the string being
%  truncated at that point (usually with a warning).
%}
%\section{Names and Identifiers}{
%  Identifiers consist of a sequence of letters, digits, the period
%  (\code{.}) and the underscore.  They must not start with a digit nor
%  underscore, nor with a period followed by a digit.  \link{Reserved}
%  words are not valid identifiers.
%
%  The definition of a \emph{letter} depends on the current locale, but
%  only ASCII digits are considered to be digits.
%
%  Such identifiers are also known as \emph{syntactic names} and may be used
%  directly in \R code.  Almost always, other names can be used
%  provided they are quoted.  The preferred quote is the backtick
%  (\samp{`}), and \code{\link{deparse}} will normally use it, but under
%  many circumstances single or double quotes can be used (as a character
%  constant will often be converted to a name).  One place where
%  backticks may be essential is to delimit variable names in formulae:
%  see \code{\link{formula}}.
%}
%\seealso{
%  \code{\link{Syntax}} for other aspects of the syntax.
%
%  \code{\link{sQuote}} for quoting English text.
%
%  \code{\link{shQuote}} for quoting OS commands.
%
%  The  \sQuote{R Language Definition} manual.
%}
%\keyword{documentation}
%
\encoding{UTF8}
