% File src/library/base/man/attr.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{attr}
\alias{attr}
\alias{attr<-}
\title{Object Attributes}
\description{
  オブジェクトの特定の属性を得る，設定する．
}
\usage{
attr(x, which, exact = FALSE)
attr(x, which) <- value
}
\arguments{
  \item{x}{属性にアクセスするオブジェクト．}
  \item{which}{どの属性にアクセスするかを指定する空でない文字列．}
  \item{exact}{論理値：\code{which} は正確にマッチすべきか?}
  \item{value}{オブジェクトで，属性の新しい値か，または属性を取り除くには \code{NULL}．}
}
\details{
これらの関数はオブジェクトの一つの属性へのアクセスを提供する．
置き換え形は名前付きの属性が指定された値を持つようにする
(もしくは与えられた値を持つ新しい属性を作る)．

取り出し関数は最初 \code{x} の属性のうち \code{which} に正確に
マッチするものを探す．(\code{exact = TRUE} で無い限り)それから
ユニークな部分マッチを探す．
(\code{\link{options}(warnPartialMatchAttr = TRUE)} の設定は
部分マッチで警告を出すようにする．)

置き換え関数は正確なマッチだけを使う．

ある種の属性(つまり \code{\link{class}},
  \code{\link{comment}}, \code{\link{dim}}, \code{\link{dimnames}},
  \code{\link{names}}, \code{\link{row.names}} そして
  \code{\link{tsp}}) は特別な扱いがされ，設定できる値に制限を持つ．
(これは  \code{levels} 関数経由で因子に対して設定される 
  \code{\link{levels}} に対しては真ではないことを注意する．)

取り出し関数は空や欠損値の \code{which} を認める(がマッチしない)：
置き換え関数は認めない．

双方はプリミティブな関数である．
}
\value{
取り出しに対してはマッチした属性の値か，正確なマッチが無いか
二つ以上の部分マッチがあれば \code{NULL}．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{attributes}}
}
\examples{
# 2 x 5 行列を作る
x <- 1:10
attr(x,"dim") <- c(2, 5)
}
\keyword{attribute}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/attr.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{attr}
%\alias{attr}
%\alias{attr<-}
%\title{Object Attributes}
%\description{
%  Get or set specific attributes of an object.
%}
%\usage{
%attr(x, which, exact = FALSE)
%attr(x, which) <- value
%}
%\arguments{
%  \item{x}{an object whose attributes are to be accessed.}
%  \item{which}{a non-empty character string specifying which attribute
%    is to be accessed.}
%  \item{exact}{logical: should \code{which} be matched exactly?}
%  \item{value}{an object, the new value of the attribute, or \code{NULL}
%    to remove the attribute.}
%}
%\details{
%  These functions provide access to a single attribute of an object.
%  The replacement form causes the named attribute to take the value
%  specified (or create a new attribute with the value given).
%
%  The extraction function first looks for an exact match to \code{which}
%  amongst the attributes of \code{x}, then (unless \code{exact = TRUE})
%  a unique partial match.
%  (Setting \code{\link{options}(warnPartialMatchAttr = TRUE)} causes
%  partial matches to give warnings.)
%
%  The replacement function only uses exact matches.
%
%  Note that some attributes (namely \code{\link{class}},
%  \code{\link{comment}}, \code{\link{dim}}, \code{\link{dimnames}},
%  \code{\link{names}}, \code{\link{row.names}} and
%  \code{\link{tsp}}) are treated specially and have restrictions on
%  the values which can be set.  (Note that this is not true of
%  \code{\link{levels}} which should be set for factors via the
%  \code{levels} replacement function.)
%
%  The extractor function allows (and does not match) empty and missing
%  values of \code{which}: the replacement function does not.
%
%  Both are \link{primitive} functions.
%}
%\value{
%  For the extractor, the value of the attribute matched, or \code{NULL}
%  if no exact match is found and no or more than one partial match is found.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{attributes}}
%}
%\examples{
%# create a 2 by 5 matrix
%x <- 1:10
%attr(x,"dim") <- c(2, 5)
%}
%\keyword{attribute}
%
\encoding{UTF8}
