% File src/library/base/man/base-defunct.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{base-defunct}
\alias{base-defunct}
\title{Defunct Functions in Package \pkg{base}}
%------ PLEASE: put \alias{.} here for  EACH !
\alias{Version}
\alias{provide}
\alias{.Provided}
\alias{category}
\alias{print.anova.glm}
\alias{print.anova.lm}
\alias{print.tabular}
\alias{print.plot}
\alias{save.plot}
\alias{system.test}
\alias{getenv}
\alias{read.table.url}
\alias{scan.url}
\alias{source.url}
\alias{httpclient}
\alias{parse.dcf}
\alias{.Alias}
\alias{print.ordered}
\alias{.Dyn.libs}
\alias{.lib.loc}
\alias{machine}
\alias{Platform}
\alias{Machine}
\alias{restart}
\alias{printNoClass}
\alias{codes}
\alias{codes.factor}
\alias{codes.ordered}
\alias{codes<-}
\alias{print.atomic}
\alias{La.eigen}
\alias{tetragamma}
\alias{pentagamma}
\alias{package.description}
\alias{loadURL}
\alias{delay}
\alias{write.table0}
\alias{format.char}
\alias{La.chol}
\alias{La.chol2inv}
\alias{symbol.C}
\alias{symbol.For}
\alias{unix}
\alias{gammaCody}
\alias{manglePackageName}
\alias{.Import}
\alias{.ImportFrom}
\alias{.Export}
\alias{.S3method}
\alias{.First.lib}
\alias{mem.limits}
\alias{.readRDS}
\alias{.saveRDS}
\alias{Sys.putenv}
\alias{real}
\alias{as.real}
\alias{is.real}
\alias{.find.package}
\alias{.path.package}
%
\description{
  ここにあげた関数や変数はもはや不要であり，もはや \R の一部ではない．
}
\usage{
# Defunct in 1.x
Version()
provide(package)
.Provided
category(\dots)
print.anova.glm(.)
print.anova.lm(.)
print.tabular(.)
print.plot(.)
save.plot(.)
system.test(.)
getenv(\dots)
read.table.url(url, method, \dots)
scan.url(url, file = tempfile(), method, \dots)
source.url(url, file = tempfile(), method, \dots)
httpclient(url, port = 80, error.is.fatal = TRUE,
           check.MIME.type = TRUE, file = tempfile(),
           drop.ctrl.z = TRUE)
parse.dcf(text = NULL, file = "", fields = NULL,
          versionfix = FALSE)
.Alias(expr)
print.ordered(.)
.Dyn.libs
.lib.loc
machine()
Machine()
Platform()
restart()
printNoClass(x, digits = NULL, quote = TRUE, na.print = NULL,
             print.gap = NULL, right = FALSE, \dots)
codes(x, \dots)
codes(x, \dots) <- value

# Defunct in 2.0.0
La.eigen(x, symmetric, only.values = FALSE,
         method = c("dsyevr", "dsyev"))
tetragamma(x)
pentagamma(x)
package.description(pkg, lib.loc = NULL, fields = NULL)

# 2.2.0 で廃止
loadURL(url, envir = parent.frame(), quiet = TRUE, \dots)
delay(x, env = .GlobalEnv)

# 2.3.0 で廃止
format.char(x, width = NULL, flag = "-")

# 2.4.0 で廃止
La.chol(x)
La.chol2inv(x, size = ncol(x))

# 2.4.0 で廃止
symbol.C(name)
symbol.For(name)

# 2.5.0 で廃止
unix(call, intern = FALSE)

# 2.8.0 で廃止
gammaCody(x)

# 2.9.0 で廃止
manglePackageName(pkgName, pkgVersion)

# 2.13.0 で廃止
.Import(...)
.ImportFrom(name, ...)
.Export(...)
.S3method(generic, class, method)

# 2.14.0 で廃止
.First.lib(lib, pkg)

# 2.15.0 で廃止
mem.limits(nsize = NA, vsize = NA)
.saveRDS(\dots)
.readRDS(\dots)
Sys.putenv(\dots)

# 3.0.0 で廃止
real(length = 0)
as.real(x, \dots)
is.real(x)

# 3.1.0 で廃止
.find.package(\dots)
.path.package(\dots)
}
\details{
  これらの一部は廃止されたことを報告するための切り株を持っているが，
殆どは完全に取り除かれている(ここでドキュメント化されている以外は)．
  
  \code{category} は因子以前の古い S の関数である；
完全に \code{\link{factor}} で置き換えられるべきである!

今や新しい関数 \code{dev.print()} がプロットをファイルに保存したり，それらをプリントするために
使われるべきである．

  \code{provide} とそのオブジェクト \code{.Provided} は取り除かれている．
これは一つのパッケージが他のパッケージを含むことを許すことが目的であったが，
決して使われなかった．

  \code{getenv} は \code{\link{Sys.getenv}} で置き換えられた．

  \code{*.url} は \code{\link{url}} コネクション上での
  \code{read.table}, \code{scan} や \code{source} の呼び出しで置き換えられた．

  \code{httpclient} は \code{\link{download.file}} の廃止された \code{"socket"}
メソッドで使われた．

  \code{parse.dcf} は \code{read.dcf} で置き換えられている．これはより
速いが少々異なったインタフェイスを持つ．

  \code{.Alias} は同じオブジェクトへの重複した参照を作る信頼できない方法を
提供した．直接の代替物はない．構文的な理由から単一のオブジェクトへの複数の
参照が必要なら環境下外部ポインタを使うことを考慮しよう．
 \url{http://developer.r-project.org} に少しノートがある．

  \code{.Dyn.libs} と \code{.lib.loc} は DLL を持つパッケージと，
既知の \R のライブラリーツリーに関する情報を保存し操作する
ために使われた内部変数である．これらは今はそれぞれ
 \code{\link{.dynLibs}} と \code{\link{.libPaths}} を使って取得・設定出来る
ダイナミックな変数である．

  \code{Machine()} と \code{Platform()} はそれぞれ変数 
 \code{\link{.Machine}} と \code{\link{.Platform}} を返す
 関数であった．

  例外ベースの移植に対する準備では，の\code{restart()} は \code{try()} で置き換えるべきである．
 \code{try()} で置き換えられないような仕方で \code{restart()} を使っているのなら，
 \code{r-devel} に相談してみよう．

  \code{printNoClass} はパッケージ \pkg{methods} 中に有り，
内部関数 \code{print.default} を呼び出していた．

  \code{codes} はほとんどいつも不適切に使われていた．
因子の内部コーディングを得るためには \code{unclass}, \code{as.vector} または 
  \code{as.integer} を使おう．順序因子に対しては，\code{codes} はこれらに
同値であるが，非順序因子に対してはこれは使用中のロケール中の
アスファベット順序を仮定していた．

  \code{La.eigen} は \code{\link{eigen}} に対する既定手法になっている．

  \code{tetragamma} と \code{pentagamma} は \code{\link{psigamma}} で
置き換えられている．

  \code{package.description} はパッケージ \pkg{utils} 中の 
  \code{\link{packageDescription}} に置き換わっている．

  \code{loadURL} は \code{\link{load}(url())} に取って代わられている．

  \code{delay} は \code{\link{delayedAssign}} に置き換わっている．
  未評価の約束は決して見ることはできない．

  \code{write.table0} は暫定的な後方互換性のために \R レベルのバージョン \code{write.table} 
が提供されている．

  \code{format.char} は \code{\link{formatC}} のための補助関数であったが，
その機能(そしてそれ以上)は \code{\link{format.default}} で提供されている．

  \code{La.chol} と \code{La.chol2inv} は
  \code{\link{chol}} と \code{\link{chol2inv}} に対する既定メソッドになった．

  関数 \code{symbol.C} と \code{symbol.For} は S との歴史的互換性のために
提供されていた．\code{symbol.C} は単にその引数を未変更で返すが，
  \code{symbol.For} は小文字に変えフォートランシンボルに対してそうするような
プラットフォーム(ほとんどすべて)でアンダスコアを付け加える．
これらはもはや \R では使い道はない．

  \code{unix} は\code{\link{system}} への(1990年代以降)廃止された 
  代替物であり，S との後方互換性のために利用可能であった．

  \code{gammaCody} はベッセル関数のコード中で C レベルで使われた Stepfun パッケージからの
\eqn{(\Gamma)} 関数であった．\R レベルのインタフェイスは実験的目的のために存在した．

  \code{manglePackageName} はバージョン対応インストールのための
廃止されたサポートの一部分であった．

  \code{.Import}, \code{.ImportFrom}, \code{.Export} そして
  \code{.S3method} は名前空間を指定するための実験的代替手法の
  一部であった．

  \code{.First.lib} は名前空間持たないパッケージに対する load/attach フックであった：
  代わりに \code{\link{.onLoad}} か \code{\link{.onAttach}} を使おう．

  \code{mem.limits} はコンスセルとベクトルヒープの数に対する古い形式の
  限界を報告した．これらは最早全体のメモリ限界を除いて制限されていない．

  \code{.readRDS} と \code{.saveRDS} は  \code{\link{.readRDS}} と \code{\link{.saveRDS}}
  の内部使用限定のバージョンであった(そして \R 2.13.0 以前のバージョンだけが利用可能であった)．

  \code{Sys.putenv} は \R 2.5.0 以降廃止された \code{\link{Sys.setenv}} の
同意語であった．

  \code{real}, \code{as.real} そして \code{is.real} は
 \code{double} のかなり前から廃止された同意語であった．

  \code{.find.package} と \code{.path.package} は \R 2.13.0 以前の
内部使用限定のバージョンであった．それ以来
  \code{\link{find.package}} と \code{\link{path.package}} に
対する廃止されたラッパであった．
}
\seealso{
  \code{\link{Defunct}}, \code{\link{base-deprecated}}
}

\keyword{internal}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%% File src/library/base/man/base-defunct.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{base-defunct}
%\alias{base-defunct}
%\title{Defunct Functions in Package \pkg{base}}
%%------ PLEASE: put \alias{.} here for  EACH !
%\alias{Version}
%\alias{provide}
%\alias{.Provided}
%\alias{category}
%\alias{print.anova.glm}
%\alias{print.anova.lm}
%\alias{print.tabular}
%\alias{print.plot}
%\alias{save.plot}
%\alias{system.test}
%\alias{getenv}
%\alias{read.table.url}
%\alias{scan.url}
%\alias{source.url}
%\alias{httpclient}
%\alias{parse.dcf}
%\alias{.Alias}
%\alias{print.ordered}
%\alias{.Dyn.libs}
%\alias{.lib.loc}
%\alias{machine}
%\alias{Platform}
%\alias{Machine}
%\alias{restart}
%\alias{printNoClass}
%\alias{codes}
%\alias{codes.factor}
%\alias{codes.ordered}
%\alias{codes<-}
%\alias{print.atomic}
%\alias{La.eigen}
%\alias{tetragamma}
%\alias{pentagamma}
%\alias{package.description}
%\alias{loadURL}
%\alias{delay}
%\alias{write.table0}
%\alias{format.char}
%\alias{La.chol}
%\alias{La.chol2inv}
%\alias{symbol.C}
%\alias{symbol.For}
%\alias{unix}
%\alias{gammaCody}
%\alias{manglePackageName}
%\alias{.Import}
%\alias{.ImportFrom}
%\alias{.Export}
%\alias{.S3method}
%\alias{.First.lib}
%\alias{mem.limits}
%\alias{.readRDS}
%\alias{.saveRDS}
%\alias{Sys.putenv}
%\alias{real}
%\alias{as.real}
%\alias{is.real}
%\alias{.find.package}
%\alias{.path.package}
%%
%\description{
%  The functions or variables listed here are no longer part of \R as
%  they are no longer needed.
%}
%\usage{
%# Defunct in 1.x
%Version()
%provide(package)
%.Provided
%category(\dots)
%print.anova.glm(.)
%print.anova.lm(.)
%print.tabular(.)
%print.plot(.)
%save.plot(.)
%system.test(.)
%getenv(\dots)
%read.table.url(url, method, \dots)
%scan.url(url, file = tempfile(), method, \dots)
%source.url(url, file = tempfile(), method, \dots)
%httpclient(url, port = 80, error.is.fatal = TRUE,
%           check.MIME.type = TRUE, file = tempfile(),
%           drop.ctrl.z = TRUE)
%parse.dcf(text = NULL, file = "", fields = NULL,
%          versionfix = FALSE)
%.Alias(expr)
%print.ordered(.)
%.Dyn.libs
%.lib.loc
%machine()
%Machine()
%Platform()
%restart()
%printNoClass(x, digits = NULL, quote = TRUE, na.print = NULL,
%             print.gap = NULL, right = FALSE, \dots)
%codes(x, \dots)
%codes(x, \dots) <- value
%
%# Defunct in 2.0.0
%La.eigen(x, symmetric, only.values = FALSE,
%         method = c("dsyevr", "dsyev"))
%tetragamma(x)
%pentagamma(x)
%package.description(pkg, lib.loc = NULL, fields = NULL)
%
%# Defunct in 2.2.0
%loadURL(url, envir = parent.frame(), quiet = TRUE, \dots)
%delay(x, env = .GlobalEnv)
%
%# Defunct in 2.3.0
%format.char(x, width = NULL, flag = "-")
%
%# Defunct in 2.4.0
%La.chol(x)
%La.chol2inv(x, size = ncol(x))
%
%# Defunct in 2.4.0
%symbol.C(name)
%symbol.For(name)
%
%# Defunct in 2.5.0
%unix(call, intern = FALSE)
%
%# Defunct in 2.8.0
%gammaCody(x)
%
%# Defunct in 2.9.0
%manglePackageName(pkgName, pkgVersion)
%
%# Defunct in 2.13.0
%.Import(...)
%.ImportFrom(name, ...)
%.Export(...)
%.S3method(generic, class, method)
%
%# Defunct in 2.14.0
%.First.lib(lib, pkg)
%
%# Defunct in 2.15.0
%mem.limits(nsize = NA, vsize = NA)
%.saveRDS(\dots)
%.readRDS(\dots)
%Sys.putenv(\dots)
%
%# Defunct in 3.0.0
%real(length = 0)
%as.real(x, \dots)
%is.real(x)
%
%# Defunct in 3.1.0
%.find.package(\dots)
%.path.package(\dots)
%}
%\details{
%  Some of these have stubs which report that they are defunct, but most
%  have been removed completely (apart from being documented here).
%  
%  \code{category} has been an old-S function before there were factors;
%  should be replaced by \code{\link{factor}} throughout!
%
%  The new function \code{dev.print()} should now be used for saving
%  plots to a file or printing them.
%
%  \code{provide} and its object \code{.Provided} have been removed.
%  Their intended purpose was to allow one package to subsume another,
%  but this was never used.
%
%  \code{getenv} has been replaced by \code{\link{Sys.getenv}}.
%
%  \code{*.url} are replaced by calling \code{read.table}, \code{scan} or
%  \code{source} on a \code{\link{url}} connection.
%
%  \code{httpclient} was used by the deprecated \code{"socket"} method
%  of \code{\link{download.file}}.
%
%  \code{parse.dcf} has been replaced by \code{read.dcf}, which is much
%  faster, but has a slightly different interface.
%
%  \code{.Alias} provided an unreliable way to create duplicate
%  references to the same object.  There is no direct replacement.  Where
%  multiple references to a single object are required for semantic
%  reasons consider using environments or external pointers.  There are
%  some notes on \url{http://developer.r-project.org}.
%
%  \code{.Dyn.libs} and \code{.lib.loc} were internal variables used for
%  storing and manipulating the information about packages with DLLs, and
%  the known \R library trees.  These are now dynamic variables which one
%  can get or set using \code{\link{.dynLibs}} and
%  \code{\link{.libPaths}}, respectively.
%
%  \code{Machine()} and \code{Platform()} were functions returning the
%  variables \code{\link{.Machine}} and \code{\link{.Platform}}
%  respectively.
%
%  \code{restart()} should be replaced by \code{try()}, in preparation
%  for an exception-based implementation.  If you use \code{restart()} in
%  a way that cannot be replaced with \code{try()} then ask for help
%  on \code{r-devel}.
%
%  \code{printNoClass} was in package \pkg{methods} and called directly the
%  internal function \code{print.default}.
%
%  \code{codes} was almost always used inappropriately.  To get the
%  internal coding of a factor, use \code{unclass}, \code{as.vector} or
%  \code{as.integer}.  For \emph{ordered} factors, \code{codes} was
%  equivalent to these, but for \emph{unordered} factors it assumed an
%  alphabetical ordering of the levels in the locale in use.
%
%  \code{La.eigen} has become the default for \code{\link{eigen}}.
%
%  \code{tetragamma} and \code{pentagamma} have been replaced by
%  \code{\link{psigamma}}.
%
%  \code{package.description} has been replaced by
%  \code{\link{packageDescription}} in package \pkg{utils}.
%
%  \code{loadURL} has been superseded by \code{\link{load}(url())}.
%
%  \code{delay} has been replaced by \code{\link{delayedAssign}}.
%  Unevaluated promises should never be visible.
%
%  \code{write.table0} was an \R-level version of \code{write.table}
%  provided for temporary back-compatibility.
%
%  \code{format.char} was an auxiliary function for \code{\link{formatC}}
%  whose functionality (and more) is provided by \code{\link{format.default}}.
%
%  \code{La.chol} and \code{La.chol2inv} became the default methods for
%  \code{\link{chol}} and \code{\link{chol2inv}}.
%
%  Functions \code{symbol.C} and \code{symbol.For} were provided for
%  historical compatibility with S.  \code{symbol.C} just returns its
%  argument unchanged, whereas \code{symbol.For} will map to lower case
%  and append an underscore on those platforms (almost all) which do so
%  for Fortran symbols.  These are no longer of any use in \R.
%
%  \code{unix} was a \emph{deprecated} (since the 1990s) alternative to
%  \code{\link{system}}, available for backwards compatibility with S.
%
%  \code{gammaCody} was the \eqn{(\Gamma)} function from the Specfun
%  package used at C level in the Bessel code. The \R-level interface was
%  here for experimental purposes.
%
%  \code{manglePackageName} was part of the defunct support for versioned
%  installs.
%
%  \code{.Import}, \code{.ImportFrom}, \code{.Export} and
%  \code{.S3method} were part of an experimental alternative way to
%  specify namespaces.
%
%  \code{.First.lib} was the load/attach hook for packages without
%  namespaces: use \code{\link{.onLoad}} or \code{\link{.onAttach}} instead.
%
%  \code{mem.limits} reported on the old-style limits on the number of
%  cons cells and size of the vector heap.  These are no longer limited
%  except by overall memory limits.
%
%  \code{.readRDS} and \code{.saveRDS}, were internal-only versions (and
%  the only versions available prior to \R 2.13.0) of
%  \code{\link{.readRDS}} and \code{\link{.saveRDS}}.
%
%  \code{Sys.putenv} was a synonym for \code{\link{Sys.setenv}},
%  deprecated since \R 2.5.0.
%
%  \code{real}, \code{as.real} and \code{is.real} were long-deprecated
%  synonyms for the \code{double} versions.
%
%  \code{.find.package} and \code{.path.package} were internal-only
%  versions prior to \R 2.13.0, and since deprecated wrappers for
%  \code{\link{find.package}} and \code{\link{path.package}}.
%}
%\seealso{
%  \code{\link{Defunct}}, \code{\link{base-deprecated}}
%}
%
%\keyword{internal}
%
\encoding{UTF8}
