% File src/library/base/man/bquote.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{bquote}
\alias{bquote}
\title{Partial substitution in expressions}
\description{
  LISP のバックコートマクロの類似物．\code{bquote} はその引数を引用化するが，
  \code{.()} 中にラップされた項が指定された環境 \code{where} で評価されることが
  異なる．
}
\usage{
bquote(expr, where = parent.frame())
}
\arguments{
  \item{expr}{言語オブジェクト．}
  \item{where}{環境．}
}

\value{
  言語オブジェクト．
}
\seealso{
  \code{\link{quote}}, \code{\link{substitute}}
}
\examples{
require(graphics)

a <- 2

bquote(a == a)
quote(a == a)

bquote(a == .(a))
substitute(a == A, list(A = a))

plot(1:10, a*(1:10), main = bquote(a == .(a)))

## 関数の既定引数を設定する
default <- 1
bquote( function(x, y = .(default)) x+y )
}
\keyword{programming}
\keyword{data}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/bquote.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{bquote}
%\alias{bquote}
%\title{Partial substitution in expressions}
%\description{
%  An analogue of the LISP backquote macro.  \code{bquote} quotes its
%  argument except that terms wrapped in \code{.()} are evaluated in the
%  specified \code{where} environment.
%}
%\usage{
%bquote(expr, where = parent.frame())
%}
%\arguments{
%  \item{expr}{A \link{language object}.}
%  \item{where}{An environment.}
%}
%
%\value{
%  A \link{language object}.
%}
%\seealso{
%  \code{\link{quote}}, \code{\link{substitute}}
%}
%\examples{
%require(graphics)
%
%a <- 2
%
%bquote(a == a)
%quote(a == a)
%
%bquote(a == .(a))
%substitute(a == A, list(A = a))
%
%plot(1:10, a*(1:10), main = bquote(a == .(a)))
%
%## to set a function default arg
%default <- 1
%bquote( function(x, y = .(default)) x+y )
%}
%\keyword{programming}
%\keyword{data}
%
\encoding{UTF8}
