% File src/library/base/man/factor.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{factor}
\title{Factors}
\alias{factor}
\alias{ordered}
\alias{is.factor}
\alias{is.ordered}
\alias{as.factor}
\alias{as.ordered}
\alias{is.na<-.factor}
\alias{Math.factor}
\alias{Ops.factor}
\alias{Summary.factor}
\alias{Ops.ordered}
\alias{Summary.ordered}
\alias{addNA}
\concept{categorical variable}
\concept{enumerated type}
\concept{category}
\description{
  関数 \code{factor} はベクトルを因子にエンコードするために使われる(因子はまた
  \sQuote{カテゴリー} や \sQuote{列挙型} とも呼ばれる．
  もし引数 \code{ordered} が \code{TRUE} ならば，因子水準は順序付けられていると
  仮定される．S との互換性のためまた関数 \code{ordered} がある．

  \code{is.factor}, \code{is.ordered}, \code{as.factor} そして \code{as.ordered}
  はこれらのクラスのための所属検査と強制変換のための関数である．
}
\usage{
factor(x = character(), levels, labels = levels,
       exclude = NA, ordered = is.ordered(x), nmax = NA)

ordered(x, \dots)

is.factor(x)
is.ordered(x)

as.factor(x)
as.ordered(x)

addNA(x, ifany = FALSE)
}
\arguments{
  \item{x}{データのベクトル，普通少数の異なった値を持つ．}
  \item{levels}{\code{x} が取るかもしれない値(文字列として)のオプションのベクトル．
    既定は \code{\link{as.character}(x)} により取る値のユニーク集合で
    \code{x} の増加順にソートされている．
    この集合は \code{sort(unique(x))} より小さく指定できることを注意する．}
  \item{labels}{オプションの水準に対するラベルの文字列ベクトル
    (\code{exclude} 中のそれらを除いた \code{levels} と同じ順序)か，
    又は長さ1の文字列ベクトル．}
  \item{exclude}{水準集合を作る際に除外される値のベクトル．
    これは \code{x} と同じ型でなければならず，必要なら強制変換される．}
  \item{ordered}{水準が順序付けられている(与えられた順序で)と見做すべきかどうかを
    決める論理フラグ．}
  \item{nmax}{水準の数の上限；\sQuote{詳細}を見よ．}
  \item{\dots}{(\code{ordered(.)} 中): \code{ordered} 自体を除く上のどれか．}
  \item{ifany}{もしそれが使われているならば \code{NA} 水準だけを付け加える，つまり
    もし \code{any(is.na(x))} ならば．}
}
\value{
  \code{factor} はクラス \code{"factor"} のオブジェクトを返す．
  これは \code{x} の長さ，モード \code{\link{character}} の \code{"levels"}
  属性，そしてユニーク (\code{!\link{anyDuplicated}(.)}) な項目を持つ．
  もし引数 \code{ordered} が真なら(もしくは \code{ordered()} が使われると)
  結果はクラス \code{c("ordered", "factor")} を持つ．

  \code{factor} を順序付き又は順序無しの因子に適用すると(同じ型の)因子で
  実際に出現する水準だけの因子を返す：またこれを実現するより見やすい
  方法は \code{\link{[.factor}} を見よ．

  \code{is.factor} は \code{TRUE} 又は \code{FALSE} をその引数が因子かどうかに
  応じて返す．対応して，
  \code{is.ordered} はその引数が順序付きならば \code{TRUE} を，さもなければ
  \code{FALSE} を返す．

  \code{as.factor} はその引数を因子に強制変換する．
  これは \code{factor} の省略形である．

  \code{as.ordered(x)} はもし \code{x} が順序付きならば \code{x} を返し，
  さもなければ \code{ordered(x)} を返す．

  \code{addNA} は \code{NA} を追加の水準に加える
  (例えばそうすることで \code{NA} 値が表にカウントされるように)
  ことで因子を変更する．
}
\details{
  ベクトル \code{x} の方には制限がない：
  \code{\link{as.character}} メソッドを持ちソート可能
  (\code{\link{sort.list}} で)というだけである．

  順序付き因子は因子とクラスだけが異なるが，メソッドと
  モデル当てはめ関数は二つのクラスを非常に異なったものとして扱う．

  ベクトルのエンコーディングは次のように行われる．
  最初に \code{exclude} 中の値が  \code{levels} からすべて取り除かれる．
  もし \code{x[i]} が \code{levels[j]} に等しければ，結果の \code{i} 番目の
  要素は \code{j} になる．もし \code{levels} 中に  \code{x[i]} にマッチするものがなければ
  (これは除外値に対して起こる)，結果の \code{i} 番目の要素は
  \code{\link{NA}} に設定される．

  普通結果の属性として使われた\sQuote{水準}は \code{exclude} 中の物を
  除いた水準の縮小集合であるが，これは
  \code{labels} を与えることで変更できる．これは水準に対する新しいラベル集合であるか，
  又は文字列である．後者の場合水準はその文字列に続き番号を加えたものになる．

  因子に適用された \code{factor(x, exclude = NULL)} は未使用の水準が無い限り
  何もしない：未使用の水準があれば縮小された水準集合が返される．
  もし \code{exclude} が使われれば，それはまた \code{x} と同じ水準集合を持つ
  因子か，除外される水準に対するコードの集合である．

  因子に対するコードは \code{\link{NA}} を含んで良い．数値の 
  \code{x} に対しては，\code{\link{NA}} を追加の水準にするためには
  \code{exclude = NULL} を設定する(\code{<NA>} とプリントされる)；
  既定ではこれは最後の水準になる．

  もし \code{NA} が水準の一つならば，欠損値(欠損水準のコードに対立するものとして)
  に対するコードを設定する方法は
  付値の左辺値として \code{\link{is.na}} を使うことである
  (\code{is.na(f)[i] <- TRUE} のように；\code{is.na} 内部での添字操作は使えない)．
  こうした状況の下では，欠損値は現在
  \code{<NA>} とプリントされる，つまり水準 \code{NA} の項目と同じになる．

  \code{is.factor} は総称的である：オブジェクトの特定のクラスを処理する
  メソッドを書くことが出来る，\link{InternalMethods} を見よ．

  \code{levels} が与えられないと \code{\link{unique}} が呼び出される．
  因子は典型的には非常に少数の水準を持つため，大きなベクトル
  \code{x} に対してはユニークな値の数の上限として \code{nmax} を与えるのは有用である．
}
\section{警告}{
  因子の解釈はコードと
  \code{"levels"} 属性の双方に依存する．同じ水準集合(そして同じ順序)を
  持つ因子だけを比較するように注意しよう．特に因子に適用された
  \code{as.numeric} は無意味であり，暗黙の強制変換が起きてしまうことがある．
  因子 \code{f} を近似的に元の数値に変換するには
  \code{as.numeric(levels(f))[f]} が推奨され，
  \code{as.numeric(as.character(f))} より少し効率的である．

  因子の水準は既定ではソートされているが，ソートの順序は
  作成時のロケールに依存する可能性があり，アスキーと仮定されるべきではない．

  \code{NA} を水準として持つ因子に関しては幾らかの例外がある．
  これらは稀にしか使わないことが推奨される，例えば
  作表を意図した場合だけに使う．
}
%% Is this still true, after Ops.factor (==, !=) is fixed ?

\section{比較演算子とグループ総称的メソッド}{
  グループ総称的な \code{\link[=S3groupGeneric]{Ops}} に対しては
  \code{"factor"} と \code{"ordered"} メソッドがあり，
  比較演算子に対するメソッドを提供する．そして
  \code{\link{min}}, \code{\link{max}} そして \code{\link{range}}
  総称関数 \code{"ordered"} の \code{\link[=S3groupGeneric]{Summary}}
  中にある．(グループの残りと
  \code{\link[=S3groupGeneric]{Math}} グループは因子に対しては無意味でありエラーを
  引き起こす．)

  因子に対しては \code{==} と \code{!=} だけが使える：因子は同じ水準集合を持つ
  他の因子(必ずしも同じ順序でなくても良い)や文字列ベクトルとだけ比較可能である．
  順序付き因子は同様に比較できるが，一般的な選択適用機構は順序付き因子と順序なし
  因子の比較を除外する．

  すべての比較演算子が順序付き因子に対して使うことが出来る．
  照合は被演算項の水準によってなされる：もし双方の被演算項が順序付きならば
  同じ水準集合を持たなければならない．
}
\note{
  以前のバージョンの \R では，もし繰り返しの割合が小さくても，文字列を因子として
  保管するほうがスペースが少なくてすんだ．しかしながら
  今では同一の文字列は保管場所を共有するため，殆どの場合差は小さい．
  (整数値は4バイトで保管される一方，文字列への各参照は4又は8バイトのポインターを必要とする．)
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  因子の部分操作は \code{\link{[.factor}}．

  釣り合い型因子の構成には \code{\link{gl}}．そして
  指定した対比を持つ因子には \code{\link{C}}．
  水準にアクセスするには \code{\link{levels}} と \code{\link{nlevels}}，
  そして整数コードを得るには \code{\link{unclass}}．
}
\examples{
(ff <- factor(substring("statistics", 1:10, 1:10), levels = letters))
as.integer(ff)      # 内部コード
(f. <- factor(ff))  # 生起しない水準を捨てる
ff[, drop = TRUE]   # 同じことをもっと明瞭に

factor(letters[1:20], labels = "letter")

class(ordered(4:1)) # "ordered", "factor" から継承
z <- factor(LETTERS[3:1], ordered = TRUE)
## そして "relational" メソッドが使える：
stopifnot(sort(z)[c(1,3)] == range(z), min(z) < max(z))
\dontshow{
of <- ordered(ff)
stopifnot(identical(range(of, rev(of)), of[3:2]),
	  identical(max(of), of[2]))
}

## "NA" を水準として使いたいとする．そして欠損値を許す．
(x <- factor(c(1, 2, NA), exclude = NULL))
is.na(x)[2] <- TRUE
x  # [1] 1    <NA> <NA>
is.na(x)
# [1] FALSE  TRUE FALSE

## addNA() を使う
Month <- airquality$Month
table(addNA(Month))
table(addNA(Month, ifany = TRUE))
}
\keyword{category}
\keyword{NA}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/factor.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{factor}
%\title{Factors}
%\alias{factor}
%\alias{ordered}
%\alias{is.factor}
%\alias{is.ordered}
%\alias{as.factor}
%\alias{as.ordered}
%\alias{is.na<-.factor}
%\alias{Math.factor}
%\alias{Ops.factor}
%\alias{Summary.factor}
%\alias{Ops.ordered}
%\alias{Summary.ordered}
%\alias{addNA}
%\concept{categorical variable}
%\concept{enumerated type}
%\concept{category}
%\description{
%  The function \code{factor} is used to encode a vector as a factor (the
%  terms \sQuote{category} and \sQuote{enumerated type} are also used for
%  factors).  If argument \code{ordered} is \code{TRUE}, the factor
%  levels are assumed to be ordered.  For compatibility with S there is
%  also a function \code{ordered}.
%
%  \code{is.factor}, \code{is.ordered}, \code{as.factor} and \code{as.ordered}
%  are the membership and coercion functions for these classes.
%}
%\usage{
%factor(x = character(), levels, labels = levels,
%       exclude = NA, ordered = is.ordered(x), nmax = NA)
%
%ordered(x, \dots)
%
%is.factor(x)
%is.ordered(x)
%
%as.factor(x)
%as.ordered(x)
%
%addNA(x, ifany = FALSE)
%}
%\arguments{
%  \item{x}{a vector of data, usually taking a small number of distinct
%    values.}
%  \item{levels}{an optional vector of the values (as character strings)
%    that \code{x} might have taken.  The default is the unique set of
%    values taken by \code{\link{as.character}(x)}, sorted into
%    increasing order \emph{of \code{x}}.  Note that this set can be
%    specified as smaller than \code{sort(unique(x))}.}
%  \item{labels}{\emph{either} an optional character vector of labels for the
%    levels (in the same order as \code{levels} after removing those in
%    \code{exclude}), \emph{or} a character string of length 1.}
%  \item{exclude}{a vector of values to be excluded when forming the
%    set of levels.  This should be of the same type as \code{x}, and
%    will be coerced if necessary.}
%  \item{ordered}{logical flag to determine if the levels should be regarded
%    as ordered (in the order given).}
%  \item{nmax}{an upper bound on the number of levels; see \sQuote{Details}.}
%  \item{\dots}{(in \code{ordered(.)}): any of the above, apart from
%    \code{ordered} itself.}
%  \item{ifany}{(only add an \code{NA} level if it is used, i.e.
%    if \code{any(is.na(x))}.}
%}
%\value{
%  \code{factor} returns an object of class \code{"factor"} which has a
%  set of integer codes the length of \code{x} with a \code{"levels"}
%  attribute of mode \code{\link{character}} and unique
%  (\code{!\link{anyDuplicated}(.)}) entries.  If argument \code{ordered}
%  is true (or \code{ordered()} is used) the result has class
%  \code{c("ordered", "factor")}.
%
%  Applying \code{factor} to an ordered or unordered factor returns a
%  factor (of the same type) with just the levels which occur: see also
%  \code{\link{[.factor}} for a more transparent way to achieve this.
%
%  \code{is.factor} returns \code{TRUE} or \code{FALSE} depending on
%  whether its argument is of type factor or not.  Correspondingly,
%  \code{is.ordered} returns \code{TRUE} when its argument is an ordered
%  factor and \code{FALSE} otherwise.
%
%  \code{as.factor} coerces its argument to a factor.
%  It is an abbreviated form of \code{factor}.
%
%  \code{as.ordered(x)} returns \code{x} if this is ordered, and
%  \code{ordered(x)} otherwise.
%
%  \code{addNA} modifies a factor by turning \code{NA} into an extra
%  level (so that \code{NA} values are counted in tables, for instance).
%}
%\details{
%  The type of the vector \code{x} is not restricted; it only must have
%  an \code{\link{as.character}} method and be sortable (by
%  \code{\link{sort.list}}).
%
%  Ordered factors differ from factors only in their class, but methods
%  and the model-fitting functions treat the two classes quite differently.
%
%  The encoding of the vector happens as follows.  First all the values
%  in \code{exclude} are removed from \code{levels}. If \code{x[i]}
%  equals \code{levels[j]}, then the \code{i}-th element of the result is
%  \code{j}.  If no match is found for \code{x[i]} in \code{levels}
%  (which will happen for excluded values) then the \code{i}-th element
%  of the result is set to \code{\link{NA}}.
%
%  Normally the \sQuote{levels} used as an attribute of the result are
%  the reduced set of levels after removing those in \code{exclude}, but
%  this can be altered by supplying \code{labels}.  This should either
%  be a set of new labels for the levels, or a character string, in
%  which case the levels are that character string with a sequence
%  number appended.
%
%  \code{factor(x, exclude = NULL)} applied to a factor is a no-operation
%  unless there are unused levels: in that case, a factor with the
%  reduced level set is returned.  If \code{exclude} is used it should
%  also be a factor with the same level set as \code{x} or a set of codes
%  for the levels to be excluded.
%
%  The codes of a factor may contain \code{\link{NA}}.  For a numeric
%  \code{x}, set \code{exclude = NULL} to make \code{\link{NA}} an extra
%  level (prints as \code{<NA>}); by default, this is the last level.
%
%  If \code{NA} is a level, the way to set a code to be missing (as
%  opposed to the code of the missing level) is to
%  use \code{\link{is.na}} on the left-hand-side of an assignment (as in
%  \code{is.na(f)[i] <- TRUE}; indexing inside \code{is.na} does not work).
%  Under those circumstances missing values are currently printed as
%  \code{<NA>}, i.e., identical to entries of level \code{NA}.
%
%  \code{is.factor} is generic: you can write methods to handle
%  specific classes of objects, see \link{InternalMethods}.
%
%  Where \code{levels} is not supplied, \code{\link{unique}} is called.
%  Since factors typically have quite a small number of levels, for large
%  vectors \code{x} it is helpful to supply \code{nmax} as an upper bound
%  on the number of unique values.
%}
%\section{Warning}{
%  The interpretation of a factor depends on both the codes and the
%  \code{"levels"} attribute.  Be careful only to compare factors with
%  the same set of levels (in the same order).  In particular,
%  \code{as.numeric} applied to a factor is meaningless, and may
%  happen by implicit coercion.  To transform a factor \code{f} to
%  approximately its original numeric values,
%  \code{as.numeric(levels(f))[f]} is recommended and slightly more
%  efficient than \code{as.numeric(as.character(f))}.
%
%  The levels of a factor are by default sorted, but the sort order
%  may well depend on the locale at the time of creation, and should
%  not be assumed to be ASCII.
%
%  There are some anomalies associated with factors that have
%  \code{NA} as a level.  It is suggested to use them sparingly, e.g.,
%  only for tabulation purposes.
%}
%%% Is this still true, after Ops.factor (==, !=) is fixed ?
%
%\section{Comparison operators and group generic methods}{
%  There are \code{"factor"} and \code{"ordered"} methods for the
%  \link{group generic} \code{\link[=S3groupGeneric]{Ops}} which
%  provide methods for the \link{Comparison} operators,
%  and for the \code{\link{min}}, \code{\link{max}}, and
%  \code{\link{range}} generics in \code{\link[=S3groupGeneric]{Summary}}
%  of \code{"ordered"}.  (The rest of the groups and the
%  \code{\link[=S3groupGeneric]{Math}} group generate an error as they
%  are not meaningful for factors.)
%
%  Only \code{==} and \code{!=} can be used for factors: a factor can
%  only be compared to another factor with an identical set of levels
%  (not necessarily in the same ordering) or to a character vector.
%  Ordered factors are compared in the same way, but the general dispatch
%  mechanism precludes comparing ordered and unordered factors.
%
%  All the comparison operators are available for ordered factors.
%  Collation is done by the levels of the operands: if both operands are
%  ordered factors they must have the same level set.
%}
%\note{
%  In earlier versions of \R, storing character data as a factor was more
%  space efficient if there is even a small proportion of
%  repeats.  However, identical character strings now share storage, so
%  the difference is small in most cases.  (Integer values are stored
%  in 4 bytes whereas each reference to a character string needs a
%  pointer of 4 or 8 bytes.)
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{[.factor}} for subsetting of factors.
%
%  \code{\link{gl}} for construction of balanced factors and
%  \code{\link{C}} for factors with specified contrasts.
%  \code{\link{levels}} and \code{\link{nlevels}} for accessing the
%  levels, and \code{\link{unclass}} to get integer codes.
%}
%\examples{
%(ff <- factor(substring("statistics", 1:10, 1:10), levels = letters))
%as.integer(ff)      # the internal codes
%(f. <- factor(ff))  # drops the levels that do not occur
%ff[, drop = TRUE]   # the same, more transparently
%
%factor(letters[1:20], labels = "letter")
%
%class(ordered(4:1)) # "ordered", inheriting from "factor"
%z <- factor(LETTERS[3:1], ordered = TRUE)
%## and "relational" methods work:
%stopifnot(sort(z)[c(1,3)] == range(z), min(z) < max(z))
%\dontshow{
%of <- ordered(ff)
%stopifnot(identical(range(of, rev(of)), of[3:2]),
%	  identical(max(of), of[2]))
%}
%
%## suppose you want "NA" as a level, and to allow missing values.
%(x <- factor(c(1, 2, NA), exclude = NULL))
%is.na(x)[2] <- TRUE
%x  # [1] 1    <NA> <NA>
%is.na(x)
%# [1] FALSE  TRUE FALSE
%
%## Using addNA()
%Month <- airquality$Month
%table(addNA(Month))
%table(addNA(Month, ifany = TRUE))
%}
%\keyword{category}
%\keyword{NA}
%
\encoding{UTF8}
