% File src/library/base/man/function.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{function}
\alias{function}
\alias{return}
\alias{closure}

\title{Function Definition}
\usage{
\special{function( arglist ) expr}
\special{return(value)}
}
\description{
  これらは \R 言語で新しい関数を定義するための基本的機構を提供する．
}
\arguments{
    \item{arglist}{空又は一つもしくはそれ以上の名前か name=expression の形の項．}
    \item{expr}{表現式．}
    \item{value}{表現式．}
}
\details{
  引数リスト中の名前はバックコート文字で引用化された非標準的な名前でも良い
  (\sQuote{\link{backquote}} を見よ)．

  もし \code{value} が欠損していれば \code{NULL} が返される．もしそれが単一の
  表現式なら，評価された表現式の値が返される．
  (表現式は \code{return} が呼び出されるや否や，そして任意の
  \code{\link{on.exit}} 表現式が評価される前に，
  関数の評価フレーム中で評価される．)

  もし関数が \code{return} を呼び出す前に終わりに達すると，
  最後に評価された表現式の値が返される．
}

\section{技術的詳細}{
  このタイプの関数は \R では唯一のタイプではない：それらはプリミティブな関数と
  比較するため \emph{クロージャ} (LISP に起源を持つ用語) と呼ばれる．

  一つのクロージャは三つの成分を持つ，その形式的引数
  (引数のリスト)，その本体(\sQuote{用法}節の \code{expr})
  そしてクロージャが使われる際の評価フレームの囲み環境であるその環境である．

  もしクロージャがバイトコンパイルされている時はもうひとつのオプション成分がある．
  これは通常ユーザには可視的でないが，関数がプリントされるときは指示される．
}

\seealso{
  \code{\link{args}}.

  関数の構成部分にアクセスするには \code{\link{formals}}, \code{\link{body}} そして
  \code{\link{environment}}．

  デバッギングには \code{\link{debug}}；不可視の返り値には
  \code{return(.)} 内部で \code{\link{invisible}} を使う．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
norm <- function(x) sqrt(x\%*\%x)
norm(1:4)

## 匿名関数：
(function(x, y){ z <- x^2 + y^2; x+y+z })(0:7, 1)
}
\keyword{programming}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/function.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{function}
%\alias{function}
%\alias{return}
%\alias{closure}
%
%\title{Function Definition}
%\usage{
%\special{function( arglist ) expr}
%\special{return(value)}
%}
%\description{
%  These functions provide the base mechanisms for defining
%  new functions in the \R language.
%}
%\arguments{
%    \item{arglist}{Empty or one or more name or name=expression terms.}
%    \item{expr}{An expression.}
%    \item{value}{An expression.}
%}
%\details{
%  The names in an argument list can be back-quoted non-standard names
%  (see \sQuote{\link{backquote}}).
%
%  If \code{value} is missing, \code{NULL} is returned.  If it is a
%  single expression, the value of the evaluated expression is returned.
%  (The expression is evaluated as soon as \code{return} is called, in
%  the evaluation frame of the function and before any
%  \code{\link{on.exit}} expression is evaluated.)
%
%  If the end of a function is reached without calling \code{return}, the
%  value of the last evaluated expression is returned.
%}
%
%\section{Technical details}{
%  This type of function is not the only type in \R: they are called
%  \emph{closures} (a name with origins in LISP) to distinguish them from
%  \link{primitive} functions.
%
%  A closure has three components, its \code{\link{formals}} (its argument
%  list), its \code{\link{body}} (\code{expr} in the \sQuote{Usage}
%  section) and its \code{\link{environment}} which provides the
%  enclosure of the evaluation frame when the closure is used.
%
%  There is an optional further component if the closure has been
%  byte-compiled.  This is not normally user-visible, but it indicated
%  when functions are printed.
%}
%
%\seealso{
%  \code{\link{args}}.
%
%  \code{\link{formals}}, \code{\link{body}} and
%  \code{\link{environment}} for accessing the component parts of a
%  function.
%
%  \code{\link{debug}} for debugging; using \code{\link{invisible}} inside
%  \code{return(.)} for returning \emph{invisibly}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%norm <- function(x) sqrt(x\%*\%x)
%norm(1:4)
%
%## An anonymous function:
%(function(x, y){ z <- x^2 + y^2; x+y+z })(0:7, 1)
%}
%\keyword{programming}
%
\encoding{UTF8}
