% File src/library/base/man/isSymmetric.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{isSymmetric}
\alias{isSymmetric}
\alias{isSymmetric.matrix}
\title{Test if a Matrix or other Object is Symmetric}
\description{
  \code{object} が対称かどうかを検査する総称的関数．
  現在行列メソッドだけが実装されている．
}
\usage{
isSymmetric(object, \dots)
\method{isSymmetric}{matrix}(object, tol = 100 * .Machine$double.eps, \dots)
}
\arguments{
  \item{object}{任意の \R オブジェクト：行列メソッドには \code{\link{matrix}}．}
  \item{tol}{数値スカラー >= 0.  僅かな差異は考慮しない，
    \code{\link{all.equal.numeric}} を見よ．}
  \item{\dots}{メソッドに渡される追加引数；行列メソッドはこれらを
    \code{\link{all.equal}} に渡す．}
}
\value{
  \code{object} が対称か否かを示す論理値．
}
\details{
  \code{\link{matrix}} メソッドは \code{\link{eigen}} の中で既定で
  \emph{誤差の範囲内で}対称性を検査するために使われ
  \code{\link{all.equal}} を用いる．
  これはあらゆる状況で適当では無いかもしれない．

  行列 \code{m} はその \code{rownames} と \code{colnames} が
  同じ時だけ対称であることを注意する．\code{\link{unname}(m)} の
  使用を考えよう．
}
\seealso{その \code{symmetric} 引数が無い時 \code{isSymmetric} を呼び出す
  \code{\link{eigen}}．

}
\examples{
isSymmetric(D3 <- diag(3)) # -> TRUE

D3[2, 1] <- 1e-100
D3
isSymmetric(D3) # TRUE
isSymmetric(D3, tol = 0) # 許容度ゼロに対して FALSE
}
\keyword{array}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/isSymmetric.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{isSymmetric}
%\alias{isSymmetric}
%\alias{isSymmetric.matrix}
%\title{Test if a Matrix or other Object is Symmetric}
%\description{
%  Generic function to test if \code{object} is symmetric or not.
%  Currently only a matrix method is implemented.
%}
%\usage{
%isSymmetric(object, \dots)
%\method{isSymmetric}{matrix}(object, tol = 100 * .Machine$double.eps, \dots)
%}
%\arguments{
%  \item{object}{any \R object; a \code{\link{matrix}} for the matrix method.}
%  \item{tol}{numeric scalar >= 0.  Smaller differences are not
%    considered, see \code{\link{all.equal.numeric}}.}
%  \item{\dots}{further arguments passed to methods; the matrix method
%    passes these to \code{\link{all.equal}}.}
%}
%\value{
%  logical indicating if \code{object} is symmetric or not.
%}
%\details{
%  The \code{\link{matrix}} method is used inside \code{\link{eigen}} by
%  default to test symmetry of matrices \emph{up to rounding error}, using
%  \code{\link{all.equal}}.  It might not be appropriate in all
%  situations.
%
%  Note that a matrix \code{m} is only symmetric if its \code{rownames} and
%  \code{colnames} are identical.  Consider using \code{\link{unname}(m)}.
%}
%\seealso{\code{\link{eigen}} which calls \code{isSymmetric} when its
%  \code{symmetric} argument is missing.
%}
%\examples{
%isSymmetric(D3 <- diag(3)) # -> TRUE
%
%D3[2, 1] <- 1e-100
%D3
%isSymmetric(D3) # TRUE
%isSymmetric(D3, tol = 0) # FALSE for zero-tolerance
%}
%\keyword{array}
%\keyword{utilities}
%
\encoding{UTF8}
