% File src/library/base/man/quit.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{quit}
\alias{quit}
\alias{q}
\alias{.Last}
\alias{.Last.sys}
\title{Terminate an R Session}
\usage{
quit(save = "default", status = 0, runLast = TRUE)
   q(save = "default", status = 0, runLast = TRUE)
}
\arguments{
    \item{save}{環境(作業空間)を保存すべきかどうかを指示する文字列で，
        \code{"no"}, \code{"yes"}, \code{"ask"} 又は
	\code{"default"} のどれか一つ．}
    \item{status}{もし関連すれば，OS に返される(数値的な)エラー状態．
        便宜的に \code{0} が成功裏の完了を指示する．}
    \item{runLast}{\code{.Last()} を実行すべきか?}
}
\description{
    関数 \code{quit} やその別名 \code{q} は現在の
    \R セッションを終了する．
    }
\details{
    \code{save} は \code{"no"}, \code{"yes"},
    \code{"ask"} 又は \code{"default"} のどれかでなければならない．
    最初のケースでは作業空間は保存されない．
    二番目ではそれは保存され，三番目ではユーザの指示を待ちそして
    終了しない決定も出来る．対話的な使用での既定は指示を待つであるが，
    コマンドライン引数で上書き出来る
    (これは非対話的な使用では提供されなければならない)．

    もし関数 \code{.Last} が存在し \code{runLast} が真ならば
    正常終了の直前に \code{.Last()} が実行される．
    もし対話的な使用で \code{.Last} 関数中にエラーがあれば，
    制御はコマンドプロンプトに返され，従って関数を詳しく検査できる．
    システムの類似の関数 \code{.Last.sys()} があり，もし
    \code{runLast} が真なら \code{.Last()} の後に実行される．

    \R セッションの終了時に正確に何が起きるかは使用中のプラットフォームと
    GUI インタフェイスに依存する．
    典型的な流れは \code{.Last()} と \code{.Last.sys()} を実行し
    (\code{runLast} が偽で無い限り)，要求されれば作業空間を保存する
    (そしてほとんどの場合セッションの履歴も保存する：\code{\link{savehistory}} を見よ)．
    それから終了時に実行するように設定されている任意の終了動作を実行し
    (\code{\link{reg.finalizer}} を見よ)，
    全てのオープンされているグラフィックデバイスを閉じ，
    セッションの一時ディレクトリを取り除き，そして残っている任意の警告
    (例えば \code{.Last()} やデバイスのクロージャからの)をプリントする．

    ある種のエラー状態は \R 自体によって使われる．
    非対話的な使用に対する既定のエラーハンドラーは実効的に
    \code{q("no", 1, FALSE)} を呼び出しエラー状態 1 を返す．
    エラー状態は \R の\sQuote{自殺}時に使われる，つまり破滅的な失敗である．
    他の小さな値が初期化の失敗に対する特定のポートによって使われる．
    ユーザは状態 10 かそれ以上を使うことが勧められる．

    \code{status} の適正な値はシステム依存であるが，
    普通 \code{0:255} は適正である．
    (多くの OS は値の最後のバイトだけを報告するので値はモジュラス 256
    になる．しかし全てではない．)
#ifdef windows
% https://www.microsoft.com/resources/documentation/windows/xp/all/proddocs/en-us/ntcmds_shelloverview.mspx?mfr=true
% https://www.microsoft.com/resources/documentation/windows/xp/all/proddocs/en-us/if.mspx?mfr=true

    Windows は状態を \sQuote{エラーコード} とか \sQuote{終了コード} と呼ぶ．
    これは \code{cmd.exe} では環境変数 \env{\%ERRORLEVEL\%} に，
    そして Windows PowerShell では \env{LASTEXITCODE} に記録される．
    \code{Rterm} が返す \code{status} の値は信頼できるが，
    \code{Rgui} は GUI インタフェイスからのエラーコードを与えるかもしれない．
#endif
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\section{警告}{
  \code{.Last} の値はエンドユーザが制御するためのものである：
  これはセッション中に例えばパッケージで後から置き換えることが出来るが，
  プログラム上は安全に使うことは出来ない．
  セッションの最後に実行されるコードを設定する別の方法は
  \emph{finalizer} を使うことである：
  \code{\link{reg.finalizer}} を見よ．
}
\note{
  OS X 上の \code{R.app} GUI はこれらの関数のそれ自体のバージョンを持つが，
  \code{save} 引数に対する挙動が少し異なる
  (GUI のこのアクションに対する \sQuote{Startup} 優先度が考慮される)．
}
\seealso{
  起動時の設定には \code{\link{.First}}．
}
\examples{
\dontrun{## Unix 風味の例
.Last <- function() {
  graphics.off() # プリント前にデバイスを閉じる
  cat("Now sending PDF graphics to the printer:\n")
  system("lpr Rplots.pdf")
  cat("bye bye...\n")
}
quit("yes")}
}
\keyword{environment}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/quit.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{quit}
%\alias{quit}
%\alias{q}
%\alias{.Last}
%\alias{.Last.sys}
%\title{Terminate an R Session}
%\usage{
%quit(save = "default", status = 0, runLast = TRUE)
%   q(save = "default", status = 0, runLast = TRUE)
%}
%\arguments{
%    \item{save}{a character string indicating whether the environment
%        (workspace) should be saved, one of \code{"no"}, \code{"yes"},
%        \code{"ask"} or \code{"default"}.}
%    \item{status}{the (numerical) error status to be returned to the
%        operating system, where relevant.  Conventionally \code{0}
%        indicates successful completion.}
%    \item{runLast}{should \code{.Last()} be executed?}
%}
%\description{
%    The function \code{quit} or its alias \code{q} terminate the current
%    \R session.
%}
%\details{
%    \code{save} must be one of \code{"no"}, \code{"yes"},
%    \code{"ask"} or \code{"default"}.  In the first case the workspace
%    is not saved, in the second it is saved and in the third the user is
%    prompted and can also decide \emph{not} to quit.  The default is to
%    ask in interactive use but may be overridden by command-line
%    arguments (which must be supplied in non-interactive use).
%
%    Immediately \emph{before} normal termination, \code{.Last()} is
%    executed if the function \code{.Last} exists and \code{runLast} is
%    true.  If in interactive use there are errors in the \code{.Last}
%    function, control will be returned to the command prompt, so do test
%    the function thoroughly.  There is a system analogue,
%    \code{.Last.sys()}, which is run after \code{.Last()} if
%    \code{runLast} is true.
%
%    Exactly what happens at termination of an \R session depends on the
%    platform and GUI interface in use.  A typical sequence is to run
%    \code{.Last()} and \code{.Last.sys()} (unless \code{runLast} is
%    false), to save the workspace if requested (and in most cases also
%    to save the session history: see \code{\link{savehistory}}), then
%    run any finalizers (see \code{\link{reg.finalizer}}) that have been
%    set to be run on exit, close all open graphics devices, remove the
%    session temporary directory and print any remaining warnings
%    (e.g., from \code{.Last()} and device closure).
%
%    Some error status values are used by \R itself.  The default error
%    handler for non-interactive use effectively calls \code{q("no", 1,
%    FALSE)} and returns error status 1.  Error status 2 is used for \R
%    \sQuote{suicide}, that is a catastrophic failure, and other small
%    numbers are used by specific ports for initialization failures.  It
%    is recommended that users choose statuses of 10 or more.
%
%    Valid values of \code{status} are system-dependent, but \code{0:255}
%    are normally valid.  (Many OSes will report the last byte of the
%    value, that is report the value modulo 256.  But not all.)
%#ifdef windows
%% https://www.microsoft.com/resources/documentation/windows/xp/all/proddocs/en-us/ntcmds_shelloverview.mspx?mfr=true
%% https://www.microsoft.com/resources/documentation/windows/xp/all/proddocs/en-us/if.mspx?mfr=true
%
%    Windows calls the status the \sQuote{error code} or \sQuote{exit
%      code}.  It is returned in the environment variable
%    \env{\%ERRORLEVEL\%} in \code{cmd.exe}, and in \env{LASTEXITCODE}
%    in Windows PowerShell.  Note that the \code{Rterm} reliably reports
%    the \code{status} value, but \code{Rgui} may give an error code from
%    the GUI interface.
%#endif
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\section{Warning}{
%  The value of \code{.Last} is for the end user to control: as
%  it can be replaced later in the session, it cannot safely be used
%  programmatically, e.g.\sspace{}by a package.  The other way to set code to be run
%  at the end of the session is to use a \emph{finalizer}: see
%  \code{\link{reg.finalizer}}.
%}
%\note{
%  The \code{R.app} GUI on OS X has its own version of these functions
%  with slightly different behaviour for the \code{save} argument (the
%  GUI's \sQuote{Startup} preferences for this action are taken into account).
%}
%\seealso{
%  \code{\link{.First}} for setting things on startup.
%}
%\examples{
%\dontrun{## Unix-flavour example
%.Last <- function() {
%  graphics.off() # close devices before printing
%  cat("Now sending PDF graphics to the printer:\n")
%  system("lpr Rplots.pdf")
%  cat("bye bye...\n")
%}
%quit("yes")}
%}
%\keyword{environment}
%
\encoding{UTF8}
