% File src/library/base/man/strptime.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{strptime}
\alias{format.POSIXct}
\alias{format.POSIXlt}
\alias{strftime}
\alias{strptime}
\alias{as.character.POSIXt}
\title{Date-time Conversion Functions to and from Character}
\description{
  文字列と，暦日と時刻を表現するクラス
  \code{"POSIXlt"} と \code{"POSIXct"} のオブジェクトの間の
  変換関数．
}
\usage{
\method{format}{POSIXct}(x, format = "", tz = "", usetz = FALSE, \dots)
\method{format}{POSIXlt}(x, format = "", usetz = FALSE, \dots)

\method{as.character}{POSIXt}(x, \dots)

strftime(x, format = "", tz = "", usetz = FALSE, \dots)
strptime(x, format, tz = "")
}
\arguments{
  \item{x}{変換されるオブジェクト：\code{strptime} に対しては文字列，
    \code{strftime} に対してはクラス \code{"\link{POSIXlt}"} に変換できるオブジェクト．}
  \item{tz}{変換に用いられるタイムゾーンを指定する文字列．
    システム固有(\code{\link{as.POSIXlt}} を見よ)であるが，
    \code{""} は現在のタイムゾーンで，\code{"GMT"} は UTC．
    不正な値は最も普通に UTC として扱われ，ある種のプラットフォームでは警告が出る．}
  \item{format}{文字列．\code{format} メソッドに対する既定値は
    もしある要素が真夜中でない成分を持てば \code{"\%Y-\%m-\%d \%H:\%M:\%S"} で，
    さもなければ \code{"\%Y-\%m-\%d"} である．
    もし \code{\link{options}("digits.secs")} が設定されていれば，最大指定された
    桁数まで秒がプリントされる．}
  \item{\dots}{他のメソッドへ・から渡される追加引数．}
  \item{usetz}{論理値．タイムゾーンの短縮形を出力に加えるか? 
    これは時間のプリントに使われ，\code{"\%Z"} を使うよりも信頼できる．}
}
\details{
  \code{format} と \code{as.character} メソッド，そして \code{strftime}
  はクラス \code{"\link{POSIXlt}"} と \code{"\link{POSIXct}"} のオブジェクトを
  文字列に変換する．

  \code{strptime} は文字列をクラス \code{"POSIXlt"} に変換する：
  その入力 \code{x} は最初 \code{\link{as.character}} によって変換される．
  各入力文字列は指定された書式に対して必要な限り処理される：
  任意の末尾の文字は無視される．

  \code{strftime} は \code{format.POSIXlt} に対するラッパであり，これと
  \code{format.POSIXct} は最初 \code{\link{as.POSIXlt}} を呼び出して
  クラス \code{"POSIXlt"} に変換される
  (従ってそれらはクラス \code{"\link{Date}"} に対しても動作する)．
  この変換だけがタイムゾーンに依存することを注意する．

  通常のベクトルのリサイクル規則が \code{x} と \code{format} に適用されるので，
  回答はこれらのベクトルの最大のものの長さになる．

  ロケール固有の文字列への・からの変換が適当で利用可能なら使われる．
  これは日と月の名前，(もし使われていれば) AM/PM の指示，
  そして \code{\%x} や \code{\%X} のような書式中の分離子に，
  \code{\link{LC_TIME}} のロケールカテゴリの設定により
  影響する．
  述べられた\sQuote{現在のロケール}とは
  \R セッションの開始時に使われているものかこれらの関数が最初に
  使われた時のものである．
  
  % strftime is C99: strptime is POSIX.
  書式の詳細はプラットフォーム固有であるが，以下は広く使われている可能性が
  高い：殆どは POSIX 標準で定義されている．
  \emph{変換指定}は \code{\%} によって導入され，普通文字一つか
  \code{O} か \code{E} が続き，それから文字一つが続く．
  変換指定の一部分でない書式中の任意の文字は文字通り
  (そして \code{\%\%} は \code{\%} を与える)解釈される．
  広く実装されている変換指定は次を含む
  \describe{
    \item{\code{\%a}}{このプラットフォームの現在のロケール中の
      曜日名の短縮形．(入力では完全な名前ともマッチする：
      ある種のロケールでは名前の短縮形はない．)}
    \item{\code{\%A}}{現在のロケール中の完全な曜日名．
      (入力では省略形ともマッチする．)}
    \item{\code{\%b}}{このプラットフォームの現在のロケール中の
      月名の短縮形．(入力では完全な名前ともマッチする：
      ある種のロケールでは名前の短縮形はない．)}
    \item{\code{\%B}}{現在のロケール中の完全な月名．
      (入力では省略形ともマッチする．)}
    \item{\code{\%c}}{日付と時刻．出力ではロケール固有で，
      入力では \code{"\%a \%b \%e \%H:\%M:\%S \%Y"}．}
    \item{\code{\%C}}{世紀 (00--99): 年度を100で割った整数部分．}
    \item{\code{\%d}}{10進数(01--31)としての月の日にち．}
    \item{\code{\%D}}{\code{\%m/\%d/\%y} の様な日付書式：C99
      標準はこれは正確な書式であるべきと主張する(が全ての OS が従っているわけではない)．}
    \item{\code{\%e}}{10進数(01--31)としての月の日にちで，
      数字が一つなら先頭に空白を持つ．}
    \item{\code{\%F}}{\%Y-\%m-\%d に等しい(ISO 8601 日付書式)．}
    \item{\code{\%g}}{一年を週数で計った最後の二つの数字
      (\code{\%V} を見よ)．(入力では受け入れられるが無視される．)}
    \item{\code{\%G}}{10進数としての一年を週数で計った数字
      (\code{\%V} を見よ)．(入力では受け入れられるが無視される．)}
    \item{\code{\%h}}{\code{\%b} と同値．}
    \item{\code{\%H}}{10進数としての時間(00--23)．ISO 8601 が認めているため，
      特別な例外である \samp{24:00:00} の様な文字列は入力では受け入れられる．}
    \item{\code{\%I}}{10進数としての時間(01--12)．}
    \item{\code{\%j}}{10進数としての一年の日(001--366)．}
    \item{\code{\%m}}{10進数としての月(01--12).}
    \item{\code{\%M}}{10進数としての分(00--59).}
    \item{\code{\%n}}{出力では新行，入力では任意の空白．}
    \item{\code{\%p}}{ロケールでの AM/PM 指示．\code{\%I} と一緒
      そして \code{\%H} 無しで使われる．ある種のロケールでは
      空文字列(もしそうしたロケール中の入力として使われると挙動は
      未定義である)．

      ある種のプラットフォームは出力に対して \code{\%P} を受け入れ，小文字
      を使う：他は \code{P} を出力する．}
    \item{\code{\%r}}{12時間制の時刻(ロケールの AM や
      PM を使う)．ある種のロケールでだけ定義される．}
    \item{\code{\%R}}{\code{\%H:\%M} と同値．}
    \item{\code{\%S}}{整数としての秒数(00--61)，最大二つの閏秒を受け入れる
      (しかし POSIX 準拠の実装は閏秒を無視する)．}
    \item{\code{\%t}}{出力ではタブ，入力では任意の空白．}
    \item{\code{\%T}}{\code{\%H:\%M:\%S} と同値．}
    \item{\code{\%u}}{10進数としての曜日(1--7，月曜日は 1)．}
    % see https://en.wikipedia.org/wiki/Week_number#Week_number
    \item{\code{\%U}}{10進数としての一年の週(00--53)で
      日曜日が週の第1日(そして典型的には一年の最初の日曜日が
      第1週の第1日)．US の慣例．}
    \item{\code{\%V}}{ISO 8601 で定義されたような10進数としての
      一年の週(01--53)．
      もし新年に1月1日を含む週(月曜日に始まる)が4日以上あれば，それが週1と
      考えられる．さもなければ，それは前年の最後の週であり，次の週が種1である．
      (受け入れられるが入力では無視される．)}
    \item{\code{\%w}}{10 進数としての曜日(0--6, 日曜日が 0)．}
    \item{\code{\%W}}{10進数としての年の週(00--53)で月曜日を
      週の最初の日とする(そして典型的に一年の最初の月曜日を週1とする)．
      UK の慣習．}
    \item{\code{\%x}}{日付．出力ではロケール固有，入力では
      \code{"\%y/\%m/\%d"}．}
    \item{\code{\%X}}{時刻．出力ではロケール固有，入力では
      \code{"\%H:\%M:\%S"}．}
    \item{\code{\%y}}{西暦を除いた年(00--99)．入力では値
      00 から 68 は先頭に 20 が 69 から 99 は 19 が付く -- これは
      behaviour specified by the 2004年と2008年の POSIX 表現で
      指定された挙動であるが，それはまた
      \sQuote{将来のバージョンでは二桁の年から推測された既定の世紀は
        変更されるであろう}と主張している．}
    \item{\code{\%Y}}{世紀付きの年．元々のグレゴリオ暦ではゼロが無いにも
      かかわらず，ISO 8601:2004 はそれが正当であると定義する
      (1BC と解釈される)：\url{https://en.wikipedia.org/wiki/0_(year)} を見よ．
      この標準はまたカレンダー中の 1582 年以前の年は関係者の合意の下でのみ
      使われるべきであると主張する．
  
      入力に対しては年 \code{0:9999} だけが受け入れられる．}
    \item{\code{\%z}}{UTC からの時間と分の符号付きオフセットで，
      従って \code{-0800} は UTC の8 時間前になる．最大
      \code{+1400} までの値が \R 3.1.1 以来受け入れられる：
      それよりも前のバージョンは最大 \code{+1200} までを受け入れた．
      (出力対してだけの標準．)} 
    \item{\code{\%Z}}{(出力のみ．)  文字列としてのタイムゾーンの省略形
      (もし利用できなければ空)．これはタイムゾーンが年と共に変わっている場合は
      信頼できないかもしれない．}
  }
  先頭のゼロが現れるところは出力では示されるが入力ではオプションである．
  名前は文字の大小を蟲師てマッチされる：
  それらが出力で大文字になるかどうかはプラットフォームとロケールに依存する．
  短縮名はプラットフォーム依存であることを注意する
  (標準は  \samp{C} ロケールではそれらは大文字化された英語名の
  最初の三つの文字と指定している：この慣習は英語圏のロケールでは広く
  使われているが，例えばフランスの月名の省略は Linux, OS X, Solaris 
  そして Windows のどの二つをとっても同じではない)．
  短縮形が何なのかを知っていることは
  もし \code{\%a}, \code{\%b} または \code{\%h} を入力書式の一部として
  使いたければ本質的である：どのようにチェックするかは例を見よ．
% Unlike Dominic Comtois in non-bug PR#16301

  付値されたタイムゾーンを持つオブジェクトとともに
  \code{\%z} か \code{\%Z} が出力に対して使われると
  そのタイムゾーンに対する値を使おうと試みられる ---
  しかし成功するとは限らない．
  
  標準ではなくあまり広くは実装されていないものは
  \describe{
    \item{\code{\%k}}{一つだけの数字は前に空白をつけた 24 時間の時刻．}
    \item{\code{\%l}}{一つだけの数字は前に空白をつけた 12 時間の時刻．}
    \item{\code{\%s}}{(出力のみ．) 出来事からの秒数．}
    \item{\code{\%+}}{(出力のみ．) \code{\%c} に似るがしばしば
      \code{"\%a \%b \%e \%H:\%M:\%S \%Z \%Y"}．ロケールに依存するかもしれない．}
  }
  出力に対してはまた \code{\%O[dHImMUVwWy]} があり数を別種のロケール依存の
  書式(例えば，ローマ数字)で発生し，\code{\%E[cCyYxX]} は別種の
  \sQuote{紀元}(例えば，異なった宗教カレンダー)を使うことが出来る．
  これらは入力に対しては受け入れられるが標準的に解釈される．

  \R に固有なものは \code{\%OSn} であり，出力に対しては
  \code{0 <= n <= 6} 桁で切り詰められた秒を与える
  (そしてもし \code{\%OS} に数字が続かなければ
  設定 \code{\link{getOption}("digits.secs")} を使う，もしくはそれが
  未設定なら \code{n = 3})．
  更に \code{strptime} に対しては \code{\%OS} は小数秒を含む秒を入力する．
  \code{\%S} は出力では小数部を読み取らない．

  他の変換指定(そして \code{\%} で始まる他の文字列が変換指定だとしても)
  はシステム固有である．ある種のシステムは \code{format} 中の
  多バイト文字の使用はサポートされていないと解説されている：
  UTF-8 ロケールは問題が起きる可能性は少ない．
}
\value{
  \code{format} メソッドと \code{strftime} は時間を表現する文字列ベクトルを
  返す．時間の \code{NA} は \code{NA_character_} として返される．
  要素は 256 バイトに制限され，もし \code{usetz} が真なら
  タイムゾーンの省略形が加わる．(既知のプラットフォームでは
  長すぎる文字列は 255 か 256 バイトに切り詰められるが，これは
  C99 標準では保証されない．)

  \code{strptime} は文字列表現をクラス
  class \code{"\link{POSIXlt}"} のオブジェクトに変換する．
  タイムゾーンは \code{isdst} 成分と，もし \code{tz != ""} ならば
  \code{"tzone"} 属性を設定するのに使われる．
  もし指定された時間が不正確なら(例えば \samp{"2010-02-30 08:00"})
  結果の全ての成分は \code{NA} になる．
  (NB： これはそれが主張することを正確に意味している -- 単にあるタイムゾーンで
  存在しない時間というだけでなく，もしそれが不正確な時間なら．)
  %% One of Master B Diggs moments of infamy
}

\section{年のプリント}{
  誰もが 1000 から 9999 までの年は4桁でプリントされるべきことは
  同意するが，標準はこの範囲外ではどうするかは定義していいない．
  0 から 999 までの年では殆どの OS はゼロや空白で埋めて4桁にするが，
  Linux は単にその数を出力する．
  
  OS の機能は恐らく 1 CE (又は 1 AD)を\sQuote{正確に}プリントしない
  (それらは年 0 の存在を仮定していない：
  \url{https://en.wikipedia.org/wiki/0_(year)} を見よ．
  そしてある種の OS はそれらを全く間違って受け取る)．
  普通の書式は \code{-45} と \code{-045} である．

  9999 後と -999 以前は普通5桁かそれ以上の文字でプリントする．

  ある種のプラットフォームは POSIX 2008 (そしてその他)からの
  修正をサポートする．Linux の書式 \code{"\%04Y"} は最低4文字と
  ゼロによる補填を保証する．内部コード(Windows で使用され
  OS X では既定)は既定でゼロ補填を行い，書式
  \code{\%_4Y} と \code{\%_Y} は空白による補填と，補填をしない
  ために使える．
}

\section{タイムゾーンオフセット}{
  GMT (UTC としても知られている)はタイムゾーンと
  クラス \code{"POSIXct"} へ・からの変換の一部であるが，
  しばしば不正確に計算されるので困難を招く．

  これらは慣例としてタイムゾーン指定からの逆の符号を持つ
  (\code{\link{Sys.timezone}} を見よ)：正の値は子午線の東部
  である．00:09:21 (1900 のパリ)や 00:44:30 (1972 までのリベリア)
  のようなオフセットを持つタイムゾーンが存在したが，
  オフセットは普通全部の分数として扱われ，そして
  最も普通には RFC 822 電子メイルヘッダー中の 
  \code{-0800} の様な形式でみられる(たとえば，冬季の US の
  太平洋岸)．
  
  書式 \code{\%z} は入力と出力に対して使うことが出来る：
  これは文字列で，慣例的にプラスかマイナスに時間に対する二つの数字と
  分に対する二つの数字が続く：標準はオフセットが未知なら空文字列が
  出力されるべきと述べるが，ある種のシステムは現在の年に対して使われている
  タイムゾーンに対するオフセットを使う．
}

\note{
  既定の書式は ISO 8601 国際標準に従い，
  日を \code{"2001-02-28"}，時刻を 
  \code{"14:01:02"} のように先頭のゼロを使って表す．
  (ISO 書式は日付と時刻を分離する空白を使わないが 
  \R は既定でそうする．)

  \code{strptime} に対しては入力文字列は日付を完全に指定する必要はない：
  未指定の秒，分，時間はゼロと仮定され，月や日は現在のものである．
  (しかしながらもし月が指定されると，現在の月のその日は指定された月に対しては
  不正かもしれないので，その月の日を \code{\%d} や \code{\%e}
  を使って指定する必要がある．)
  ある成分は \code{NA} として返されるかもしれない
  (しかし未知の \code{tzone} 成分は空の文字列で表現される)．

  もし指定されたタイムゾーンが自分のシステムで不正なら，
  何が起きるかはシステム依存であるが恐らく無視される．

  \sQuote{daylight saving} (又はサマー)タイムへ・からの推移のせいで，
  殆どのタイムゾーンではある時刻は起きず，ある時刻は二回起きることを
  注意しよう．\code{strptime} はそうした時刻を検証しない
  (それは特定のタイムゾーンを仮定しない)が，
  \code{\link{as.POSIXct}} による変換はする．
  \code{strftime} による変換と整形/プリントは OS 機能を使っており，
  DST の推移時に存在しない時間に対しては無意味な結果を返すかもしれない．
  
  \R 3.1.0 以前の Windows でははるかに不完全な出力指定が
  サポートされていた．
  
  C ロケールでは \code{\%c} は \code{"\%a \%b \%e \%H:\%M:\%S \%Y"}
  である必要がある．Windows はそれを守らない(そして北アメリカ以外では
  理解できない書式を使う)．その書式が Windows 版の \R では
  全てのロケールで使われる．
  
  入力では \code{\%A \%a \%B \%b} は完全名と短縮名の双方がマッチするという
  事実は \R 3.0.3 以前ではある種のロケール中で問題を起こす：
  例えばフランスの OS X では \samp{juillet} は6月に対する短縮形である
  \code{jui} とマッチしてしまう．
}

\references{
  International Organization for Standardization (2004, 2000, \dots)
  \emph{ISO 8601.  Data elements and interchange formats --
    Information interchange -- Representation of dates and times.}
  (執筆時に)オンラインで利用できるバージョンのリンクは
  \url{http://dotat.at/tmp/ISO_8601-2004_E.pdf} と
  \url{http://www.qsl.net/g1smd/isopdf.htm} を見よ；
  現在の公式バージョンに関する情報は
  \url{http://www.iso.org/iso/iso8601} である．

  POSIX 1003.1 標準，これは幾つかの点で ISO 8601 より厳格である．
}
\seealso{
  日付・時刻クラスの詳細は \link{DateTimeClasses}；
  ロケールの確認と設定は \link{locales}．

  書式をどのように設定するかは自分のシステムの \code{strftime} の
  ヘルプページ．
  (Windows を含むある種のシステムでは \code{strftime} は
  より包括的な内部コードで置き換えられている．)
}
\examples{\donttest{
## date() のロケール固有バージョン
format(Sys.time(), "\%a \%b \%d \%X \%Y \%Z")

## 1/10 秒精度の時間(OS がサポートしていれば)
format(Sys.time(), "\%H:\%M:\%OS3")

## 書式 'ddmmmyyyy' でデータ情報を読み込む
## これはある種のロケールでは NA を与える；
## コメント行のように C ロケールを設定すればほとんどのシステムでこれを克服できる．
## lct <- Sys.getlocale("LC_TIME"); Sys.setlocale("LC_TIME", "C")
x <- c("1jan1960", "2jan1960", "31mar1960", "30jul1960")
z <- strptime(x, "\%d\%b\%Y")
## Sys.setlocale("LC_TIME", lct)
z

## 書式 'm/d/y h:m:s' で日付/時刻 情報を読み込む
dates <- c("02/27/92", "02/27/92", "01/14/92", "02/28/92", "02/01/92")
times <- c("23:03:20", "22:29:56", "01:03:30", "18:21:03", "16:56:26")
x <- paste(dates, times)
strptime(x, "\%m/\%d/\%y \%H:\%M:\%S")

## 小数秒の時間
z <- strptime("20/2/06 11:16:16.683", "\%d/\%m/\%y \%H:\%M:\%OS")
z # 小数秒無しでプリント
op <- options(digits.secs = 3)
z
options(op)

## タイムゾーン名は可搬的でないが 'EST5EDT' はかなり近くなる．
(x <- strptime(c("2006-01-08 10:07:52", "2006-08-07 19:33:02"),
               "\%Y-\%m-\%d \%H:\%M:\%S", tz = "EST5EDT"))
attr(x, "tzone")

## RFC 822 ヘッダー(DST 中の東カナダ)
strptime("Tue, 23 Mar 2010 14:36:38 -0400",  "\%a, \%d \%b \%Y \%H:\%M:\%S \%z")

## もし省略名を入力に使いたければ(それらは大・小文字を区別しない)
## それらが何なのか正確に知っていることが必要である
format(seq.Date(as.Date('1978-01-01'), by = 'day', len = 7), "\%a")
format(seq.Date(as.Date('2000-01-01'), by = 'month', len = 12), "\%b")
}}
\keyword{utilities}
\keyword{chron}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/strptime.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{strptime}
%\alias{format.POSIXct}
%\alias{format.POSIXlt}
%\alias{strftime}
%\alias{strptime}
%\alias{as.character.POSIXt}
%\title{Date-time Conversion Functions to and from Character}
%\description{
%  Functions to convert between character representations and objects of
%  classes \code{"POSIXlt"} and \code{"POSIXct"} representing calendar
%  dates and times.
%}
%\usage{
%\method{format}{POSIXct}(x, format = "", tz = "", usetz = FALSE, \dots)
%\method{format}{POSIXlt}(x, format = "", usetz = FALSE, \dots)
%
%\method{as.character}{POSIXt}(x, \dots)
%
%strftime(x, format = "", tz = "", usetz = FALSE, \dots)
%strptime(x, format, tz = "")
%}
%\arguments{
%  \item{x}{An object to be converted: a character vector for
%    \code{strptime}, an object which can be converted to
%    \code{"\link{POSIXlt}"} for \code{strftime}.}
%  \item{tz}{A character string specifying the time zone to be used for
%    the conversion.  System-specific (see \code{\link{as.POSIXlt}}), but
%    \code{""} is the current time zone, and \code{"GMT"} is UTC.
%    Invalid values are most commonly treated as UTC, on some platforms with
%    a warning.}
%  \item{format}{A character string.  The default for the \code{format}
%    methods is
%    \code{"\%Y-\%m-\%d \%H:\%M:\%S"} if any element has a time
%    component which is not midnight, and \code{"\%Y-\%m-\%d"}
%    otherwise.  If \code{\link{options}("digits.secs")} is set, up to
%    the specified number of digits will be printed for seconds.}
%  \item{\dots}{Further arguments to be passed from or to other methods.}
%  \item{usetz}{logical.  Should the time zone abbreviation be appended
%    to the output?  This is used in printing times, and more reliable
%    than using \code{"\%Z"}.}
%}
%\details{
%  The \code{format} and \code{as.character} methods and \code{strftime}
%  convert objects from the classes \code{"\link{POSIXlt}"} and
%  \code{"\link{POSIXct}"} to character vectors.
%
%  \code{strptime} converts character vectors to class \code{"POSIXlt"}:
%  its input \code{x} is first converted by \code{\link{as.character}}.
%  Each input string is processed as far as necessary for the format
%  specified: any trailing characters are ignored.
%
%  \code{strftime} is a wrapper for \code{format.POSIXlt}, and it and
%  \code{format.POSIXct} first convert to class \code{"POSIXlt"} by
%  calling \code{\link{as.POSIXlt}} (so they also work for class
%  \code{"\link{Date}"}).  Note that only that conversion depends on the
%  time zone.
%
%  The usual vector re-cycling rules are applied to \code{x} and
%  \code{format} so the answer will be of length of the longer of these
%  vectors.
%
%  Locale-specific conversions to and from character strings are used
%  where appropriate and available.  This affects the names of the days
%  and months, the AM/PM indicator (if used) and the separators in
%  formats such as \code{\%x} and \code{\%X}, via the setting of the
%  \code{\link{LC_TIME}} locale category.  The \sQuote{current locale} of
%  the descriptions might mean the locale in use at the start of the \R
%  session or when these functions are first used.
%  
%  % strftime is C99: strptime is POSIX.
%  The details of the formats are platform-specific, but the following are
%  likely to be widely available: most are defined by the POSIX standard.
%  A \emph{conversion specification} is introduced by \code{\%}, usually
%  followed by a single letter or \code{O} or \code{E} and then a single
%  letter.  Any character in the format string not part of a conversion
%  specification is interpreted literally (and \code{\%\%} gives
%  \code{\%}).  Widely implemented conversion specifications include
%  \describe{
%    \item{\code{\%a}}{Abbreviated weekday name in the current
%      locale on this platform.  (Also matches full name on input:
%      in some locales there are no abbreviations of names.)}
%    \item{\code{\%A}}{Full weekday name in the current locale.  (Also
%      matches abbreviated name on input.)}
%    \item{\code{\%b}}{Abbreviated month name in the current locale on
%      this platform.  (Also matches full name on input: in
%      some locales there are no abbreviations of names.)}
%    \item{\code{\%B}}{Full month name in the current locale.  (Also
%      matches abbreviated name on input.)}
%    \item{\code{\%c}}{Date and time.   Locale-specific on output,
%      \code{"\%a \%b \%e \%H:\%M:\%S \%Y"} on input.}
%    \item{\code{\%C}}{Century (00--99): the integer part of the year
%      divided by 100.}
%    \item{\code{\%d}}{Day of the month as decimal number (01--31).}
%    \item{\code{\%D}}{Date format such as \code{\%m/\%d/\%y}: the C99
%      standard says it should be that exact format (but not all OSes
%      comply).}
%    \item{\code{\%e}}{Day of the month as decimal number (1--31), with
%      a leading space for a single-digit number.}
%    \item{\code{\%F}}{Equivalent to \%Y-\%m-\%d (the ISO 8601 date
%      format).}
%    \item{\code{\%g}}{The last two digits of the week-based year
%      (see \code{\%V}).  (Accepted but ignored on input.)}
%    \item{\code{\%G}}{The week-based year (see \code{\%V}) as a decimal
%      number.  (Accepted but ignored on input.)}
%    \item{\code{\%h}}{Equivalent to \code{\%b}.}
%    \item{\code{\%H}}{Hours as decimal number (00--23).  As a special
%      exception strings such as \samp{24:00:00} are accepted for input,
%      since ISO 8601 allows these.}
%    \item{\code{\%I}}{Hours as decimal number (01--12).}
%    \item{\code{\%j}}{Day of year as decimal number (001--366).}
%    \item{\code{\%m}}{Month as decimal number (01--12).}
%    \item{\code{\%M}}{Minute as decimal number (00--59).}
%    \item{\code{\%n}}{Newline on output, arbitrary whitespace on input.}
%    \item{\code{\%p}}{AM/PM indicator in the locale.  Used in
%      conjunction with \code{\%I} and \bold{not} with \code{\%H}.  An
%      empty string in some locales (and the behaviour is undefined if
%      used for input in such a locale).
%
%      Some platforms accept \code{\%P} for output, which uses a lower-case
%      version: others will output \code{P}.} 
%    \item{\code{\%r}}{The 12-hour clock time (using the locale's AM or
%      PM).  Only defined in some locales.}
%    \item{\code{\%R}}{Equivalent to \code{\%H:\%M}.}
%    \item{\code{\%S}}{Second as integer (00--61), allowing for
%      up to two leap-seconds (but POSIX-compliant implementations
%      will ignore leap seconds).}
%    \item{\code{\%t}}{Tab on output, arbitrary whitespace on input.}
%    \item{\code{\%T}}{Equivalent to \code{\%H:\%M:\%S}.}
%    \item{\code{\%u}}{Weekday as a decimal number (1--7, Monday is 1).}
%    % see https://en.wikipedia.org/wiki/Week_number#Week_number
%    \item{\code{\%U}}{Week of the year as decimal number (00--53) using
%      Sunday as the first day 1 of the week (and typically with the
%      first Sunday of the year as day 1 of week 1).  The US convention.}
%    \item{\code{\%V}}{Week of the year as decimal number (01--53) as
%      defined in ISO 8601.
%      If the week (starting on Monday) containing 1 January has four or
%      more days in the new year, then it is considered week 1.  Otherwise, it
%      is the last week of the previous year, and the next week is week
%      1.  (Accepted but ignored on input.)}
%    \item{\code{\%w}}{Weekday as decimal number (0--6, Sunday is 0).}
%    \item{\code{\%W}}{Week of the year as decimal number (00--53) using
%      Monday as the first day of week (and typically with the
%      first Monday of the year as day 1 of week 1).  The UK convention.}
%    \item{\code{\%x}}{Date.  Locale-specific on output,
%      \code{"\%y/\%m/\%d"} on input.}
%    \item{\code{\%X}}{Time.  Locale-specific on output,
%      \code{"\%H:\%M:\%S"} on input.}
%    \item{\code{\%y}}{Year without century (00--99).  On input, values
%      00 to 68 are prefixed by 20 and 69 to 99 by 19 -- that is the
%      behaviour specified by the 2004 and 2008 POSIX standards, but they do
%      also say \sQuote{it is expected that in a future version the
%	default century inferred from a 2-digit year will change}.}
%    \item{\code{\%Y}}{Year with century.  Note that whereas there was no
%      zero in the original Gregorian calendar, ISO 8601:2004 defines it
%      to be valid (interpreted as 1BC): see
%      \url{https://en.wikipedia.org/wiki/0_(year)}.  Note that the standards
%      also say that years before 1582 in its calendar should only be used
%      with agreement of the parties involved.
%  
%      For input, only years \code{0:9999} are accepted.}
%    \item{\code{\%z}}{Signed offset in hours and minutes
%      from UTC, so \code{-0800} is 8 hours behind UTC. Values up to
%      \code{+1400} are accepted as from \R 3.1.1: previous versions only
%      accepted up to \code{+1200}.  (Standard only for output.)} 
%    \item{\code{\%Z}}{(Output only.)  Time zone abbreviation as a
%      character string (empty if not available).  This may not be reliable
%      when a time zone has changed abbreviations over the years.}
%  }
%  Where leading zeros are shown they will be used on output but are
%  optional on input.  Names are matched case-insensitively on input:
%  whether they are capitalized on output depends on the platform and the
%  locale.  Note that abbreviated names are platform-specific (although
%  the standards specify that in the \samp{C} locale they must be the
%  first three letters of the capitalized English name: this convention
%  is widely used in English-language locales but for example the French
%  month abbreviations are not the same on any two of Linux, OS X, Solaris
%  and Windows). Knowing what the abbreviations are is essential
%  if you wish to use \code{\%a}, \code{\%b} or \code{\%h} as part of an
%  input format: see the examples for how to check.
%% Unlike Dominic Comtois in non-bug PR#16301
%
%  When \code{\%z} or \code{\%Z} is used for output with an
%  object with an assigned time zone an attempt is made to use the values
%  for that time zone --- but it is not guaranteed to succeed.
%  
%  Not in the standards and less widely implemented are
%  \describe{
%    \item{\code{\%k}}{The 24-hour clock time with single digits preceded
%      by a blank.}
%    \item{\code{\%l}}{The 12-hour clock time with single digits preceded
%      by a blank.}
%    \item{\code{\%s}}{(Output only.) The number of seconds since the
%      epoch.}
%    \item{\code{\%+}}{(Output only.) Similar to \code{\%c}, often
%      \code{"\%a \%b \%e \%H:\%M:\%S \%Z \%Y"}. May depend on the locale.}
%  }
%  For output there are also \code{\%O[dHImMUVwWy]} which may emit
%  numbers in an alternative locale-dependent format (e.g., roman
%  numerals), and \code{\%E[cCyYxX]} which can use an alternative
%  \sQuote{era} (e.g., a different religious calendar).  Which of these
%  are supported is OS-dependent.  These are accepted for input, but with
%  the standard interpretation.
%
%  Specific to \R is \code{\%OSn}, which for output gives the seconds
%  truncated to \code{0 <= n <= 6} decimal places (and if \code{\%OS} is
%  not followed by a digit, it uses the setting of
%  \code{\link{getOption}("digits.secs")}, or if that is unset, \code{n =
%  3}).  Further, for \code{strptime} \code{\%OS} will input seconds
%  including fractional seconds.  Note that \code{\%S} does not read
%  fractional parts on output. 
%
%  The behaviour of other conversion specifications (and even if other
%  character sequences commencing with \code{\%} \emph{are} conversion
%  specifications) is system-specific.  Some systems document that the
%  use of multi-byte characters in \code{format} is unsupported: UTF-8
%  locales are unlikely to cause a problem.
%}
%\value{
%  The \code{format} methods and \code{strftime} return character vectors
%  representing the time.  \code{NA} times are returned as
%  \code{NA_character_}.  The elements are restricted to 256 bytes, plus
%  a time zone abbreviation if \code{usetz} is true.  (On known platforms
%  longer strings are truncated at 255 or 256 bytes, but this is not
%  guaranteed by the C99 standard.)
%
%  \code{strptime} turns character representations into an object of
%  class \code{"\link{POSIXlt}"}.  The time zone is used to set the
%  \code{isdst} component and to set the \code{"tzone"} attribute if
%  \code{tz != ""}. If the specified time is invalid (for example
%  \samp{"2010-02-30 08:00"}) all the components of the result are
%  \code{NA}.  (NB: this does means exactly what it says -- if it is an
%  invalid time, not just a time that does not exist in some time zone.)
%  %% One of Master B Diggs moments of infamy
%}
%
%\section{Printing years}{
%  Everyone agrees that years from 1000 to 9999 should be printed with 4
%  digits, but the standards do not define what is to be done outside
%  that range.  For years 0 to 999 most OSes pad with zeros or spaces to
%  4 characters, and Linux outputs just the number.
%  
%  OS facilities will probably not print years before 1 CE (aka 1 AD)
%  \sQuote{correctly} (they tend to assume the existence of a year 0: see
%  \url{https://en.wikipedia.org/wiki/0_(year)}, and some OSes get them
%  completely wrong).  Common formats are \code{-45} and \code{-045}.
%
%  Years after 9999 and before -999 are normally printed with five or
%  more characters.
%
%  Some platforms support modifiers from POSIX 2008 (and others).  On
%  Linux the format \code{"\%04Y"} assures a minimum of four characters
%  and zero-padding.  The internal code (as used on Windows and by
%  default on OS X) uses zero-padding by default, and formats
%  \code{\%_4Y} and \code{\%_Y} can be used for space padding and no
%  padding.
%}
%
%\section{Time zone offsets}{
%  Offsets from GMT (also known as UTC) are part of the conversion
%  between timezones and to/from class \code{"POSIXct"}, but cause
%  difficulties as they often computed incorrectly.
%
%  They conventionally have the opposite sign from time-zone
%  specifications (see \code{\link{Sys.timezone}}): positive values are
%  East of the meridian.  Although there have been time zones with
%  offsets like 00:09:21 (Paris in 1900), and 00:44:30 (Liberia until
%  1972), offsets are usually treated as whole numbers of minutes, and
%  are most often seen in RFC 822 email headers in forms like
%  \code{-0800} (e.g., used on the Pacific coast of the US in winter).
%  
%  Format \code{\%z} can be used for input or output: it is a character
%  string, conventionally plus or minus followed by two digits for
%  hours and two for minutes: the standards say that an empty string
%  should be output if the offset is unknown, but some systems use the
%  offsets for the time zone in use for the current year.
%}
%
%\note{
%  The default formats follow the rules of the ISO 8601 international
%  standard which expresses a day as \code{"2001-02-28"} and a time as
%  \code{"14:01:02"} using leading zeroes as here.  (The ISO form uses no
%  space to separate dates and times: \R does by default.)
%
%  For \code{strptime} the input string need not specify the date
%  completely: it is assumed that unspecified seconds, minutes or hours
%  are zero, and an unspecified year, month or day is the current one.
%  (However, if a month is specified, the day of that month has to be
%  specified by \code{\%d} or \code{\%e} since the current day of the
%  month need not be valid for the specified month.)  Some components may
%  be returned as \code{NA} (but an unknown \code{tzone} component is
%  represented by an empty string).
%
%  If the time zone specified is invalid on your system, what happens is
%  system-specific but it will probably be ignored.
%
%  Remember that in most time zones some times do not occur and some
%  occur twice because of transitions to/from \sQuote{daylight saving}
%  (also known as \sQuote{summer}) time.  \code{strptime} does not
%  validate such times (it does not assume a specific time zone), but
%  conversion by \code{\link{as.POSIXct}} will do so.  Conversion by
%  \code{strftime} and formatting/printing uses OS facilities and may
%  return nonsensical results for non-existent times at DST transitions.
%  
%  Much less comprehensive support for output specifications was provided
%  on Windows before \R 3.1.0.
%  
%  In a C locale \code{\%c} is required to be
%  \code{"\%a \%b \%e \%H:\%M:\%S \%Y"}.  As Windows does not comply (and
%  uses a date format not understood outside N. America), that format is
%  used by \R on Windows in all locales.
%  
%  That \code{\%A \%a \%B \%b} on input match both full and abbreviated names
%  caused problems in some locales prior to \R 3.0.3: e.g.\sspace{}in French on
%  OS X \samp{juillet} was matched by \code{jui}, the abbreviation for
%  June.
%  
%}
%
%\references{
%  International Organization for Standardization (2004, 2000, \dots)
%  \emph{ISO 8601.  Data elements and interchange formats --
%    Information interchange -- Representation of dates and times.}
%  For links to versions available on-line see (at the time of writing)
%  \url{http://dotat.at/tmp/ISO_8601-2004_E.pdf} and
%  \url{http://www.qsl.net/g1smd/isopdf.htm}; for information on the
%  current official version, see \url{http://www.iso.org/iso/iso8601}.
%
%  The POSIX 1003.1 standard, which is in some respects stricter than ISO 8601.
%}
%\seealso{
%  \link{DateTimeClasses} for details of the date-time classes;
%  \link{locales} to query or set a locale.
%
%  Your system's help page on \code{strftime} to see how to specify their
%  formats.  (On some systems, including Windows, \code{strftime} is
%  replaced by more comprehensive internal code.)
%}
%\examples{\donttest{
%## locale-specific version of date()
%format(Sys.time(), "\%a \%b \%d \%X \%Y \%Z")
%
%## time to sub-second accuracy (if supported by the OS)
%format(Sys.time(), "\%H:\%M:\%OS3")
%
%## read in date info in format 'ddmmmyyyy'
%## This will give NA(s) in some locales; setting the C locale
%## as in the commented lines will overcome this on most systems.
%## lct <- Sys.getlocale("LC_TIME"); Sys.setlocale("LC_TIME", "C")
%x <- c("1jan1960", "2jan1960", "31mar1960", "30jul1960")
%z <- strptime(x, "\%d\%b\%Y")
%## Sys.setlocale("LC_TIME", lct)
%z
%
%## read in date/time info in format 'm/d/y h:m:s'
%dates <- c("02/27/92", "02/27/92", "01/14/92", "02/28/92", "02/01/92")
%times <- c("23:03:20", "22:29:56", "01:03:30", "18:21:03", "16:56:26")
%x <- paste(dates, times)
%strptime(x, "\%m/\%d/\%y \%H:\%M:\%S")
%
%## time with fractional seconds
%z <- strptime("20/2/06 11:16:16.683", "\%d/\%m/\%y \%H:\%M:\%OS")
%z # prints without fractional seconds
%op <- options(digits.secs = 3)
%z
%options(op)
%
%## time zones name are not portable, but 'EST5EDT' comes pretty close.
%(x <- strptime(c("2006-01-08 10:07:52", "2006-08-07 19:33:02"),
%               "\%Y-\%m-\%d \%H:\%M:\%S", tz = "EST5EDT"))
%attr(x, "tzone")
%
%## An RFC 822 header (Eastern Canada, during DST)
%strptime("Tue, 23 Mar 2010 14:36:38 -0400",  "\%a, \%d \%b \%Y \%H:\%M:\%S \%z")
%
%## Make sure you know what the abbreviated names are for you if you wish
%## to use them for input (they are matched case-insensitively):
%format(seq.Date(as.Date('1978-01-01'), by = 'day', len = 7), "\%a")
%format(seq.Date(as.Date('2000-01-01'), by = 'month', len = 12), "\%b")
%}}
%\keyword{utilities}
%\keyword{chron}
%
\encoding{UTF8}
