% File src/library/base/man/strtoi.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-10 R Core Team
% Distributed under GPL 2 or later

\name{strtoi}
\alias{strtoi}
\title{Convert Strings to Integers}
\description{
  C 関数 \code{strtol} を使い与えられた底に従い文字列を整数に変換する，
  又は C の規則に従い適切な底を選ぶ．
}
\usage{strtoi(x, base = 0L)}
\arguments{
  \item{x}{文字列，又は \code{\link{as.character}} により
    文字列に変換できる何か．}
  \item{base}{両端を含む 2 と 36 の間にある整数，又はゼロ(既定値)．}
}
\details{
  変換は C のライブラリ関数 \code{strtol} に基づく．

  既定の \code{base = 0L} に対しては，底は \code{x} のその要素の
  文字列表現から選ばれので，異なった要素は異なった底を持てる
  (最初の例を見よ)．底を選ぶ標準の C 規則は8進法
  (\code{x} か \code{X} が続かない接頭辞 \code{0})そして16進法定数
  (接頭辞 \code{0x} 又は \code{0X})は底 \code{8} そして 
  \code{16} と解釈される；全ての他の文字列は底 \code{10} と
  解釈される．

  \code{10} より大きな数字に対しては，文字 \code{a} から \code{z}
  (又は \code{A} から \code{Z}) は \code{10} から \code{35} を
  表す．
}
\value{
  \code{x} と同じ長さの整数ベクトル．整数と解釈出来ない値，又は
  桁溢れする値は \code{\link{NA_integer_}} として返される．
}
\seealso{
  数値文字列に対しては \code{\link{as.integer}} が同様に役に立つ．
}
\examples{
strtoi(c("0xff", "077", "123"))
strtoi(c("ffff", "FFFF"), 16L)
strtoi(c("177", "377"), 8L)
}
\keyword{classes}
\keyword{character}
\keyword{utilities}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/strtoi.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-10 R Core Team
%% Distributed under GPL 2 or later
%
%\name{strtoi}
%\alias{strtoi}
%\title{Convert Strings to Integers}
%\description{
%  Convert strings to integers according to the given base using the C
%  function \code{strtol}, or choose a suitable base following the C rules.
%}
%\usage{strtoi(x, base = 0L)}
%\arguments{
%  \item{x}{a character vector, or something coercible to this by
%    \code{\link{as.character}}.}
%  \item{base}{an integer which is between 2 and 36 inclusive, or zero
%    (default).}
%}
%\details{
%  Conversion is based on the C library function \code{strtol}.
%
%  For the default \code{base = 0L}, the base chosen from the string
%  representation of that element of \code{x}, so different elements can
%  have different bases (see the first example).  The standard C rules
%  for choosing the base are that octal constants (prefix \code{0} not
%  followed by \code{x} or \code{X}) and hexadecimal constants (prefix
%  \code{0x} or \code{0X}) are interpreted as base \code{8} and
%  \code{16}; all other strings are interpreted as base \code{10}.
%
%  For a base greater than \code{10}, letters \code{a} to \code{z} (or
%  \code{A} to \code{Z}) are used to represent \code{10} to \code{35}.
%}
%\value{
%  An integer vector of the same length as \code{x}.  Values which cannot
%  be interpreted as integers or would overflow are returned as
%  \code{\link{NA_integer_}}.
%}
%\seealso{
%  For decimal strings \code{\link{as.integer}} is equally useful.
%}
%\examples{
%strtoi(c("0xff", "077", "123"))
%strtoi(c("ffff", "FFFF"), 16L)
%strtoi(c("177", "377"), 8L)
%}
%\keyword{classes}
%\keyword{character}
%\keyword{utilities}
%
\encoding{UTF8}
