% File src/library/base/man/strtrim.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{strtrim}
\alias{strtrim}
\title{Trim Character Strings to Specified Display Widths}
\description{
  文字列を指定したディスプレイ幅に切り詰める．
}
\usage{
strtrim(x, width)
}
\arguments{
  \item{x}{文字列ベクトル，又は \code{\link{as.character}} で文字列ベクトルに
    変換できるオブジェクト．}
  \item{width}{正整数：\code{x} の長さまでリサイクルされる．}
}
\details{
  \sQuote{幅}は等幅フォントでのディスプレイ幅と解釈される．
  プリント不能な文字(バックスペースやタブのような)がどうなるかは
  実装依存であり，ロケールに依存数かもしれない(例えばそれらは
  カウントに入るかもしれないし除外されるかもしれない)．

  \code{\link{substr}} でなくこの関数を使うことは，文字列ベクトルに
  倍幅文字(例えば中国語/日本語/韓国語)がある場合は重要である．
}
\value{
  (可能な変換の後で) \code{x} と同じ長さと同じ属性の文字列ベクトル．
  

  もし対応する入力が宣言されたエンコーディングを持ち，現在のロケールが
  Latin-1 か UTF-8 ならば，結果の要素は現在のロケールのそれで宣言された
  エンコーディングを持つ(\code{\link{Encoding}} を見よ)．
}

\examples{
strtrim(c("abcdef", "abcdef", "abcdef"), c(1,5,10))
}
\keyword{ character }
\keyword{ utilities }
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/strtrim.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{strtrim}
%\alias{strtrim}
%\title{Trim Character Strings to Specified Display Widths}
%\description{
%  Trim character strings to specified display widths.
%}
%\usage{
%strtrim(x, width)
%}
%\arguments{
%  \item{x}{a character vector, or an object which can be coerced to a
%    character vector by \code{\link{as.character}}.}
%  \item{width}{Positive integer values: recycled to the length of \code{x}.}
%}
%\details{
%  \sQuote{Width} is interpreted as the display width in a monospaced
%  font.  What happens with non-printable characters (such as backspace, tab)
%  is implementation-dependent and may depend on the locale (e.g., they
%  may be included in the count or they may be omitted).
%
%  Using this function rather than \code{\link{substr}} is important when
%  there might be double-width (e.g., Chinese/Japanese/Korean) characters
%  in the character vector.
%}
%\value{
%  A character vector of the same length and with the same attributes
%  as \code{x} (after possible coercion).
%
%  Elements of the result will have the encoding declared as that of
%  the current locale (see \code{\link{Encoding}}) if the corresponding
%  input had a declared encoding and the current locale is either Latin-1
%  or UTF-8.
%}
%
%\examples{
%strtrim(c("abcdef", "abcdef", "abcdef"), c(1,5,10))
%}
%\keyword{ character }
%\keyword{ utilities }
%
\encoding{UTF8}
