% File src/library/datasets/man/ChickWeight.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{ChickWeight}
\docType{data}
\alias{ChickWeight}
\title{ひよこの体重データ}
%%\title{Weight versus age of chicks on different diets}
\description{
  578行と4列のデータフレーム \code{ChickWeight} はひよこの初期成長に関する
  給餌の効果の実験の結果を与える． 
}
\usage{ChickWeight}
\format{
  クラス
  \code{c("nfnGroupedData", "nfGroupedData", "groupedData", "data.frame")}
  のオブジェクトで次の列を含む：
  \describe{
    \item{weight}{
      ひよこの体重を与える数値ベクトル(グラム)．
    }
    \item{Time}{
      測定時の誕生以来の日数を与える数値ベクトル．
    }
    \item{Chick}{
      ひよこに対するユニークな識別子を与える水準
      \code{18} < \dots < \code{48} を持つ順序付き因子．
      
      水準の順序は同じ餌を貰ったひよこでグループ分けし
      それらを同じ餌内で最終体重に応じて順序付ける
      (軽い方から重い方へ)．
    }
    \item{Diet}{
      水準 1, \dots, 4 の因子でどの実験的な餌をひよこが
      与えられたかを指示する．
    }
  }
}
\details{
  ひよこの体重は誕生時とそれから二日置きに20日まで測定された．
  21日目にも測定がされた．4種類のタンパク質飼料に関して四つのグループが
  あった．

  このデータセットは元々パッケージ \code{nlme} の一部であり，
  それはそのグループ化されたクラスに対するメソッド
  (\code{[}, \code{as.data.frame}, \code{plot} そして
  \code{print} を含む)を持つ．
}
\source{
  Crowder, M. and Hand, D. (1990), \emph{Analysis of Repeated Measures},
  Chapman and Hall (example 5.3)

  Hand, D. and Crowder, M. (1996), \emph{Practical Longitudinal Data
    Analysis}, Chapman and Hall (table A.2)

  Pinheiro, J. C. and Bates, D. M. (2000) \emph{Mixed-effects Models in
    S and S-PLUS}, Springer.
}
\seealso{
  このデータセットに当てはめたモデルに対しては \code{\link{SSlogis}}．
}

\examples{\donttest{
require(graphics)
coplot(weight ~ Time | Chick, data = ChickWeight,
       type = "b", show.given = FALSE)
}}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/ChickWeight.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ChickWeight}
%\docType{data}
%\alias{ChickWeight}
%\title{Weight versus age of chicks on different diets}
%\description{
%  The \code{ChickWeight} data frame has 578 rows and 4 columns from an
%  experiment on the effect of diet on early growth of chicks.
%}
%\usage{ChickWeight}
%\format{
%  An object of class
%  \code{c("nfnGroupedData", "nfGroupedData", "groupedData", "data.frame")}
%  containing the following columns:
%  \describe{
%    \item{weight}{
%      a numeric vector giving the body weight of the chick (gm).
%    }
%    \item{Time}{
%      a numeric vector giving the number of days since birth when
%      the measurement was made.
%    }
%    \item{Chick}{
%      an ordered factor with levels
%      \code{18} < \dots < \code{48}
%      giving a unique identifier for the chick.  The ordering of
%      the levels groups chicks on the same diet together and
%      orders them according to their final weight (lightest to
%      heaviest) within diet.
%    }
%    \item{Diet}{
%      a factor with levels 1, \dots, 4 indicating which
%      experimental diet the chick received.
%    }
%  }
%}
%\details{
%  The body weights of the chicks were measured at birth and every
%  second day thereafter until day 20.  They were also measured on day
%  21.  There were four groups on chicks on different protein diets.
%
%  This dataset was originally part of package \code{nlme}, and that has
%  methods (including for \code{[}, \code{as.data.frame}, \code{plot} and
%  \code{print}) for its grouped-data classes.
%}
%\source{
%  Crowder, M. and Hand, D. (1990), \emph{Analysis of Repeated Measures},
%  Chapman and Hall (example 5.3)
%
%  Hand, D. and Crowder, M. (1996), \emph{Practical Longitudinal Data
%    Analysis}, Chapman and Hall (table A.2)
%
%  Pinheiro, J. C. and Bates, D. M. (2000) \emph{Mixed-effects Models in
%    S and S-PLUS}, Springer.
%}
%\seealso{
%  \code{\link{SSlogis}} for models fitted to this dataset.
%}
%
%\examples{\donttest{
%require(graphics)
%coplot(weight ~ Time | Chick, data = ChickWeight,
%       type = "b", show.given = FALSE)
%}}
%\keyword{datasets}
%
%\encoding{UTF8}
%