% File src/library/datasets/man/Titanic.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{Titanic}
\docType{data}
\title{タイタニック号乗客の生存状況データ}
\alias{Titanic}
%%\title{Survival of passengers on the Titanic}
\description{
  このデータセットは
  外洋航路船 \sQuote{タイタニック} の破滅的な処女航海の
  乗員の運命に関する情報を提供し，
  経済状況(クラス)，性別，年齢，そして生存状況について要約する．
}
\usage{Titanic}
\format{
  4変数に関する2201の観測値をクロス集計した4次元配列．
  変数とそれらの水準は次の通りである：

  \tabular{rll}{
    No \tab 名前 \tab 水準\cr
    1 \tab クラス \tab 1st, 2nd, 3rd, Crew\cr
    2 \tab 性別 \tab Male, Female\cr
    3 \tab 年齢 \tab Child, Adult\cr
    4 \tab 生存 \tab No, Yes
  }
}
\details{
  タイタニック号の沈没は有名な出来事であり，それに関する新しい本が
  いまだに出版される．多くのよく知られた事実
  ---一等船客の\sQuote{女性と子供優先}方針に対する割合，
  そして三等船客中の女性と子供
  の救助が完全には成功しなかった
  ---が乗客の様々なクラスに対する生存率に反映している．

  これらのデータは最初イギリスの商業会議所による沈没の
  調査で集められた．
  正確な乗員，救助者そして死亡者に関しては一次的資料間で完全な
  合意がないことを注意する．

  特に部分的には映画 \sQuote{Titanic} の大成功のせいで，
  最近タイタニック号に対する一般的関心が上昇している．
  非常に詳細な乗客に関するデータが今やインターネット上で
  得られる．例えば
  \emph{Encyclopedia Titanica}
  (\url{http://www.rmplc.co.uk/eduweb/sites/phind})．
}
\source{
  Dawson, Robert J. MacG. (1995),
  The \sQuote{Unusual Episode} Data Revisited.
  \emph{Journal of Statistics Education}, \bold{3}.
  \url{https://www.amstat.org/publications/jse/v3n3/datasets.dawson.html}

  この出典はタイタニック号の各乗員の乗船クラス，性別，年齢，
  そして生存状況を記録し，イギリスの商業会議所により最初集められ
  以下に再録されているデータによる：

  British Board of Trade (1990),
  \emph{Report on the Loss of the \sQuote{Titanic} (S.S.)}.
  British Board of Trade Inquiry Report (reprint).
  Gloucester, UK: Allan Sutton Publishing.
}
\examples{
require(graphics)
mosaicplot(Titanic, main = "Survival on the Titanic")
## 子供の高い生存率?
apply(Titanic, c(3, 4), sum)
## 女性の高い生存率?
apply(Titanic, c(2, 4), sum)
## さらなる解析にはパッケージ 'MASS' 中の loglm() を使う
}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/Titanic.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Titanic}
%\docType{data}
%\alias{Titanic}
%\title{Survival of passengers on the Titanic}
%\description{
%  This data set provides information on the fate of passengers on the
%  fatal maiden voyage of the ocean liner \sQuote{Titanic}, summarized according
%  to economic status (class), sex, age and survival.
%}
%\usage{Titanic}
%\format{
%  A 4-dimensional array resulting from cross-tabulating 2201
%  observations on 4 variables.  The variables and their levels are as
%  follows:
%
%  \tabular{rll}{
%    No \tab Name \tab Levels\cr
%    1 \tab Class \tab 1st, 2nd, 3rd, Crew\cr
%    2 \tab Sex \tab Male, Female\cr
%    3 \tab Age \tab Child, Adult\cr
%    4 \tab Survived \tab No, Yes
%  }
%}
%\details{
%  The sinking of the Titanic is a famous event, and new books are still
%  being published about it.  Many well-known facts---from the
%  proportions of first-class passengers to the \sQuote{women and
%    children first} policy, and the fact that that policy was not
%  entirely successful in saving the women and children in the third
%  class---are reflected in the survival rates for various classes of
%  passenger.
%
%  These data were originally collected by the British Board of Trade in
%  their investigation of the sinking.  Note that there is not complete
%  agreement among primary sources as to the exact numbers on board,
%  rescued, or lost.
%
%  Due in particular to the very successful film \sQuote{Titanic}, the last
%  years saw a rise in public interest in the Titanic.  Very detailed
%  data about the passengers is now available on the Internet, at sites
%  such as \emph{Encyclopedia Titanica}
%  (\url{http://www.rmplc.co.uk/eduweb/sites/phind}).
%}
%\source{
%  Dawson, Robert J. MacG. (1995),
%  The \sQuote{Unusual Episode} Data Revisited.
%  \emph{Journal of Statistics Education}, \bold{3}.
%  \url{https://www.amstat.org/publications/jse/v3n3/datasets.dawson.html}
%
%  The source provides a data set recording class, sex, age, and survival
%  status for each person on board of the Titanic, and is based on data
%  originally collected by the British Board of Trade and reprinted in:
%
%  British Board of Trade (1990),
%  \emph{Report on the Loss of the \sQuote{Titanic} (S.S.)}.
%  British Board of Trade Inquiry Report (reprint).
%  Gloucester, UK: Allan Sutton Publishing.
%}
%\examples{
%require(graphics)
%mosaicplot(Titanic, main = "Survival on the Titanic")
%## Higher survival rates in children?
%apply(Titanic, c(3, 4), sum)
%## Higher survival rates in females?
%apply(Titanic, c(2, 4), sum)
%## Use loglm() in package 'MASS' for further analysis ...
%}
%\keyword{datasets}
%
%\encoding{UTF8}
%