% File src/library/datasets/man/crimtab.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{crimtab}
\title{スチューデントの犯罪者データ}
\alias{crimtab}
\docType{data}
%%\title{Student's 3000 Criminals Data}
\description{
  イングランドとウェールズの主要監獄に服役中の20才以上の男性犯罪者3000人のデータ．
}
\usage{crimtab}
\format{
  \code{\link{integer}} カウントの \code{\link{table}} オブジェクトで，
  次元は \eqn{42 \times 22}{42 * 22} で総和 \code{sum(crimtab)} は
  3000．

  42の \code{\link{rownames}} (\code{"9.4"}, \code{"9.5"}, \dots)
  は指の長さの区間の中央値に対応し，
  22の列名(\code{\link{colnames}})
  (\code{"142.24"}, \code{"144.78"}, \dots)は3000名の囚人の
  身長に対応する，下も見よ．
}
\details{
  Student は William Sealy Gosset の匿名である．
  タイトルが
  \emph{Practical Test of the forgoing Equations} の彼の1908年の
  論文の節 VI の冒頭(13ページ)でこう書いている：

  \dQuote{問題を解析的に解くのに成功する前に
    私はそれを経験的に行うことに没頭した．
    使われた題材は W. R. MacDonell
    (\emph{Biometrika}, Vol.\sspace{}I., p.\sspace{}219) の論文からの
    3000人の囚人の身長と左手の中指の測定を含む
    相関表である．測定値は
    3000枚の厚紙に書かれ，それからそれを十分にシャッフルし無作為に
    抽出した．各カードが取り出される度にその番号が本に書きだされ，
    それは従って3000人の囚人のランダムな順序での
    測定値を含む．最後に引き続く4枚のセット---全部で750組---が標本として取られ
    各サンプルの平均，標準偏差，相関が決定された．
    各サンプルの平均と全体の平均の差が
    標本の標準偏差で割られ．節 III の \emph{z} が得られた．}

  表は実際には
  MacDonell(1902) の219ページではなく216頁にある．
  MacDonell の表では中指の長さは
  mm で与えられ身長は フィート/インチ 区間で与えられ．それらは共に
  ここでは cm に変換されている．区間の中央値が使われており，
  例えば MacDonell で \eqn{4' 7''9/16 -- 8''9/16} ならば，我々は
  142.24 を得，これは 2.54*56 = 2.54*(\eqn{4' 8''}) である．

  MacDonell はデータのソースを次のように述べている(178 ページ)：
  \emph{このメモワールの元になっているデータは
  New Scotland Yard の一般計量事務所の Dr Garson の
  好意による．}
  彼は179ページで指摘している：\emph{用紙は無作為に
    事務所の棚の塊から取り出された；従って我々は
    無作為抽出を行っている．}

}
\source{
  \url{http://pbil.univ-lyon1.fr/R/donnees/criminals1902.txt}
  Jean R. Lobry と \enc{Anne-Béatrice}{Anne-Beatrice} Dufour の好意による．
}
\references{
  Garson, J.G. (1900)
  The metric system of identification of criminals, as used in in Great
  Britain and Ireland.
  \emph{The Journal of the Anthropological Institute of Great Britain
    and Ireland} \bold{30}, 161--198.

  MacDonell, W.R. (1902)
  On criminal anthropometry and the identification of criminals.
  \emph{Biometrika} \bold{1}, 2, 177--227.

  Student (1908) The probable error of a mean.
  \emph{Biometrika} \bold{6}, 1--25.
}
\examples{
require(stats)
dim(crimtab)
utils::str(crimtab)
## より良いプリントのため：
local({cT <- crimtab
       colnames(cT) <- substring(colnames(cT), 2, 3)
       pri(cT, zero.print = " ")
})

## スチューデントの実験を繰り返す：

# 1) 3000 個のインチ単位の生データを再構成しスチューデントの論文のように
#    最近接整数に丸める：

(heIn <- round(as.numeric(colnames(crimtab)) / 2.54))
d.hei <- data.frame(height = rep(heIn, colSums(crimtab)))

# 2) データをシャッフル：

set.seed(1)
d.hei <- d.hei[sample(1:3000), , drop = FALSE]

# 3) 各々サイズ4の750組のサンプル：

d.hei$sample <- as.factor(rep(1:750, each = 4))

# 4) 750組のサンプルに対する平均と標準偏差を計算：

h.mean <- with(d.hei, tapply(height, sample, FUN = mean))
h.sd   <- with(d.hei, tapply(height, sample, FUN = sd)) * sqrt(3/4)

# 5) 各標本の平均と全体の平均の差を計算し
#    それから標本の標準偏差で割る：

zobs <- (h.mean - mean(d.hei[,"height"]))/h.sd

# 6) スチューデントの論文のように無限値を +/- 6 で置き換える：

zobs[infZ <- is.infinite(zobs)] # それらの内の 3
zobs[infZ] <- 6 * sign(zobs[infZ])

# 7) 分布をプロット

require(grDevices); require(graphics)
hist(x = zobs, probability = TRUE, xlab = "Student's z",
     col = grey(0.8), border = grey(0.5),
     main = "Distribution of Student's z score  for 'crimtab' data")
}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/crimtab.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{crimtab}
%\alias{crimtab}
%\docType{data}
%\title{Student's 3000 Criminals Data}
%\description{
%  Data of 3000 male criminals over 20 years old undergoing their
%  sentences in the chief prisons of England and Wales.
%}
%\usage{crimtab}
%\format{
%  A \code{\link{table}} object of  \code{\link{integer}} counts, of dimension
%  \eqn{42 \times 22}{42 * 22} with a total count, \code{sum(crimtab)} of
%  3000.
%
%  The 42 \code{\link{rownames}} (\code{"9.4"}, \code{"9.5"}, \dots)
%  correspond to midpoints of intervals of finger lengths
%  whereas the 22 column names (\code{\link{colnames}})
%  (\code{"142.24"}, \code{"144.78"}, \dots) correspond to (body) heights
%  of 3000 criminals, see also below.
%}
%\details{
%  Student is the pseudonym of William Sealy Gosset.
%  In his 1908 paper he wrote (on page 13) at the beginning of section VI
%  entitled \emph{Practical Test of the forgoing Equations}:
%
%  \dQuote{Before I had succeeded in solving my problem analytically,
%    I had endeavoured to do so empirically.  The material used was a
%    correlation table containing the height and left middle finger
%    measurements of 3000 criminals, from a paper by W. R. MacDonell
%    (\emph{Biometrika}, Vol.\sspace{}I., p.\sspace{}219).  The
%    measurements were written 
%    out on 3000 pieces of cardboard, which were then very thoroughly
%    shuffled and drawn at random.  As each card was drawn its numbers
%    were written down in a book, which thus contains the measurements of
%    3000 criminals in a random order.  Finally, each consecutive set of
%    4 was taken as a sample---750 in all---and the mean, standard
%    deviation, and correlation of each sample determined.  The
%    difference between the mean of each sample and the mean of the
%    population was then divided by the standard deviation of the sample,
%    giving us the \emph{z} of Section III.}
%
%  The table is in fact page 216 and not page 219 in MacDonell(1902).
%  In the MacDonell table, the middle finger lengths were given in mm
%  and the heights in feet/inches intervals, they are both converted into
%  cm here.  The midpoints of intervals were used, e.g., where MacDonell
%  has \eqn{4' 7''9/16 -- 8''9/16}, we have 142.24 which is 2.54*56 =
%  2.54*(\eqn{4' 8''}).
%
%  MacDonell credited the source of data (page 178) as follows:
%  \emph{The data on which the memoir is based were obtained, through the
%    kindness of Dr Garson, from the Central Metric Office, New Scotland Yard...}
%  He pointed out on page 179 that : \emph{The forms were drawn at random
%    from the mass on the office shelves; we are therefore dealing with a
%    random sampling.}
%}
%\source{
%  \url{http://pbil.univ-lyon1.fr/R/donnees/criminals1902.txt}
%  thanks to Jean R. Lobry and \enc{Anne-Béatrice}{Anne-Beatrice} Dufour.
%}
%\references{
%  Garson, J.G. (1900)
%  The metric system of identification of criminals, as used in in Great
%  Britain and Ireland.
%  \emph{The Journal of the Anthropological Institute of Great Britain
%    and Ireland} \bold{30}, 161--198.
%
%  MacDonell, W.R. (1902)
%  On criminal anthropometry and the identification of criminals.
%  \emph{Biometrika} \bold{1}, 2, 177--227.
%
%  Student (1908) The probable error of a mean.
%  \emph{Biometrika} \bold{6}, 1--25.
%}
%\examples{
%require(stats)
%dim(crimtab)
%utils::str(crimtab)
%## for nicer printing:
%local({cT <- crimtab
%       colnames(cT) <- substring(colnames(cT), 2, 3)
%       print(cT, zero.print = " ")
%})
%
%## Repeat Student's experiment:
%
%# 1) Reconstitute 3000 raw data for heights in inches and rounded to
%#    nearest integer as in Student's paper:
%
%(heIn <- round(as.numeric(colnames(crimtab)) / 2.54))
%d.hei <- data.frame(height = rep(heIn, colSums(crimtab)))
%
%# 2) shuffle the data:
%
%set.seed(1)
%d.hei <- d.hei[sample(1:3000), , drop = FALSE]
%
%# 3) Make 750 samples each of size 4:
%
%d.hei$sample <- as.factor(rep(1:750, each = 4))
%
%# 4) Compute the means and standard deviations (n) for the 750 samples:
%
%h.mean <- with(d.hei, tapply(height, sample, FUN = mean))
%h.sd   <- with(d.hei, tapply(height, sample, FUN = sd)) * sqrt(3/4)
%
%# 5) Compute the difference between the mean of each sample and
%#    the mean of the population and then divide by the
%#    standard deviation of the sample:
%
%zobs <- (h.mean - mean(d.hei[,"height"]))/h.sd
%
%# 6) Replace infinite values by +/- 6 as in Student's paper:
%
%zobs[infZ <- is.infinite(zobs)] # 3 of them
%zobs[infZ] <- 6 * sign(zobs[infZ])
%
%# 7) Plot the distribution:
%
%require(grDevices); require(graphics)
%hist(x = zobs, probability = TRUE, xlab = "Student's z",
%     col = grey(0.8), border = grey(0.5),
%     main = "Distribution of Student's z score  for 'crimtab' data")
%}
%\keyword{datasets}
%
%\encoding{UTF8}
%