% File src/library/datasets/man/warpbreaks.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{warpbreaks}
\docType{data}
\title{織り糸の切断データ}
\alias{warpbreaks}
%%\title{The Number of Breaks in Yarn during Weaving}
\description{
  このデータは織機毎の縦糸の断線数を与える，ここで
  織機は決まった長さの織り糸に対応する．
}
\usage{warpbreaks}
\format{
  3変数54観測値のデータフレーム．
  \tabular{rlll}{
    \code{[,1]} \tab \code{breaks}  \tab 数値  \tab 断線数\cr
    \code{[,2]} \tab \code{wool}    \tab 因子  \tab 羊毛の種類(A か B)\cr
    \code{[,3]} \tab \code{tension} \tab 因子  \tab 張力のレベル(L, M, H)
  }
  6種類の縦糸のタイプ
  (\code{AL}, \code{AM}, \code{AH}, \code{BL}, \code{BM}, \code{BH})毎に
  9台の織機に関する測定がある．
}
\source{
  Tippett, L. H. C. (1950)
  \emph{Technological Applications of Statistics}.
  Wiley.  Page 106.

}
\references{
  Tukey, J. W. (1977)
  \emph{Exploratory Data Analysis}.
  Addison-Wesley.

  McNeil, D. R. (1977)
  \emph{Interactive Data Analysis}.
  Wiley.
}
\seealso{
  これらのデータを表として表示する方法については \code{\link{xtabs}}．
}
\examples{
require(stats); require(graphics)
summary(warpbreaks)
opar <- par(mfrow = c(1, 2), oma = c(0, 0, 1.1, 0))
plot(breaks ~ tension, data = warpbreaks, col = "lightgray",
     varwidth = TRUE, subset = wool == "A", main = "Wool A")
plot(breaks ~ tension, data = warpbreaks, col = "lightgray",
     varwidth = TRUE, subset = wool == "B", main = "Wool B")
mtext("warpbreaks data", side = 3, outer = TRUE)
par(opar)
summary(fm1 <- lm(breaks ~ wool*tension, data = warpbreaks))
anova(fm1)
}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/warpbreaks.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{warpbreaks}
%\docType{data}
%\alias{warpbreaks}
%\title{The Number of Breaks in Yarn during Weaving}
%\description{
%  This data set gives the number of warp breaks per loom, where a loom
%  corresponds to a fixed length of yarn.
%}
%\usage{warpbreaks}
%\format{
%  A data frame with 54 observations on 3 variables.
%  \tabular{rlll}{
%    \code{[,1]} \tab \code{breaks}  \tab numeric \tab The number of breaks\cr
%    \code{[,2]} \tab \code{wool}    \tab factor  \tab The type of wool (A or B)\cr
%    \code{[,3]} \tab \code{tension} \tab factor  \tab The level of tension (L, M, H)
%  }
%  There are measurements on 9 looms for each of the six types of warp
%  (\code{AL}, \code{AM}, \code{AH}, \code{BL}, \code{BM}, \code{BH}).
%}
%\source{
%  Tippett, L. H. C. (1950)
%  \emph{Technological Applications of Statistics}.
%  Wiley.  Page 106.
%
%}
%\references{
%  Tukey, J. W. (1977)
%  \emph{Exploratory Data Analysis}.
%  Addison-Wesley.
%
%  McNeil, D. R. (1977)
%  \emph{Interactive Data Analysis}.
%  Wiley.
%}
%\seealso{
%  \code{\link{xtabs}} for ways to display these data as a table.
%}
%\examples{
%require(stats); require(graphics)
%summary(warpbreaks)
%opar <- par(mfrow = c(1, 2), oma = c(0, 0, 1.1, 0))
%plot(breaks ~ tension, data = warpbreaks, col = "lightgray",
%     varwidth = TRUE, subset = wool == "A", main = "Wool A")
%plot(breaks ~ tension, data = warpbreaks, col = "lightgray",
%     varwidth = TRUE, subset = wool == "B", main = "Wool B")
%mtext("warpbreaks data", side = 3, outer = TRUE)
%par(opar)
%summary(fm1 <- lm(breaks ~ wool*tension, data = warpbreaks))
%anova(fm1)
%}
%\keyword{datasets}
%
%\encoding{UTF8}
%