% File src/library/datasets/man/zCO2.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-20011 R Core Team
% Distributed under GPL 2 or later

\name{CO2}
\docType{data}
\title{草の二酸化炭素吸収データ}
\alias{CO2}
%%\title{Carbon Dioxide Uptake in Grass Plants}
\description{
  \code{CO2} データフレームは84行と5列を持つ，
  種類 \emph{Echinochloa crus-galli} の草の耐寒性に関する
  実験から得られたデータである．
}
\usage{CO2}
\format{
  クラス
  \code{c("nfnGroupedData", "nfGroupedData", "groupedData", "data.frame")}
  のオブジェクトで次の列を含む：
  \describe{
    \item{Plant}{
      水準
      \code{Qn1} < \code{Qn2} < \code{Qn3} < \dots < \code{Mc1}
      の順序付き因子で，各植物に対するユニークな識別子を与える．
    }
    \item{Type}{
      水準 \code{Quebec} と \code{Mississippi} の因子で
      植物の由来を表す．
    }
    \item{Treatment}{
      水準 \code{nonchilled} と \code{chilled} の因子．
    }
    \item{conc}{
      周囲の二酸化炭素濃度(mL/L)の数値．
    }
    \item{uptake}{
      二酸化炭素の吸収率
      (\eqn{\mu\mbox{mol}/m^2}{umol/m^2} 秒)．
    }
  }
}
\details{
  ケベックの6本の植物とミシシッピの6本の植物の \eqn{CO_2}{CO2} 吸収度が
  様々な周辺 \eqn{CO_2}{CO2} 濃度で測定された．
  各タイプの植物の半数は実験が行われる前に一晩冷やされた．

  このデータセットは元々パッケージ \code{nlme} の一部分であり，
  それはそのグループ化されたクラスに対するメソッドを持つ
  (\code{[}, \code{as.data.frame}, \code{plot} そして
  \code{print} に対するものを含む)．
}
\source{
  Potvin, C., Lechowicz, M. J. and Tardif, S. (1990)
  \dQuote{The statistical analysis of ecophysiological response curves
  obtained from experiments involving repeated measures}, \emph{Ecology},
  \bold{71}, 1389--1400.

  Pinheiro, J. C. and Bates, D. M. (2000)
  \emph{Mixed-effects Models in S and S-PLUS}, Springer.
}
\examples{
require(stats); require(graphics)
\testonly{options(show.nls.convergence=FALSE)}
coplot(uptake ~ conc | Plant, data = CO2, show.given = FALSE, type = "b")
## 最初の植物に対するデータに当てはめ
fm1 <- nls(uptake ~ SSasymp(conc, Asym, lrc, c0),
   data = CO2, subset = Plant == "Qn1")
summary(fm1)
## 各植物に個別に当てはめ
fmlist <- list()
for (pp in levels(CO2$Plant)) {
  fmlist[[pp]] <- nls(uptake ~ SSasymp(conc, Asym, lrc, c0),
      data = CO2, subset = Plant == pp)
}
## 植物による係数をチェック
print(sapply(fmlist, coef), digits = 3)
}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/zCO2.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-20011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{CO2}
%\docType{data}
%\alias{CO2}
%\title{Carbon Dioxide Uptake in Grass Plants}
%\description{
%  The \code{CO2} data frame has 84 rows and 5 columns of data from an
%  experiment on the cold tolerance of the grass species
%  \emph{Echinochloa crus-galli}.
%}
%\usage{CO2}
%\format{
%  An object of class
%  \code{c("nfnGroupedData", "nfGroupedData", "groupedData", "data.frame")}
%  containing the following columns:
%  \describe{
%    \item{Plant}{
%      an ordered factor with levels
%      \code{Qn1} < \code{Qn2} < \code{Qn3} < \dots < \code{Mc1}
%      giving a unique identifier for each plant.
%    }
%    \item{Type}{
%      a factor with levels
%      \code{Quebec}
%      \code{Mississippi}
%      giving the origin of the plant
%    }
%    \item{Treatment}{
%      a factor with levels
%      \code{nonchilled}
%      \code{chilled}
%    }
%    \item{conc}{
%      a numeric vector of ambient carbon dioxide concentrations (mL/L).
%    }
%    \item{uptake}{
%      a numeric vector of carbon dioxide uptake rates
%      (\eqn{\mu\mbox{mol}/m^2}{umol/m^2} sec).
%    }
%  }
%}
%\details{
%  The \eqn{CO_2}{CO2} uptake of six plants from Quebec and six plants
%  from Mississippi was measured at several levels of ambient
%  \eqn{CO_2}{CO2} concentration.  Half the plants of each type were
%  chilled overnight before the experiment was conducted.
%
%  This dataset was originally part of package \code{nlme}, and that has
%  methods (including for \code{[}, \code{as.data.frame}, \code{plot} and
%  \code{print}) for its grouped-data classes.
%}
%\source{
%  Potvin, C., Lechowicz, M. J. and Tardif, S. (1990)
%  \dQuote{The statistical analysis of ecophysiological response curves
%  obtained from experiments involving repeated measures}, \emph{Ecology},
%  \bold{71}, 1389--1400.
%
%  Pinheiro, J. C. and Bates, D. M. (2000)
%  \emph{Mixed-effects Models in S and S-PLUS}, Springer.
%}
%\examples{
%require(stats); require(graphics)
%\testonly{options(show.nls.convergence=FALSE)}
%coplot(uptake ~ conc | Plant, data = CO2, show.given = FALSE, type = "b")
%## fit the data for the first plant
%fm1 <- nls(uptake ~ SSasymp(conc, Asym, lrc, c0),
%   data = CO2, subset = Plant == "Qn1")
%summary(fm1)
%## fit each plant separately
%fmlist <- list()
%for (pp in levels(CO2$Plant)) {
%  fmlist[[pp]] <- nls(uptake ~ SSasymp(conc, Asym, lrc, c0),
%      data = CO2, subset = Plant == pp)
%}
%## check the coefficients by plant
%print(sapply(fmlist, coef), digits = 3)
%}
%\keyword{datasets}
%
%\encoding{UTF8}
%