% File src/library/grDevices/man/chull.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{chull}
\alias{chull}
\title{点集合の凸包}
%%\title{Compute Convex Hull of a Set of Points}
\usage{
chull(x, y = NULL)
}
\arguments{
  \item{x, y}{点の座標ベクトル．
    これはベクトル \code{x} と \code{y}，二列の行列 \code{x}，
    二つの成分を持つリスト等として指定できる，
    \code{\link{xy.coords}} を見よ．}
}
\description{
  指定された点集合の凸包上に位置する点の部分集合を計算する．
}
\details{
  \code{\link{xy.coords}} は点の指定を解釈するのに使われる．
  無現値，\code{NaN} 値は許されない．

  アルゴリズムは Eddy (1977) のそれである．
}
\value{
  凸包上に位置するユニークな点の添字を与える整数ベクトル，
  反時計回り．
  (最初の点は重複点として返される．)
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Eddy, W. F. (1977) A new convex hull algorithm for planar sets.
  \emph{ACM Transactions on Mathematical Software}, \bold{3}, 398--403.

  Eddy, W. F. (1977) Algorithm 523. CONVEX, A new convex hull
  algorithm for planar sets[Z]. \emph{ACM Transactions on
    Mathematical Software}, \bold{3}, 411--412.
}
\seealso{\code{\link{xy.coords}}, \code{\link{polygon}}}

\examples{
X <- matrix(stats::rnorm(2000), ncol = 2)
chull(X)
\dontrun{
  # graphics パッケージからの使用例
  plot(X, cex = 0.5)
  hpts <- chull(X)
  hpts <- c(hpts, hpts[1])
  lines(X[hpts, ])
}
}
\keyword{graphs}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/chull.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{chull}
%\alias{chull}
%\title{Compute Convex Hull of a Set of Points}
%\usage{
%chull(x, y = NULL)
%}
%\arguments{
%  \item{x, y}{coordinate vectors of points. This can be specified as two
%    vectors \code{x} and \code{y}, a 2-column matrix \code{x}, a list
%    \code{x} with two components, etc, see \code{\link{xy.coords}}.}
%}
%\description{
%  Computes the subset of points which lie on the convex hull of the
%  set of points specified.
%}
%\details{
%  \code{\link{xy.coords}} is used to interpret the specification of the
%  points. Infinite, missing and \code{NaN} values are not allowed.
%
%  The algorithm is that given by Eddy (1977).
%}
%\value{
%  An integer vector giving the indices of the unique points lying on the
%  convex hull, in clockwise order.  (The first will be returned for
%  duplicate points.)
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Eddy, W. F. (1977) A new convex hull algorithm for planar sets.
%  \emph{ACM Transactions on Mathematical Software}, \bold{3}, 398--403.
%
%  Eddy, W. F. (1977) Algorithm 523. CONVEX, A new convex hull
%  algorithm for planar sets[Z]. \emph{ACM Transactions on
%    Mathematical Software}, \bold{3}, 411--412.
%}
%\seealso{\code{\link{xy.coords}}, \code{\link{polygon}}}
%
%\examples{
%X <- matrix(stats::rnorm(2000), ncol = 2)
%chull(X)
%\dontrun{
%  # Example usage from graphics package
%  plot(X, cex = 0.5)
%  hpts <- chull(X)
%  hpts <- c(hpts, hpts[1])
%  lines(X[hpts, ])
%}
%}
%\keyword{graphs}
%
%\encoding{UTF-8}
%