% File src/library/grDevices/man/dev2bitmap.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{dev2bitmap}
\title{ビットマップファイルに対するグラフィックスデバイス}
\alias{dev2bitmap}
\alias{bitmap}

%%\title{Graphics Device for Bitmap Files via Ghostscript}
\usage{
bitmap(file, type = "png16m", height = 7, width = 7, res = 72,
       units = "in", pointsize, taa = NA, gaa = NA, \dots)

dev2bitmap(file, type = "png16m", height = 7, width = 7, res = 72,
           units = "in", pointsize, \dots,
           method = c("postscript", "pdf"), taa = NA, gaa = NA)
}
\arguments{
  \item{file}{出力ファイル名，適当な拡張子を持つ．}
  \item{type}{ビットマップのタイプ．}
  \item{width, height}{ディスプレイ領域の次元．}
  \item{res}{解像度，インチあたりのドット数．}
  \item{units}{
    \code{height} と \code{width} で用いるられる単位．
    \code{in} (インチ), \code{px} (pixels), \code{cm} 又は
    \code{mm} が可能．}
  \item{pointsize}{テキストに使われる点のサイズ：
    既定では幅と高さをあたえた上で合理的な何か．}
  \item{\dots}{
    \code{\link{postscript}} か \code{\link{pdf}} に渡される他の引数．}
  \item{method}{
    プロットは \code{\link{postscript}} 又は \code{\link{pdf}}
    を使ってなされるべきか?}
  \item{taa, gaa}{それぞれテキストとグラフィックスに対するアンチエイリアシングの
    普通 4 (最良の効果用)か 2．全てのタイプでサポートされていはいない．}
}
\description{
  \code{bitmap} はグラフィックスファイルを作る．
  \code{dev2bitmap} は現在のグラフィックスデバイスをグラフィックス書式の
  ファイルにコピーする．
}
\details{
  \code{dev2bitmap} は現在のデバイスを
  \code{\link{postscript}} か \code{\link{pdf}} デバイスに
  コピーすることで動作し，そして \code{ghostscript} を使って
  出力ファイルを事後処理する．
  \code{bitmap} は
  \code{postscript} デバイスを使って同様に動作し
  \sQuote{printing} のように出力を事後処理する．

  \code{ghostscript} が必要になる：実行ファイルへのフルパスは
  環境変数 \env{R_GSCMD} で設定できる．
  もしこれが未設定なら
  GhostScript 実行ファイルが自分のパス上で探される：
  Unix 風システムでは \code{"gs"} が使われ，Windows では
  環境変数 \env{GSC} の設定が使われる．さもなければ
  \code{"gswi64c.exe"} そして次に \code{"gswin32c.exe"} が試みられる．

  利用できるタイプは
  \code{ghostscript} のバージョンに依存するが，以下を含む
  可能性が高い，
  \code{"jpeg"}, \code{"jpegcmyk"}, \code{"jpeggray"},
  \code{"tiffcrle"}, \code{"tiffg3"},
  \code{"tiffg32d"}, \code{"tiffg4"}, \code{"tiffgray"}, \code{"tifflzw"},
  \code{"tiffpack"}, \code{"tiff12nc"}, \code{"tiff24nc"}, \code{"tiff32nc"}
  \code{"png16"}, \code{"png16m"}, \code{"png256"}, \code{"png48"},
  \code{"pngmono"}, \code{"pnggray"}, \code{"pngalpha"},
  \code{"bmp16"}, \code{"bmp16m"} \code{"bmp256"}, \code{"bmp32b"},
  \code{"bmpgray"}, \code{"bmpmono"}.

  既定タイプの \code{"png16m"} は24ビットカラーとアンチエイリアシングを
  サポートする．タイプ \code{"png256"} は256色のパレットを使い
  よりコンパクトな表現を与えるかもしれない．
  モノクロのグラフィックスは \code{"pngmono"}を使うことが出来，
  もしアンチエイリアシングが希望なら \code{"pnggray"} を使う．
  透明な背景と変化する透明度を持つプロットは
  \code{"pngalpha"} を使うべきである．

  色付きの TIFF イメージに対しては恐らく \code{"tiff24nc"} を
  使いたくなるであろう．これは
  8ビットチャンネルの RGB (最も普通の TIFF 書式)である．
  リストされた TIFF タイプのどれも透明機能をサポートしていない．
  \code{"tiff32nc"} は8ビットチャンネルの CMYK を使う．
  これはプリンターが必要とするかもしれない．

  単一のイメージを含む書式に対しては，
  \code{Rplots\%03d.png} のようなファイル指定を使うことが出来る：
  これは Ghostscript により解釈される．

  \code{dev2bitmap} に対してもし \code{width} と \code{height} の一つが
  指定されると，他はコピーされるデバイスのアスペクト比を保つように選ばれる．
  既定よりも \code{method = "pdf"} を好む主な理由は
  半透明色の使用を許すことであろう．

  \code{"cra"} のようなピクセルを使って作業する必要のある
  グラフィックスパラメータに対しては，
  既定の解像度 72dpi が常に使われる．

%#ifdef windows
  (Windows 用) 空白を含む \code{file} と \env{R_GSCMD} に対するパスは
  \code{\link{shortPathName}} を\emph{用いて}短い名前にマップされる．
%endif
}
\value{
  無い．
}

\note{
%#ifdef windows
  (Windows 用) \code{bitmap} の使用は一時ファイルを残す
  (ファイル名は \code{Rbit} で始まる)．

%#endif
  \code{type = "pdfwrite"} の使用は簡単なプロットに対しては動作するが，
  勧められない．
  PDFを直接作るには \code{\link{pdf}}，又は
  \code{\link{postscript}} の出力に
  \command{ps2pdf -dAutoRotatePages=/None} を呼び出す：
  この命令はPDFへの変換に対しこれらの関数が行わない最適化がされている．
}

\section{慣例}{
  この節は
  \dQuote{R Internals Manual} 中で設定されているグラフィックスデバイス用の
  慣例の実装を説明している．
  これらのデバイスは基礎にあるデバイスに従うので，
  述べられた \code{res} で眺められた時のものである：

  \itemize{
    \item 既定のデバイスサイズは 7 インチ四方．
    \itemフォントサイズはビッグポイント．
    \item 既定のフォントファミリは(標準の Ghostscript 設定に対しては)
      URW Nimbus Sans．
    \item 線幅は 1/96 インチの倍数で，最少は無い．
    \item 任意の半径の円が許される．
    \item 色は眺める/プリントするアプリケーションにより解釈される．
  }
}

\seealso{
  \code{\link{savePlot}}，これは \code{windows} と
  \code{X11(type = "cairo")} に対して現在のプロットを
  PNG により記録する簡単な方法を与える．

  \code{\link{postscript}}, \code{\link{pdf}}, \code{\link{png}},
  \code{\link{jpeg}}, \code{\link{tiff}} そして  \code{bmp}．

  データ配列の表示には \code{\link{image}} を見よ．
}

\keyword{utilities}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/dev2bitmap.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dev2bitmap}
%\alias{dev2bitmap}
%\alias{bitmap}
%
%\title{Graphics Device for Bitmap Files via Ghostscript}
%\usage{
%bitmap(file, type = "png16m", height = 7, width = 7, res = 72,
%       units = "in", pointsize, taa = NA, gaa = NA, \dots)
%
%dev2bitmap(file, type = "png16m", height = 7, width = 7, res = 72,
%           units = "in", pointsize, \dots,
%           method = c("postscript", "pdf"), taa = NA, gaa = NA)
%}
%\arguments{
%  \item{file}{The output file name, with an appropriate extension.}
%  \item{type}{The type of bitmap.}
%  \item{width, height}{Dimensions of the display region.}
%  \item{res}{Resolution, in dots per inch.}
%  \item{units}{The units in which \code{height} and \code{width} are
%    given.  Can be \code{in} (inches), \code{px} (pixels), \code{cm} or
%    \code{mm}.}
%  \item{pointsize}{The pointsize to be used for text: defaults to
%    something reasonable given the width and height}
%  \item{\dots}{Other parameters passed to \code{\link{postscript}} or
%    \code{\link{pdf}}.}
%  \item{method}{Should the plot be done by \code{\link{postscript}} or
%    \code{\link{pdf}}?}
%  \item{taa, gaa}{Number of bits of antialiasing for text and for graphics
%    respectively.  Usually 4 (for best effect) or 2.  Not supported on
%    all types.}
%}
%\description{
%  \code{bitmap} generates a graphics file.
%  \code{dev2bitmap} copies the current graphics device to a file in a
%  graphics format.
%}
%\details{
%  \code{dev2bitmap} works by copying the current device to a
%  \code{\link{postscript}} or \code{\link{pdf}} device, and
%  post-processing the output file using \code{ghostscript}.
%  \code{bitmap} works in the same way using a \code{postscript} device
%  and post-processing the output as \sQuote{printing}.
%
%  You will need \code{ghostscript}: the full path to the executable can
%  be set by the environment variable \env{R_GSCMD}. If this is unset, a
%  GhostScript executable will be looked for by name on your path: on a
%  Unix alike \code{"gs"} is used, and on Windows the setting of the
%  environment variable \env{GSC} is used, otherwise commands
%  \code{"gswi64c.exe"} then \code{"gswin32c.exe"} are tried.
%
%  The types available will depend on the version of \code{ghostscript},
%  but are likely to include
%  \code{"jpeg"}, \code{"jpegcmyk"}, \code{"jpeggray"},
%  \code{"tiffcrle"}, \code{"tiffg3"},
%  \code{"tiffg32d"}, \code{"tiffg4"}, \code{"tiffgray"}, \code{"tifflzw"},
%  \code{"tiffpack"}, \code{"tiff12nc"}, \code{"tiff24nc"}, \code{"tiff32nc"}
%  \code{"png16"}, \code{"png16m"}, \code{"png256"}, \code{"png48"},
%  \code{"pngmono"}, \code{"pnggray"}, \code{"pngalpha"},
%  \code{"bmp16"}, \code{"bmp16m"} \code{"bmp256"}, \code{"bmp32b"},
%  \code{"bmpgray"}, \code{"bmpmono"}.
%
%  The default type, \code{"png16m"}, supports 24-bit colour and
%  anti-aliasing.  Type \code{"png256"} uses a palette of 256 colours and
%  could give a more compact representation.  Monochrome graphs can use
%  \code{"pngmono"}, or \code{"pnggray"} if anti-aliasing is desired.
%  Plots with a transparent background and varying degrees of
%  transparency should use \code{"pngalpha"}.
%
%  Note that for a colour TIFF image you probably want \code{"tiff24nc"},
%  which is 8-bit per channel RGB (the most common TIFF format).  None of
%  the listed TIFF types support transparency.  \code{"tiff32nc"} uses
%  8-bit per channel CMYK, which printers might require.
%
%  For formats which contain a single image, a file specification like
%  \code{Rplots\%03d.png} can be used: this is interpreted by Ghostscript.
%
%  For \code{dev2bitmap} if just one of \code{width} and \code{height} is
%  specified, the other is chosen to preserve the aspect ratio of the
%  device being copied.  The main reason to prefer \code{method = "pdf"}
%  over the default would be to allow semi-transparent colours to be used.
%
%  For graphics parameters such as \code{"cra"} that need to work in
%  pixels, the default resolution of 72dpi is always used.
%
%#ifdef windows
%  Paths for \code{file} and \env{R_GSCMD} which contain spaces are
%  mapped to short names \emph{via} \code{\link{shortPathName}}.
%#endif
%}
%\value{
%  None.
%}
%
%\note{
%#ifdef windows
%  Use of \code{bitmap} will leave a temporary file (with file name
%  starting \code{Rbit}).
%
%#endif
%  Although using \code{type = "pdfwrite"} will work for simple plots, it
%  is not recommended.  Either use \code{\link{pdf}} to produce PDF
%  directly, or call \command{ps2pdf -dAutoRotatePages=/None} on the
%  output of \code{\link{postscript}}: that command is optimized to do
%  the conversion to PDF in ways that these functions are not.
%}
%
%\section{Conventions}{
%  This section describes the implementation of the conventions for
%  graphics devices set out in the \dQuote{R Internals Manual}.  These
%  devices follow the underlying device, so when viewed at the stated
%  \code{res}:
%
%  \itemize{
%    \item The default device size is 7 inches square.
%    \item Font sizes are in big points.
%    \item The default font family is (for the standard Ghostscript
%    setup) URW Nimbus Sans.
%    \item Line widths are as a multiple of 1/96 inch, with no minimum.
%    \item Circle of any radius are allowed.
%    \item Colours are interpreted by the viewing/printing application.
%  }
%}
%
%\seealso{
%  \code{\link{savePlot}}, which for \code{windows} and
%  \code{X11(type = "cairo")} provides a simple way to record a PNG
%  record of the current plot.
%
%  \code{\link{postscript}}, \code{\link{pdf}}, \code{\link{png}},
%  \code{\link{jpeg}}, \code{\link{tiff}} and  \code{bmp}.
%
%  To display an array of data, see \code{\link{image}}.
%}
%
%\keyword{utilities}
%
%\encoding{UTF-8}
%