% File src/library/grDevices/man/pdf.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2016 R Core Team
% Distributed under GPL 2 or later

\name{pdf}
\title{PDF グラフィックスデバイス}
\alias{pdf}

%%\title{PDF Graphics Device}
%% The definitive doc is the source :-)
\description{
  \code{pdf} は PDF グラフィックスを生成するためのグラフィックスドライバを
  開始する．
}
\usage{
pdf(file = if(onefile) "Rplots.pdf" else "Rplot\%03d.pdf",
    width, height, onefile, family, title, fonts, version,
    paper, encoding, bg, fg, pointsize, pagecentre, colormodel,
    useDingbats, useKerning, fillOddEven, compress)
}
\arguments{
  \item{file}{ファイルの名前を与える文字列．
    もしこれが形式 \code{"|cmd"} ならば出力は
    \command{cmd} で与えられる命令にパイプされる．
    もしこれが \code{NULL} なら外部ファイルは作られない
    (実効的には如何なる描画も行われない)が，
    デバイスは依然問い合わせされるかもしれ無い(例えば，テキストのサイズ)．

    \code{onefile = FALSE} と共に使うためには
    \code{"Rplot\%03d.pdf"} (その場合の既定)のような
    C の整数書式を与える(より詳細は \code{\link{postscript}} を見よ．)

    チルド展開(\code{\link{path.expand}} を見よ)がなされる．
  }
  \item{width, height}{
    インチ単位のグラフィックス領域の幅と高さ．
    既定値は \code{7}．}
  \item{onefile}{論理値：もし真(既定値)なら一つのファイルに複数の図を
    許す．もし偽なら，各頁に対してページ番号を含む名前のファイルを一つ作る．
    既定は \code{TRUE} で，もし
    \code{file} がパイプなら真に強制される．}
  \item{family}{
    使用されるフォントファミリ，
    \code{\link{postscript}} を見よ．既定は \code{"Helvetica"}．}
  \item{title}{
    ファイルの
    \samp{/Title} 欄として埋め込まれるタイトル文字列．
    既定は\cr
    \code{"R Graphics Output"}．}
  \item{fonts}{
    PDF ファイル中に含められる追加フォントに対する
    \R グラフィクスのフォントファミリを指定される文字列．
    既定では \code{NULL}．}
  \item{version}{
    出力を眺めるために必要とされる
    PDF バージョンを記述する文字れる．
    これは最小限で必要なら増加できる(警告と共に)．
    既定は \code{"1.4"} であるが，\sQuote{詳細}節を見よ．}
  \item{paper}{目標の用紙サイズ．
    選択は \code{"a4"}, \code{"letter"}, \code{"legal"} (又は \code{"us"})
    そして \code{"executive"} (そしてこれらは大文字化出来る)，又は
    回転(\sQuote{ランドスケープ})に対しては \code{"a4r"}
    と \code{"USr"}．既定値は \code{"special"} であり，これは \code{width}
    と \code{height} が用紙サイズを指定する．
    \code{"default"} も選択できる：もしこれが選択されると，
    用紙サイズはオプションもしこれが設定されていれば
    \code{"papersize"} で，もしこれが未設定か空ならば
    \code{"a4"} とされる．既定は \code{"special"}．
  }
  \item{encoding}{
    エンコード用のファイルの名前．
    詳細は \code{\link{postscript}} を見よ．
    既定は \code{"default"}．}
  \item{bg}{使用される初期背景色．
    既定は \code{"transparent"}．}
  \item{fg}{使用される初期前景色．
   既定は \code{"black"}．}
  \item{pointsize}{
    使用される既定のポイントサイズ．
    厳密に言えばこれは 1 インチの 1/72 であるが，近似的なポイントである．
    既定は \code{12}．}
  \item{pagecentre}{
    論理値：デバイス領域は頁の中心に置くか? --
    \code{paper != "special"} に対してだけ関係する．
    既定は \code{TRUE}．}
  \item{colormodel}{
    色モデルを記述する文字列文字列：
    現在許される値は
    \code{"srgb"}, \code{"gray"} (又は \code{"grey"}) そして \code{"cmyk"}．
    既定は \code{"srgb"}．\sQuote{色モデル}節を見よ．}
  \item{useDingbats}{論理値．小さな円は
    Dingbats フォントを使い描くべきか?
    既定は \code{TRUE} でより小さくて見栄えの良い出力を作る．
    これを \code{FALSE} に設定することは
    壊れた PDF ビューアーによるフォント表示を応急処置できる：
    このフォントは
    全ての PDF ビューアーで使えることが保証されている14のうちの一つであるが，
    この保証は常に尊重されるわけではない．
%#ifdef unix
    (Unix の場合) 幾つかのビューアーに対する可能な処置については\sQuote{注意}
    節を見よ．
%#endif
    }
  \item{useKerning}{論理値．
    テキストの設定と文字列幅の計算中にカーニング補正を含めるべきか?
    既定は \code{TRUE}．}
  \item{fillOddEven}{
    多角形の塗りつぶしモードを制御する論理値：
    詳細は \code{\link{polygon}} を見よ．既定値は \code{FALSE}．}
  \item{compress}{
    論理値．PDF ストリームは Flate 圧縮で生成されるべきか?
    既定は \code{TRUE}．}
}
\details{
  \code{file} を除く全ての引数は
  \code{\link{pdf.options}()} で与えられる既定値を持つ．
  究極の既定値は引数節で引用されている．

  \code{pdf()} はファイル \code{file} を開き，任意の要求される
  グラフィクスのプロットに必要な PDF 命令はそのファイルに送られる．

  \code{file} 引数は
  \code{\link{sprintf}} が使うような C 整数書式として解釈
  され，ページ番号が整数引数になる．
  既定値はファイル \file{Rplot001.pdf}, \dots, \file{Rplot999.pdf},
  \file{Rplot1000.pdf}, \dots を与える．

  \code{family} 引数は
  デバイスに対する初期/既定フォントとしての PDF 個通のフォントファミリを
  指定するのに使える．
  もし追加のフォントファミリが使われるのなら，それらは
  \code{fonts} 引数に含められるべきである．

  もしデバイス独立な \R グラフィクスのフォントファミリが
  指定されると
  (例えば graphics パッケージ中の \code{par(family = )})，
  PDF デバイスは
  \R グラフィクスフォントファミリを
  PDF 固有のフォントファミリ記述に変換するのに
  PostScript のフォントマッピングを利用する．
  (\code{\link{pdfFonts}} に対するドキュメントを見よ．)

  このデバイスは PDF ファイル中にフォントを埋め込ま\emph{ない}ので，
  任意の PDF ビューア中で利用できると仮定出来る
  フォントファミリにマッピングするのが簡単である：
  \code{"Times"}(\code{"serif"} と同値)，
  \code{"Helvetica"} (\code{"sans"} と同値) そして
  \code{"Courier"} (\code{"mono"} と同値)．
  他のフォントも指定できるかもしれないが，
  これらのフォントがシステムで
  利用できることを保証するのはユーザの責任であり，
  サードパーティーのソフトウェア
  (例えば Ghostscript) は PDF が他のドキュメント(例えば LaTeX)ni
  含められることが出来るようにフォントの埋め込みを要求するかもしれない：
  \code{\link{embedFonts}} を見よ．
  \code{\link{postscript}} に対して説明された URW に基づくファミリは
  (Unix では)
  URW フォントを使う設定のビューアーで使うことが出来る，これは
  \code{xpdf} や Ghostscript では普通である．
  (Windows では) URW フォントを使う GSView のような
  ビューアで使うことが出来る．
  \code{\link{embedFonts}} は Ghostscript を利用するので，それは
  他のビューアで使うために
  URW ベースのファミリを埋め込むことが出来なければならない．

  内部コードはドライバー間で共有されるため，
  エンコーディングに関する詳細は \code{\link{postscript}} を見よ．
  ネイティブの PDF エンコーディングはファイル \file{PDFDoc.enc} 中に
  与えられている．

  作られた PDF はかなり単純であり，
  各ページは単一のストリーム
  (既定では圧縮されもしかするとラスタ―イメージへの参照を持つ)．
  \R のグラフィクスモデルはドライバのインタフェイスのレベルでは
  グラフィクスオブジェクトを区別しない．

  \code{version} 引数は作成された PDF のバージョンを宣言する．
  バージョンは圧縮が使われているときは少なくとも 1.2，
  半透明な出力が使われるならば 1.4，そして
  CID フォントを使うならば 1.3 でなければならない：
  もしこれらの特徴のどれかが使われるならばバージョン番号は
  増やされる(警告と共に)．(PDF 1.4 は最初
  2001年に Acrobat 5 でサポートされた；これが現在のビューアーで
  サポートされていないことは非常にありそうもない．)

  \code{par(lwd = )} で制御される線幅は
  1/96 インチの倍数である．
  inch.  1 未満の倍数は許されない．
  \code{cex = 1} と共に使われる \code{pch = "."} は
  側面が 1/72 インチの正方形に対応し，
  また \code{"cra"} のようなグラフィクスパラメータに対する
  \sQuote{ピクセル}サイズである．

  \code{paper} 引数はファイル中の \samp{/MediaBox} 項目を設定し，
  既定値は \code{width} 対 \code{height} である．
  もしこれが
  \code{"special"} 以外の何かに設定されると，指定されたサイズのデバイス領域は
  (既定で)用紙サイズで与えられる矩形の中心に置かれる：
  もし \code{width} か \code{height} が
  \code{0.1} 未満か合計で
  0.5 インチのマージンを与えるには大き過ぎる時は，
  これは対応する用紙の次元から
  0.5 を引いたものにリセットされる．
  従ってもし
  既定の \code{\link{postscript}} の挙動が欲しければ，
  デバイス領域を 0.25 インチの余白を持つランドスケープの A4
  上にデバイス領域をセンタリングするには
  \code{pdf(paper = "a4r", width = 0, height = 0)} を使う．

  背景色が完全に透明
  (初期既定値がそうであるように)ならば，作られた PDF は背景を
  塗らない．
  殆どの PDF ビューアーは白いキャンバスを使うので
  目に見える効果は背景があたかも白いようになることである．
  しかしながら，これは色付きの紙へのプリントではそうではない．
}

\section{色モデル}{
  既定の色モデル(\code{"srgb"})は sRGB である．モデル \code{"gray"}
  (又は \code{"grey"}) は sRGB 色を知覚される光度
  (緑側にかたよる)を利用してグレイスケールに変換する．
  \code{"cmyk"} は CMYK 色空間に出力する．
  sRGB から CMYK への最も簡単な変換が使われ
  (\url{https://en.wikipedia.org/wiki/CMYK_color_model#Mapping_RGB_to_CMYK})，
  そしてラスタ―イメージは RGB で出力される．

  後方互換性から利用可能なモデルは
  \code{"rgb"} で，未調整の
  RGB を使い 2.13.0 以前の \R の同名のモデルに対応する．
  ある種のビューアーはこの色空間で sRGB よりもある種のプロットを
  速く作成し，プロットファイルはより小さくなる.
}

\section{慣例}{
  この節は \dQuote{R Internals Manual} 中で設定されているグラフィックス
  デバイスに対する.慣例の実装を説明する

  \itemize{
    \item 既定のデバイスは 7 インチ四方．
    \item フォントのサイズはビッグポイント．
    \item 既定のフォントは Helvetica．
    \item 線幅は 1/96 インチの倍数で，最小値 0.01 が強制される．
    \item 任意の半径の円が許される．
      \code{useDingbats = FALSE} で無い限り，10 ビッグポイント未満の不透明の円
      は Dingbats フォントの文字 108 を用いて描画される：
      全ての半透明とより大きな円は各象限で
      \enc{Bézier}{Bezier} 曲線を用いる．
    \item 色は既定で sRGB として指定される．
  }

  非常に小さな線幅に対しては，線種は実線に強制されるかもしれない．
}

\section{プリント}{
  Windows を除いては
  \code{pdf} から直接に次のようにしてプリントすることが可能である
  (これは CUPS プリントシステムに対して適当である)：
\preformatted{    pdf("|lp -o landscape", paper = "a4r")}
  これは \code{onefile = TRUE} を強制する．
}

\note{
  PDF の出力関して問題が見られれば，問題は \R よりもビューアーに
  問題がある可能性が高いことを忘れない欲しい．
  もし可能ならば別のビューアーを試みよう．
  ビューアーが欠陥をもつ症状はイメージのプロット上の見かけ上のグリッド
  (もし可能ならグラフィクスのアンチエイリアシングをオフにしておく)
  とテキスト中の欠損又は不正確なグリフである
  (ビューアは黙ってフォントの置き換えを行う)．

  不幸なことに殆どの
  Linux と OS X システムの既定ビューアーはこれらの問題を持ち，
  グラフィクスのアンチエイリアシングをオフにする明白な方法はない．

  Acrobat Reader はフォントの置換えを行わずむしろ
  それらを multiple-master フォントから模倣する．
  これは文字の不正確なセンタリングで見ることが出来る，例えば
  Helvetica の掛算よ除算記号．
  これは可能ならば埋め込みにより克服できる．
  殆どの他のビューアーはフォントを置き換える，例えば
  標準の Helvetica と Times フォントに対して \sspace{}URW フォントを使い，
  これらもしばしば真のフォントとは異なるフォントメトリックを持つ．

  Acrobat Reader は
  \sQuote{フォントパック}で拡張することが出来，これらは
  Latin-1 以外のエンコーディングをフルに使うために必要である
  (必要に応じてダウンロード出来るように提供されているが)．

  ある種の Unix システムでは既定のプロット文字
  \code{pch = 1} はある PDF ビューアーでは不正確に
  文字 \code{"q"} として表示された．
  (これらは
  \samp{poppler} の PDF レンダリングライブラリに基づくビューアー
  のように見える．
  これはフォント名のシステムで使うそれらへの不正確か不完全なマッピングに
  基づくかもしれない．
  次の行を
  \file{~/.fonts.conf} 又は \file{/etc/fonts/local.conf} に加えることで
  この問題を克服できるかもしれない，これは影響を受けるシステムで
  概ね訂正されているが．
\preformatted{<fontconfig>
<alias binding="same">
  <family>ZapfDingbats</family>
  <accept><family>Dingbats</family></accept>
</alias>
</fontconfig>
}
  \sQuote{fontconfig} を使ったビューアーのシンボルフォントに関する問題の
  応急措置は
  \code{\link{X11}} に対するヘルプの\sQuote{Cairo フォント}の節に
  与えられている．

  Windows では TeXworks PDF ビューアーが
  Dingbats (例えば\sspace{}\code{pch = 1} で使われる)を正確に表示するのに
  失敗するものの一つである．
  他のプラットフォームでは問題は不正確な出力である一方，
  Windows ではポイントは黙って省略される：
  しかしながら最近のバージョンは Dingbats を表示できるようである．

  Firefox 19 とそれ以降に含まれる \command{pdf.js} ビューアー中には
  異なったフォントのバグがある：
  これは Dingbats をシンボルフォントにマップし，従って
  \code{pch = 1} のようなシンボルをラムダとして表示する．
}

\seealso{
  \code{\link{pdfFonts}}, \code{\link{pdf.options}},
  \code{\link{embedFonts}},
  \code{\link{Devices}},
  \code{\link{postscript}}.

%#ifdef unix
  (Unix 用) PDF を生成できる他のデバイスに対しては \code{\link{cairo_pdf}} と
  (OS X のみ) \code{\link{quartz}}．
%#endif
%#ifdef windows
  (Windows 用) PDF を生成できる他のデバイスに対しては \code{\link{cairo_pdf}} と
  (OS X のみ) \code{\link{quartz}}．
%#endif

  フォントファミリとエンコーディング，そして特に
  非 Latin-1 エンコーディングでのテキストとフォントの埋め込みについては
  以下により詳細がある

  Paul Murrell and Brian Ripley (2006) Non-standard fonts in PostScript
  and PDF graphics. \emph{R News}, 6(2):41--47.
  \url{https://www.r-project.org/doc/Rnews/Rnews_2006-2.pdf}.
}
\examples{
\donttest{
## エンコーディングのためのテスト関数
TestChars <- function(encoding = "ISOLatin1", ...)
{
    pdf(encoding = encoding, ...)
    par(pty = "s")
    plot(c(-1,16), c(-1,16), type = "n", xlab = "", ylab = "",
         xaxs = "i", yaxs = "i")
         title(paste("Centred chars in encoding", encoding))
    grid(17, 17, lty = 1)
    for(i in c(32:255)) {
        x <- i \%\% 16
        y <- i \%/\% 16
        points(x, y, pch = i)
    }
    dev.off()
}
## 多くの警告が出る．
TestChars("ISOLatin2")
## これは古いビューアーでは正しく読めない．
TestChars("ISOLatin2", family = "URWHelvetica")
## gs に基づくビューアー，そしてしばしば xpdf では正しく動作する．
}}
\keyword{device}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/pdf.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{pdf}
%\alias{pdf}
%
%\title{PDF Graphics Device}
%%% The definitive doc is the source :-)
%\description{
%  \code{pdf} starts the graphics device driver for producing PDF
%  graphics.
%}
%\usage{
%pdf(file = if(onefile) "Rplots.pdf" else "Rplot\%03d.pdf",
%    width, height, onefile, family, title, fonts, version,
%    paper, encoding, bg, fg, pointsize, pagecentre, colormodel,
%    useDingbats, useKerning, fillOddEven, compress)
%}
%\arguments{
%  \item{file}{a character string giving the name of the file.
%    If it is of the form \code{"|cmd"}, the output is piped to the
%    command given by \command{cmd}.  If it is \code{NULL},
%    then no external file is created (effectively, no drawing occurs),
%    but the device may still be queried (e.g., for size of text).
%
%    For use with \code{onefile = FALSE} give a C integer format such
%    as \code{"Rplot\%03d.pdf"} (the default in that case).
%    (See \code{\link{postscript}} for further details.)
%
%    Tilde expansion (see \code{\link{path.expand}}) is done.
%  }
%  \item{width, height}{the width and height of the graphics region in
%    inches.  The default values are \code{7}.}
%  \item{onefile}{logical: if true (the default) allow multiple figures
%    in one file.  If false, generate a file with name containing the page
%    number for each page.  Defaults to \code{TRUE}, and forced to true
%    if \code{file} is a pipe.}
%  \item{family}{the font family to be used, see
%    \code{\link{postscript}}.  Defaults to \code{"Helvetica"}.}
%  \item{title}{title string to embed as the \samp{/Title} field in the
%    file.  Defaults to \code{"R Graphics Output"}.}
%  \item{fonts}{a character vector specifying \R graphics font family
%    names for additional fonts which will be included in the PDF file.
%    Defaults to \code{NULL}.}
%  \item{version}{a string describing the PDF version that will be
%    required to view the output.  This is a minimum, and will be
%    increased (with a warning) if necessary.  Defaults to \code{"1.4"},
%    but see \sQuote{Details}.}
%  \item{paper}{the target paper size.  The choices are
%    \code{"a4"}, \code{"letter"}, \code{"legal"} (or \code{"us"}) and
%    \code{"executive"} (and these can be capitalized), or \code{"a4r"}
%    and \code{"USr"} for rotated (\sQuote{landscape}).
%    The default is \code{"special"}, which means that the \code{width}
%    and \code{height} specify the paper size.  A further choice is
%    \code{"default"}; if this is selected, the
%    papersize is taken from the option \code{"papersize"}
%    if that is set and as \code{"a4"} if it is unset or empty.
%    Defaults to \code{"special"}.
%  }
%  \item{encoding}{the name of an encoding file.  See
%    \code{\link{postscript}} for details.  Defaults to \code{"default"}.}
%  \item{bg}{the initial background color to be used.  Defaults to
%    \code{"transparent"}.}
%  \item{fg}{the initial foreground color to be used.  Defaults to
%   \code{"black"}.}
%  \item{pointsize}{the default point size to be used.  Strictly
%    speaking, in bp, that is 1/72 of an inch, but approximately in
%    points.  Defaults to \code{12}.}
%  \item{pagecentre}{logical: should the device region be centred on the
%    page? -- is only relevant for \code{paper != "special"}.
%    Defaults to \code{TRUE}.}
%  \item{colormodel}{a character string describing the color model:
%    currently allowed values are \code{"srgb"}, \code{"gray"} (or
%    \code{"grey"}) and \code{"cmyk"}.  Defaults to \code{"srgb"}.  See section
%    \sQuote{Color models}.}
%  \item{useDingbats}{logical.  Should small circles be rendered
%    \emph{via} the Dingbats font?  Defaults to \code{TRUE}, which produces
%    smaller and better output.  Setting this to \code{FALSE} can work
%    around font display problems in broken PDF viewers: although this
%    font is one of the 14 guaranteed to be available in all PDF viewers,
%    that guarantee is not always honoured.
%#ifdef unix
%    See the \sQuote{Note} for a possible fix for some viewers.
%#endif
%    }
%  \item{useKerning}{logical.  Should kerning corrections be included in
%    setting text and calculating string widths?  Defaults to \code{TRUE}.}
%  \item{fillOddEven}{logical controlling the polygon fill mode:  see
%    \code{\link{polygon}} for details.  Defaults to \code{FALSE}.}
%  \item{compress}{logical.  Should PDF streams be generated with Flate
%    compression?  Defaults to \code{TRUE}.}
%}
%\details{
%  All arguments except \code{file} default to values given by
%  \code{\link{pdf.options}()}.  The ultimate defaults are quoted in the
%  arguments section.
%
%  \code{pdf()} opens the file \code{file} and the PDF commands needed to
%  plot any graphics requested are sent to that file.
%
%  The \code{file} argument is interpreted as a C integer format as used
%  by \code{\link{sprintf}}, with integer argument the page number.
%  The default gives files \file{Rplot001.pdf}, \dots, \file{Rplot999.pdf},
%  \file{Rplot1000.pdf}, \dots.
%
%  The \code{family} argument can be used to specify a PDF-specific
%  font family as the initial/default font for the device.  If additional
%  font families are to be used they should be included in the
%  \code{fonts} argument.
%
%  If a device-independent \R graphics font family is specified (e.g., via
%  \code{par(family = )} in the graphics package), the PDF device makes use
%  of the PostScript font mappings to convert the \R graphics font family
%  to a PDF-specific font family description.  (See the
%  documentation for \code{\link{pdfFonts}}.)
%
%  This device does \emph{not} embed fonts in the PDF file, so it is only
%  straightforward to use mappings to the font families that can be
%  assumed to be available in any PDF viewer: \code{"Times"}
%  (equivalently \code{"serif"}), \code{"Helvetica"} (equivalently
%  \code{"sans"}) and \code{"Courier"} (equivalently \code{"mono"}).
%  Other families may be specified, but it is the user's responsibility
%  to ensure that these fonts are available on the system and third-party
%  software (e.g., Ghostscript) may be required to embed the fonts so
%  that the PDF can be included in other documents (e.g., LaTeX): see
%  \code{\link{embedFonts}}.  The URW-based families described for
%  \code{\link{postscript}} can be used with viewers
%#ifdef unix
%  set up to use URW fonts, which is usual with those based on
%  \code{xpdf} or Ghostscript.
%#endif
%#ifdef windows
%  such as GSView which utilise URW fonts.
%#endif
%  Since \code{\link{embedFonts}} makes use of Ghostscript, it should be
%  able to embed the URW-based families for use with other viewers.
%
%  See \code{\link{postscript}} for details of encodings, as the internal
%  code is shared between the drivers.  The native PDF encoding is given
%  in file \file{PDFDoc.enc}.
%
%  The PDF produced is fairly simple, with each page being represented as
%  a single stream (by default compressed and possibly with references to
%  raster images).  The \R graphics model does not distinguish graphics
%  objects at the level of the driver interface.
%
%  The \code{version} argument declares the version of PDF that gets
%  produced.  The version must be at least 1.2 when compression is used,
%  1.4 for semi-transparent output to be understood, and at least 1.3 if
%  CID fonts are to be used: if any of these features are used the
%  version number will be increased (with a warning).  (PDF 1.4 was first
%  supported by Acrobat 5 in 2001; it is very unlikely not to be
%  supported in a current viewer.)
%
%  Line widths as controlled by \code{par(lwd = )} are in multiples of
%  1/96 inch.  Multiples less than 1 are allowed.  \code{pch = "."} with
%  \code{cex = 1} corresponds to a square of side 1/72 inch, which is
%  also the \sQuote{pixel} size assumed for graphics parameters such as
%  \code{"cra"}.
%
%  The \code{paper} argument sets the \samp{/MediaBox} entry in the file,
%  which defaults to \code{width} by \code{height}.  If it is set to
%  something other than \code{"special"}, a device region of the
%  specified size is (by default) centred on the rectangle given by the
%  paper size: if either \code{width} or \code{height} is less
%  than \code{0.1} or too large to give a total margin of 0.5 inch, it is
%  reset to the corresponding paper dimension minus 0.5.  Thus if you
%  want the default behaviour of \code{\link{postscript}} use
%  \code{pdf(paper = "a4r", width = 0, height = 0)} to centre the device region
%  on a landscape A4 page with 0.25 inch margins.
%
%  When the background colour is fully transparent (as is the initial
%  default value), the PDF produced does not paint the background.  Most
%  PDF viewers will use a white canvas so the visual effect is if the
%  background were white.  This will not be the case when printing onto
%  coloured paper, though.
%}
%
%\section{Color models}{
%  The default color model (\code{"srgb"}) is sRGB.  Model \code{"gray"}
%  (or \code{"grey"}) maps sRGB colors to greyscale using perceived
%  luminosity (biased towards green).  \code{"cmyk"} outputs in CMYK
%  colorspace.  The simplest possible conversion from sRGB to CMYK is
%  used
%  (\url{https://en.wikipedia.org/wiki/CMYK_color_model#Mapping_RGB_to_CMYK}),
%  and raster images are output in RGB.
%
%  Also available for backwards compatibility is model \code{"rgb"} which
%  uses uncalibrated RGB and corresponds to the model used with that name
%  in \R prior to 2.13.0.  Some viewers may render some plots in that
%  colorspace faster than in sRGB, and the plot files will be smaller.
%}
%
%\section{Conventions}{
%  This section describes the implementation of the conventions for
%  graphics devices set out in the \dQuote{R Internals Manual}.
%
%  \itemize{
%    \item The default device size is 7 inches square.
%    \item Font sizes are in big points.
%    \item The default font family is Helvetica.
%    \item Line widths are as a multiple of 1/96 inch, with a minimum
%    of 0.01 enforced.
%    \item Circles of any radius are allowed.  Unless \code{useDingbats =
%      FALSE}, opaque circles of less than 10 big points radius are
%    rendered using char 108 in the Dingbats font: all semi-transparent
%    and larger circles using a \enc{Bézier}{Bezier} curve for each
%    quadrant.
%    \item Colours are by default specified as sRGB.
%  }
%
%  At very small line widths, the line type may be forced to solid.
%}
%
%\section{Printing}{
%  Except on Windows it is possible to print directly from \code{pdf} by
%  something like (this is appropriate for a CUPS printing system):
%\preformatted{    pdf("|lp -o landscape", paper = "a4r")}
%  This forces \code{onefile = TRUE}.
%}
%
%\note{
%  If you see problems with PDF output, do remember that the problem is
%  much more likely to be in your viewer than in \R.  Try another
%  viewer if possible.  Symptoms for which the viewer has been at fault
%  are apparent grids on image plots (turn off graphics anti-aliasing
%  in your viewer if you can) and missing or incorrect glyphs in text
%  (viewers silently doing font substitution).
%
%  Unfortunately the default viewers on most Linux and OS X systems
%  have these problems, and no obvious way to turn off graphics anti-aliasing.
%
%  Acrobat Reader does not use the fonts specified but rather emulates
%  them from multiple-master fonts.  This can be seen in imprecise
%  centering of characters, for example the multiply and divide signs in
%  Helvetica.  This can be circumvented by embedding fonts where
%  possible.  Most other viewers substitute fonts, e.g.\sspace{}URW fonts
%  for the standard Helvetica and Times fonts, and these too often have
%  different font metrics from the true fonts.
%
%  Acrobat Reader can be extended by \sQuote{font packs}, and these will
%  be needed for the full use of encodings other than Latin-1 (although
%  they may be offered for download as needed).
%
%#ifdef unix
%  On some systems the default plotting character \code{pch = 1} was
%  displayed in some PDF viewers incorrectly as a \code{"q"}
%  character.  (These seem to be viewers based on the \samp{poppler} PDF
%  rendering library).  This may be due to incorrect or incomplete mapping
%  of font names to those used by the system.  Adding the following lines
%  to \file{~/.fonts.conf} or \file{/etc/fonts/local.conf} may circumvent
%  this problem, although this has largely been corrected on the affected
%  systems.
%\preformatted{<fontconfig>
%<alias binding="same">
%  <family>ZapfDingbats</family>
%  <accept><family>Dingbats</family></accept>
%</alias>
%</fontconfig>
%}
%  Some further workarounds for problems with symbol fonts on
%  viewers using \sQuote{fontconfig} are given in the \sQuote{Cairo Fonts}
%  section of the help for \code{\link{X11}}.
%#endif
%#ifdef windows
%  The TeXworks PDF viewer was one of those which has been seen to fail to
%  display Dingbats (used by e.g.\sspace{}\code{pch = 1}) correctly.
%  Whereas on other platforms the problems seen were incorrect output, on
%  Windows points were silently omitted: however recent versions seem to
%  manage to display Dingbats.
%#endif
%
%  There is a different font bug in the \command{pdf.js} viewer included
%  in Firefox 19 and later: that maps Dingbats to the Symbol font and so
%  displays symbols such \code{pch = 1} as lambda.
%}
%
%\seealso{
%  \code{\link{pdfFonts}}, \code{\link{pdf.options}},
%  \code{\link{embedFonts}},
%  \code{\link{Devices}},
%  \code{\link{postscript}}.
%
%#ifdef unix
%  \code{\link{cairo_pdf}} and (on OS X only) \code{\link{quartz}}
%  for other devices that can produce PDF.
%#endif
%#ifdef windows
%  \code{\link{cairo_pdf}} and (on OS X only) \code{quartz}
%  for other devices that can produce PDF.
%#endif
%
%  More details of font families and encodings and especially handling
%  text in a non-Latin-1 encoding and embedding fonts can be found in
%
%  Paul Murrell and Brian Ripley (2006) Non-standard fonts in PostScript
%  and PDF graphics. \emph{R News}, 6(2):41--47.
%  \url{https://www.r-project.org/doc/Rnews/Rnews_2006-2.pdf}.
%}
%\examples{
%\donttest{
%## Test function for encodings
%TestChars <- function(encoding = "ISOLatin1", ...)
%{
%    pdf(encoding = encoding, ...)
%    par(pty = "s")
%    plot(c(-1,16), c(-1,16), type = "n", xlab = "", ylab = "",
%         xaxs = "i", yaxs = "i")
%         title(paste("Centred chars in encoding", encoding))
%    grid(17, 17, lty = 1)
%    for(i in c(32:255)) {
%        x <- i \%\% 16
%        y <- i \%/\% 16
%        points(x, y, pch = i)
%    }
%    dev.off()
%}
%## there will be many warnings.
%TestChars("ISOLatin2")
%## this does not view properly in older viewers.
%TestChars("ISOLatin2", family = "URWHelvetica")
%## works well for viewing in gs-based viewers, and often in xpdf.
%}}
%\keyword{device}
%
%\encoding{UTF-8}
%