% File src/library/grDevices/man/postscript.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2016 R Core Team
% Distributed under GPL 2 or later

\name{postscript}
\title{ポストスクリプトグラフィックス}
\alias{postscript}
\alias{.ps.prolog}
\concept{encoding}
%%\title{PostScript Graphics}
\description{
  \code{postscript} はポストスクリプトグラフィックスを生成するグラフィックスデバイス
  を開始する．
}
%% The definitive doc is the source :-)
%%      ../../../main/devices.c  &   ../../../unix/devPS.c
\usage{
postscript(file = if(onefile) "Rplots.ps" else "Rplot\%03d.ps",
           onefile, family, title, fonts, encoding, bg, fg,
           width, height, horizontal, pointsize,
           paper, pagecentre, print.it, command,
           colormodel, useKerning, fillOddEven)
}
\arguments{
  \item{file}{ファイルの名前を与える文字列．もしこれが
    \code{""} なら出力は
    \code{command} で与えられる命令にパイプされる．
    もしこれが形式 \code{"|cmd"} なら，出力は
    \command{cmd} で与えられる命令にパイプされる．

    \code{onefile = FALSE} と共に使うためには
    \code{"Rplot\%03d.ps"} (この場合の既定)のような
    \code{printf} 書式を使う．
    さもなければ文字列は
    \code{\%} を含むべきではない：もしこれがどうしても必要なら，
    ファイル名中の \code{\%} に対する文字列に
    \code{\%\%} を使う．
    正規表現 \code{"\%[#0 +=-]*[0-9.]*[diouxX]"} にマッチする単一の
    整数書式が許される．

    チルド展開(\code{\link{path.expand}} を見よ)が行われる．
  }
  \item{onefile}{論理値：もし真なら(既定値)一つのファイルに
    複数の図が許される．
    もし偽なら，各ページにページ番号を含むファイル名が作られ，
    EPSF ヘッダーを使い
    \code{DocumentMedia} コメントはない．既定は \code{TRUE}．}
  \item{family}{使用される初期フォントファミリで，普通
    文字列として与えられる．
    \sQuote{ファミリ}節を見よ．既定では \code{"Helvetica"}．}
  \item{title}{ファイルの
    \code{Title} コメントとして埋め込まれるタイトル文字．
    既定は\cr
    \code{"R Graphics Output"}．}
  \item{fonts}{追加の \R グラフィックスフォントファミリ名を
    指定する文字列で，その宣言は
    PostScript ファイルに含められデバイスと共に使うことが出来る．
    下の\sQuote{ファミリ}節を見よ．
    既定は \code{NULL}．}
  \item{encoding}{エンコーディングファイルの名前．
    既定値は \code{"default"}．後者は
    Unix では
    ISO 8859-\{2,5,7,13,15\} 又は KOI8-\{R,U\} を使う言語に
    対応すると認識されるロケールでない限り \file{"ISOLatin1.enc"} と解釈される．

    Windows では，もしこれらのコードページの一つが使用されているならば 
    \file{"CP1250.enc"} (中央ヨーロッパ), \code{"CP1251.enc"} (キリル),
    \code{"CP1253.enc"} (ギリシャ) 又は \code{"CP1257.enc"} (バルティック)．
    さもなければ \file{"WinAnsi.enc"} (コードページ 1252)．

    ファイルはもしパスがパス分離記号を含まなければ
    パッケージ \pkg{grDevices} の \file{enc} ディレクトリ中で
    探される．拡張子 \code{".enc"} は省略できる．
  }
  \item{bg}{使用される初期背景色．
    もし \code{"transparent"} (又は任意の他の不透明でない色)なら
    背景は塗られない．既定は \code{"transparent"}．}
  \item{fg}{使用される初期前景色．
    既定は \code{"black"}．}
  \item{width, height}{インチ単位のグラフィックス領域の幅と高さ．
    既定値は \code{0}．

    もし \code{paper != "special"} で \code{width} か \code{height}
    が \code{0.1} 未満か，又は総計で 0.5 インチの余白を与えるには
    大きすぎれば，
    グラフィックス領域は対応する用紙のサイズから 0.5 を引いたものにリセットされる．
  }
  \item{horizontal}{論理値，プリントイメージの方向．
    既定では真で，幅が高さより小さい用紙サイズではランドスケープ方向．}
  \item{pointsize}{使用される既定のポイントサイズ．
    厳密に言えば単位は 1/72 インチである bp であるが，ポイントでは近似値．
    既定は \code{12}．}
  \item{paper}{
    プリンターでの用紙サイズ．選択は
    \code{"a4"}, \code{"letter"} (又は \code{"us"}), \code{"legal"} そして
    \code{"executive"} (そしてこれらは大文字でも良い)．
    又引数 \code{width} と \code{height} が用紙サイズを指定するときは
    \code{"special"} を使うことが出来る．
    もうひとつの選択は \code{"default"} (既定)である：もしこれが
    選択されると用紙サイズは
    それが設定されていればオプション \code{"papersize"} から取られ，
    未設定か空なら \code{"a4"} となる．}
  \item{pagecentre}{論理値：デバイス領域をページでセンタリングするか?
    既定では真．}
  \item{print.it}{論理値：デバイスが閉じられた時ファイルをプリントすべきか?
    (これはもし \code{file} が真のファイル名の時だけ適用される．)
    既定値は偽．}
  \item{command}{
    \sQuote{プリント}に対して使われる命令．既定値は
    \code{"default"} でオプション \code{"printcmd"} の値．長さの上界は
    \code{2*PATH_MAX} で，Unix では典型的に
    8096 バイトで，Windows では 520 バイト．
  }
  \item{colormodel}{色モデルを記述する文字列：
    現在許される値は \code{"srgb"}, \code{"srgb+gray"},
    \code{"rgb"}, \code{"rgb-nogray"}, \code{"gray"} (又は \code{"grey")}
    そして \code{"cmyk"}．既定では \code{"srgb"}．
    \sQuote{色モデル}の節を見よ．}
  \item{useKerning}{論理値．テキストの設定中にカーニング補正と
    文字列幅の計算を含めるべきか?
    既定値は \code{TRUE}．}
  \item{fillOddEven}{多角形の塗りつぶしモードを制御する論理値：
    詳細は \code{\link{polygon}} を見よ．既定値は \code{FALSE}．}
}
\details{
  \code{file} を除く全ての引数の既定は
  \code{\link{ps.options}()} で与えられる．究極の既定値は
  引数節で引用されている．

  \code{postscript} はファイル \code{file} を開き，任意の要求されたグラフィックス
  をプロットするために必要なポストスクリプト命令がそのファイルに書き込まれる．
  このファイルはそれから適当なデバイス上でハードコピーを得るために
  開くことが出来る．

  \code{file} 引数は
  \code{\link{sprintf}} が使うような C 整数書式として解釈され，
  整数引数はページ番号になる．
  既定値はファイル \file{Rplot001.ps}, \dots, \file{Rplot999.ps},
  \file{Rplot1000.ps}, \dots を与える．

  単一の \R プロットに対して作られるポストスクリプトは
  EPS (\emph{Encapsulated PostScript}) 互換であり，
  例えば LaTeX のような他のドキュメントに \code{\\includegraphics{<filename>}}
  を使って含めることが出来る．
  このようにして使うためには恐らく\code{\link{setEPS}()} を使い既定
  \code{horizontal = FALSE, onefile = FALSE, paper = "special"} を
  設定したいであろう．
  バウンディングボックスは
  \emph{デバイス}領域に対するものになる：
  もしプロット領域のまわりの余白が多すぎると思うのなら
  \code{\link{par}(mar = )} を使って図領域を減らす．

  殆どの PostScript の序辞は \R の文字列ベクトル
  \code{.ps.prolog} から取られる．これは出力中にマークされ，
  そのベクトルを変項することで変更できる．
  (これはポストスクリプトのエキスパートにだけ勧められる：
  標準バージョンは \code{namespace:grDevices} 中にある．)

  ポストスクリプトデバイスは既定のファミリを持ち，これは
  ユーザが \code{family} を使って設定できる．
  ポストスクリプトデバイスに描く時他のフォントファミリを使うべきならば，
  それらはデバイスが作られる時
  \code{fonts} を使って宣言されなければならない；
  この引数のフォントファミリ名は
  \R のグラフィックスフォントファミリ名である
  (\code{\link{postscriptFonts}} に対するドキュメントを見よ)．

  \code{par(lwd = )} で制御される線幅は
  1/96 インチの倍数である：
  1 未満の倍数が許される．
  \code{cex = 1} の \code{pch = "."} は幅が 1/72 インチの正方形で，
  これはまた
  \code{"cra"} 等のグラフィックスパラメータに対して仮定される
  \sQuote{ピクセル}サイズである．

  背景色が完全に透明
  (初期値がそうであるように)の時は，ポストスクリプトは背景を塗らない．
  ほとんどすべてのポストスクリプトのビューアーは
  白いキャンバスを使うので，視覚的効果はあたかも背景が白であるように
  見える．しかしながら，これは色付き用紙にプリントする場合は
  そうではない．
}

\section{ファミリ}{
  フォントファミリは五種類のフォントフェイス
  (慣例的に plain, bold, italic, bold-italic そして symbol)を集めたもので，
  グラフィックスパラメータ \code{\link{par}(font = )} やグリッド
  パラメータ \code{\link{gpar}(fontface = )} により選択される．
  フォントファミリは \code{family} 引数による
  デバイスに対する初期/既定フォントファミリとして，
  又はデバイスが開かれた後で
  グラフィックスパラメータ \code{\link{par}(family = )} 又は
  グリッドパラメータ
  \code{\link{gpar}(fontfamily = )} により指定出来る．
  初期ファミリに加えて使われるファミリはデバイスが開かれるときに
  \code{fonts} 引数中で指定されなければならない．

  フォントファミリは
  \code{\link{postscriptFonts}} への呼び出しで宣言される．

  引数 \code{family} は使われる初期/既定フォントファミリを指定する．
  通常の使用ではこれは
  \code{"AvantGarde"},
  \code{"Bookman"}, \code{"Courier"}, \code{"Helvetica"},
  \code{"Helvetica-Narrow"},\cr
  \code{"NewCenturySchoolbook"},
  \code{"Palatino"} 又は \code{"Times"} の一つであり，
  全ての通常のポストスクリプトデバイス中に含まれる
  (又はクローン化されている)その名前の標準の
  Adobe ポストスクリプトフォントを参照する．

  多くのポストスクリプトのエミュレータ
  (\code{ghostscript} に基づくものを含む)は
  これらのフォントに同値な URW を使い，
  これらはそれぞれ
  \code{"URWGothic"}, \code{"URWBookman"}, \code{"NimbusMon"},
  \code{"NimbusSan"}, \code{"NimbusSanCond"}, \code{"CenturySch"},
  \code{"URWPalladio"} そして \code{"NimbusRom"} である．
  もし自分のポストスクリプトデバイスが URW フォントを使っているのならば，
  これらの名前を使うことでより多くの文字と適当なメトリックに
  アクセスできる．
  これらを覚えやすくするために
  \code{"URWHelvetica" == "NimbusSan"} と
  \code{"URWTimes" == "NimbusRom"} がまたサポートされている．

  別のタイプのファミリは東アジア言語に対し
  CID-keyed フォントを使っている
  -- \code{\link{postscriptFonts}} を見よ．

  \code{family} 引数は普通フォントファミリの名前である文字列であるが，
  \code{\link{Type1Font}} と \code{\link{CIDFont}} で生成される
  ファミリオブジェクトがまた受け入れられる．
  以前のバージョンの \R との互換性から，初期ファミリはまた
  4又は5種類の afm ファイルのベクトルで指定することも出来る．

  \R はポストスクリプト出力中で使われるフォントを埋め込まないことを注意する：
  これを助けるためのユーティリティについては
  \code{\link{embedFonts}} を見よ．

  ビューアー又は埋め込みアプリケーションは頻繁に
  ファミリ中で指定されたものに対してフォントを置き換え，
  そして置き換えはしばしば少々異なるフォントメトリックを持つ．\cr
  \code{useKerning = TRUE} は
  意図されたファミリに対するカーニング補正を用いて文字を配置する：
  これは
  \code{useKerning = FALSE} の時よりも醜い外観を持つかもしれない．
}

\section{エンコーディング}{
  エンコーディングは文字コード
  (範囲 0--255 中)を表示するときにどのグリフを使うかを記述する．
  最も普通には \R は ISOLatin1 エンコーディングを使い，
  そして
  \code{\link{text}} に対する例はそのエンコーディングを使っている．
  しかしながら，\R が稼働している機械で使われているエンコーディングは
  異なるかもしれず，そして
  \code{encoding} 引数を使うことによりグリフは使用中のエンコーディングに
  マッチさせることが出来る．
  これはヨーロッパとキリル言語に対しては十分であるが，
  東アジア言語に対しては不十分である．後者に対しては，
  複合 CID フォントが使われる．これらのフォントは他の言語に対しても有用である：
  例えばそれらはギリシャ語のグリフを含む．
  (この節の残りは
  CID フォントが使われない時だけに適用される．)

  全てのエンコーディング(\code{"TeXtext"} を除く)はその範囲で一致するため，
  これのどれももし ASCII 文字(codes 32--126)を使うのなら何も問題はない．
  ある種のエンコーディングも ISOLatin1 の上位集合である．
  しかしながら，もしアクセント付きや特殊文字が期待したようには
  現れなければ，エンコーディングを変える必要があるかもしれない．
  幾つかの他のエンコーディングが \R に用意されている：
  \code{"WinAnsi.enc"} と \code{"MacRoman.enc"} は
  普通 Windows と Classic Mac OS (少なくとも Adobe によって)で
  使われ，そして \code{"PDFDoc.enc"}は
  Unicode の最初の 256 文字であり，PDF に対しての標準である．
  又エンコーディング
  \code{"ISOLatin2.enc"}, \code{"CP1250.enc"}, \code{"ISOLatin7.enc"}
  (ISO 8859-13), \code{"CP1257.enc"}，そして \code{"ISOLatin9.enc"} (ISO
  8859-15), \code{"Cyrillic.enc"} (ISO 8859-5), \code{"KOI8-R.enc"},
  \code{"KOI8-U.enc"}, \code{"CP1251.enc"}, \code{"Greek.enc"} (ISO
  8859-7) そして \code{"CP1253.enc"} がある．
  これらのエンコーディング中の多くのグリフは標準的なファミリに対応する
  フォント中にないことを注意する．
  (Adobe のものは Courier 以外の全て，Helvetica と Times は
  Latin-1 より僅かに多く，他方で URW のものは Latin-2, Latin-7,
  Latin-9 そしてキリル文字を含むがギリシャ文字は含まない．
  Adobe の例外は Latin 文字集合を含むが，ユーロは含まない．)

  もしエンコーディングを指定すると，ポストスクリプトフォントが使われるグリフを
  含むことを確実にするのは自分の責任になる．
  ここでの一つの話題は
  WinAnsi と MacRoman エンコーディング中にあるがポストスクリプトフォントには
  無いユーロシンボルである．
  (これは URW の変種中にある；しかし提供される
  Adobe フォントメトリックファイル中にない．)

  ある例外がある．
  文字 45 (\code{"-"}) は他のエンコーディング中ではハイフンであるが
  常にマイナス(その Adobe ISOLatin1 中の値)と設定される．
  ハイフンは全ての Latin エンコーディング，キリルそしてギリシャ語で
  文字 173 (8進数 0255) で得られる．
  グリフ 39 と 96 の記述にはある相違がある：
  Adobe のドキュメントにあるように，提供されるエンコーディング
  (CP1250 と CP1251 を除く)はそれらを
  \sQuote{右引用符}と\sQuote{左引用符}
  (それぞれ\sQuote{一重引用符}/\sQuote{アキュート}と
  \sQuote{グレーブ}ではなく)として扱う．
}

\section{TeX フォント}{
  TeX は伝統的に
  かなり異なった7ビットのエンコーディングを持つ Computer Modern のような
  フォントを使ってきた．
  このエンコーディングは \code{encoding = "TeXtext.enc"} で
  指定できるが，
  アスキー文字 \code{< > \\ _ \{ \}} はこれらのフォントでは利用できないことを
  注意する．

  このエンコーディングを使うファミリ \code{"ComputerModern"} と
  \code{"ComputerModernItalic"} が提供されており，
  これは
  \code{postscript} (そして \code{pdf} ではない)に対してだけ
  サポートされている．これらは
  TeX の CM フォントの Type 1 バージョンとして使うことが意図されている．
  普通 \code{dvips -Ppfb -j0} や自分のシステムでの同値物で
  処理されている限り，そうした出力を TeX や LaTeX に含めることが出来るであろう．
  (\code{-j0} はフォントの置換えをオフにする．)
  \code{family = "ComputerModern"} が使われた時は，使われる
  イタリック/ボールドイタリック体は斜体である
  (\code{cmsl10} と \code{cmbxsl10})．テキストイタリック体を代わりに使うには，
  \code{family = "ComputerModernItalic"} を設定する．

  これらのファミリは，他のファミリ中で Adobe シンボルフォントによりカバーされる
  グリフの広くはあるが不完全な範囲
  に対して TeX の数式イタリック体とシンボルフォントを使う．
  提供された \file{CM_symbol_10.afm} から生成されたポストスクリプトコードの
  特殊な梱包により実現される．
}

\section{色モデル}{
  既定の色モデル (\code{"srgb"}) は sRGB である．

  もうひとつの \code{"srgb+gray"} は色に対して sRGB を使うが，
  グレイスケールとして表現された白の pure gray 色(黒と白を含む)を使う
   (これはより小さなファイルになりある種のプリンタードライバーに対しては
   利点になり得る)．逆に，そのファイルはある種のビューアーでは
   かなり描画が遅くなり得，
  グレイと白を含む色勾配に認識できる不連続性が見られるかもしれない．

  他の可能性は 
  グレイスケールだけに使われる(そして他の色を光度に変換する)
  \code{"gray"} (又は \code{"grey"}) と \code{"cmyk"} である．
  sRGB から CMYK への可能な最も簡単な変換
  (\url{https://en.wikipedia.org/wiki/CMYK_color_model#Mapping_RGB_to_CMYK})
  が使われ，ラスタ―イメージは RGB で出力される．

  後方互換性のために提供される色モデルは \code{"rgb"}
  (RGB+gray) と，調整された RGB を使う \code{"rgb-nogray"}
  (2.13.0 以前の \R で使われた)である．
  これらは少し小さなファイルになり描画がより速くなるかもしれないが，
  適正に調整されたビューアーを前提にしている．
}

\section{プリント}{
  ポストスクリプトのプロットは
  \code{postscript} を使い二つの仕方でプリントできる．
  \enumerate{
    \item 設定 \code{print.it = TRUE} はデバイスが閉じられた時
    引数 \code{command} 中に与えられた命令が引数 \code{"file"}
    で呼び出されるようにする．
    \code{command} がそれを消去するように按配しない限りプロットファイルは
    消去されないことを注意する．

    \item \code{file = ""} や \code{file = "|cmd"} はパイプを使いプリントすることに
    使える．
    命令の開始の失敗は\R にではなく恐らく端末に報告され， 
    この場合即座にデバイスを 
    \code{dev.off} で閉じる．
  }

  Windows では既定の
  \code{"printcmd"} は空であり
  もし \code{print.it = TRUE} を使うとエラーになる．
  PostScript ファイルをプリンタ用にスプールする適当な命令は
  \url{http://www.cs.wisc.edu/~ghost/index.html} から
  利用可能な \file{RedMon} 命令群にある．
  命令は最小化されたウィンド中で実行される．
  GSView 4.x はより簡便かもしれない \file{gsprint.exe}
  を提供する(これは Ghostscript のバージョン 6.50 又はそれ以降を必要とする)．
}
\section{慣例}{
  この節は
  \dQuote{R Internals Manual} 中で設定されているグラフィックスデバイスに
  対する慣例の実装を解説する．

  \itemize{
    \item デバイスの規定サイズは7インチ四方である．
    \item フォントサイズはビッグポイント．
    \item 既定のフォントファミリは Helvetica．
    \item 線幅は 1/96 インチの倍数で，最小値は 0.01 に強制される．
    \item 任意の半径の円が許される．
    \item 色は既定では sRGB と指定される．
  }

  非常に小さな線幅では線種は実線に強制されるかもしれない．

  ラスタ―イメージは現在不透明色に限られる．
}

\note{
  ポストスクリプト出力に関して問題が起これば，
  問題は \R ではなくビューアにあることがより確からしいことを覚えておこう．
  もし可能ならば他のビューアを試してみよう．
  ビューアに欠陥がある症状は
  イメージプロット上の見かけのグリッド線
  (もし可能ならグラフィックスのアンチエイリアシングをオフにしてみよ)
  そして欠損又は不正確なテキスト中のグリフである
  (ビューアは黙ってフォントの置換えを行っている)．

  不幸なことに
  殆どの Linux と OS X システムはこの問題を抱えており，
  グラフィックスのアンチエイリアシングをオフにする
  明らかな方法はない．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}

\seealso{
  \code{\link{postscriptFonts}},
  \code{\link{Devices}},
  そして \code{\link{ps.options}} と \code{postscript} の双方から
  呼び出される \code{\link{check.options}}．

  PostScript を作り出すことが出来る別のデバイスに対しては \code{\link{cairo_ps}}．

  フォントファミリとエンコーディング，そして特に
  非 Latin-1 エンコーディングでのテキストの処理と埋め込みフォントに対する
  より詳細は以下で見られる．

  Paul Murrell and Brian Ripley (2006) Non-standard fonts in PostScript
  and PDF graphics. \emph{R News}, 6(2):41--47.
  \url{https://www.r-project.org/doc/Rnews/Rnews_2006-2.pdf}.
}

\author{
  Computer Modern フォントに対するサポートは
  Brian D'Urso \email{durso@hussle.harvard.edu} の
  貢献に基づく．
}

\examples{
require(graphics)
\dontrun{
# グラフィックス出力に対するファイル "foo.ps" を開く
postscript("foo.ps")
# 希望のグラフを作成する
dev.off()              # ポストスクリプトデバイスを閉じる
#ifdef unix
postscript("|lp -dlw")
# 希望のグラフを作成する
dev.off()              # プロットがプリンターに現れる
#endif
#ifdef windows
options(printcmd = 'redpr -P"\\\\printhost\\lw"')
postscript(file = tempfile("Rps."), print.it = TRUE)
# 希望のグラフを作成する
dev.off()              # プロットファイルをプリンターに送る
## 別の方法として GSView 4.x を使う
options(printcmd = '/GhostGum/gsview/gsprint -query')
#endif

# URW PostScript デバイス
postscript("foo.ps", family = "NimbusSan")

## Computer Modern TeX ドキュメント中へ含めるには，恐らく
postscript("cm_test.eps", width = 4.0, height = 3.0,
           horizontal = FALSE, onefile = FALSE, paper = "special",
           family = "ComputerModern", encoding = "TeXtext.enc")
## 結果のポストスクリプトファイルは
## dvips -Ppfb -j0 で使うことが出来る．

## エンコーディングの検査には次を使うことが出来る
TestChars <- function(encoding = "ISOLatin1", family = "URWHelvetica")
{
    postscript(encoding = encoding, family = family)
    par(pty = "s")
    plot(c(-1,16), c(-1,16), type = "n", xlab = "", ylab = "",
         xaxs = "i", yaxs = "i")
    title(paste("Centred chars in encoding", encoding))
    grid(17, 17, lty = 1)
    for(i in c(32:255)) {
        x <- i \%\% 16
        y <- i \%/\% 16
        points(x, y, pch = i)
    }
    dev.off()
}
## 多くの警告が出る．十分完全なフォントメトリックのセットを
## 得るためには URW を使う．
TestChars()
TestChars("ISOLatin2")
TestChars("WinAnsi")
}
\dontshow{
xx <- seq(0, 7, length = 701)
yy <- sin(xx)/xx; yy[1] <- 1
plot(xx,yy)                     # 希望のグラフを作成
}
}
\keyword{device}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/postscript.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{postscript}
%\alias{postscript}
%\alias{.ps.prolog}
%\concept{encoding}
%\title{PostScript Graphics}
%\description{
%  \code{postscript} starts the graphics device driver for producing
%  PostScript graphics.
%}
%%% The definitive doc is the source :-)
%%%      ../../../main/devices.c  &   ../../../unix/devPS.c
%\usage{
%postscript(file = if(onefile) "Rplots.ps" else "Rplot\%03d.ps",
%           onefile, family, title, fonts, encoding, bg, fg,
%           width, height, horizontal, pointsize,
%           paper, pagecentre, print.it, command,
%           colormodel, useKerning, fillOddEven)
%}
%\arguments{
%  \item{file}{a character string giving the name of the file.  If it is
%    \code{""}, the output is piped to the command given by the argument
%    \code{command}.
%    If it is of the form \code{"|cmd"}, the output is piped to the
%    command given by \command{cmd}.
%
%    For use with \code{onefile = FALSE} give a \code{printf} format such
%    as \code{"Rplot\%03d.ps"} (the default in that case).  The string
%    should not otherwise contain a \code{\%}: if it is really necessary,
%    use \code{\%\%} in the string for \code{\%} in the file name.
%    A single integer format matching the \link{regular expression}
%    \code{"\%[#0 +=-]*[0-9.]*[diouxX]"} is allowed.
%
%    Tilde expansion (see \code{\link{path.expand}}) is done.
%  }
%  \item{onefile}{logical: if true (the default) allow multiple figures
%    in one file.  If false, generate a file name containing the page
%    number for each page and use an EPSF header and no
%    \code{DocumentMedia} comment.  Defaults to \code{TRUE}.}
%  \item{family}{the initial font family to be used, normally as a
%    character string.  See the section \sQuote{Families}.  Defaults to
%    \code{"Helvetica"}.}
%  \item{title}{title string to embed as the \code{Title} comment in the
%    file.  Defaults to \code{"R Graphics Output"}.}
%  \item{fonts}{a character vector specifying additional \R graphics font
%    family names for font families whose declarations will be included
%    in the PostScript file and are available for use with the device.
%    See \sQuote{Families} below.  Defaults to \code{NULL}.}
%  \item{encoding}{the name of an encoding file.  Defaults to
%    \code{"default"}.  The latter is interpreted as
%#ifdef unix
%    \file{"ISOLatin1.enc"} unless the locale is recognized as
%    corresponding to a language using ISO 8859-\{2,5,7,13,15\} or KOI8-\{R,U\}.
%#endif
%#ifdef windows
%    \file{"CP1250.enc"} (Central European), \code{"CP1251.enc"} (Cyrillic),
%    \code{"CP1253.enc"} (Greek) or \code{"CP1257.enc"} (Baltic) if one
%    of those codepages is in use, otherwise \file{"WinAnsi.enc"}
%    (codepage 1252).
%#endif
%    The file is looked for in the \file{enc} directory of package
%    \pkg{grDevices} if the path does not contain a path separator.  An
%    extension \code{".enc"} can be omitted.
%  }
%  \item{bg}{the initial background color to be used.  If
%    \code{"transparent"} (or any other non-opaque colour), no background
%    is painted.  Defaults to \code{"transparent"}.}
%  \item{fg}{the initial foreground color to be used.  Defaults to
%    \code{"black"}.}
%  \item{width, height}{the width and height of the graphics region in
%    inches.  Default to \code{0}.
%
%    If \code{paper != "special"} and \code{width} or \code{height} is less
%    than \code{0.1} or too large to give a total margin of 0.5 inch, the
%    graphics region is reset to the corresponding paper dimension minus 0.5.
%  }
%  \item{horizontal}{the orientation of the printed image, a logical.
%    Defaults to true, that is landscape orientation on paper sizes
%    with width less than height.}
%  \item{pointsize}{the default point size to be used.  Strictly
%    speaking, in bp, that is 1/72 of an inch, but approximately in
%    points.  Defaults to \code{12}.}
%  \item{paper}{the size of paper in the printer.  The choices are
%    \code{"a4"}, \code{"letter"} (or \code{"us"}), \code{"legal"} and
%    \code{"executive"} (and these can be capitalized).
%    Also, \code{"special"} can be used, when arguments \code{width}
%    and \code{height} specify the paper size.  A further choice is
%    \code{"default"} (the default): If this is selected, the papersize
%    is taken from the option \code{"papersize"} if that is set and to
%    \code{"a4"} if it is unset or empty.}
%  \item{pagecentre}{logical: should the device region be centred on the
%    page?  Defaults to true.}
%  \item{print.it}{logical: should the file be printed when the device is
%    closed?  (This only applies if \code{file} is a real file name.)
%    Defaults to false.}
%  \item{command}{the command to be used for \sQuote{printing}.  Defaults
%    to \code{"default"}, the value of option \code{"printcmd"}.  The
%    length limit is \code{2*PATH_MAX},
%#ifdef unix
%    typically 8096 bytes.
%#endif
%#ifdef windows
%    520 bytes.
%#endif
%  }
%  \item{colormodel}{a character string describing the color model:
%    currently allowed values as \code{"srgb"}, \code{"srgb+gray"},
%    \code{"rgb"}, \code{"rgb-nogray"}, \code{"gray"} (or \code{"grey")} and
%    \code{"cmyk"}.  Defaults to \code{"srgb"}.  See section
%    \sQuote{Color models}.}
%  \item{useKerning}{logical.  Should kerning corrections be included in
%    setting text and calculating string widths?  Defaults to \code{TRUE}.}
%  \item{fillOddEven}{logical controlling the polygon fill mode:  see
%      \code{\link{polygon}} for details.  Default \code{FALSE}.}
%}
%\details{
%  All arguments except \code{file} default to values given by
%  \code{\link{ps.options}()}.  The ultimate defaults are quoted in the
%  arguments section.
%
%  \code{postscript} opens the file \code{file} and the PostScript
%  commands needed to plot any graphics requested are written to that
%  file.  This file can then be printed on a suitable device to obtain
%  hard copy.
%
%  The \code{file} argument is interpreted as a C integer format as used
%  by \code{\link{sprintf}}, with integer argument the page number.
%  The default gives files \file{Rplot001.ps}, \dots, \file{Rplot999.ps},
%  \file{Rplot1000.ps}, \dots.
%
%  The postscript produced for a single \R plot is EPS (\emph{Encapsulated
%    PostScript}) compatible, and can be included into other documents,
%  e.g., into LaTeX, using \code{\\includegraphics{<filename>}}.  For use
%  in this way you will probably want to use \code{\link{setEPS}()} to
%  set the defaults as \code{horizontal = FALSE, onefile = FALSE, paper =
%    "special"}.  Note that the bounding box is for the \emph{device}
%  region: if you find the white space around the plot region excessive,
%  reduce the margins of the figure region via \code{\link{par}(mar = )}.
%
%  Most of the PostScript prologue used is taken from the \R character
%  vector \code{.ps.prolog}.  This is marked in the output, and can be
%  changed by changing that vector.  (This is only advisable for
%  PostScript experts: the standard version is in
%  \code{namespace:grDevices}.)
%
%  A PostScript device has a default family, which can be set by the user
%  via \code{family}.  If other font families are to be used when drawing
%  to the PostScript device, these must be declared when the device is
%  created via \code{fonts};  the font family names for this argument are
%  \R graphics font family names (see the documentation for
%  \code{\link{postscriptFonts}}).
%
%  Line widths as controlled by \code{par(lwd = )} are in multiples of
%  1/96 inch: multiples less than 1 are allowed.  \code{pch = "."} with
%  \code{cex = 1} corresponds to a square of side 1/72 inch, which is
%  also the \sQuote{pixel} size assumed for graphics parameters such as
%  \code{"cra"}.
%
%  When the background colour is fully transparent (as is the initial
%  default value), the PostScript produced does not paint the
%  background. Almost all PostScript viewers will use a white canvas so
%  the visual effect is if the background were white.  This will not be
%  the case when printing onto coloured paper, though.
%}
%
%\section{Families}{
%  Font families are collections of fonts covering the five font faces,
%  (conventionally plain, bold, italic, bold-italic and symbol) selected
%  by the graphics parameter \code{\link{par}(font = )} or the grid
%  parameter \code{\link{gpar}(fontface = )}.  Font families can be
%  specified either as an an initial/default font family for the device
%  via the \code{family} argument or after the device is opened by
%  the graphics parameter \code{\link{par}(family = )} or the grid
%  parameter \code{\link{gpar}(fontfamily = )}.  Families which will be
%  used in addition to the initial family must be specified in the
%  \code{fonts} argument when the device is opened.
%
%  Font families are declared via a call to \code{\link{postscriptFonts}}.
%
%  The argument \code{family} specifies the initial/default font family
%  to be used.  In normal use it is one of \code{"AvantGarde"},
%  \code{"Bookman"}, \code{"Courier"}, \code{"Helvetica"},
%  \code{"Helvetica-Narrow"}, \code{"NewCenturySchoolbook"},
%  \code{"Palatino"} or \code{"Times"}, and refers to the standard Adobe
%  PostScript fonts families of those names which are included (or
%  cloned) in all common PostScript devices.
%
%  Many PostScript emulators (including those based on
%  \code{ghostscript}) use the URW equivalents of these fonts, which are
%  \code{"URWGothic"}, \code{"URWBookman"}, \code{"NimbusMon"},
%  \code{"NimbusSan"}, \code{"NimbusSanCond"}, \code{"CenturySch"},
%  \code{"URWPalladio"} and \code{"NimbusRom"} respectively.  If your
%  PostScript device is using URW fonts, you will obtain access to more
%  characters and more appropriate metrics by using these names.  To make
%  these easier to remember, \code{"URWHelvetica" == "NimbusSan"} and
%  \code{"URWTimes" == "NimbusRom"} are also supported.
%
%  Another type of family makes use of CID-keyed fonts for East Asian
%  languages -- see \code{\link{postscriptFonts}}.
%
%  The \code{family} argument is normally a character string naming a
%  font family, but family objects generated by \code{\link{Type1Font}}
%  and \code{\link{CIDFont}} are also accepted.  For compatibility with
%  earlier versions of \R, the initial family can also be specified as a
%  vector of four or five afm files.
%
%  Note that \R does not embed the font(s) used in the PostScript output:
%  see \code{\link{embedFonts}} for a utility to help do so.
%
%  Viewers and embedding applications frequently substitute fonts for
%  those specified in the family, and the substitute will often have
%  slightly different font metrics. \code{useKerning = TRUE} spaces the
%  letters in the string using kerning corrections for the intended
%  family: this may look uglier than \code{useKerning = FALSE}.
%}
%
%\section{Encodings}{
%  Encodings describe which glyphs are used to display the character codes
%  (in the range 0--255).  Most commonly \R uses ISOLatin1 encoding, and
%  the examples for \code{\link{text}} are in that encoding.  However,
%  the encoding used on machines running \R may well be different, and by
%  using the \code{encoding} argument the glyphs can be matched to
%  encoding in use.  This suffices for European and Cyrillic languages,
%  but not for East Asian languages.  For the latter, composite CID fonts are
%  used.  These fonts are useful for other languages: for example they
%  may contain Greek glyphs. (The rest of this section applies only when CID
%  fonts are not used.)
%
%  None of this will matter if only ASCII characters (codes 32--126) are
%  used as all the encodings (except \code{"TeXtext"}) agree over that
%  range.  Some encodings are supersets of ISOLatin1, too.  However, if
%  accented and special characters do not come out as you expect, you may
%  need to change the encoding.  Some other encodings are supplied with
%  \R: \code{"WinAnsi.enc"} and \code{"MacRoman.enc"} correspond to the
%  encodings normally used on Windows and Classic Mac OS (at least by
%  Adobe), and \code{"PDFDoc.enc"} is the first 256 characters of the
%  Unicode encoding, the standard for PDF.  There are also encodings
%  \code{"ISOLatin2.enc"}, \code{"CP1250.enc"}, \code{"ISOLatin7.enc"}
%  (ISO 8859-13), \code{"CP1257.enc"}, and \code{"ISOLatin9.enc"} (ISO
%  8859-15), \code{"Cyrillic.enc"} (ISO 8859-5), \code{"KOI8-R.enc"},
%  \code{"KOI8-U.enc"}, \code{"CP1251.enc"}, \code{"Greek.enc"} (ISO
%  8859-7) and \code{"CP1253.enc"}.  Note that many glyphs in these
%  encodings are not in the fonts corresponding to the standard families.
%  (The Adobe ones for all but Courier, Helvetica and Times cover little
%  more than Latin-1, whereas the URW ones also cover Latin-2, Latin-7,
%  Latin-9 and Cyrillic but no Greek.  The Adobe exceptions cover the
%  Latin character sets, but not the Euro.)
%
%  If you specify the encoding, it is your responsibility to ensure that
%  the PostScript font contains the glyphs used.  One issue here is the Euro
%  symbol which is in the WinAnsi and MacRoman encodings but may well not
%  be in the PostScript fonts.  (It is in the URW variants; it is not in
%  the supplied Adobe Font Metric files.)
%
%  There is an exception.  Character 45 (\code{"-"}) is always set
%  as minus (its value in Adobe ISOLatin1) even though it is hyphen in
%  the other encodings.  Hyphen is available as character 173 (octal
%  0255) in all the Latin encodings, Cyrillic and Greek.  (This can be
%  entered as \code{"\uad"} in a UTF-8 locale.)  There are some
%  discrepancies in accounts of glyphs 39 and 96: the supplied encodings
%  (except CP1250 and CP1251) treat these as \sQuote{quoteright} and
%  \sQuote{quoteleft} (rather than \sQuote{quotesingle}/\sQuote{acute}
%  and \sQuote{grave} respectively), as they are in the Adobe
%  documentation.
%}
%
%\section{TeX fonts}{
%  TeX has traditionally made use of fonts such as Computer Modern which
%  are encoded rather differently, in a 7-bit encoding.  This encoding
%  can be specified by \code{encoding = "TeXtext.enc"}, taking care that
%  the ASCII characters \code{< > \\ _ \{ \}} are not available in those
%  fonts.
%
%  There are supplied families \code{"ComputerModern"} and
%  \code{"ComputerModernItalic"} which use this encoding, and which are
%  only supported for \code{postscript} (and not \code{pdf}).  They are
%  intended to use with the Type 1 versions of the TeX CM fonts.  It will
%  normally be possible to include such output in TeX or LaTeX provided
%  it is processed with \code{dvips -Ppfb -j0} or the equivalent on your
%  system. (\code{-j0} turns off font subsetting.)  When \code{family =
%    "ComputerModern"} is used, the italic/bold-italic fonts used are
%  slanted fonts (\code{cmsl10} and \code{cmbxsl10}).  To use text italic
%  fonts instead, set \code{family = "ComputerModernItalic"}.
%
%  These families use the TeX math italic and  symbol fonts for a
%  comprehensive but incomplete coverage of the glyphs covered by the
%  Adobe symbol font in other families.  This is achieved by
%  special-casing the postscript code generated from the supplied
%  \file{CM_symbol_10.afm}.
%}
%
%\section{Color models}{
%  The default color model (\code{"srgb"}) is sRGB.
%
%  The alternative \code{"srgb+gray"} uses sRGB for colors, but with pure
%  gray colors (including black and white) expressed as greyscales (which
%  results in smaller files and can be advantageous with some printer
%  drivers).  Conversely, its files can be rendered much slower on some
%  viewers, and there can be a noticeable discontinuity in color
%  gradients involving gray or white.
%
%  Other possibilities are \code{"gray"} (or \code{"grey"}) which used
%  only greyscales (and converts other colours to a luminance), and
%  \code{"cmyk"}.  The simplest possible conversion from sRGB to CMYK is
%  used
%  (\url{https://en.wikipedia.org/wiki/CMYK_color_model#Mapping_RGB_to_CMYK}),
%  and raster images are output in RGB.
%
%  Color models provided for backwards compatibility are \code{"rgb"})
%  (which is RGB+gray) and \code{"rgb-nogray"} which use uncalibrated RGB
%  (as used in \R prior to 2.13.0).  These result in slightly smaller
%  files which may render faster, but do rely on the viewer being
%  properly calibrated.
%}
%
%\section{Printing}{
%  A postscript plot can be printed via \code{postscript} in two ways.
%  \enumerate{
%    \item Setting \code{print.it = TRUE} causes the command given in
%    argument \code{command} to be called with argument \code{"file"}
%    when the device is closed.  Note that the plot file is not deleted
%    unless \code{command} arranges to delete it.
%
%    \item \code{file = ""} or \code{file = "|cmd"} can be used to print
%    using a pipe.  Failure to open the command will probably be reported
%    to the terminal but not to \R, in which case close the
%    device by \code{dev.off} immediately.
%  }
%#ifdef windows
%  On Windows the default
%  \code{"printcmd"} is empty and will give an error if
%  \code{print.it = TRUE} is used.  Suitable commands to spool a PostScript
%  file to a printer can be found in \file{RedMon} suite available from
%  \url{http://www.cs.wisc.edu/~ghost/index.html}.  The command will be
%  run in a minimized window.   GSView 4.x provides \file{gsprint.exe}
%  which may be more convenient (it requires Ghostscript version 6.50
%  or later).
%#endif
%}
%\section{Conventions}{
%  This section describes the implementation of the conventions for
%  graphics devices set out in the \dQuote{R Internals Manual}.
%
%  \itemize{
%    \item The default device size is 7 inches square.
%    \item Font sizes are in big points.
%    \item The default font family is Helvetica.
%    \item Line widths are as a multiple of 1/96 inch, with a minimum
%    of 0.01 enforced.
%    \item Circle of any radius are allowed.
%    \item Colours are by default specified as sRGB.
%  }
%
%  At very small line widths, the line type may be forced to solid.
%
%  Raster images are currently limited to opaque colours.
%}
%
%\note{
%  If you see problems with postscript output, do remember that the
%  problem is much more likely to be in your viewer than in \R.  Try
%  another viewer if possible.  Symptoms for which the viewer has been at
%  fault are apparent grids on image plots (turn off graphics
%  anti-aliasing in your viewer if you can) and missing or incorrect glyphs
%  in text (viewers silently doing font substitution).
%
%  Unfortunately the default viewers on most Linux and OS X systems
%  have these problems, and no obvious way to turn off graphics anti-aliasing.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%
%\seealso{
%  \code{\link{postscriptFonts}},
%  \code{\link{Devices}},
%  and \code{\link{check.options}} which is called from both
%  \code{\link{ps.options}} and \code{postscript}.
%
%  \code{\link{cairo_ps}} for another device that can produce PostScript.
%
%  More details of font families and encodings and especially handling
%  text in a non-Latin-1 encoding and embedding fonts can be found in
%
%  Paul Murrell and Brian Ripley (2006) Non-standard fonts in PostScript
%  and PDF graphics. \emph{R News}, 6(2):41--47.
%  \url{https://www.r-project.org/doc/Rnews/Rnews_2006-2.pdf}.
%}
%
%\author{
%  Support for Computer Modern fonts is based on a contribution by
%  Brian D'Urso \email{durso@hussle.harvard.edu}.
%}
%
%\examples{
%require(graphics)
%\dontrun{
%# open the file "foo.ps" for graphics output
%postscript("foo.ps")
%# produce the desired graph(s)
%dev.off()              # turn off the postscript device
%#ifdef unix
%postscript("|lp -dlw")
%# produce the desired graph(s)
%dev.off()              # plot will appear on printer
%#endif
%#ifdef windows
%options(printcmd = 'redpr -P"\\\\printhost\\lw"')
%postscript(file = tempfile("Rps."), print.it = TRUE)
%# produce the desired graph(s)
%dev.off()              # send plot file to the printer
%## alternative using GSView 4.x
%options(printcmd = '/GhostGum/gsview/gsprint -query')
%#endif
%
%# for URW PostScript devices
%postscript("foo.ps", family = "NimbusSan")
%
%## for inclusion in Computer Modern TeX documents, perhaps
%postscript("cm_test.eps", width = 4.0, height = 3.0,
%           horizontal = FALSE, onefile = FALSE, paper = "special",
%           family = "ComputerModern", encoding = "TeXtext.enc")
%## The resultant postscript file can be used by dvips -Ppfb -j0.
%
%## To test out encodings, you can use
%TestChars <- function(encoding = "ISOLatin1", family = "URWHelvetica")
%{
%    postscript(encoding = encoding, family = family)
%    par(pty = "s")
%    plot(c(-1,16), c(-1,16), type = "n", xlab = "", ylab = "",
%         xaxs = "i", yaxs = "i")
%    title(paste("Centred chars in encoding", encoding))
%    grid(17, 17, lty = 1)
%    for(i in c(32:255)) {
%        x <- i \%\% 16
%        y <- i \%/\% 16
%        points(x, y, pch = i)
%    }
%    dev.off()
%}
%## there will be many warnings.  We use URW to get a complete enough
%## set of font metrics.
%TestChars()
%TestChars("ISOLatin2")
%TestChars("WinAnsi")
%}
%\dontshow{
%xx <- seq(0, 7, length = 701)
%yy <- sin(xx)/xx; yy[1] <- 1
%plot(xx,yy)                     # produce the desired graph(s)
%}
%}
%\keyword{device}
%
%\encoding{UTF-8}
%