% File src/library/grDevices/man/unix/quartz.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{quartz}
\title{OS X の Quartz デバイス}
\alias{quartz}
\alias{quartz.options}
\alias{quartz.save}

%%\title{OS X Quartz Device}
\encoding{UTF-8}
\description{
  \code{quartz} は
  OS X システムに対するデバイスドライバを開く．
  これはスクリーン(既定)と様々なグラフィックスファイル書式
  へのプロットをサポートする．
}
\usage{
quartz(title, width, height, pointsize, family, antialias, type,
      file = NULL, bg, canvas, dpi)

quartz.options(\dots, reset = FALSE)

quartz.save(file, type = "png", device = dev.cur(), dpi = 100, ...)
}
\arguments{
  \item{title}{
    Quartz ウィンドに対するタイトル(スクリーン出力にだけ適用される)，
    既定は \code{"Quartz \%d"}． C 風の整数に対する書式が
    デバイス番号で代入される
    (詳細は \code{\link{postscript}} への \code{file} 引数を見よ)．}
  \item{width}{インチ単位のプロット領域の幅．既定値は \code{7}．}
  \item{height}{インチ単位のプロット領域の高さ．既定値は \code{7}．}
  \item{pointsize}{使われる既定のポイントサイズ．既定値は \code{12}．}
  \item{family}{これはデバイスにより使用されるフォントの
    ファミリ名である．既定は \code{"Arial"}．これは
    Font Book 中で示されているようなフォントの基本名である．}
  \item{antialias}{アンチエイリアシングを使うかどうか．
    既定値は \code{TRUE}．}
  \item{type}{使用する出力タイプ．
    より多くの情報は \sQuote{Details} 節を見よ．
    既定値は \code{"native"}．}
  \item{file}{グラフィックスデバイスに対するオプションのターゲット．
    既定の \code{NULL} は必要な箇所で既定名を選択する．
    より多くの情報は\sQuote{詳細}節を見よ．}
  \item{bg}{デバイスに対して使われる初期背景色．
    既定値は \code{"transparent"}．
    \code{"white"} のような不透明色が普通
    \code{"png"} と \code{"tiff"} の様な透明性をサポートする
    スクリーンを使わないタイプでは必要とされる．}
  \item{canvas}{スクリーン利用のデバイスに対して使われるキャンバス色．
    既定値は \code{"white"} で不透明色に強制される．}
  \item{dpi}{出力の解像度．スクリーン利用のディスプレイに
    対する既定値(\code{NA_real_})は主スクリーンの解像度で，
    さもなければ 72 dpi．\sQuote{詳細}節を見よ．}
  \item{\dots}{\code{file} 以外の任意の \code{quartz} への引数．}
  \item{reset}{論理値：既定値をそれらの既定の値にリセットすべきか?}
  \item{device}{コピーされるべきデバイス番号．}
}
\details{
  \code{quartz} のただ一つを除く全ての引数の既定値は
  \code{quartz.options} で設定される：\sQuote{引数}節は
  \sQuote{工場出荷時}既定値を与える．

  Quartz グラフィックスデバイスは様々な出力タイプをサポートする．
  スクリーンを使う出力タイプは \code{""} 又は \code{"native"} 又は
  \code{"Cocoa"} である．スクリーンを使わない出力タイプは
  \code{file} 引数を使い出力ファイルを生成する．
  \code{type = "pdf"} は PDF 出力を作る．
  以下のビットマップ書式がサポートされているかもしれない
  (OS バージョンによる)：\code{"png"}, \code{"jpeg"}, \code{"jpg"},
  \code{"jpeg2000"}, \code{"tif"}, \code{"tiff"}, \code{"gif"},
  \code{"psd"} (Adobe Photoshop), \code{"bmp"} (Windows ビットマップ),
  \code{"sgi"} そして \code{"pict"}．

  \code{file} 引数はスクリーンを使わない描画に使われる．
  実際のファイルはデバイスが閉じられた時だけ作られる
  (つまり \code{dev.off()} を使う)．
  ビットマップデバイスに対しては，ページ番号が
  もし C の整数書式が文字列に含まれていれば代入される
  つまり\sspace{}\code{Rplot\%03d.png}．
  (結果は文字数長 \code{PATH_MAX} 未満でなければならず，
  もし超えれば打ち切られるかもしれない．
  もし \code{file} 引数が与えられないと，
  既定は \code{Rplots.pdf} 又は \code{Rplot\%03d.\var{type}} である．
  チルド展開(\code{\link{path.expand}} を見よ)が行われる．

  もしデバイス独立な \R グラフィックスフォントファミリが
  指定されると(例えば \code{par(family =) を使って}，
  Quartz デバイスは
  Quartz のフォントデータベース(\code{quartzFonts} を見よ)を
  R のグラフィックスフォントファミリを
  Quartz 固有のフォントファミリ記述に変換するのに使う．
  既定の変換は \code{sans} に対しては(MonoType TrueType バージョンの)
  \code{Helvetica}， \code{serif} に対しては \code{Times-Roman} ，そして
  \code{mono} に対しては \code{Courier} である．

  スクリーンを使うデバイスは半透明なキャンバスを用い起動される．
  新しいプロットが一旦描かれると．キャンバスは先ず
  \code{canvas} 色で塗られ，それから現在の背景色で塗られる
  (これは透明や半透明であって良い)．
  スクリーンを使わないデバイスはキャンバス色を持たないでの，
  可能ならば透明な背景で開始される
  (例えば \code{type = "png"} と \code{type = "tiff"}) --
  さもなければそれは Quartz コード中で一様な白キャンバスが
  仮定されているかのように見える．
  PNG と TIFF ファイルは暗いグレーの艶消しを使い保存され，
  \command{Preview} を含むある種のビューアーで見ることが出来る．


  \code{title} はスクリーンを使った出力に対して使うことが出来る．
  これは単一の文字列で，オプションの整数プリントスタイルの書式を
  伴いデバイス番号として代入される．
  これはまたオプションで(書式無しで)
  PDF ファイルのタイトルを与えるのに使われる．

  \code{quartz()} の呼び出しはスクリーンを使うデバイスに
  対しては \code{\link{.Device}} を \code{"quartz"}
  に設定し，さもなければ \code{"quartz_off_screen"} に設定する．

  選ばれたフォントファミリは使われる文字をカバーする必要がある：
  フォントに含まれない文字は長方形で描かれる．
  非西ヨーロッパ言語に対しては
  既定の \code{"Arial"} 以外の何かが恐らく必要になる
  ---中国語に対する一つの選択は \code{"MingLiU"} である．

  \code{quartz.save} はプロットを
  現在のスクリーンデバイスから
  \code{quartz} デバイスにコピーする
  \code{\link{dev.copy2pdf}} の変更版である．
  既定では PNG ファイルにコピーされる．
}
\section{慣例}{
  この節は
  \dQuote{R Internals Manual} 中で設定されているグラフィックスデバイス
  に対する慣例の移植を解説する．

  \itemize{
    \item 既定のデバイスサイズは 7 インチ四方．
    \item フォントサイズはビッグポイント．
    \item 既定のフォントファミリは Arial．
    \item 線幅は 1/96 インチの倍数で最小値は \R が設定する．
    \item 円半径は実数値で最小値は \R が設定する．
    \item 色は sRGB と指定される．
  }
}

\note{
  長い間既定のフォントファミリは
  OS X 10.4 の欠陥の応急措置として \code{"Arial"} に変更されていたが
  \code{"Helvetica"} と文章化されていた．
  これは将来変更されるかもしれない．
  
  かなり普通の Mac の問題は自分のシステムでの
  破損したり重複したりするフォントのせいでプロットにテキストが
  表示されないことである．
  例えば\sspace{}\code{family = "serif"} のような別のフォントファミリ
  に変更することでこれを確認出来るかもしれない．
  \code{Font Book} アプリケーション(\code{Applications} 中)を開き
  使っているフォントをチェックせよ．

}
\seealso{
  \code{\link{quartzFonts}}, \code{\link{Devices}}.

  \R の標準のビットマップデバイスを使いこのデバイスのビットマップタイプに
  アクセスする方法は \code{\link{png}}．
}
\examples{\dontrun{
## 既定のカスタマイズにはこの様なものを自分の .Rprofile に置く
setHook(packageEvent("grDevices", "onLoad"),
        function(...) grDevices::quartz.options(width = 8, height = 6,
                                                pointsize = 10))
}}
\keyword{device}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/unix/quartz.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{quartz}
%\alias{quartz}
%\alias{quartz.options}
%\alias{quartz.save}
%
%\title{OS X Quartz Device}
%\description{
%  \code{quartz} starts a graphics device driver for the OS X System.
%  It supports plotting both to the screen (the default) and to various
%  graphics file formats.
%}
%\usage{
%quartz(title, width, height, pointsize, family, antialias, type,
%      file = NULL, bg, canvas, dpi)
%
%quartz.options(\dots, reset = FALSE)
%
%quartz.save(file, type = "png", device = dev.cur(), dpi = 100, ...)
%}
%\arguments{
%  \item{title}{title for the Quartz window (applies to on-screen output
%    only), default \code{"Quartz \%d"}.  A C-style format for an integer
%    will be substituted by the device number (see the \code{file}
%    argument to \code{\link{postscript}} for further details).}
%  \item{width}{the width of the plotting area in inches.  Default \code{7}.}
%  \item{height}{the height of the plotting area in inches.  Default \code{7}.}
%  \item{pointsize}{the default pointsize to be used.  Default \code{12}.}
%  \item{family}{this is the family name of the font
%    that will be used by the device.  Default \code{"Arial"}.  This will
%    be the base name of a font as  shown in Font Book.}
%  \item{antialias}{whether to use antialiasing.  Default \code{TRUE}.}
%  \item{type}{the type of output to use.  See \sQuote{Details} for
%    more information.  Default \code{"native"}.}
%  \item{file}{an optional target for the graphics device. The default,
%    \code{NULL}, selects a default name where one is needed.  See
%    \sQuote{Details} for more information.}
%  \item{bg}{the initial background colour to use for the device.  Default
%    \code{"transparent"}.  An opaque colour such as \code{"white"} will
%    normally be required on off-screen types that support transparency
%    such as \code{"png"} and \code{"tiff"}.}
%  \item{canvas}{canvas colour to use for an on-screen device.  Default
%    \code{"white"}, and will be forced to be an opaque colour.}
%  \item{dpi}{resolution of the output.  The default (\code{NA_real_})
%    for an on-screen display defaults to the resolution of
%    the main screen, and to 72 dpi otherwise.  See \sQuote{Details}.}
%  \item{\dots}{Any of the arguments to \code{quartz} except \code{file}.}
%  \item{reset}{logical: should the defaults be reset to their defaults?}
%  \item{device}{device number to copy from.}
%}
%\details{
%  The defaults for all but one of the arguments of \code{quartz} are set
%  by \code{quartz.options}: the \sQuote{Arguments} section gives the
%  \sQuote{factory-fresh} defaults.
%
%  The Quartz graphics device supports a variety of output types.
%  On-screen output types are \code{""} or \code{"native"} or
%  \code{"Cocoa"}.  Off-screen output types produce output files and
%  utilize the \code{file} argument.  \code{type = "pdf"} gives PDF
%  output.  The following bitmap formats may be supported (depending on
%  the OS version): \code{"png"}, \code{"jpeg"}, \code{"jpg"},
%  \code{"jpeg2000"}, \code{"tif"}, \code{"tiff"}, \code{"gif"},
%  \code{"psd"} (Adobe Photoshop), \code{"bmp"} (Windows bitmap),
%  \code{"sgi"} and \code{"pict"}.
%
%  The \code{file} argument is used for off-screen drawing.  The actual
%  file is only created when the device is closed (e.g., using
%  \code{dev.off()}).  For the bitmap devices, the page number is
%  substituted if a C integer format is included in the character string,
%  e.g.\sspace{}\code{Rplot\%03d.png}.  (The result must be less than
%  \code{PATH_MAX} characters long, and may be truncated if not. See
%  \code{\link{postscript}} for further details.)  If a \code{file}
%  argument is not supplied, the default is \code{Rplots.pdf} or
%  \code{Rplot\%03d.\var{type}}.  Tilde expansion
%  (see \code{\link{path.expand}}) is done.
%
%  If a device-independent \R graphics font family is specified (e.g.,
%  via \code{par(family =)} in the graphics package), the Quartz device
%  makes use of the Quartz font database (see \code{quartzFonts}) to
%  convert the R graphics font family to a Quartz-specific font family
%  description.  The default conversions are (MonoType TrueType versions
%  of) \code{Helvetica} for \code{sans}, \code{Times-Roman} for
%  \code{serif} and \code{Courier} for \code{mono}.
%
%  On-screen devices are launched with a semi-transparent canvas.  Once a
%  new plot is created, the canvas is first painted with the
%  \code{canvas} colour and then the current background colour (which can
%  be transparent or semi-transparent).  Off-screen devices have no
%  canvas colour, and so start with a transparent background where
%  possible (e.g., \code{type = "png"} and \code{type = "tiff"}) --
%  otherwise it appears that a solid white canvas is assumed in the
%  Quartz code.  PNG and TIFF files are saved with a dark grey matte
%  which will show up in some viewers, including \command{Preview}.
%
%  \code{title} can be used for on-screen output.  It must be a single
%  character string with an optional integer printf-style format that
%  will be substituted by the device number.  It is also optionally used
%  (without a format) to give a title to a PDF file.
%
%  Calling \code{quartz()} sets \code{\link{.Device}} to \code{"quartz"}
%  for on-screen devices and to \code{"quartz_off_screen"} otherwise.
%
%  The font family chosen needs to cover the characters to be used:
%  characters not in the font are rendered as empty oblongs.  For
%  non-Western-European languages something other than the default of
%  \code{"Arial"} is likely to be needed---one choice for Chinese is
%  \code{"MingLiU"}.
%
%  \code{quartz.save} is a modified version of \code{\link{dev.copy2pdf}}
%  to copy the plot from the current screen device to a \code{quartz}
%  device, by default to a PNG file.
%}
%\section{Conventions}{
%  This section describes the implementation of the conventions for
%  graphics devices set out in the \dQuote{R Internals Manual}.
%
%  \itemize{
%    \item The default device size is 7 inches square.
%    \item Font sizes are in big points.
%    \item The default font family is Arial.
%    \item Line widths are a multiple of 1/96 inch with no minimum set by \R.
%    \item Circle radii are real-valued with no minimum set by \R.
%    \item Colours are specified as sRGB.
%  }
%}
%
%\note{
%  For a long time the default font family was documented as
%  \code{"Helvetica"} after it had been changed to \code{"Arial"} to work
%  around a deficiency in OS X 10.4.   It may be changed back in future.
%  
%  A fairly common Mac problem is no text appearing on plots due to
%  corrupted or duplicated fonts on your system.  You may be able to
%  confirm this by using another font family,
%  e.g.\sspace{}\code{family = "serif"}.
%  Open the \code{Font Book} application (in \code{Applications}) and
%  check the fonts that you are using.
%}
%\seealso{
%  \code{\link{quartzFonts}}, \code{\link{Devices}}.
%
%  \code{\link{png}} for way to access the bitmap types of this device
%  via \R's standard bitmap devices.
%}
%\examples{\dontrun{
%## put something like this is your .Rprofile to customize the defaults
%setHook(packageEvent("grDevices", "onLoad"),
%        function(...) grDevices::quartz.options(width = 8, height = 6,
%                                                pointsize = 10))
%}}
%\keyword{device}
%
