% File src/library/grDevices/man/windows/savePlot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{savePlot}
\title{プロットをファイルに保存}
\alias{savePlot}
%%\title{Save Windows Plot to a File}
\encoding{UTF-8}
\usage{
savePlot(filename = "Rplot",
         type = c("wmf", "emf", "png", "jpg", "jpeg", "bmp",
                  "tif", "tiff", "ps", "eps", "pdf"),
         device = dev.cur(),
         restoreConsole = TRUE)
}
\arguments{
  \item{filename}{プロットを保存するファイル名．
    チルド展開(\code{\link{path.expand}} を見よ)がサポートされる．}
  \item{type}{プロットのタイプ，Windows メタファイル，PNG, JPEG, BMP
    (Windows のビットマップ書式), TIFF, PostScript 又は PDF．}
  \item{device}{
    \code{windows} デバイスのデバイス番号，既定では現在のデバイス．}
  \item{restoreConsole}{
    \code{\link{windows}} の \sQuote{詳細}節を見よ．}
}
\description{
  \code{windows} デバイス上の現在のプロットをファイルに保存する．
}
\details{
  これは \code{\link{windows}} デバイスの
  \sQuote{Save as} メニュー項目を選択するのと同じである．

  もし \code{filename} がドット
  (\sQuote{.})を含まなければ，savePlot
  はファイルタイプを拡張子として加える；つまり
  ファイル名は \code{paste(filename, type, sep = ".")} と設定される．
  もし \code{filename} 中にドットがあれば，ファイル名は
  拡張子を含むと仮定され変更なしに使われる．

  \code{filename} を \code{type = "wmf"} と共に \code{"clipboard"} 又は
  \code{""} とすればクリップボードにコピーする．

  タイプ \code{"eps"} と \code{"ps"} は
  既定の \code{filename} に対する拡張子を除けば同じことである．
  \code{"wmf"}/\code{"emf"}, \code{"jpeg"}/\code{"jpg"} そして
  \code{"tiff"}/\code{"tif"} も同様である．

  JPEG の品質は 75\% であり，TIFF は圧縮無しで保存する．
}
\value{
  無い，しかしプロットが作られる．
}

\note{
  Unix 風システム上の
  cairo に基づく \code{X11} デバイスに対しては
  同じ名前であるがより少ないタイプの
  類似の関数がある．
}

\seealso{
  \code{\link{png}}, \code{\link{dev.print}}
}

\keyword{misc}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/windows/savePlot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{savePlot}
%\alias{savePlot}
%\title{Save Windows Plot to a File}
%\usage{
%savePlot(filename = "Rplot",
%         type = c("wmf", "emf", "png", "jpg", "jpeg", "bmp",
%                  "tif", "tiff", "ps", "eps", "pdf"),
%         device = dev.cur(),
%         restoreConsole = TRUE)
%}
%\arguments{
%  \item{filename}{The filename under which to save the plot.
%    Tilde-expansion (see \code{\link{path.expand}} is supported.}
%  \item{type}{The type of plot, Windows metafile, PNG, JPEG, BMP
%    (Windows bitmap format), TIFF, PostScript or PDF.}
%  \item{device}{A device number of a \code{windows} device, by default
%    the current device.}
%  \item{restoreConsole}{See the \sQuote{Details} section
%    of \code{\link{windows}}.}
%}
%\description{
%  Saves the current plot on a \code{windows} device to a file.
%}
%\details{
%  This is equivalent to selecting the \sQuote{Save as} menu item on the
%  \sQuote{File} menu of a \code{\link{windows}} device.
%
%  If \code{filename} does not include a dot (\sQuote{.}), savePlot
%  will add the file type as an extension; that is, the filename will
%  be set to \code{paste(filename, type, sep = ".")}. If a dot is present in
%  \code{filename}, the filename is assumed to include an extension and
%  is used without change.
%
%  Using \code{filename} as \code{"clipboard"} or \code{""} with
%  \code{type = "wmf"} will copy to the clipboard.
%
%  Types \code{"eps"} and \code{"ps"} are the same thing apart from the
%  extension for the default \code{filename}.  Similarly
%  \code{"wmf"}/\code{"emf"}, \code{"jpeg"}/\code{"jpg"} and
%  \code{"tiff"}/\code{"tif"}.
%
%  JPEG quality is 75\%, and TIFF is saved without compression.
%}
%\value{
%  None, but a plot file will be created.
%}
%
%\note{
%  There is a similar function of the same name but fewer types for
%  cairo-based \code{X11} devices on Unix-alikes
%}
%
%\seealso{
%  \code{\link{png}}, \code{\link{dev.print}}
%}
%
%\keyword{misc}
%
