% File src/library/graphics/man/coplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{coplot}
\title{Conditioning Plots}
\usage{
coplot(formula, data, given.values, panel = points, rows, columns,
       show.given = TRUE, col = par("fg"), pch = par("pch"),
       bar.bg = c(num = gray(0.8), fac = gray(0.95)),
       xlab = c(x.name, paste("Given :", a.name)),
       ylab = c(y.name, paste("Given :", b.name)),
       subscripts = FALSE,
       axlabels = function(f) abbreviate(levels(f)),
       number = 6, overlap = 0.5, xlim, ylim, \dots)
co.intervals(x, number = 6, overlap = 0.5)
}
\alias{coplot}
\alias{co.intervals}
\arguments{
  \item{formula}{条件プロットの形式を記述する公式．
    形式 \code{y ~ x | a} の公式は \code{x} に対する
    \code{y} のプロットは変数 \code{a} で条件を付けて
    作られるべきであることを指示する．
    形式 \code{y ~ x| a * b} の公式は
    \code{x} に対する \code{y} のプロットは変数 \code{a} と
    \code{b} で条件を付けて作られるべきであることを指示する．

    三つ又は四つの変数は数値か因子かもしれない．
    \code{x} や \code{y} が因子である時，結果は
    \code{as.numeric()} が適用されたかのようになる．
    一方因子の \code{a} または \code{b} に対しては，
    条件付け(そしてもし \code{show.given} が真なら
    そのグラフィックス)が適合される．
  }
  \item{data}{公式中の変数に対する値を含むデータフレーム．
    既定ではそこから \code{coplot} が呼び出された環境．}
  \item{given.values}{\code{a} と \code{b} に関する条件付け
    がどのように起こるかを決める一つの値又は二つの値のリスト．

    \code{b} が無い時(つまり \code{a} だけに関する条件付け)，
    普通これは二つの列を持つ行列でその各行は条件を与える区間を
    与えるが，一つの数値ベクトルか因子レベルの集合でも良い
    (もし条件を付けられる変数が因子の時)．
    この場合(\code{b} が無い)，\code{co.intervals} の結果は
    直接 \code{given.values} 引数として使うことが出来る．
  }
  \item{panel}{ディスプレイの各パネル中で実行される行動を与える
      既定では \code{points} である
      \code{\link{function}(x, y, col, pch, \dots)}．}
  \item{rows}{プロットのパネルは \code{rows x columns}
    の配列に配置される．\code{rows} は配列中の行の数を与える．}
  \item{columns}{パネルのレイアウト配列中の列数．}
  \item{show.given}{論理値(二つの条件付け変数に対する長さ2
    かもしれない)：対応する条件付け変数に対して条件付きプロットを
    を示すべきか(既定では \code{TRUE})．}
  \item{col}{点をプロットするのに使われる色のベクトル．
    もし短すぎると値はリサイクルされる．}
  \item{pch}{プロットされるシンボルや文字のベクトル．もし短すぎると
    値はリサイクルされる．}
  \item{bar.bg}{(小看板)バーに対する背景色を与える
    成分 \code{"num"} と \code{"fac"} を持つ名前付きベクトルで，
    それぞれ数値と因子の条件付け変数に対応する．}
%  \item{bar.bg}{a named vector with components \code{"num"} and
%    \code{"fac"} giving the background colors for the (shingle) bars,
%    for \bold{num}eric and \bold{fac}tor conditioning variables respectively.}
\item{xlab}{文字列；x 軸と最初の条件付け変数に対して使われるラベル．
    もし一つのラベルだけが与えられると，それは x 軸に対して
    使われ，既定ラベルは条件付け変数に対して使われる．}
  \item{ylab}{文字列；y 軸と任意の二番目の条件付け変数に対して使われる
    ラベル．}
  \item{subscripts}{論理値：もし真ならパネル関数はそのパネルに渡される
    データの添字を与える追加(三番目)の引数 \code{subscripts}
    が与えられる．}
  \item{axlabels}{ x と y が因子の時軸(チック)ラベルを作る関数．}
  \item{number}{整数；a と b に対する条件付け区間の数で
    長さ2かもしれない．これは対応する条件付け変数が
    \code{\link{factor}} でない時だけ使われる．}
  \item{overlap}{数値 < 1；条件付け変数の重なりの割合で，
    x と y 方向用に長さが2かもしれない．
    \code{overlap < 0} ならデータスライス間には\emph{隙間}がある．}
  \item{xlim}{x 軸のレンジ．}
  \item{ylim}{y 軸のレンジ．}
  \item{\dots}{パネル関数への追加引数．}
  \item{x}{数値ベクトル．}
}
\description{
  この関数は以下の参考文献で議論されている条件プロットの二つの変種を作る．
}
\details{
  単一の条件付け変数 \code{a} の場合，
  \code{rows} と \code{columns} が未指定なら，
  \code{columns >= rows} である\sQuote{正方形に近い}レイアウトが選ばれる．

  複数の \code{rows} の場合，パネルプロットの\emph{順序}は
  下からそして左からである(典型的には \code{a} の増加順に対応する)．

  パネル関数は新しいプロットを開始しようとすべきではなく，単に与えられた
  座標系中でプロットすべきである：従って \code{plot} と \code{boxplot}
  はパネル関数ではない．

  引数 \code{xlab} と \code{ylab} の表現は，それらが
  \code{\link{title}} ではなく \code{\link{mtext}} でプロットされるものの，
  \code{\link{par}} 引数 \code{cex.lab} と \code{font.lab} では制御されない．
}
\value{
  \code{co.intervals(., number, .)} は (\code{number} \eqn{\times}{x} 2) 行列，
  \code{ci} とする，を返す．ここで \code{ci[k,]} は
  \code{k} 番目の区間に対する \code{x} 値のレンジである．
}
\references{
  Chambers, J. M. (1992)
  \emph{Data for models.}
  Chapter 3 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.

  Cleveland, W. S. (1993) \emph{Visualizing Data.} New Jersey: Summit Press.
}
\seealso{
  \code{\link{pairs}},
  \code{\link{panel.smooth}},
  \code{\link{points}}.
}
\examples{
## トンガ海溝の地震
coplot(lat ~ long | depth, data = quakes)
given.depth <- co.intervals(quakes$depth, number = 4, overlap = .1)
coplot(lat ~ long | depth, data = quakes, given.v = given.depth, rows = 1)

## 二つの変数で条件付け：
ll.dm <- lat ~ long | depth * mag
coplot(ll.dm, data = quakes)
coplot(ll.dm, data = quakes, number = c(4, 7), show.given = c(TRUE, FALSE))
coplot(ll.dm, data = quakes, number = c(3, 7),
       overlap = c(-.5, .1)) # 負の重なり DROPS 値

## 二つの因子を与える
Index <- seq(length = nrow(warpbreaks)) # より良い既定のラベルを得るため
coplot(breaks ~ Index | wool * tension, data = warpbreaks,
       show.given = 0:1)
coplot(breaks ~ Index | wool * tension, data = warpbreaks,
       col = "red", bg = "pink", pch = 21,
       bar.bg = c(fac = "light blue"))

## 空のパネルを持つ例：
with(data.frame(state.x77), {
coplot(Life.Exp ~ Income | Illiteracy * state.region, number = 3,
       panel = function(x, y, ...) panel.smooth(x, y, span = .8, ...))
## y ~ factor -- それほど意味はないが参考のため：
coplot(Life.Exp ~ state.region | Income * state.division,
       panel = panel.smooth)
})
}
\keyword{hplot}
\keyword{aplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/coplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{coplot}
%\title{Conditioning Plots}
%\usage{
%coplot(formula, data, given.values, panel = points, rows, columns,
%       show.given = TRUE, col = par("fg"), pch = par("pch"),
%       bar.bg = c(num = gray(0.8), fac = gray(0.95)),
%       xlab = c(x.name, paste("Given :", a.name)),
%       ylab = c(y.name, paste("Given :", b.name)),
%       subscripts = FALSE,
%       axlabels = function(f) abbreviate(levels(f)),
%       number = 6, overlap = 0.5, xlim, ylim, \dots)
%co.intervals(x, number = 6, overlap = 0.5)
%}
%\alias{coplot}
%\alias{co.intervals}
%\arguments{
%  \item{formula}{a formula describing the form of conditioning plot.  A
%    formula of the form \code{y ~ x | a} indicates that plots of
%    \code{y} versus \code{x} should be produced conditional on the
%    variable \code{a}.  A formula of the form \code{y ~ x| a * b}
%    indicates that plots of \code{y} versus \code{x} should be produced
%    conditional on the two variables \code{a} and \code{b}.
%
%    All three or four variables may be either numeric or factors.
%    When \code{x} or \code{y} are factors, the result is almost as if
%    \code{as.numeric()} was applied, whereas for factor
%    \code{a} or \code{b}, the conditioning (and its graphics if
%    \code{show.given} is true) are adapted.
%  }
%  \item{data}{a data frame containing values for any variables in the
%    formula.  By default the environment where \code{coplot} was called
%    from is used.}
%  \item{given.values}{a value or list of two values which determine how
%    the conditioning on \code{a} and \code{b} is to take place.
%
%    When there is no \code{b} (i.e., conditioning only on \code{a}),
%    usually this is a matrix with two columns each row of which gives an
%    interval, to be conditioned on, but is can also be a single vector
%    of numbers or a set of factor levels (if the variable being
%    conditioned on is a factor). In this case (no \code{b}),
%    the result of \code{co.intervals} can be used directly as
%    \code{given.values} argument.
%  }
%  \item{panel}{a \code{\link{function}(x, y, col, pch, \dots)}
%      which gives the action to be carried out in
%      each panel of the display.  The default is \code{points}.}
%  \item{rows}{the panels of the plot are laid out in a \code{rows} by
%    \code{columns} array.  \code{rows} gives the number of rows in the
%    array.}
%  \item{columns}{the number of columns in the panel layout array.}
%  \item{show.given}{logical (possibly of length 2 for 2 conditioning
%      variables): should conditioning plots be shown for the
%    corresponding conditioning variables (default \code{TRUE}).}
%  \item{col}{a vector of colors to be used to plot the points.  If too
%    short, the values are recycled.}
%  \item{pch}{a vector of plotting symbols or characters.  If too short,
%    the values are recycled.}
%  \item{bar.bg}{a named vector with components \code{"num"} and
%    \code{"fac"} giving the background colors for the (shingle) bars,
%    for \bold{num}eric and \bold{fac}tor conditioning variables respectively.}
%  \item{xlab}{character; labels to use for the x axis and the
%    first conditioning variable.  If only one label is given, it is used
%    for the x axis and the default label is used for the conditioning
%    variable.}
%  \item{ylab}{character; labels to use for the y axis and any
%    second conditioning variable.}
%  \item{subscripts}{logical: if true the panel function is given an
%    additional (third) argument \code{subscripts} giving the subscripts
%    of the data passed to that panel.}
%  \item{axlabels}{function for creating axis (tick) labels when x or y
%      are factors.}
%  \item{number}{integer; the number of conditioning intervals,
%    for a and b, possibly of length 2.  It is only used if the
%    corresponding conditioning variable is not a \code{\link{factor}}.}
%  \item{overlap}{numeric < 1; the fraction of overlap of the
%    conditioning variables, possibly of length 2 for x and y
%    direction.  When overlap < 0, there will be \emph{gaps} between
%    the data slices.}
%  \item{xlim}{the range for the x axis.}
%  \item{ylim}{the range for the y axis.}
%  \item{\dots}{additional arguments to the panel function.}
%
%  \item{x}{a numeric vector.}
%}
%\description{
%  This function produces two variants of the \bold{co}nditioning plots
%  discussed in the reference below.
%}
%\details{
%  In the case of a single conditioning variable \code{a}, when both
%  \code{rows} and \code{columns} are unspecified, a \sQuote{close to
%    square} layout is chosen with \code{columns >= rows}.
%
%  In the case of multiple \code{rows}, the \emph{order} of the panel
%  plots is from the bottom and from the left (corresponding to
%  increasing \code{a}, typically).
%
%  A panel function should not attempt to start a new plot, but just plot
%  within a given coordinate system: thus \code{plot} and \code{boxplot}
%  are not panel functions.
%
%  The rendering of arguments \code{xlab} and
%  \code{ylab} is not controlled by \code{\link{par}} arguments
%  \code{cex.lab} and \code{font.lab} even though they are plotted by
%  \code{\link{mtext}} rather than \code{\link{title}}.
%}
%\value{
%  \code{co.intervals(., number, .)} returns a (\code{number} \eqn{\times}{x}
%  2) \code{\link{matrix}}, say \code{ci},  where \code{ci[k,]} is
%  the \code{\link{range}} of \code{x} values for the \code{k}-th interval.
%}
%\references{
%  Chambers, J. M. (1992)
%  \emph{Data for models.}
%  Chapter 3 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%
%  Cleveland, W. S. (1993) \emph{Visualizing Data.} New Jersey: Summit Press.
%}
%\seealso{
%  \code{\link{pairs}},
%  \code{\link{panel.smooth}},
%  \code{\link{points}}.
%}
%\examples{
%## Tonga Trench Earthquakes
%coplot(lat ~ long | depth, data = quakes)
%given.depth <- co.intervals(quakes$depth, number = 4, overlap = .1)
%coplot(lat ~ long | depth, data = quakes, given.v = given.depth, rows = 1)
%
%## Conditioning on 2 variables:
%ll.dm <- lat ~ long | depth * mag
%coplot(ll.dm, data = quakes)
%coplot(ll.dm, data = quakes, number = c(4, 7), show.given = c(TRUE, FALSE))
%coplot(ll.dm, data = quakes, number = c(3, 7),
%       overlap = c(-.5, .1)) # negative overlap DROPS values
%
%## given two factors
%Index <- seq(length = nrow(warpbreaks)) # to get nicer default labels
%coplot(breaks ~ Index | wool * tension, data = warpbreaks,
%       show.given = 0:1)
%coplot(breaks ~ Index | wool * tension, data = warpbreaks,
%       col = "red", bg = "pink", pch = 21,
%       bar.bg = c(fac = "light blue"))
%
%## Example with empty panels:
%with(data.frame(state.x77), {
%coplot(Life.Exp ~ Income | Illiteracy * state.region, number = 3,
%       panel = function(x, y, ...) panel.smooth(x, y, span = .8, ...))
%## y ~ factor -- not really sensible, but 'show off':
%coplot(Life.Exp ~ state.region | Income * state.division,
%       panel = panel.smooth)
%})
%}
%\keyword{hplot}
%\keyword{aplot}
%
\encoding{UTF8}
