% File src/library/graphics/man/lines.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{lines}
\alias{lines}
\alias{lines.default}
\title{Add Connected Line Segments to a Plot}
\description{
  様々な方法で与えられた座標を与えて対応する点を線分で結ぶ
  総称的な関数．
}
\usage{
lines(x, \dots)

\method{lines}{default}(x, y = NULL, type = "l", \dots)
}
\arguments{
  \item{x, y}{結ぶ点の座標ベクトル．}
  \item{type}{プロットのタイプを指定する文字列；
    実際には \code{\link{plot.default}} 中に於けるような
    任意のタイプ．}
  \item{\dots}{追加のグラフィカルパラメータ(\code{\link{par}} を見よ)
    が又引数として提供できる，特に線種 \code{lty}，
    線幅 \code{lwd}，色 \code{col} そして \code{type = "b"} に対しては
    \code{pch}．又線の特性 \code{lend}, \code{ljoin}
    そして \code{lmitre}．}
}
\details{
  座標はプロット構造(\code{x} と \code{y} 成分を持つリスト)，
  二列の行列，時系列，\dots 等の中で与えることが出来る．
  \code{\link{xy.coords}} を見よ．
  もし別個に与えられると，それらは同じ長さでなければならない．

  座標は \code{NA} 値を含むことが出来る．もし点が
  \code{NA} をその \code{x} か \code{y} 値のどれかに含めば，
  それはプロットから除外される．そして直線はそうした点から/点へ
  描かれない．このように欠損値は線を中断するのに
  使うことが出来る．

  \code{type = "h"} に対しては，\code{col} はベクトルでよく，必要なら
  リサイクルされる．

  \code{lwd} はベクトルで良い：その最初の要素は線に適用されるが，
  全てのベクトルはシンボルに適用される(必要に応じてリサイクルされる)．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  公式メソッドに対しては \code{\link{lines.formula}}；
  \code{\link{points}}, 特に \code{type \%in\% c("p","b","o")} に対しては
  \code{\link{plot}}，
  そして実働関数 \code{\link{plot.xy}}．

  (単一の)直線を描くには \code{\link{abline}}．

  線種 (\code{lty}) 指定と色をどう指定するかは \code{\link{par}}．
}
\examples{
# 散布図を通る滑らかな線を描く
plot(cars, main = "Stopping Distance versus Speed")
lines(stats::lowess(cars))
}
\keyword{aplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/lines.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{lines}
%\alias{lines}
%\alias{lines.default}
%\title{Add Connected Line Segments to a Plot}
%\description{
%  A generic function taking coordinates given in various ways and
%  joining the corresponding points with line segments.
%}
%\usage{
%lines(x, \dots)
%
%\method{lines}{default}(x, y = NULL, type = "l", \dots)
%}
%\arguments{
%  \item{x, y}{coordinate vectors of points to join.}
%  \item{type}{character indicating the type of plotting; actually any of
%    the \code{type}s as in \code{\link{plot.default}}.}
%  \item{\dots}{Further graphical parameters (see \code{\link{par}}) may
%    also be supplied as arguments, particularly, line type, \code{lty},
%    line width, \code{lwd}, color, \code{col} and for \code{type = "b"},
%    \code{pch}.  Also the line characteristics \code{lend}, \code{ljoin}
%    and \code{lmitre}.}
%}
%\details{
%  The coordinates can be passed in a plotting structure
%  (a list with \code{x} and \code{y} components), a two-column matrix, a
%  time series, \dots.  See \code{\link{xy.coords}}.  If supplied
%  separately, they must be of the same length.
%
%  The coordinates can contain \code{NA} values. If a point contains
%  \code{NA} in either its \code{x} or \code{y} value, it is omitted from
%  the plot, and lines are not drawn to or from such points.  Thus
%  missing values can be used to achieve breaks in lines.
%
%  For \code{type = "h"}, \code{col} can be a vector and will be recycled
%  as needed.
%
%  \code{lwd} can be a vector: its first element will apply to lines but
%  the whole vector to symbols (recycled as necessary).
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{lines.formula}} for the formula method;
%  \code{\link{points}}, particularly for \code{type \%in\% c("p","b","o")},
%  \code{\link{plot}},
%  and the workhorse function \code{\link{plot.xy}}.
%
%  \code{\link{abline}} for drawing (single) straight lines.
%
%  \code{\link{par}} for line type (\code{lty}) specification and how to
%  specify colors.
%}
%\examples{
%# draw a smooth line through a scatter plot
%plot(cars, main = "Stopping Distance versus Speed")
%lines(stats::lowess(cars))
%}
%\keyword{aplot}
%
%\encoding{UTF8}
%