% File src/library/graphics/man/plot.xy.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{plot.xy}
\alias{plot.xy}
\title{Basic Internal Plot Function}
\description{
  これは点と線の基本的プロットを行う内部関数である．
  普通代わりに高水準の関数を使うべきであり，それらの
  引数の解説はそれらのヘルプページを参照せよ．
}
\usage{
plot.xy(xy, type, pch = par("pch"), lty = par("lty"),
        col = par("col"), bg = NA,
        cex = 1, lwd = par("lwd"), \dots)
}
\arguments{
  \item{xy}{
    \code{\link{xy.coords}} に由来する要素が4つのリスト．}
  \item{type}{1文字のコード：\code{\link{plot.default}} を見よ．
    \code{NULL} は \code{"p"} の同義語として受け入れられる．}
  \item{pch}{点の種類に対する文字又は整数コード，
    \code{\link{points.default}} を見よ．}
  \item{lty}{線種のコード，\code{\link{lines}} を見よ．}
  \item{col}{色コード又は名前，\code{\link{colors}} と
    \code{\link{palette}} を見よ．ここで \code{NULL} は色 0 を意味する．}
  \item{bg}{オープンなプロットシンボル
    21:25 に対する背景(塗りつぶし)色：\cr
    \code{\link{points.default}} を見よ．}
  \item{cex}{文字拡大率．}
  \item{lwd}{線幅で，(塗りつぶされない)プロットシンボルとしても使われる，
    \code{\link{lines}} と \code{\link{points}} を見よ．}
  \item{\dots}{
    \code{xpd}, \code{lend}, \code{ljoin} そして \code{lmitre}
    のような追加のグラフィックスパラメータ．}
}
\details{
  引数 \code{pch}, \code{col}, \code{bg}, \code{cex},
  \code{type}: 詳細は \code{\link{points}} と \code{\link{lines}} を見よ．
  特に \code{lwd} は点に対してはベクトルとして扱われ，
  線に対しては単一(最初)の値として扱われる．

  \code{cex} は
  \code{type} \code{"p"},
  \code{"o"}, \code{"b"} そして \code{"c"} で描かれるシンボルと文字
  に影響する \code{par("cex")} に加えて数値因子である．
}
\seealso{
  \code{\link{plot}},
  \code{\link{plot.default}},
  \code{\link{points}},
  \code{\link{lines}}.
}
\examples{
points.default # それがどのようにls "plot.xy(xy.coords(x, y), ...)" を使うかを見るため
}
\keyword{aplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/plot.xy.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{plot.xy}
%\alias{plot.xy}
%\title{Basic Internal Plot Function}
%\description{
%  This is \emph{the} internal function that does the basic plotting of
%  points and lines.  Usually, one should rather use the higher level
%  functions instead and refer to their help pages for explanation of the
%  arguments.
%}
%\usage{
%plot.xy(xy, type, pch = par("pch"), lty = par("lty"),
%        col = par("col"), bg = NA,
%        cex = 1, lwd = par("lwd"), \dots)
%}
%\arguments{
%  \item{xy}{A four-element list as results from
%    \code{\link{xy.coords}}.}
%  \item{type}{1 character code: see \code{\link{plot.default}}.
%    \code{NULL} is accepted as a synonym for \code{"p"}.}
%  \item{pch}{character or integer code for kind of points, see
%    \code{\link{points.default}}.}
%  \item{lty}{line type code, see \code{\link{lines}}.}
%  \item{col}{color code or name, see \code{\link{colors}},
%    \code{\link{palette}}.  Here \code{NULL} means colour 0.}
%  \item{bg}{background (fill) color for the open plot symbols 21:25:
%    see \code{\link{points.default}}.}
%  \item{cex}{character expansion.}
%  \item{lwd}{line width, also used for (non-filled) plot symbols, see
%    \code{\link{lines}} and \code{\link{points}}.}
%  \item{\dots}{further \link{graphical parameters} such as \code{xpd},
%    \code{lend}, \code{ljoin} and \code{lmitre}.}
%}
%\details{
%  The arguments \code{pch}, \code{col}, \code{bg}, \code{cex},
%  \code{lwd} may be vectors and may be recycled, depending on
%  \code{type}: see \code{\link{points}} and \code{\link{lines}} for
%  specifics.  In particular note that \code{lwd} is treated as a vector
%  for points and as a single (first) value for lines.
%
%  \code{cex} is a numeric factor in addition to \code{par("cex")} which
%  affects symbols and characters as drawn by \code{type} \code{"p"},
%  \code{"o"}, \code{"b"} and \code{"c"}.
%}
%\seealso{
%  \code{\link{plot}},
%  \code{\link{plot.default}},
%  \code{\link{points}},
%  \code{\link{lines}}.
%}
%\examples{
%points.default # to see how it calls "plot.xy(xy.coords(x, y), ...)"
%}
%\keyword{aplot}
%
%\encoding{UTF8}
%