% File src/library/grid/man/grid.add.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{grid.add}
%@%\alias{グラフィカルオブジェクトを加える}
\alias{grid.add}
\alias{addGrob}
\alias{setChildren}
\title{グリッドのグラフィカルオブジェクトを加える}
%\title{Add a Grid Graphical Object}
\description{
  gTree や gTree の子孫に grob を加える．
}
\usage{
grid.add(gPath, child, strict = FALSE, grep = FALSE,
         global = FALSE, allDevices = FALSE, redraw = TRUE)

addGrob(gTree, child, gPath = NULL, strict = FALSE, grep = FALSE,
        global = FALSE, warn = TRUE)

setChildren(x, children)
}
\arguments{
  \item{gTree, x}{gTree オブジェクト．}
  \item{gPath}{gPath オブジェクト．\code{grid.add} に対しては
    これはディスプレイリスト上の
    gTree を指定する．\code{addGrob} に対してはこれは
    指定された gTree の子孫を指定する．}
  \item{child}{grob オブジェクト．}
  \item{children}{gList オブジェクト．}
  \item{strict}{
    gPath は正確にマッチされるべきかどうかを指示する論理値．}
  \item{grep}{
    \code{gPath} は正規表現として扱われるかどうかを指示するブール値．
    値は \code{gPath} の要素に渡ってリサイクルされる
    (たとえば \code{c(TRUE, FALSE)} は
    \code{gPath} の全ての奇数番目の要素が正規表現として
    扱われることを意味する)．
  }
  \item{global}{関数は最初にマッチした \code{gPath} だけに
    作用するか，それとも
    マッチした全てに作用するかを指示するブール値．}
  \item{warn}{
    指定された gPath を見つけるのに失敗したらエラーを発生するかどうかを
    指示する論理値．}
  \item{allDevices}{マッチするものを全ての開かれたデバイスで
    探すか，それとも現在のデバイスだけを探すかを指示するブール値．
    現在まだ移植されていない．}
  \item{redraw}{grob を再描画するかどうかを指示する論理値．}
}
\details{
  \code{addGrob} は指定された grob をコピーし，そして
  修正された grob を返す．

  \code{grid.add} はディスプレイリスト上の grob を破滅的に
  変更する．もし \code{redraw} が \code{TRUE} ならばそれは
  変更を反映するために全てを再描画する．

  \code{setChildren} は
  一つの gTree の全ての子供を一度に設定する
  (\code{addGrob} を繰り返し呼び出す代わりに)
  ための基本関数である．
}
\value{
  \code{addGrob} は grob オブジェクトを返す；
  \code{grid.add} は \code{NULL} を返す．
}
\author{Paul Murrell}
\seealso{
  \code{\link{grob}}, \code{\link{getGrob}},
  \code{\link{addGrob}}, \code{\link{removeGrob}}.
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.add.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.add}
%\alias{grid.add}
%\alias{addGrob}
%\alias{setChildren}
%\title{Add a Grid Graphical Object}
%\description{
%  Add a grob to a gTree or a descendant of a gTree.
%}
%\usage{
%grid.add(gPath, child, strict = FALSE, grep = FALSE,
%         global = FALSE, allDevices = FALSE, redraw = TRUE)
%
%addGrob(gTree, child, gPath = NULL, strict = FALSE, grep = FALSE,
%        global = FALSE, warn = TRUE)
%
%setChildren(x, children)
%}
%\arguments{
%  \item{gTree, x}{A gTree object.}
%  \item{gPath}{ A gPath object. For \code{grid.add} this
%    specifies a gTree on the display list.  For \code{addGrob} this
%    specifies a descendant of the specified gTree. }
%  \item{child}{ A grob object. }
%  \item{children}{ A gList object. }
%  \item{strict}{ A boolean indicating whether the gPath must be
%    matched exactly. }
%  \item{grep}{A boolean indicating whether the \code{gPath} should
%    be treated as a regular expression.  Values are recycled across
%    elements of the \code{gPath} (e.g., \code{c(TRUE, FALSE)} means
%    that every odd element of the \code{gPath} will be treated as
%    a regular expression).
%  }
%  \item{global}{ A boolean indicating whether the function should affect
%    just the first match of the \code{gPath}, or whether all matches
%    should be affected.
%  }
%  \item{warn}{A logical to indicate whether failing to find the
%    specified gPath should trigger an error.  }
%  \item{allDevices}{ A boolean indicating whether all open devices
%    should
%    be searched for matches, or just the current device.
%    NOT YET IMPLEMENTED.
%  }
%  \item{redraw}{A logical value to indicate whether to redraw the grob. }
%}
%\details{
%  \code{addGrob} copies the specified grob and returns a modified
%  grob.
%
%  \code{grid.add} destructively modifies a grob on the display list.
%  If \code{redraw}
%  is \code{TRUE} it then redraws everything to reflect the change.
%
%  \code{setChildren} is a basic function for setting all children
%  of a gTree at once (instead of repeated calls to \code{addGrob}).
%}
%\value{
%  \code{addGrob} returns a grob object;  \code{grid.add} returns \code{NULL}.
%}
%\author{Paul Murrell}
%\seealso{
%  \code{\link{grob}}, \code{\link{getGrob}},
%  \code{\link{addGrob}}, \code{\link{removeGrob}}.
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%