% File src/library/grid/man/grid.force.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{grid.force}
%@%\alias{grob をその成分に強制}
\alias{grid.force}
\alias{grid.force.default}
\alias{grid.force.gPath}
\alias{grid.force.grob}
\alias{forceGrob}
\alias{grid.revert}
\alias{grid.revert.gPath}
\alias{grid.revert.grob}
\title{grob をその成分に強制する}
%\title{ Force a grob into its components }
\description{
  ある種の grob は描画時に描画する内容を生成する；
  この関数はそうした grob を
  それらの描画時の内容に置き換える．
}
\usage{
grid.force(x, ...)
\method{grid.force}{default}(x, redraw = FALSE, ...)
\method{grid.force}{gPath}(x, strict = FALSE, grep = FALSE, global = FALSE,
                           redraw = FALSE, ...) 
\method{grid.force}{grob}(x, draw = FALSE, ...)
forceGrob(x)
grid.revert(x, ...)
\method{grid.revert}{gPath}(x, strict = FALSE, grep = FALSE, global = FALSE,
                            redraw = FALSE, ...) 
\method{grid.revert}{grob}(x, draw = FALSE, ...)
}
\arguments{
  \item{x}{
    既定のメソッドに対しては
    \code{x} は指定されるべきではない．
    さもなければ \code{x} は
    grob か gPath であるべきである．
    もし \code{x} が文字列ならば，それは
    gPath と仮定される．
  }
  \item{strict}{
    \code{path} は正確にマッチされるべきかどうかを指示するブール値．
  }
  \item{grep}{
    \code{path} は正規表現として扱われるべきか．
  }
  \item{global}{
    関数が \code{path} の最初のマッチに影響するか，
    それとも全てのマッチに影響するかを指示する論理値．
  }
  \item{draw}{
    強制された後で grob を描画すべきかどうかを指示する論理値．
  }
  \item{redraw}{
    強制操作の後で
    \pkg{grid} シーンを再描画するかどうかを指示する論理値．
  }
  \item{\dots}{メソッドが使う追加引数．}
}
\details{
  ある種の grob は描画時までは実際に描かれる内容の生成を待つ
  (\code{at} や \code{NULL} で \code{grid.xaxis()} により
  生成される軸は，それがどのようなチックマークを描くかを
  決定可能になる前にそのようなビューポートに描き込もうとしているのか
  を見なければならないので，良い例になる)．

  そうした grob の内容(例えばチックマーク)は普通
  \code{grid.ls()} には不可視であるか
  \code{grid.edit()} ではアクセスできない．

  \code{grid.force()} 関数は grob を描画時内容で
  \emph{置き換える}．
  例えば軸は実際に描かれる軸チックマークを表現する線とテキストを
  持つバニラ gTree で置き換えられる．
  これはチックマークを \code{grid.ls()} に可視で
  \code{grid.edit()} でアクセス出来るようにする．

  \code{forceGrob()} 関数は
  \code{grid.force()} に対する内部的実働関数であり，
  普通ユーザから直接呼び出されることはない．
  これは移出されるので必要なら grob クラスをカスタム化する
  メソッドを書くことが出来る．
  
  \code{grid.revert()} 関数は
  \code{grid.force()} の効果を逆転し，
  強制された内容をオリジナルのものに置き換える．
}
\section{警告}{
  明示的な grob 手順の強制は grob が
  \emph{現在}の描画コンテキスト中で grob が描かれたかのような
  結果を作る．
  異なった描画コンテキスト中で結果を描画することは意味がないかもしれない．
}
\section{注意}{
  これらの関数は描画時に
  \code{makeContext()} と \code{makeContent()} メソッドを使ってそれらの内容を
  生成する grob に対してだけ効果を持つ
  (描画時に \code{preDrawDetails()} と \code{drawDetails()} メソッドを使って
  それらの内容を生成する grob に対してでは\emph{無い})．
}
\author{ Paul Murrell }
\examples{
grid.newpage()
pushViewport(viewport(width=.5, height=.5))
# xaxis を描く
grid.xaxis(name="xax")
grid.ls()
# xaxis を強制する
grid.force()
grid.ls()
# xaxis を戻す
grid.revert()
grid.ls()
# yaxis を描き強制する
grid.force(yaxisGrob(), draw=TRUE)
grid.ls()
# yaxis を元に戻す
grid.revert()
grid.ls()
# xaxis だけを強制する
grid.force("xax")
grid.ls()
# 全てを強制する
grid.force()
grid.ls()
# xaxis だけを元に戻す
grid.revert("xax")
grid.ls()
}
\keyword{ dplot }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.force.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.force}
%\alias{grid.force}
%\alias{grid.force.default}
%\alias{grid.force.gPath}
%\alias{grid.force.grob}
%\alias{forceGrob}
%\alias{grid.revert}
%\alias{grid.revert.gPath}
%\alias{grid.revert.grob}
%\title{ Force a grob into its components }
%\description{
%  Some grobs only generate their content to draw at
%  drawing time;  this function replaces such grobs with
%  their at-drawing-time content.
%}
%\usage{
%grid.force(x, ...)
%\method{grid.force}{default}(x, redraw = FALSE, ...)
%\method{grid.force}{gPath}(x, strict = FALSE, grep = FALSE, global = FALSE,
%                           redraw = FALSE, ...) 
%\method{grid.force}{grob}(x, draw = FALSE, ...)
%forceGrob(x)
%grid.revert(x, ...)
%\method{grid.revert}{gPath}(x, strict = FALSE, grep = FALSE, global = FALSE,
%                            redraw = FALSE, ...) 
%\method{grid.revert}{grob}(x, draw = FALSE, ...)
%}
%\arguments{
%  \item{x}{
%    For the default method, \code{x} should not be specified.
%    Otherwise, \code{x} should be a grob or a gPath.
%    If \code{x} is character, it is assumed to be a gPath.
%  }
%  \item{strict}{
%    A boolean indicating whether the \code{path} must be matched
%    exactly.
%  }
%  \item{grep}{
%    Whether the \code{path} should be treated as a regular expression.
%  }
%  \item{global}{
%    A boolean indicating whether the function should affect just the
%    first match of the \code{path}, or whether all matches should be
%    affected.
%  }
%  \item{draw}{logical value indicating whether a grob should be
%    drawn after it is forced.
%  }
%  \item{redraw}{logical value indicating whether to redraw the
%    \pkg{grid} scene after the forcing operation.
%  }
%  \item{\dots}{ Further arguments for use by methods. }
%}
%\details{
%  Some grobs wait until drawing time to generate what content
%  will actually be drawn (an axis, as produced by \code{grid.xaxis()},
%  with an \code{at} or \code{NULL} is a good example because it
%  has to see what viewport it is going to be drawn in before
%  it can decide what tick marks to draw).
%
%  The content of such grobs (e.g., the tick marks) are not usually
%  visible to \code{grid.ls()} or accessible to \code{grid.edit()}.
%
%  The \code{grid.force()} function \emph{replaces} a grob with its
%  at-drawing-time contents.  For example, an axis will be
%  replaced by a vanilla gTree with lines and text representing
%  the axis tick marks that were actually drawn.  This makes
%  the tick marks
%  visible to \code{grid.ls()} and accessible to \code{grid.edit()}.
%
%  The \code{forceGrob()} function is the internal work horse for
%  \code{grid.force()}, so will not normally be called directly by
%  the user.  It is exported so that methods can be written for
%  custom grob classes if necessary.
%  
%  The \code{grid.revert()} function reverses the effect of
%  \code{grid.force()}, replacing forced content with the original
%  grob.
%}
%\section{Warning}{
%  Forcing an explicit grob produces a result as if the grob were
%  drawn in the \emph{current} drawing context.
%  It may not make sense to draw the result in a different
%  drawing context.
%}
%\section{Note}{
%  These functions only have an effect for grobs that generate their content
%  at drawing time using \code{makeContext()} and \code{makeContent()}
%  methods (\emph{not} for grobs that generate their content
%  at drawing time using \code{preDrawDetails()} and
%  \code{drawDetails()} methods).
%}
%\author{ Paul Murrell }
%\examples{
%grid.newpage()
%pushViewport(viewport(width=.5, height=.5))
%# Draw xaxis
%grid.xaxis(name="xax")
%grid.ls()
%# Force xaxis
%grid.force()
%grid.ls()
%# Revert xaxis
%grid.revert()
%grid.ls()
%# Draw and force yaxis
%grid.force(yaxisGrob(), draw=TRUE)
%grid.ls()
%# Revert yaxis
%grid.revert()
%grid.ls()
%# Force JUST xaxis
%grid.force("xax")
%grid.ls()
%# Force ALL
%grid.force()
%grid.ls()
%# Revert JUST xaxis
%grid.revert("xax")
%grid.ls()
%}
%\keyword{ dplot }
%
%\encoding{UTF8}
%