% File src/library/grid/man/grid.grob.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{grid.grob}
\title{別名 "Grob" として知られるグリッドのグラフィカルオブジェクトを作る}
%\title{Create Grid Graphical Objects, aka "Grob"s}
%@%\alias{grob を作る}
\alias{grob}
\alias{gTree}
\alias{grobTree}
\alias{childNames}
\alias{gList}
\alias{is.grob}
\description{
  グリッドのグラフィカルオブジェクト(省略形 \dQuote{grob})を作る．

  \code{grob()} と \code{gTree()} は基本的な構成子であり，
  \code{grobTree()} と \code{gList()} は新しい grob を作るために
  幾つかの grob を引数に取る．
}
\usage{
## Grob Creation:

grob (..., name = NULL, gp = NULL, vp = NULL, cl = NULL)
gTree(..., name = NULL, gp = NULL, vp = NULL, children = NULL,
      childrenvp = NULL, cl = NULL)
grobTree(..., name = NULL, gp = NULL, vp = NULL,
         childrenvp = NULL, cl = NULL)
gList(...)

## Grob Properties:
childNames(gTree)
is.grob(x)

}
\arguments{
  \item{...}{
    \code{grob} と \code{gTree} に対しては，
    グラフィカルオブジェクトの重要な特性を記述する
    名前付きのスロット．\code{gList} と \code{grobTree} に対しては
    一連の grob オブジェクト．}
  \item{name}{
    grob に対する文字列識別子．
    ディスプレイリストと別の grob の子供またはどちらかにある
    grob を見つけるために使われる．}
  \item{children}{\code{"gList"} オブジェクト．}
  \item{childrenvp}{\code{\link{viewport}} オブジェクト(または \code{NULL})．}
  \item{gp}{gpar オブジェクト，典型的には
    関数 \code{gpar} への呼び出しからの出力．基本的には
    グラフィカルパラメータ設定のリスト．}
  \item{vp}{\code{\link{viewport}} オブジェクト(または \code{NULL})．}
  \item{cl}{新しいクラスに対するクラス属性を与える文字列．}
  \item{gTree}{\code{"gTree"} オブジェクト．}
  \item{x}{\R オブジェクト．}
}
\details{
  これらの関数は基本的な
  \code{"grob"}, \code{"gTree"} または \code{"gList"} オブジェクト，または
  これらの一つから導かれた新しいクラスを作るのに使うことが出来る．

  グリッドのグラフィカルオブジェクト(\dQuote{grob})はグラフィカルな
  事項の記述である．
  これらの基本的なクラスはグラフィカルオブジェクトの
  検証，描画そして修正に対する既定の動作を提供する．
  \code{grob()} と \code{gTree()} は共に
  返されるオブジェクトが内部的に一貫性を持つことをチェックするために
  関数 \code{\link{validDetails}} を呼び出す．

  \code{"gTree"} は他の grob を子供として持つことが出来る；
  gTree が描画される時，それはその子供全てを描画する．
  その子供を描画する前に，
  gTree はその \code{childrenvp} スロットをプッシュし，
  そしてそれから \code{\link{vpPath}} を使い
  子供が \code{childrenvp} 内のそれらの位置を特定できるように
  逆に巡回する(\code{\link{upViewport}} を呼び出す)．

  grob の名前は一般にユニークである必要はないが，
  全ての gTree の全ての子供は異なった名前を持たなければならない．
  grob 名は任意の文字列で良いが，
  grob 名に \code{\link{gPath}} 分離記号
  (現在 \code{::})を使うことは勧められない．

  関数 \code{childNames} は gTree の子供である
  grob の名前を返す．

  全てのグリッドのプリミティブ
  (\code{\link{grid.lines}}, \code{grid.rect}, ...)
  そしてある種の高水準のグリッド成分
  (例えば \code{\link{grid.xaxis}} と
  \code{grid.yaxis}) はこれらのクラスから導かれる．

  \code{grobTree} は
  gTree の唯一の成分が grob の時
  (従って全ての名前無しの引数は gTree の子供になる)
  の \code{gTree} の単なる便利なラッパである．
  
  関数 \code{grid.grob} は廃止された．
}
\value{
  クラス \code{"grob"} の \R オブジェクト，
  \bold{gr}aphical \bold{ob}ject．
}
\author{Paul Murrell}
\seealso{
  \code{\link{grid.draw}},
  \code{\link{grid.edit}},
  \code{\link{grid.get}}.
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.grob.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.grob}
%\title{Create Grid Graphical Objects, aka "Grob"s}
%\alias{grob}
%\alias{gTree}
%\alias{grobTree}
%\alias{childNames}
%\alias{gList}
%\alias{is.grob}
%\description{
%  Creating grid graphical objects, short (\dQuote{grob}s).
%
%  \code{grob()} and \code{gTree()} are the basic creators,
%  \code{grobTree()} and \code{gList()} take several grobs to build a new
%  one.
%}
%\usage{
%## Grob Creation:
%
%grob (..., name = NULL, gp = NULL, vp = NULL, cl = NULL)
%gTree(..., name = NULL, gp = NULL, vp = NULL, children = NULL,
%      childrenvp = NULL, cl = NULL)
%grobTree(..., name = NULL, gp = NULL, vp = NULL,
%         childrenvp = NULL, cl = NULL)
%gList(...)
%
%## Grob Properties:
%childNames(gTree)
%is.grob(x)
%
%}
%\arguments{
%  \item{...}{For \code{grob} and \code{gTree}, the
%    named slots describing important features of
%    the graphical object.  For \code{gList} and \code{grobTree},
%    a series of grob objects. }
%  \item{name}{a character identifier for the grob.  Used to find the
%    grob on the display list and/or as a child of another grob. }
%  \item{children}{a \code{"gList"} object. }
%  \item{childrenvp}{a \code{\link{viewport}} object (or \code{NULL}).}
%  \item{gp}{A gpar object, typically the output
%    from a call to the function \code{gpar}.  This is basically
%    a list of graphical parameter settings.}
%  \item{vp}{a \code{\link{viewport}} object (or \code{NULL}).}
%  \item{cl}{string giving the class attribute for the new class.}
%  \item{gTree}{a \code{"gTree"} object.}
%  \item{x}{ An \R object. }
%}
%\details{
%  These functions can be used to create a basic \code{"grob"},
%  \code{"gTree"}, or \code{"gList"} object, or a new class derived from
%  one of these.
%
%  A grid graphical object (\dQuote{grob}) is a description of a graphical
%  item.  These basic classes provide default behaviour for
%  validating, drawing,
%  and modifying graphical objects.  Both \code{grob()} and
%  \code{gTree()} call the function \code{\link{validDetails}} to check
%  that the object returned is internally coherent.
%
%  A \code{"gTree"} can have other grobs as children;  when a gTree is drawn, it
%  draws all of its children.  Before drawing its children, a gTree
%  pushes its \code{childrenvp} slot and then navigates back up (calls
%  \code{\link{upViewport}}) so that the children can specify their location
%  within the \code{childrenvp} via a \code{\link{vpPath}}.
%
%  Grob names need not be unique in general, but all children of a
%  gTree must have different names.
%  A grob name can be any string, though it is not
%  advisable to use the \code{\link{gPath}} separator (currently
%  \code{::}) in grob names.
%
%  The function \code{childNames} returns the names of the grobs
%  which are children of a gTree.
%
%  All grid primitives (\code{\link{grid.lines}}, \code{grid.rect}, ...)
%  and some higher-level grid components (e.g., \code{\link{grid.xaxis}}
%  and \code{grid.yaxis}) are derived from these classes.
%
%  \code{grobTree} is just a convenient wrapper for \code{gTree}
%  when the only components of the gTree are grobs (so all
%  unnamed arguments become children of the gTree).
%
%  The \code{grid.grob} function is defunct.
%}
%\value{
%  An \R object of class \code{"grob"}, a \bold{gr}aphical \bold{ob}ject.
%}
%\author{Paul Murrell}
%\seealso{
%  \code{\link{grid.draw}},
%  \code{\link{grid.edit}},
%  \code{\link{grid.get}}.
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%