% File src/library/grid/man/grid.locator.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{grid.locator}
%@%\alias{マウスクリックの捕捉}
\alias{grid.locator}
\title{マウスのクリックを捕捉する}
%\title{ Capture a Mouse Click }
\description{
  ユーザが現在のグラフィックスデバイス内でマウスを一回クリックし
  現在のビューポート内の指定座標でのマウスクリック位置を返すことを
  許す．
}
\usage{
grid.locator(unit = "native")
}
\arguments{
  \item{unit}{マウスのクリック位置を返す座標系．
  適正な座標系については \code{\link{unit}} 関数を見よ．}
}
\details{
  この関数は形式的であり
  (graphics パッケージの関数 \code{locator} と同様に)
  従ってコマンドラインとグラフィックス描画は
  ユーザが現在のデバイス内でマウスをクリックするまでブロックされる．
}
\value{
  現在のビューポート内の指定座標でのマウスがクリックされた位置を表現する単位オブジェクト．

  もしユーザがマウスボタン 1 をクリックしなければ，
  関数は(不可視で) \code{NULL} を返す．
}
\author{ Paul Murrell }
\seealso{パッケージ \pkg{graphics} 中の \code{\link{viewport}}, \code{\link{unit}},
  \code{locator}，そして応用についてはパッケージ \CRANpkg{lattice} 中の
  \code{\link[lattice:interaction]{trellis.focus}} と
  \code{\link[lattice:interaction]{panel.identify}}．
  
}
\examples{
if (interactive()) {
  ## より洗練された unit as.character メソッドを書く必要
  unittrim <- function(unit) {
    sub("^([0-9]+|[0-9]+[.][0-9])[0-9]*", "\\\\1", as.character(unit))
  }
  do.click <- function(unit) {
    click.locn <- grid.locator(unit)
    grid.segments(unit.c(click.locn$x, unit(0, "npc")),
                  unit.c(unit(0, "npc"), click.locn$y),
                  click.locn$x, click.locn$y,
                  gp=gpar(lty="dashed", col="grey"))
    grid.points(click.locn$x, click.locn$y, pch=16, size=unit(1, "mm"))
    clickx <- unittrim(click.locn$x)
    clicky <- unittrim(click.locn$y)
    grid.text(paste0("(", clickx, ", ", clicky, ")"),
              click.locn$x + unit(2, "mm"), click.locn$y,
              just="left")
  }
  do.click("inches")
  pushViewport(viewport(width=0.5, height=0.5,
                         xscale=c(0, 100), yscale=c(0, 10)))
  grid.rect()
  grid.xaxis()
  grid.yaxis()
  do.click("native")
  popViewport()
}
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.locator.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.locator}
%\alias{grid.locator}
%\title{ Capture a Mouse Click }
%\description{
%  Allows the user to click the mouse once within the current
%  graphics
%  device and returns the location of the mouse click within the
%  current viewport, in the specified coordinate system.
%}
%\usage{
%grid.locator(unit = "native")
%}
%\arguments{
%  \item{unit}{ The coordinate system in which to return the location
%    of the mouse click.
%        See the \code{\link{unit}} function for valid coordinate systems.}
%}
%\details{
%  This function is modal (like the graphics package
%  function \code{locator}) so
%  the command line and graphics drawing is blocked until
%  the use has clicked the mouse  in the current device.
%}
%\value{
%  A unit object representing the location of the mouse click within the
%  current viewport, in the specified coordinate system.
%
%  If the user did not click mouse button 1, the function
%  (invisibly) returns \code{NULL}.
%}
%\author{ Paul Murrell }
%\seealso{ \code{\link{viewport}}, \code{\link{unit}},
%  \code{locator} in package \pkg{graphics}, and for an application
%  see \code{\link[lattice:interaction]{trellis.focus}} and
%  \code{\link[lattice:interaction]{panel.identify}} in package
%  \CRANpkg{lattice}.
%}
%\examples{
%if (interactive()) {
%  ## Need to write a more sophisticated unit as.character method
%  unittrim <- function(unit) {
%    sub("^([0-9]+|[0-9]+[.][0-9])[0-9]*", "\\\\1", as.character(unit))
%  }
%  do.click <- function(unit) {
%    click.locn <- grid.locator(unit)
%    grid.segments(unit.c(click.locn$x, unit(0, "npc")),
%                  unit.c(unit(0, "npc"), click.locn$y),
%                  click.locn$x, click.locn$y,
%                  gp=gpar(lty="dashed", col="grey"))
%    grid.points(click.locn$x, click.locn$y, pch=16, size=unit(1, "mm"))
%    clickx <- unittrim(click.locn$x)
%    clicky <- unittrim(click.locn$y)
%    grid.text(paste0("(", clickx, ", ", clicky, ")"),
%              click.locn$x + unit(2, "mm"), click.locn$y,
%              just="left")
%  }
%  do.click("inches")
%  pushViewport(viewport(width=0.5, height=0.5,
%                         xscale=c(0, 100), yscale=c(0, 10)))
%  grid.rect()
%  grid.xaxis()
%  grid.yaxis()
%  do.click("native")
%  popViewport()
%}
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%