% File src/library/grid/man/grid.reorder.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{grid.reorder}
\alias{grid.reorder}
%\alias{gTree の子供の並べ替え}
\alias{reorderGrob}
\title{gTree の子供を並べ替える}
%\title{ Reorder the children of a gTree }
\description{
  gTree の子供達が描画される順序を変更する．
}
\usage{
grid.reorder(gPath, order, back=TRUE, grep=FALSE, redraw=TRUE)
reorderGrob(x, order, back=TRUE)
}
\arguments{
  \item{gPath}{現在のシーン中の gTree を指定する gPath オブジェクト．}
  \item{x}{修正される gTree オブジェクト．}
  \item{order}{
    gTree の子供達に対する新しい描画順序を指定する文字列ベクトルか
    数値ベクトル．
    gTree の全ての子供達を参照していないかもしれない(詳細節を見よ)．}
  \item{back}{
    gTree の全ての子供達を参照していない時(詳細節を見よ)に
    何が起きるかを制御する．}
  \item{grep}{
    \code{gPath} は正規表現として扱うべきか?}
  \item{redraw}{修正されたシーンは再描画されるべきか?}
}
\details{
  最も単純な場合，
  \code{order} は gTree の全ての子供に対する新しい順序を指定する．
  子供達は名前でも既存の数値順序でも指定することが出来る．

  もし the \code{order} が gTree の全ての子供を指定していなければ，
  既定では \code{order} で指定された子供達は最初に描画され，それから
  全ての残りの子供達が描画される．もし \code{back=FALSE} ならば
  \code{order} 中に指定されない子供達が最初に描画され，
  次に指定された子供達が続く．
  これは後送りや前送りの再描画の指定を容易にする．
  \code{order} 引数は\emph{常に}後が先の順序である．

  ディスプレイリストは grob とビューポートの混合物であるので
  (従ってどのような再順序化が意味を持つのかは明らかでなく
  描かれないシーンは終了するほうがよっぽど簡単である)
  グリッドのディスプレイリスト
  (現在のシーン中のトップレベルの grob)
  を並べかえることは不可能である．
  もしグリッドのディスプレイリストを並べ替えたければ，
  \code{grid.grab()} で gTree を作りそれからその
  gTree を並べ替え(そして再描画す)る．
}
\section{警告}{
  この関数は描かれない gTree を返すかもしれない．
  例えば，二つの子供 A と B (この順序)を持ち
  そして子供 B の幅が子供 A の幅に依存する
  (例えばテキストの断片のまわりのボックス)．
  もしこれが \code{grid.reorder()} で起きれば，
  修正は実行されない．もしこれが
  \code{reorderGrob()} で起きれば単にオリジナルの順序を
  回復することが可能であるべきである．
}
\value{
  \code{grid.reorder()} は現在のシーンを修正するという副作用の
  ために呼び出される．
  \code{reorderGrob()} は修正された gTree を返す．
}
\author{ Paul Murrell }
\examples{
# 二つの子供 "red-rect" と "blue-rect" (この順序)を持つ gTree
gt <- gTree(children=gList(
                rectGrob(gp=gpar(col=NA, fill="red"),
                         width=.8, height=.2, name="red-rect"),
                rectGrob(gp=gpar(col=NA, fill="blue"),
                         width=.2, height=.8, name="blue-rect")),
            name="gt")
grid.newpage()
grid.draw(gt)
# 全ての順序を数値として指定(blue-rect, red-rect)
grid.reorder("gt", 2:1)
# 全ての順序を文字列で指定する
grid.reorder("gt", c("red-rect", "blue-rect"))
# 後ろにしたいものだけを文字列で指定
grid.reorder("gt", "blue-rect")
# 前にしたいものだけを文字列で指定
grid.reorder("gt", "blue-rect", back=FALSE)
}
\keyword{ dplot }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.reorder.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.reorder}
%\alias{grid.reorder}
%\alias{reorderGrob}
%\title{ Reorder the children of a gTree }
%\description{
%  Change the order in which the children of a gTree get drawn.
%}
%\usage{
%grid.reorder(gPath, order, back=TRUE, grep=FALSE, redraw=TRUE)
%reorderGrob(x, order, back=TRUE)
%}
%\arguments{
%  \item{gPath}{A gPath object specifying a gTree within the current
%    scene.}
%  \item{x}{A gTree object to be modified.}
%  \item{order}{A character vector or a numeric vector that specifies
%    the new drawing order for the children of the gTree.  May not refer
%    to all children of the gTree (see Details).}
%  \item{back}{Controls what happens when the \code{order} does not
%    specify all children of the gTree (see Details).}
%  \item{grep}{Should the \code{gPath} be treated as a regular expression?}
%  \item{redraw}{Should the modified scene be redrawn?}
%}
%\details{
%  In the simplest case, \code{order} specifies a new ordering for all of
%  the children of the gTree.  The children may be specified either by
%  name or by existing numerical order.
%
%  If the \code{order} does not
%  specify all children of the gTree then, by default, the children
%  specified by \code{order} are drawn first and then all remaining
%  children are drawn.  If \code{back=FALSE} then the children not
%  specified in \code{order} are drawn first, followed by the specified
%  children.  This makes it easy to specify a send-to-back or
%  bring-to-front reordering.  The \code{order} argument is \emph{always}
%  in back-to-front order.
%
%  It is not possible to reorder the grid display list (the top-level
%  grobs in the current scene) because the display list is a mixture of
%  grobs and viewports (so it is not clear what reordering even means and
%  it would be too easy to end up with a scene that would not draw).
%  If you want to reorder the grid display list, try \code{grid.grab()}
%  to create a gTree and then reorder (and redraw) that gTree.
%}
%\section{Warning}{
%  This function may return a gTree that will not draw.  For example, a
%  gTree has two children, A and B (in that order),
%  and the width of child B depends on the width of child A (e.g., a box
%  around a piece of text).  Switching the order so that B is drawn
%  before A will not allow B to be drawn.  If this happens with
%  \code{grid.reorder()}, the modification will not be performed.  If
%  this happens with \code{reorderGrob()} it should be possible simply to
%  restore the original order.
%}
%\value{
%  \code{grid.reorder()} is called for its side-effect of modifying the
%  current scene.
%  \code{reorderGrob()} returns the modified gTree.
%}
%\author{ Paul Murrell }
%\examples{
%# gTree with two children, "red-rect" and "blue-rect" (in that order)
%gt <- gTree(children=gList(
%                rectGrob(gp=gpar(col=NA, fill="red"),
%                         width=.8, height=.2, name="red-rect"),
%                rectGrob(gp=gpar(col=NA, fill="blue"),
%                         width=.2, height=.8, name="blue-rect")),
%            name="gt")
%grid.newpage()
%grid.draw(gt)
%# Spec entire order as numeric (blue-rect, red-rect)
%grid.reorder("gt", 2:1)
%# Spec entire order as character
%grid.reorder("gt", c("red-rect", "blue-rect"))
%# Only spec the one I want behind as character
%grid.reorder("gt", "blue-rect")
%# Only spec the one I want in front as character
%grid.reorder("gt", "blue-rect", back=FALSE)
%}
%\keyword{ dplot }
%
%\encoding{UTF8}
%