% File src/library/grid/man/viewport.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009 R Core Team
% Distributed under GPL 2 or later

\name{xsplinePoints}
%@%\alias{Xスプラインに使われる点}
\alias{xsplinePoints}
\alias{bezierPoints}
\title{
  Xスプライン(またはベジエ曲線)を描くのに使われる点を返す．
}
%\title{Return the points that would be used to draw an Xspline (or a Bezier curve).}
\description{
  Xスプライン(または Bezier 曲線)を描く代わりに，
  書くのに使われる点を返す．
  この関数はXスプラインに対する一連の線分を描くのに使われる
  一連の点を返す．
  これは例えば曲線のクリップの様な，Xスプライン曲線の事後処理に便利である．
}
\usage{
xsplinePoints(x)
bezierPoints(x)
}
\arguments{
  \item{x}{
    \code{xsplineGrob()} 関数により作られるような
    Xsplinegrob
    (または \code{bezierGrob()} 関数が作るような beziergrob)．
  }
}
\details{
  この関数が返す点はこの関数が呼び出された時の
  内容の強制的な描画に対してだけ意味がある．
}
\value{
  幾つXスプラインを描くかに依存する．
  もし唯一つなら，共に単位オブジェクト(インチ単位) である
  x と y という名前の二つの成分を持つリスト．
  もし幾つかのXスプラインが書かれるならばこの関数の結果は
  リストのリストである．
}
\author{
  Paul Murrell
}
\seealso{
  \code{\link{xsplineGrob}} と
  \code{\link{bezierGrob}}
}
\examples{
grid.newpage()
xsg <- xsplineGrob(c(.1, .1, .9, .9), c(.1, .9, .9, .1), shape=1)
grid.draw(xsg)
trace <- xsplinePoints(xsg)
grid.circle(trace$x, trace$y, default.units="inches", r=unit(.5, "mm"))

grid.newpage()
vp <- viewport(width=.5)
xg <- xsplineGrob(x=c(0, .2, .4, .2, .5, .7, .9, .7),
                  y=c(.5, 1, .5, 0, .5, 1, .5, 0),
                  id=rep(1:2, each=4),
                  shape=1,
                  vp=vp)
grid.draw(xg)
trace <- xsplinePoints(xg)
pushViewport(vp)
invisible(lapply(trace, function(t) grid.lines(t$x, t$y, gp=gpar(col="red"))))
popViewport()

grid.newpage()
bg <- bezierGrob(c(.2, .2, .8, .8), c(.2, .8, .8, .2))
grid.draw(bg)
trace <- bezierPoints(bg)
grid.circle(trace$x, trace$y, default.units="inches", r=unit(.5, "mm"))
}
\keyword{ dplot }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/viewport.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{xsplinePoints}
%\alias{xsplinePoints}
%\alias{bezierPoints}
%\title{
%  Return the points that would be used to draw an Xspline
%  (or a Bezier curve).
%}
%\description{
%  Rather than drawing an Xspline (or Bezier curve), this function returns
%  the points that would be used to draw the series of line
%  segments for the Xspline.  This may be useful to post-process
%  the Xspline curve, for example, to clip the curve.
%}
%\usage{
%xsplinePoints(x)
%bezierPoints(x)
%}
%\arguments{
%  \item{x}{
%    An Xspline grob, as produced by the \code{xsplineGrob()} function
%    (or a beziergrob, as produced by the \code{bezierGrob()} function).
%  }
%}
%\details{
%  The points returned by this function will only be relevant
%  for the drawing context in force when this function was called.
%}
%\value{
%  Depends on how many Xsplines would be drawn.  If only one, then
%  a list with two components, named x and y, both of which are
%  unit objects (in inches).  If several Xsplines would be drawn
%  then the result of this function is a list of lists.
%}
%\author{
%  Paul Murrell
%}
%\seealso{
%  \code{\link{xsplineGrob}} and
%  \code{\link{bezierGrob}}
%}
%\examples{
%grid.newpage()
%xsg <- xsplineGrob(c(.1, .1, .9, .9), c(.1, .9, .9, .1), shape=1)
%grid.draw(xsg)
%trace <- xsplinePoints(xsg)
%grid.circle(trace$x, trace$y, default.units="inches", r=unit(.5, "mm"))
%
%grid.newpage()
%vp <- viewport(width=.5)
%xg <- xsplineGrob(x=c(0, .2, .4, .2, .5, .7, .9, .7),
%                  y=c(.5, 1, .5, 0, .5, 1, .5, 0),
%                  id=rep(1:2, each=4),
%                  shape=1,
%                  vp=vp)
%grid.draw(xg)
%trace <- xsplinePoints(xg)
%pushViewport(vp)
%invisible(lapply(trace, function(t) grid.lines(t$x, t$y, gp=gpar(col="red"))))
%popViewport()
%
%grid.newpage()
%bg <- bezierGrob(c(.2, .2, .8, .8), c(.2, .8, .8, .2))
%grid.draw(bg)
%trace <- bezierPoints(bg)
%grid.circle(trace$x, trace$y, default.units="inches", r=unit(.5, "mm"))
%}
%\keyword{ dplot }
%
%\encoding{UTF8}
%