% File src/library/methods/man/BasicClasses.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{BasicClasses}
\docType{class}
%@%\alias{基本データタイプのクラス}
\alias{character-class}
\alias{complex-class}
\alias{double-class}
\alias{expression-class}
\alias{externalptr-class}
\alias{integer-class}
\alias{list-class}
\alias{logical-class}
\alias{numeric-class}
\alias{raw-class}
\alias{single-class}
\alias{vector-class}
\alias{NULL-class}
\alias{builtin-class}
\alias{special-class}
\alias{function-class}
\alias{ANY-class}
\alias{VIRTUAL-class}
\alias{missing-class}
\alias{S4-class}
\alias{namedList-class}
\title{基本データタイプに対応するクラス}
%\title{Classes Corresponding to Basic Data Types }
\description{
  R 基本オブジェクトタイプに対応する形式的クラスが存在し，
  クラス定義中のスロットとしてメソッドのシグネチャ中で
  これらのタイプを使ったり，
  新しいクラスで拡張したりすることを許す．}
\usage{
### 以下は全ての基本ベクトルクラスである．
### これらはメソッドのシグネチャ中や as(), is() 
### そして new() への呼び出しでクラス名として登場出来る．
.
"character"
"complex"
"double"
"expression"
"integer"
"list"
"logical"
"numeric"
"single"
"raw"

### クラス
"vector"
### は仮想的なクラスで，上の全てにより拡張される．

### クラス
"S4"
### はクラス S4 のオブジェクトで基本的なベクトルクラスの
### どれも拡張しない．これは仮想的クラスである．

### 次は追加の基本的クラスである
"NULL"     #  NULL オブジェクト
"function" #  プリミティブを含む関数オブジェクト
"externalptr" # C コードで使うバイト型外部ポインタ

"ANY"  # メソッドのパッケージ自体で使われる仮想的クラス
"VIRTUAL"
"missing"

"namedList" # 名前属性を保存する "list" の代替物
}
\section{クラスからのオブジェクト}{
  クラスが仮想的で無ければ(\code{\link{Classes}} 中の節を見よ)，
  オブジェクトは形式
  \code{new(Class, ...)} の呼び出しで作ることが出来，
  ここで \code{Class} は引用符付きのクラス名で，
  残りの引数はもしあればこのクラスのベクトルとして解釈される
  オブジェクトである．
  複数の引数は連結される．

  クラス \code{"expression"} は
  \dots 引数が評価\emph{されない}という点で少々奇妙である；
  従ってそれらを \code{quote()} への呼び出しで囲まない．

  クラス \code{"list"} は純粋なベクトルであることを注意する．
  名前付きリストは
  S の最も初期のバージョンに遡るが，それらは
  属性(今はスロットで良い)を持つという点でベクトルの概念の拡張であり，
  属性は \code{NULL} かベクトルと同じ長さの文字列ベクトルである．
  もしリスト名が保存されることを保証したければ
  \code{"list"} ではなく
  クラス \code{"namedList"} を使う．このクラスからの
  オブジェクトはスロット \code{"names"} に対応し
  タイプ \code{"character"} の名前属性を持たなければならない．
  内部的には R はリストに対する名前を特別に扱い，
  クラス \code{"namedList"} 中の対応するスロットが
  文字列名と \code{NULL} の合併であることは実際的ではない．

}

\section{クラスとタイプ}{
基本クラスは基本的な R タイプに対するクラスを含む．
これらのタイプは普通
S4 オブジェクトではない
(\code{\link{isS4}} は \code{FALSE} を返す)が，基本クラスを含む
クラスからのオブジェクトは
S4 オブジェクトであり，依然同じクラスである．
\code{\link{typeof}} が返すようなタイプは時おりクラスが
異なるが，
単に用語の選択からか
(例えば，タイプ \code{"symbol"} とクラス
\code{"name"})またはクラスとタイプ間に一対一対応が
無いせいである
(例えば，クラス \code{"language"} を継承する殆どのクラスはタイプ
\code{"language"} を持つ)．
}


\section{拡張}{
  ベクトルクラスは \code{"vector"} を直接に拡張する．
}
\section{メソッド}{
  \describe{
    \item{coerce}{
      対応する基本関数を呼び出すことにより，
      任意のオブジェクトをベクトルクラスに強制変換するメソッドが
      定義されている，例えば
      \code{as(x, "numeric")} は \code{as.numeric(x)} を呼び出す．}
  }
}
\keyword{classes}

\encoding{UTF8}

%% File src/library/methods/man/BasicClasses.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{BasicClasses}
%\docType{class}
%\alias{character-class}
%\alias{complex-class}
%\alias{double-class}
%\alias{expression-class}
%\alias{externalptr-class}
%\alias{integer-class}
%\alias{list-class}
%\alias{logical-class}
%\alias{numeric-class}
%\alias{raw-class}
%\alias{single-class}
%\alias{vector-class}
%\alias{NULL-class}
%\alias{builtin-class}
%\alias{special-class}
%\alias{function-class}
%\alias{ANY-class}
%\alias{VIRTUAL-class}
%\alias{missing-class}
%\alias{S4-class}
%\alias{namedList-class}
%\title{Classes Corresponding to Basic Data Types }
%\description{
%  Formal classes exist corresponding to the basic R object types, allowing
%  these types to be used in method signatures, as slots in class
%  definitions, and to be extended by new classes.}
%\usage{
%### The following are all basic vector classes.
%### They can appear as class names in method signatures,
%### in calls to as(), is(), and new().
%"character"
%"complex"
%"double"
%"expression"
%"integer"
%"list"
%"logical"
%"numeric"
%"single"
%"raw"
%
%### the class
%"vector"
%### is a virtual class, extended by all the above
%
%### the class
%"S4"
%### is an object type for S4 objects that do not extend
%### any of the basic vector classes.  It is a virtual class.
%
%### The following are additional basic classes
%"NULL"     #  NULL objects
%"function" #  function objects, including primitives
%"externalptr" # raw external pointers for use in C code
%
%"ANY"  # virtual classes used by the methods package itself
%"VIRTUAL"
%"missing"
%
%"namedList" # the alternative to "list" that preserves
%            # the names attribute
%}
%\section{Objects from the Classes}{
%  If a class is not virtual (see section in \code{\link{Classes}}),
%  objects can be created by calls of the form \code{new(Class, ...)},
%  where \code{Class} is the quoted class name, and the remaining
%  arguments if any are objects to be interpreted as vectors of this
%  class.  Multiple arguments will be concatenated.
%
%  The class \code{"expression"} is slightly odd, in that the \dots
%  arguments will \emph{not} be evaluated; therefore, don't enclose them
%  in a call to \code{quote()}.
%
%  Note that class \code{"list"} is a pure vector.  Although lists with
%  names go back to the earliest versions of S, they are an extension
%  of the vector concept in that they have an attribute (which can now
%  be a slot) and which is either \code{NULL} or a character vector of
%  the same length as the vector.  If you want to guarantee that list
%  names are preserved, use class \code{"namedList"}, rather than
%  \code{"list"}.  Objects from this class must have a names attribute,
%  corresponding to slot \code{"names"},
%  of type \code{"character"}.  Internally, R treats names for
%  lists  specially, which makes it impractical to have the corresponding slot in
%  class \code{"namedList"} be a union of character names and \code{NULL}.
%
%}
%
%\section{Classes and Types}{
%The basic classes include classes for the basic R types.  Note that
%objects of these types will not usually be S4 objects
%(\code{\link{isS4}} will return \code{FALSE}), although objects from
%classes that contain the basic class will be S4 objects, still with
%the same type.  The type as
%returned by \code{\link{typeof}} will sometimes differ from the class,
%either just from a choice of terminology (type \code{"symbol"} and
%class \code{"name"}, for example) or because there is not a one-to-one
%correspondence between class and type (most of the classes that
%inherit from class \code{"language"} have type \code{"language"}, for example).
%}
%
%
%\section{Extends}{
%  The vector classes extend \code{"vector"}, directly.
%}
%\section{Methods}{
%  \describe{
%    \item{coerce}{Methods are defined to coerce arbitrary objects to
%      the vector classes, by calling the corresponding basic function, for
%      example, \code{as(x, "numeric")} calls \code{as.numeric(x)}. }
%  }
%}
%\keyword{classes}
%