% File src/library/methods/man/Classes.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{Classes}
%@%\alias{クラス定義}
\alias{Classes}
\alias{__ClassMetaData}
\alias{.environment-class}
\alias{.externalptr-class}
\alias{.name-class}
\alias{.NULL-class}
\title{クラスの定義}
%\title{Class Definitions}
\description{
  クラス定義は
  \R オブジェクトのクラスの形式的定義を含むオブジェクトで，
  非形式的な S3 クラスと区別するために，普通
  S4 クラスと参照される．このドキュメントは S4 クラスの概観を与える；
  クラス表現オブジェクトの詳細については
  クラス \code{\linkS4class{classRepresentation}} に対するヘルプを見よ．
}
\section{メタデータ情報}{
  クラスが定義されるとクラスに関する情報を格納するオブジェクトが
  保管される．
  クラスを定義する\emph{メタデータ}として知られるこのオブジェクトは
  クラスの名前により保管されず
  (プログラマがその名前の生成関数を書くことを認めるために)，
  特別に構成された名前で保管される．クラス定義を吟味するためには
  \code{\link{getClass}} を呼び出す．メタデータ情報は以下を含む：

  \describe{
    \item{スロット：}{

      S4 クラスからのオブジェクト中に含まれるデータは
      クラス定義の\emph{スロット}により定義される．

      オブジェクト中の各スロットはオブジェクトの成分である；
      リストの成分(つまり要素)の様にこれらは
      関数 \code{\link{slot}()} またはよりしばしば演算子
      \code{"\link{@}"} で取り出したり設定できる．
      しかしながら，重要な点でそれらはリスト成分とは異なる．
      先ずスロットは名前でだけ参照でき位置では出来ず，
      リスト要素とは異なり部分マッチングは出来ない．

      特定のクラスからの全てのオブジェクトは同じスロット名のセットを持つ；
      特にスロット名はクラス定義に含まれている．
      各オブジェクト中の各スロットは
      常に現在のクラスの定義中のこのスロットに対して指定された
      クラスのオブジェクトである．
      単語 \dQuote{is} は同名の
      \R 関数(\code{\link{is}}) に対応し，
      スロット中のオブジェクトのクラスが定義で指定されたクラス
      または定義中のそれを拡張するあるクラス(\emph{サブクラス})
      と同じでなければならないことを意味する．

      特別なスロット名 \code{.Data} はオブジェクトの
      \sQuote{データ部}用である．
      データ部を持つクラスからのオブジェクトはクラスが
      \R のオブジェクトタイプの一つか特別な擬似クラス
      \code{matrix} または \code{array} のどれかを含むことを
      指定することで定義される．普通クラスまたはそのスーパークラス
      の一つの定義はその \code{contains} 引数中に
      タイプや擬似クラスを含むからである．
      二番目の特殊スロット名 \code{.xData} は
      \code{"environment"} の様な特殊なタイプからの継承を可能にするために
      使われる．
      これらのクラスからのオブジェクトを持つ S3 メソッドの表現と
      挙動に関する詳細については非 S4 クラスからの継承に関する
      節を見よ．

      ある種のスロット名は旧式の S3 オブジェクト中と
      明示的なクラスを持たない \R オブジェクト中の
      属性に対応する，例えば \code{names} 属性．
      名前付きベクトルのサブクラスのような，
      属性が設定されるクラスを定義するならば，
      \code{"names"} をスロットとして含めるべきである．
      例えば \code{"namedList"} クラスの定義を見よ．
      そうした名前の設定に \code{names()} 付値を使うと
      もし名前付きのスロットがなければ警告が出，
      問題のオブジェクトがベクトルタイプでなければ
      エラーになる．\code{"names"} と呼ばれるスロットはどこでも使えるが，
      それがスロットとして付値された時だけで
      既定の \code{names()} 付値を使ってではない．

    }
    \item{スーパークラス：}{

      クラスの定義はこのクラスを拡張するクラスである
      \emph{スーパークラス}を含む．
      例えばクラス \code{Fancy} は，もし
      \code{Fancy} クラスからのオブジェクトが
      \code{Simple} クラスの全て(そして恐らくそれ以上)の機能を持てば
      クラス \code{Simple} を拡張する．特に，そして非常に有用に，
      \code{Simple} オブジェクトに対して動作する任意の定義されたオブジェクト
      は同様に \code{Fancy} オブジェクトにも適用できる．

      この関係は同じことであるが
      \code{Simple} は \code{Fancy} のスーパークラスである，または
      \code{Fancy} は \code{Simple} のサブクラスであると表現できる．

      あるクラスの直接のスーパークラスは
      明示的に定義されたスーパークラスである．
      直接のスーパークラスは三つの方法で定義できる．
      最も普通にはスーパークラスは
      サブクラスを作る \code{\link{setClass}} への呼び出し中の
      \code{contains=} 引数中に並べられる．
      この場合サブクラスはスーパークラスの全てのスロットを
      含み，クラス間の関係はそれが実際そうであるように
      \emph{単純}であると呼ばれる；
      スーパークラスは又
      \code{\link{setIs}} への呼び出しで明示的に定義できる；
      この場合関係はサブクラスからスーパークラスへ向かうための
      指定されたメソッドを必要とする．
      三つ目として，クラスの合併は合併の全てのメンバーのスーパークラス
      になる．この場合も関係は単純であるが，関係はスーパークラスが
      定義された時に定義され，
      \code{contains=} 機構をもちいた時の様にサブクラスが
      作られた時では無いことを注意する．

      スーパークラスの定義はまた潜在的に
      それ自体の直接のスーパークラスを含む．
      これらはオリジナルのクラスから距離2のスーパークラスを
      考えら(そして表示され)れる；
      それらの直接のスーパークラスは距離3にある，云々．
      これら全てはメソッド選択等の目的に取っては正当なスーパークラスである．

      \code{contains=} 引数へスーパークラスの名前を含めることで
      スーパークラスが定義される時，
      このクラスからのオブジェクトはそれ自体のクラスに対して
      定義された全てのスロットと\emph{そして}
      その全てのスーパークラスに対して定義された全てのスロットを持つ．

      クラスとその特定のスーパークラス間の関係の情報は
      クラス \code{\linkS4class{SClassExtension}} のオブジェクトとして
      エンコードされる．
      スーパークラス(ある場合にはサブクラス)に対するそうしたオブジェクトの
      リストはクラスを定義するメタデータオブジェクト中に含まれる．
      もしこれらのオブジェクトを用いた計算
      が必要なら(例えば距離を比較する)，関数
      \code{\link{extends}} を引数 \code{fullInfo=TRUE} で呼び出す．

    }
    \item{プロトタイプ：}{

      \code{\link{new}} への呼び出しで作られたクラスからのオブジェクト
      はクラスに対する\emph{プロトタイプ}オブジェクトと
      \code{\link{new}} への呼び出し中の追加引数により定義される．
      引数は関数 \code{\link{initialize}} に対するそのクラスのメソッドに
      渡される．

      オブジェクトを表現する各クラスはそのクラスに対する
      プロトタイプオブジェクトをを含む
      (仮想クラスに対してはプロトタイプオブジェクトは
      \code{NULL} かもしれない)．
      プロトタイプオブジェクトはそのクラスの全てのスロット
      に対して値を持たなければならない．
      既定では対応するスロットクラスのプロトタイプがある．
      しかしながらクラスの定義は任意のスロットに対する任意の適正な
      オブジェクトを指定できる．
    }
  }
}
\section{仮想的クラス；基本クラス}{

      \code{\link{new}} への呼び出しで実際のオブジェクトが何も
      作られない\emph{仮想的}なクラスがあり，実際には
      非常に重要なプログラミングツールである．
      それらはある種のプログラミング挙動を共有したい通常のクラスを
      ，挙動をどのように実装するかを制約する必要無しにまとめるために使われる．
      仮想クラスの定義は希望すればスロットを含むことが出来る
      (オブジェクトを完全に定義することなしにある種の共通の挙動を
      提供するために --- 例えばクラス \code{\linkS4class{traceable}} を見よ)．

      仮想クラスの単純で有用な形式は\emph{合併クラス}であり，
      \code{\link{setClassUnion}} への呼び出しで一つ又はそれ以上の
      サブクラスを羅列することで定義される仮想クラスである
      (合併クラスを拡張するクラス)．
      合併クラスはサブクラスとして基本的なオブジェクトタイプを
      含むことが出来る(その定義はさもなければ封印される)．

      幾つかの\sQuote{基本}クラスがあり，
      \R 中で登場する通常の種類のデータに対応する．
      例えば \code{"numeric"} は数値ベクトルに対応するクラスである．
      他のベクトル基本クラスは
      \code{"logical"}, \code{"integer"},
      \code{"complex"}, \code{"character"},  \code{"raw"}, \code{"list"}
      そして \code{"expression"} である．
      ベクトルクラスに対するプロトタイプは
      対応するタイプの長さ0のベクトルである．
      基本クラスはプロトタイプオブジェクトがクラス自体からの
      ものであるという点で普通ではない．

      ベクトルクラスに加えて \code{"function"} や \code{"call"}
      のような言語中のオブジェクトに対応する基本クラスがまたある．
      これらのクラスは仮想的クラス
      \code{"language"} のサブクラスである．
      最後に \code{"environment"} と \code{"externalptr"} の様な
      \dQuote{異常}なオブジェクトに対するオブジェクトタイプと
      対応する基本クラスがある．
      これらのオブジェクトは言語の機能的挙動に従わない；
      特にそれらはコピーされず，従って局所的に定義される
      属性やスロットを持つことが出来ない．

     これら全てのクラスは任意の他のクラス定義に対するスロットや
     スーパークラスとして使うことができるが，
     それら自体は明示的なクラスを伴わない．
     異常なオブジェクトタイプに対しては，
     以下で述べる継承を可能にするために特別な機構が使われる．

}
% S3 classes

\section{非 S4 クラスからの継承}{
  クラス定義は正規の S4 以外のクラスも拡張でき，
  普通それらを
  \code{\link{setClass}} への \code{contains=} 引数として
  指定する．そうしたクラスの三種類のグループは異なった挙動を持つ：
\enumerate{
\item
S3 クラス，これは事前に
\code{\link{setOldClass}} の呼び出しで登録されている必要がある
(これが行われているかどうかは
  \code{\link{getClass}} の呼び出しでチェックでき，これは
  \linkS4class{oldClass} を拡張するクラスを返すべきである)．

\item
  典型的にはベクトルタイプの \R のオブジェクトタイプの一つで，
    これはすると S4 オブジェクトのタイプを定義するが，
    S4 オブジェクトに対するタイプとしては直接使えない
    \code{\link{environment}} の様なタイプも定義する．
    下を見よ．

\item
  擬似クラス \code{\linkS4class{matrix}} と \code{\linkS4class{array}} の
      一つで，任意のベクトルタイプに
      \code{dim} と \code{dimnames} 属性を加えたオブジェクトを意味する．
  }

  この節は S4 クラスと旧式の S3 クラスを用いた計算を
  そうしたクラスをスーパークラスとして用いて結合するアプローチを
  解説する．デザインの目標は S4 クラスが S3 メソッドと
  既定の計算を継承することを可能な限り一貫性のある形式で
  許すことである．

  R 中の S4 と S3 コードをより一貫性のあるものにする一般的な努力の
  一部として，S3 総称的関数
  (\code{\link{UseMethod}} を呼び出すもの)に対してかまたは
  S3 メソッドを選択適用するプリミティブ関数のどれかに対してか
  S4 クラスが
  非既定の S3 メソッドの第一引数として使われた時，そのメソッドに対して
  適正なオブジェクトを提供する努力が行われる．
  特に，もし S4 クラスが
  S3 クラスや \code{matrix} 又は \code{array} を拡張し，そして
  これらのクラスにマッチする S3 メソッドがあれば，S3 クラスの形式的
  定義が無いという条件の下で可能な範囲内で
  S4 オブジェクトは適正な S3 オブジェクトに強制変換される．

  例えば \code{"myFrame"} が
  S3 クラス \code{"data.frame"} を \code{\link{setClass}} の
  \code{contains=} 引数中に含む S4 クラスであると仮定する．
  この S4 クラスからのオブジェクトが関数，例えば
  \code{"data.frame"} に対する S3 メソッドを持つ \code{\link{as.matrix}} に
  渡されると，\code{\link{UseMethod}} に対する内部コードはオブジェクトを
  データフレームに変換する；特にそのクラス属性が
  S3 クラス(可能性として複数のクラス名を含む)に対応するベクトルである
  S3 オブジェクトに変換する．同様に
  \code{"matrix"} または \code{"array"} を継承する S4 オブジェクトに
  対しては，S4 オブジェクトは適正な S3 行列または配列に変換される．

  S4 オブジェクトが既定の S3 メソッドに渡された時は変換は適用
  \emph{されない}ことを注意しよう．
  ある種の S3 総称的関数は S4 オブジェクトを含む一般的なオブジェクト
  を処理しようと試みる．
  又選択された S3 メソッドに対応しない S4 オブジェクトには如何なる
  変換も行われない；特に S3 クラスか基本的タイプのどれかを含まない
  クラスからのオブジェクトに対してはそうである．
  変換の詳細については \code{\link{asS4}} を見よ．

      明示的な S3 総称的関数に加えて，
      S3 メソッドはプリミティブとして実装されている様々な演算子と
      関数に対して定義されている．
      これらのメソッドはある内部的な C コードにより，
      一部は実際の S3 総称的関数と同じコードを通じて，
      そして一部は特別な配慮
      (例えば二項演算子の二つの引数がメソッドを探す時に吟味される)
      により選択適用される．S4 オブジェクトを
      S3 メソッドに適合させる同じ機構が又これらの計算に適用されるが，
      適当な S3 クラスやタイプに拡張されない S4 オブジェクトが
      二項演算子に渡されるとエラーが発生する等の少数の例外がある．

      この節の残りは基本的オブジェクトタイプからの継承に対する機構を
      解説する．行列と配列擬似クラスや時系列からの継承については
      \code{\linkS4class{matrix}} や \code{\linkS4class{array}} を見よ．
      対応する S3 クラスからの継承に関する詳細は \code{\link{setOldClass}} を見よ．

      \R の基本的データタイプの一つを直接かつ単純に含むクラスからのオブジェクト
      は対応するそのタイプの
      \code{.Data} スロットを暗黙のうちに持ち，
      他のスロットを変更せずにデータ部分を取り出したり置き換える
      ことが許される．
      もしタイプが属性を受け入れ普通に複製できるのなら，
      継承はまたオブジェクトのタイプも決める；
      もしクラス定義が普通のタイプに対応する
      \code{.Data} スロットを持てば，スロットのクラスが
      オブジェクトのタイプを決定する
      (つまり \code{\link{typeof}(x)} の値)．
      そうしたクラスに対しては \code{.Data} は擬似スロットである；
      つまりそれを取り出したり設定するとデータ中の非スロットデータを
      変更する．
      関数 \code{\link{getDataPart}} と \code{\link{setDataPart}} は
      よりクリーンであるが，データ部分を処理する本質的に同値な
      方法である．

      基本的タイプをこのように拡張することはオブジェクトが
      S4 メソッドと並んで対応するタイプに対する旧式のコードを
      使うことを可能にする．
      \code{.Data} に対しては任意の基本的タイプが使用可能であるが，
      幾つかのタイプは通常のオブジェクトのようには振るまわないので
      異なって扱われる；例えば
      \code{"NULL"}，環境，そして外部ポインターが該当する．

      クラスはこれらのタイプを
      それ自体内部的に定義された S4 クラスを継承する
      スロット \code{.xData} を持つことで拡張する．
      このスロットは実際には継承されたタイプのオブジェクトを含み，
      そのタイプの参照セマンティックスから計算を防御する．
      非標準的なオブジェクトタイプへの強制変換はすると
      他のタイプやクラスの \code{"simple"} な抱合ではなく
      実際の計算を必要とする．
      目的はプログラマーが機構を考慮する必要が無いが，
      任意のオブジェクトタイプからの継承を検出するために
      S4 オブジェクトのタイプを明示的に使うべきでは\emph{無い}という
      ことを含意する．代わりに \code{\link{is}} や類似の関数を使う．
}

\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョン．)

  Chambers, John M.  and Hastie, Trevor  J. eds (1992)
  \emph{Statistical Models in S.}
  Wadsworth & Brooks/Cole (S3 クラスに対しては Appendix A．)

  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole. (絶版．)
  (ベクトル，行列，配列，そして時系列オブジェクトの記述．)
}

\seealso{
  メソッドに対する同様の議論については \code{\link{Methods}}，
  クラス定義の指定の詳細は \code{\link{setClass}}，
  \code{\link{is}},
  \code{\link{as}},
  \code{\link{new}},
  \code{\link{slot}}
}
\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/Classes.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Classes}
%\alias{Classes}
%\alias{__ClassMetaData}
%\alias{.environment-class}
%\alias{.externalptr-class}
%\alias{.name-class}
%\alias{.NULL-class}
%\title{Class Definitions}
%\description{
%  Class definitions are objects that contain the formal definition of a
%  class of \R objects, usually referred to as an S4 class, to
%  distinguish them from the informal S3 classes.
%  This document gives an overview of S4 classes; for
%  details of the class representation objects, see help for the class
%  \code{\linkS4class{classRepresentation}}.
%}
%\section{Metadata Information}{
%  When a class is defined, an object is stored that contains the
%  information about that class.  The object, known as the
%  \emph{metadata} defining the class, is not stored under the name of
%  the class (to allow programmers to write generating functions of
%  that name), but under a specially constructed name.
%  To examine the class definition, call \code{\link{getClass}}.  The
%  information in the metadata object includes:
%
%  \describe{
%    \item{Slots:}{
%
%        The data contained in an object from an S4 class is defined by
%        the \emph{slots} in the class definition.
%
%        Each slot in an object is a component of the object;
%        like components (that is, elements) of a
%      list, these may be extracted and set, using the
%      function \code{\link{slot}()} or more often the operator
%        \code{"\link{@}"}.  However, they
%      differ from list components in important ways.
%      First, slots can only be referred to by name, not by position,
%      and there is no partial matching of names as with list elements.
%
%      All the objects from a particular class have the same set of slot
%      names; specifically, the slot names that are contained in the
%      class definition.  Each slot in each object always is an object
%      of  the
%      class specified for this slot in the definition of the current class.
%      The word \dQuote{is} corresponds to the \R function of the same
%      name (\code{\link{is}}), meaning that the class of the object in
%      the slot must be the same as the class specified in the
%      definition, or some class that extends the one in the
%      definition (a \emph{subclass}).
%
%      A special slot name, \code{.Data}, stands for the
%      \sQuote{data part} of the object.  An object from a class with a
%      data part is defined by specifying that the class contains one
%      of the \R object types or one of the special pseudo-classes,
%      \code{matrix} or \code{array}, usually because the definition of
%      the class, or of one of its superclasses, has included the type
%      or pseudo-class in its \code{contains} argument.  A second
%      special slot name, \code{.xData}, is used to enable inheritance
%      from abnormal types such as \code{"environment"}
%      See the section on inheriting from non-S4 classes
%      for details on the representation and
%      for the behavior of S3 methods with objects from these classes.
%
%      Some slot names correspond to attributes used in old-style S3
%      objects and in \R objects without an explicit class, for
%      example, the \code{names} attribute.  If you define a class for
%      which that attribute will be set, such as a subclass of named
%      vectors, you should include \code{"names"} as a slot.  See the
%      definition of class \code{"namedList"} for an example.  Using the
%      \code{names()} assignment to set such names will generate a
%      warning if there is no names slot and an error if the object in
%      question is not a vector type.  A slot called \code{"names"} can
%      be used anywhere, but only if it is assigned as a slot, not via
%      the default \code{names()} assignment.
%
%    }
%    \item{Superclasses:}{
%
%      The definition of a class includes the \emph{superclasses} ---the
%      classes that this class extends.  A
%      class \code{Fancy}, say, extends a class \code{Simple} if an
%      object from the \code{Fancy} class has all the capabilities of
%      the \code{Simple} class (and probably some more as well).  In
%      particular, and very usefully, any method defined to work for a
%      \code{Simple} object can be applied to a \code{Fancy} object as
%      well.
%
%      This relationship is expressed equivalently by saying that
%      \code{Simple} is a superclass of \code{Fancy}, or that
%      \code{Fancy} is a subclass of \code{Simple}.
%
%      The direct superclasses of a class are those superclasses
%      explicitly defined.   Direct superclasses can be defined in
%      three ways.  Most commonly, the superclasses are listed in the
%      \code{contains=} argument in the call to \code{\link{setClass}}
%      that creates the subclass.   In this case the subclass will
%      contain all the slots of the superclass, and the relation
%      between the class is called \emph{simple}, as it in fact is.
%      Superclasses can also be defined
%      explicitly by a call to \code{\link{setIs}}; in this case, the
%      relation requires methods to be specified to go from subclass to
%      superclass.   Thirdly, a class union is a superclass of all the
%      members of the union.  In this case too the relation is simple,
%      but notice that the relation is defined when the superclass is
%      created, not when the subclass is created as with the
%      \code{contains=} mechanism.
%
%      The definition of a superclass will also potentially contain
%      its own direct superclasses.  These are considered (and shown) as
%      superclasses at distance 2 from the original class; their direct
%      superclasses are at distance 3, and so on.  All these are
%      legitimate superclasses for purposes such as method selection.
%
%      When superclasses are defined  by including the names of
%      superclasses in the \code{contains=} argument to
%      \code{\link{setClass}}, an object from the class will have all the
%      slots defined for its own class \emph{and} all the slots defined
%      for all its superclasses as well.
%
%      The information about the relation between a class and a
%      particular superclass is encoded as an object of class
%      \code{\linkS4class{SClassExtension}}.  A list of such objects for
%      the superclasses (and sometimes for the subclasses) is included in
%      the metadata object defining the class.  If you need to compute
%      with these objects (for example, to compare the distances), call
%      the function \code{\link{extends}} with argument \code{fullInfo=TRUE}.
%
%    }
%    \item{Prototype:}{
%
%      The objects from a class created by a call to
%      \code{\link{new}}
%      are defined by the \emph{prototype} object for the class and by
%      additional arguments in the call to \code{\link{new}}, which are
%      passed to a method for that class for the function
%      \code{\link{initialize}}.
%
%      Each class representation object contains a prototype object
%      for the class (although for a virtual class the prototype may be
%      \code{NULL}). The prototype object must have values for all the
%      slots of the class.
%      By default, these are the prototypes of the corresponding slot
%      classes.  However, the definition of the class can specify any
%      valid object for any of the slots.
%    }
%  }
%}
%\section{Virtual classes; Basic classes}{
%
%      Classes exist for which no actual objects can be created by a
%      call to \code{\link{new}}, the \emph{virtual} classes, in fact a
%      very important programming tool.  They are used to group together
%      ordinary classes that want to share some programming behavior,
%      without necessarily restricting how the behavior is implemented.
%      Virtual class definitions may if you want include
%      slots (to provide some common behavior without fully defining
%      the object---see the class \code{\linkS4class{traceable}} for an example).
%
%      A simple and useful form of virtual class is the \emph{class
%        union}, a virtual class that is defined in a call to
%      \code{\link{setClassUnion}} by listing one or
%      more of subclasses (classes that extend the class union).  Class
%      unions can include as subclasses basic object types (whose
%      definition is otherwise sealed).
%
%      There are a number of \sQuote{basic} classes, corresponding to the
%      ordinary kinds of data occurring in \R.  For example,
%      \code{"numeric"} is a class corresponding to numeric vectors.
%      The other vector basic classes are \code{"logical"}, \code{"integer"},
%      \code{"complex"}, \code{"character"},  \code{"raw"}, \code{"list"}
%      and \code{"expression"}.
%      The prototypes for
%      the vector classes are vectors of length 0 of the corresponding
%      type.  Notice that basic classes are unusual in that the
%      prototype object is from the class itself.
%
%      In addition to the vector classes there are also basic classes
%      corresponding to objects in the
%      language, such as \code{"function"} and \code{"call"}.
%      These classes are subclasses of the virtual class \code{"language"}.
%      Finally, there are object types and corresponding basic classes for
%      \dQuote{abnormal} objects, such as \code{"environment"} and
%      \code{"externalptr"}.
%      These objects do not follow the
%      functional behavior of the language; in particular, they are not
%      copied and so cannot have attributes or slots defined locally.
%
%     All these classes can be used as slots or as
%      superclasses for any other class definitions, although they do
%      not themselves come with an explicit class.  For the abnormal
%      object types, a special mechanism is used to enable inheritance
%      as described below.
%
%
%}
%% S3 classes
%
%\section{Inheriting from non-S4 Classes}{
%  A class definition can extend classes other than
%  regular S4 classes, usually by specifying them in the
%  \code{contains=} argument to \code{\link{setClass}}.  Three groups
%  of such classes behave distinctly:
%\enumerate{
%\item
%S3 classes, which must have been registered by a previous call to
%\code{\link{setOldClass}} (you can check that this has been done
%  by calling \code{\link{getClass}}, which should return a class that
%  extends \linkS4class{oldClass});
%
%\item
%  One of the \R object types, typically a vector type, which then
%    defines the type of the S4 objects, but also a type such as
%    \code{\link{environment}} that can not be used directly as a type
%    for an S4 object.  See
%    below.
%
%\item
%  One of the pseudo-classes \code{\linkS4class{matrix}}
%      and \code{\linkS4class{array}}, implying objects with
%      arbitrary vector types plus the \code{dim} and \code{dimnames}
%      attributes.
%  }
%
%  This section describes the approach to combining S4 computations
%  with older S3 computations by using such classes as superclasses. The
%  design goal is to allow the S4 class to inherit S3 methods and
%  default computations in as consistent a form as possible.
%
%  As part of a general effort to make the S4 and S3 code in R more
%  consistent, when objects from an S4 class are used as the first
%  argument to a non-default S3 method, either for an S3 generic function
%  (one that calls \code{\link{UseMethod}}) or for one of the primitive
%  functions that dispatches S3 methods, an effort is made to provide a
%  valid object for that method.  In particular, if the S4 class extends
%  an S3 class or \code{matrix} or \code{array}, and there is an S3
%  method matching one of these classes, the S4 object will be coerced to
%  a valid S3 object, to the extent that is possible given that there is
%  no formal definition of an S3 class.
%
%  For example, suppose \code{"myFrame"} is an S4 class that includes the
%  S3 class \code{"data.frame"} in the \code{contains=} argument to
%  \code{\link{setClass}}.  If an object from this S4 class is passed to
%  a function, say \code{\link{as.matrix}}, that has an S3 method for
%  \code{"data.frame"}, the internal code for \code{\link{UseMethod}}
%  will convert the object to a data frame; in particular, to an S3
%  object whose class attribute will be the vector corresponding to the
%  S3 class (possibly containing multiple class names). Similarly for an
%  S4 object inheriting from \code{"matrix"} or \code{"array"}, the S4
%  object will be converted to a valid S3 matrix or array.
%
%  Note that the conversion is \emph{not} applied when an S4 object is
%  passed to the default S3 method.  Some S3 generics attempt to deal
%  with general objects, including S4 objects.  Also, no transformation
%  is applied to S4 objects that do not correspond to a selected S3
%  method; in particular, to objects from a class that does not contain
%  either an S3 class or one of the basic types.  See \code{\link{asS4}}
%  for the transformation details.
%
%      In addition to explicit S3 generic functions, S3 methods are
%      defined for a variety of operators and functions implemented as
%      primitives.  These methods are dispatched by some internal C
%      code that operates partly through the same code as real S3
%      generic functions and partly via special considerations (for
%      example, both arguments to a binary operator are examined when
%      looking for methods).  The same mechanism for adapting S4
%      objects to S3 methods has been applied to these computations as
%      well, with a few exceptions such as generating an error if an S4
%      object that does not extend an appropriate S3 class or type is
%      passed to a binary operator.
%
%      The remainder of this section discusses the mechanisms for
%      inheriting from  basic object types. See \code{\linkS4class{matrix}}
%      or \code{\linkS4class{array}}
%      for inhering from the matrix and array
%      pseudo-classes, or from time-series.  For the
%      corresponding details for inheritance
%      from S3 classes, see \code{\link{setOldClass}}.
%
%      An object from a class that directly and simply contains one
%      of the basic object types in \R, has implicitly a corresponding
%      \code{.Data} slot of that type, allowing computations to extract
%      or replace the data part while leaving other slots
%      unchanged. If the type is one that can accept attributes and is
%      duplicated normally, the inheritance also determines the type of the
%      object; if the class definition has a \code{.Data} slot
%      corresponding to a normal type, the class of the
%      slot determines the type of the object (that is, the value of
%      \code{\link{typeof}(x)}).
%      For such classes,  \code{.Data} is a pseudo-slot; that
%      is, extracting or setting it modifies the non-slot data in the
%      object.  The functions \code{\link{getDataPart}} and
%      \code{\link{setDataPart}} are a cleaner, but essentially
%      equivalent way to deal with the data part.
%
%      Extending a basic type this way allows objects to
%      use old-style code for the corresponding type as well as S4
%      methods.  Any basic type can be used for \code{.Data}, but
%      a few types are treated differently because they do not behave like ordinary objects;
%      for example, \code{"NULL"}, environments, and external pointers.
%      Classes extend these types by having a slot, \code{.xData},
%      itself inherited from an internally defined S4 class.  This
%      slot actually contains an object of the inherited type, to
%      protect computations from the reference semantics of the type.
%      Coercing to the nonstandard object type then requires an
%      actual computation, rather than the \code{"simple"} inclusion
%      for other types and classes.  The intent is that programmers
%      will not need to take account of the mechanism, but one
%      implication is that you should \emph{not} explicitly use the
%      type of an S4 object to detect inheritance from an arbitrary
%      object type.  Use
%      \code{\link{is}} and similar functions instead.
%}
%
%
%
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%
%  Chambers, John M.  and Hastie, Trevor  J. eds (1992)
%  \emph{Statistical Models in S.}
%  Wadsworth & Brooks/Cole (Appendix A for S3 classes.)
%
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole. (Out of print.) (The description of
%  vectors, matrix, array and time-series objects.)
%}
%
%\seealso{
%  \code{\link{Methods}} for analogous discussion of methods,
%  \code{\link{setClass}} for details of specifying class definitions,
%  \code{\link{is}},
%  \code{\link{as}},
%  \code{\link{new}},
%  \code{\link{slot}}
%}
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%