% File src/library/methods/man/Documentation.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{Documentation}
%@%\alias{ドキュメント使う・作る}
\alias{Documentation}
\alias{Documentation-class}
\alias{Documentation-methods}
\title{クラスとメソッドに対するオンラインドキュメントを使う・作る}
%\title{Using and Creating On-line Documentation for Classes and Methods}

\description{
  メソッドパッケージのソフトウェアで作られたクラスとメソッドを
  記述する特別なドキュメントを提供することが出来る．
  このドキュメントにアクセスしそれを R のヘルプファイル中に作る
  テクニックがここで解説される．}
\section{クラスとメソッドに関するドキュメントを得る}{
  クラス定義，総称的関数の特定のメソッド，そして総称的関数の一般的な
  議論に対するオンラインヘルプを問い合わせることが出来る．
  これらの要求は \code{?} 演算子を使う
  (演算子の一般的な記述に関しては \code{\link{help}} を見よ)．
  勿論対応するトピックに関する何らかのドキュメントが
  \emph{ある}かどうかは実装者次第である．

  クラスに関するドキュメントは
  \code{?} の左に引数 \code{class} を，右にクラス名を使う；例えば，

\code{class ? genericFunction}

  はクラス \code{"genericFunction"} に関するドキュメントを問い合わせる．

特定の関数に対して定義されたメソッドに対するドキュメントが必要なら，
メソッドの一般的解説や特定のメソッド
(つまり，実際の引数の特定のセットに対して選択される特定のメソッドの
ドキュメント)を問い合わせることが出来る．

全体的なメソッドのドキュメントは
\code{?} 演算子を \code{methods} を左側引数に
そして関数名を右側に於いて呼び出すことで要求できる．
例えば，

\code{methods ? initialize}

は \code{\link{initialize}} 関数に対するメソッドに対するドキュメントを
問い合わせる．

特定のメソッドに関するドキュメントの問い合わせは
\code{"?"} 演算子の右側引数に関数呼び出し表現式を与えることで
なされる．引数に対するクラス名か，実際の呼び出し中で
使うことを意図している表現式を与えるかどちらを好むかに応じて
二つの形式がある．

例えば関数呼び出し \code{myFun(x, sqrt(wt))} を評価することを
計画しており
この呼び出しに対して使われるメソッドに関する何かを探したければ，
\code{"?"} 演算子の右側に呼び出しを置く：

\code{?myFun(x, sqrt(wt))}

呼び出し自体に対してそうあるようにメソッドが選択され，
そしてそのメソッドに対するドキュメントが要求される．
もし \code{myFun} が総称的関数でなければ，関数に対する通常の
ドキュメントが要求される．

もしメソッドのドキュメントが欲しい実際のクラスを知っていれば，
これらを引数表現の代わりに明示的に与えることが出来る．
上の例では，もし
クラス \code{"maybeNumber"} を持つ第一引数と
二番目の \code{"logical"} に対するメソッドのドキュメントを
必要とすれば \code{"?"} 演算子を今回は
左側引数 \code{method} とクラス名を引数として右側に
関数呼び出しとして用いる：

\code{method ? myFun("maybeNumber", "logical")}

再びメソッドが選ばれるが，今回は指定されたクラスに対応した
メソッドのドキュメントが要求される．
このバージョンは総称的関数に対してだけ動作する．

この二つの形式はそれぞれ長所を持つ．
実際の引数を用いたバージョンは引数のクラスを
特定(または推測)する必要がない．
一方で，引数の評価は例に応じて少し時間がかかるかもしれない．
クラス名を用いたバージョンはクラスを選ぶ必要があるが，しかし
曖昧さが無い．
これは提供されたクラスが仮想的クラスでも良いという点で
より微妙な長所を持ち，その場合
どの引数もこのクラスを明確には持たない．
例えばクラス \code{"maybeNumber"} は合併クラスであっても良い
(\code{\link{setClassUnion}} に対する例を見よ)．

どちらの形式でも，メソッドが
継承の使用とグループ総称的関数を含み実際の計算でそうなるように選択される．
詳細は適当なメソッドを見つけるのに使われる関数である
\code{\link{selectMethod}} を見よ．
}

\section{メソッドに対するドキュメントを書く}{
メソッドとクラスに対するオンラインドキュメントは
上で説明されたクラスとメソッドのドキュメントに対する
要求を実装するために R のドキュメント書式への
ある種の拡張を使う．
利用可能なマークアップ命令についてはドキュメント
\emph{Writing R Extensions} を見よ
(もし自分のソフトウェアのドキュメント化の段階にいるのならば
このドキュメントをすでに参考にしているべきである)．

解説される特定のマークアップ命令に加えて，
特定の総称的関数に対して定義されたメソッドに対して
ドキュメントの骨格を持つ全体的な初期的ファイルを作ることができる：

\code{promptMethods("myFun")}

は \code{myFun} 関数に対して定義されたメソッドに対する骨格ドキュメント
を持つファイル\cr
\file{myFun-methods.Rd} を生成する．
\code{promptMethods} からの出力はその関数に対する全てか殆どの
メソッドを，総称的関数自体のドキュメントとは別に，
一つのファイルに記述するのに適している．
ファイルが埋められ自分のソースパッケージの
\file{man} 副ディレクトリに移動されると，メソッドのドキュメント
に対する要求は，
上で解説されたような特定のメソッドドキュメントに対しても

\code{methods ? myFun}

で要求された全般的なドキュメントに対しても
そのファイルを使う．
\code{promptMethods} を使う必要は無いが，もし使えば
作られた全てのファイルを使いたくないかもしれない：
\itemize{
\item もし総称的関数自体に対するドキュメントを含む
    ファイル中にメソッドのドキュメントを入れたければ，
    カットアンドペーストで \verb{\alias} 行と
    既存のファイルに対して
    \code{promptMethods} により作られたファイルからの
    \code{Methods} 節を移動することが出来る．

\item 一方で，もしこれらが補助的なメソッドで，
    付け加えられたか修正されたソフトウェアだけをドキュメント化
    したければ，関心のあるメソッドに対するもの以外の全ての
    \verb{\alias} 行と，
    \code{Methods} 節中の対応する \verb{\item} を除く全ての項目を
    取り除くべきである．この場合普通最初の
    \verb{\alias} 行も同様に取り除く．
    なぜならこれはこの関数に対する一般的なメソッドのドキュメントに対する
    マーカーだからである
    (例では \samp{\alias\{myfun-methods\}})．
}

一つ又は複数のメソッドに対する
ドキュメントをもし特定の R ドキュメントファイルに差し向けたければ，
適当なエイリアスを挿入する．
}
\keyword{programming}
\keyword{methods}
\keyword{classes}
\keyword{documentation}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/Documentation.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Documentation}
%\alias{Documentation}
%\alias{Documentation-class}
%\alias{Documentation-methods}
%\title{Using and Creating On-line Documentation for Classes and
%  Methods}
%\description{Special documentation can be supplied to describe the
%  classes and methods that are created by the software in the methods
%  package.  Techniques to access this documentation and to create it
%  in R help files are described here.}
%\section{Getting documentation on classes and methods}{
%  You can ask for on-line help for class definitions, for specific
%  methods for a generic function, and for general discussion of
%  methods for a generic function.  These requests use the \code{?}
%  operator (see \code{\link{help}} for a general description of
%  the operator).  Of course, you are at the mercy of the implementer
%  as to whether there \emph{is} any documentation on the corresponding
%  topics.
%
%  Documentation on a class uses the argument \code{class} on the left
%  of the \code{?}, and the name of the class on the right; for
%  example,
%
%\code{class ? genericFunction}
%
%to ask for documentation on the class \code{"genericFunction"}.
%
%When you want documentation for the methods defined for a particular
%function, you can ask either for a general discussion of the methods
%or for documentation of a particular method (that is, the method that
%would be selected for a particular set of actual arguments).
%
%Overall methods documentation is requested by
%calling the \code{?} operator with \code{methods} as the left-side
%argument and the name of the function as the right-side argument. For
%example,
%
%\code{methods ? initialize}
%
%asks for documentation on the methods for the \code{\link{initialize}}
%function.
%
%Asking for documentation on a particular method is done by giving a
%function call expression as the right-hand argument to the \code{"?"}
%operator.  There are two forms, depending on whether you prefer to
%give the class names for the arguments or expressions that you intend
%to use in the actual call.
%
%If you planned to evaluate a function call, say \code{myFun(x, sqrt(wt))}
%and wanted to find out something about the method that would be used
%for this call, put the call on the right of the \code{"?"} operator:
%
%\code{?myFun(x, sqrt(wt))}
%
%A method will be selected, as it would be for the call itself, and
%documentation for that method will be requested.  If \code{myFun} is
%not a generic function, ordinary documentation for the function will
%be requested.
%
%If you know the actual classes for which you would like method
%documentation, you can supply these explicitly in place of the
%argument expressions.  In the example above, if you want method
%documentation for the first argument having class \code{"maybeNumber"}
%and the second \code{"logical"}, call the \code{"?"} operator, this
%time with a left-side argument \code{method}, and with a function call
%on the right using the class names as arguments:
%
%\code{method ? myFun("maybeNumber", "logical")}
%
%Once again, a method will be selected, this time corresponding to the
%specified classes, and method documentation will be requested.  This
%version only works with generic functions.
%
%The two forms each have advantages.  The version with actual arguments
%doesn't require you to figure out (or guess at) the classes of the
%arguments.
%On the other hand, evaluating the arguments may take some time,
%depending on the example.
%The version with class names does require you to pick classes, but
%it's otherwise unambiguous.  It has a subtler advantage, in that the
%classes supplied may be virtual classes, in which case no actual
%argument will have specifically this class.  The class
%\code{"maybeNumber"}, for example, might be a class union (see the
%example for \code{\link{setClassUnion}}).
%
%In either form, methods will be selected as they would be in actual
%computation, including use of inheritance and group generic
%functions.  See \code{\link{selectMethod}} for the details, since it is
%the function used to find the appropriate method.
%
%}
%\section{Writing Documentation for Methods}{
%The on-line documentation for methods and classes uses some extensions
%to the R documentation format to implement the requests for class and
%method documentation described above.  See the document \emph{Writing
%  R Extensions} for the available markup commands (you should
%have consulted this document already if you are at the stage of
%documenting your software).
%
%In addition to the specific markup commands to be described, you can
%create an initial, overall file with a skeleton of documentation for
%the methods defined for a particular generic function:
%
%\code{promptMethods("myFun")}
%
%will create a file, \file{myFun-methods.Rd} with a skeleton of
%documentation for the methods defined for function \code{myFun}.
%The output from \code{promptMethods} is suitable if you want to
%describe all or most of the methods for the function in one file,
%separate from the documentation of the generic function itself.
%Once the file has been filled in and moved to the \file{man}
%subdirectory of your source package, requests for methods
%documentation will use that file, both for specific methods
%documentation as described above, and for overall documentation
%requested by
%
%\code{methods ? myFun}
%
%You are not required to use \code{promptMethods}, and if you do, you
%may not want to use the entire file created:
%\itemize{
%\item If you want to document the methods in the file containing the
%    documentation for the generic function itself, you can
%    cut-and-paste to move the \verb{\alias} lines and the
%    \code{Methods} section from the file created by
%    \code{promptMethods} to the existing file.
%
%\item On the other hand, if these are auxiliary methods, and you only
%    want to document the added or modified software, you should strip
%    out all but the relevant \verb{\alias} lines for the methods of
%    interest, and remove all but the corresponding \verb{\item}
%    entries in the \code{Methods} section. Note that in this case you
%    will usually remove the first  \verb{\alias} line as well, since
%    that is the marker for general methods documentation on this
%    function (in the example, \samp{\alias\{myfun-methods\}}).
%}
%
%If you simply want to direct documentation for one or more methods to
%a particular R documentation file, insert the appropriate alias.
%}
%\keyword{programming}
%\keyword{methods}
%\keyword{classes}
%\keyword{documentation}
%
%\encoding{UTF8}
%