% File src/library/methods/man/GenericFunctions.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{GenericFunctions}
%@%\alias{総称的関数の管理}
\alias{GenericFunctions}
\alias{isGeneric}
\alias{isGroup}
\alias{removeGeneric}
\alias{getGenerics}
\alias{dumpMethod}
\alias{findFunction}
\alias{dumpMethods}
\alias{removeMethods}
\alias{signature}
\alias{setReplaceMethod}
%% FIXME:  These are basically not documented at all:
%% -----  isGroup, setReplaceMethod
\title{総称的関数の管理のためのツール}
%\title{Tools for Managing Generic Functions}
\description{
  ここでドキュメント化される関数は総称的関数に関連するメソッドの
  集まりを管理し，同様に総称的関数自体に関する情報を提供する．
}
\usage{
isGeneric(f, where, fdef, getName = FALSE)
isGroup(f, where, fdef)
removeGeneric(f, where)

dumpMethod(f, signature, file, where, def)
findFunction(f, generic = TRUE, where = topenv(parent.frame()))
dumpMethods(f, file, signature, methods, where)
signature(\dots)

removeMethods(f, where = topenv(parent.frame()), all = missing(where))

setReplaceMethod(f, \dots, where = topenv(parent.frame()))

getGenerics(where, searchForm = FALSE)
}
\section{関数の要約}{
  \describe{
    \item{\code{isGeneric}:}{
      \code{f} という名前の関数があるか，もしあれば総称的か?

      \code{getName} 引数は関数が名前を関数定義から見つけることを可能にする．
      もしこれが \code{TRUE} なら総称的関数の名前が返される．
      またはもしこれが総称的関数定義でなければ \code{FALSE} を返す．

      プリミティブ関数に対する \code{isGeneric} と \code{\link{getGeneric}}
      の挙動は少々異なる．
      これらの関数はそれらに対してメソッドが定義されているかどうかにかかわらず，
      形式的関数オブジェクトとしては存在しない
      (効率性と歴史的理由から)
      \code{isGeneric} の呼び出しはこのプリミティブ関数に対してメソッドが
      現在の検索リストや指定された位置 \code{where} のどこかに
      定義されているかどうかを知らせる．
      対照的に \code{\link{getGeneric}} の呼び出しは，それに対して如何なるメソッドも
      定義されていなくても，その関数に対する総称性を返す．
    }

    \item{\code{removeGeneric}, \code{removeMethods}:}{
      この名前の総称的関数に対する全てのメソッドを取り除く．
      加えて \code{removeGeneric} は関数自体を取り除く；
      \code{removeMethods} は既定メソッドであった非総称的関数を回復する．
      もし既定メソッドが無ければ \code{removeMethods} はメソッドが無い
      総称的関数のままにする．
    }
    \item{\code{standardGeneric}:}{
      総称的関数 \code{f} に対する現在の関数呼び出しからのメソッドを
      選択適用する．
      \code{standardGeneric} を対応する総称的関数の本体内以外から呼び出すことは
      エラーである．

      \code{\link{standardGeneric}} は効率性のため
      \pkg{base} パッケージ中のプリミティブ関数であるが，
      % << MM: this is just my guess, what *are* the reasons?
      それが本来属するここでドキュメント化されていることを注意する．
    }
    \item{\code{dumpMethod}:}{
      この総称的関数とシグネチャに対するメソッドをダンプする．
    }
    \item{\code{findFunction}:}{
      \code{name} に対する関数オブジェクトが存在する検索リスト上の位置か
      現在のトップレベルの環境のりストを返す．
      返り値は
      \emph{常に}リストであり，最初の要素を関数の最初の可視の
      バージョンにアクセスするために使う．例を見よ．

      \emph{注意：}
      \code{\link{find}} を
      \code{mode="function"} で使うよりはこれを使う，前者は
      内容がそれほど無く，
      その正規表現の使用法から幾つかの微妙なバグを持つ．
      また \code{\link{library}} の呼び出しを使ってパッケージを付加
      した際にパッケージに対するコード中でも正しく動作する．
    }
    \item{\code{dumpMethods}:}{
      この総称的関数に対する全てのメソッドをダンプする．
    }
    \item{\code{signature}:}{
      総称的関数の引数にマッチされたクラスの名前付きリストを返す．
    }
    \item{\code{getGenerics}:}{
      \code{where} にメソッドが定義されている総称的関数の名前を返す；
      この引数は環境でも検索パスへの添字でも良い．
      既定では全ての検索パスが探される．
      
      メソッドの定義はパッケージの修飾子と共に保管されている；
      例えば
      関数 \code{"initialize"} に対するメソッドは異なったパッケージ上の
      その名前の二つの異なった関数を参照するかもしれない．
      メソッドリストオブジェクトに対応するパッケージ名は
      返されるオブジェクトの
      スロット \code{package} 中に含まれている．
      返される名前の書式は
      \code{searchForm} の値に応じて
      平易(例えば \code{"base"}) でも
      検索リスト(\code{"package:base"})中で使われる形式でも良い．
  }
}}

\arguments{
  \item{f}{関数の名前である文字列．}
  \item{where}{
    オブジェクトを探す環境，名前空間，または検索リスト位置．
    既定では呼び出し関数のトップレベル環境から始まり，
    典型的には大局的環境
    (つまり検索リストを使う)，または呼び出しが由来するパッケージの
    名前空間．
    これらの関数のどれかを間接的に呼び出す際はこの引数を提供することが
    重要である．
    パッケージの名前空間と共には既定はそうした呼び出し中では
    誤る可能性が高い．}

  \item{signature}{
    関連するメソッドのクラスシグネチャ．
    シグネチャは名前付きか名前無しの文字列のベクトルである．
    もし名前付きなら，名前は総称的関数に対する形式的引数名
    でなければならない．
    シグネチャは
    総称的関数のシグネチャスロット中で指定された引数にマッチされる
    (\code{\link{setMethod}} のドキュメントの詳細節を見よ)．

    \code{dumpMethods} への \code{signature} 引数は無視される
    (これは過去の実装中で内部的に使われていた)． }

  \item{file}{そこにメソッド定義をダンプするファイルかコネクション．}

  \item{def}{メソッドを定義する関数オブジェクト；もし省略されると
    シグネチャに対応する現在のメソッド定義．    }

  \item{\dots}{シグネチャを形作る名前付きか名前無しの引数．}

  \item{generic}{
    関数をテストしたり見つける際，総称的関数も含めるべきか．
    非総称的関数だけを得るには \code{FALSE} と置く．    }

  \item{fdef}{
    オプション，総称的関数定義．

    \code{isGeneric} への呼び出しでは普通省略される．   }

  \item{getName}{
    もし \code{TRUE} なら \code{isGeneric} は総称的関数の
    名前を返す．既定では \code{TRUE} を返す．    }
  \item{methods}{
    ダンプされるメソッドを含むメソッドオブジェクト．
    既定ではこの総称的関数に対して定義されるメソッド
    (オプションで指定された \code{where} 位置で)．
  }
  \item{all}{
    \code{removeMethods} 中で，全て
    (既定)か最初に見つかったメソッドが消去されるかを指示する論理値．
    }
  \item{searchForm}{
    \code{getGenerics} 中で，もし \code{TRUE} ならば
    返された結果の \code{package} スロットは
    \code{search()} で使われる形式で，さもなければ
    単純なパッケージ名(例えば \code{"package:base"} 対 \code{"base"})．
  }
}

\section{詳細}{
  \describe{
    \item{\code{setGeneric}:}{
      もしすでにこの名前の非総称的関数が存在すれば，
      \code{def} が提供されない限りそれは総称的関数の定義に使われる．
      そして現在の関数は総称的関数に対する既定メソッドになる．

      もし \code{def} が提供されると，これは総称的関数を定義し
      そして既定メソッドはない
      (関数が全てのオブジェクトの意味のある部分集合に対してだけ
      利用可能であるべきなら，しばしば良い特徴である)．

      引数 \code{group} と \code{valueClass} は
      S-Plus との互換性のために保持されているが現在使われない．
    }
    \item{\code{isGeneric}:}{
      もし \code{fdef} 引数が提供されると，これが総称的関数の
      定義とされ，それが本当に総称的関数かどうかをテストする．
      \code{f} は総称的関数の名前とされる．
      (この引数は S-Plus では利用できない．)
    }
    \item{\code{removeGeneric}:}{
      もし \code{where} が提供されると，検索リストの
      この要素のバージョンを単に取り除く；さもなければ
      最初にであったバージョンが取り除かれる．
    }
    \item{\code{standardGeneric}:}{
      総称的関数は普通それらの本体全体として
      \code{standardGeneric} への呼び出しを持つべきである．
      しかしながら，任意の他の計算も又行える．

      通常の \code{setGeneric} (直接または
      \code{setMethod} の呼び出し経由で) は
      \code{standardGeneric} への呼び出しを持つ関数を作る．
    }
    \item{\code{dumpMethod}:}{
      結果のソースファイルはメソッドを再生性する．
    }
    \item{\code{findFunction}:}{
      もし \code{generic} が \code{FALSE} ならば，総称的関数を無視する．
    }
    \item{\code{dumpMethods}:}{
      もし \code{signature} が提供されると
      この初期シグネチャにマッチするメソッドだけがダンプされる．
      (この特徴は S-Plus には無い：互換性のためには使わないこと．)
    }
    \item{\code{signature}:}{
      \code{signature} を使う利点はどの引数を考えているかについての
      チェックと並んで，メソッド指定に於いてより明快なドキュメント化
      を提供することである．
      加えて \code{signature} は要素の各々が単一の文字列で
      あることをチェックする．
    }
    \item{\code{removeMethods}:}{
      もし \code{f} が総称的関数であれば \code{TRUE} を返す．
      さもなければ \code{FALSE} を(黙って)返す．

      もし既定メソッドがあれば，
      関数はこの定義を持つ単純な関数として再付値される．
      さもなければ，総称的関数にとどまるが既定メソッドは無い
      (従ってそれへの任意の呼び出しはエラーを発生する)．
      どちらの場合も引き続く
      \code{setMethod} への呼び出しは以前のような
      同じ総称的関数を一貫性を持って再確立する．
    }
  }
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (For the R version.)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (For the original S4 version.)
}
\seealso{
  \code{\link{getMethod}} (\code{selectMethod} に対しても)，
  \code{\link{setGeneric}},
  \code{\link{setClass}},
  \code{\link{showMethods}}
}
\examples{
require(stats) # lm に対して

## 関数 "myFun" を得る -- もし 0 かまたは > 1 バージョンが可視なら：
findFuncStrict <- function(fName) {
  allF <- findFunction(fName)
  if(length(allF) == 0)
    stop("No versions of ",fName," visible")
  else if(length(allF) > 1)
    stop(fName," is ambiguous: ", length(allF), " versions")
  else
    get(fName, allF[[1]])
}

try(findFuncStrict("myFun"))# エラー：どのバージョンも無い
lm <- function(x) x+1
try(findFuncStrict("lm"))#    エラー：二つのバージョン
findFuncStrict("findFuncStrict")# 丁度一つのバージョン
rm(lm)

\dontshow{
## nosegfault はメソッドパッケージ無しで standardGeneric を実行するので，
## 実際には何もテストされない．以下はそれが何らかのエラーをキャッチするかチェックする
mustDie <- function(expr)
   stopifnot(is(tryCatch(expr, error=function(e)e), "error"))

mustDie(standardGeneric()) # 単一の文字列を必要とする三つのテスト
mustDie(standardGeneric(NULL))
mustDie(standardGeneric(""))
mustDie(standardGeneric("notAGenericFunction"))
mustDie(standardGeneric("show"))  # 総称的，しかしその本体から呼ばれていない
}

## メソッドのダンプ ------------------------------------

setClass("A", representation(a="numeric"))
setMethod("plot", "A", function(x,y,...){ cat("A meth\n") })
dumpMethod("plot","A", file="")
\dontrun{
setMethod("plot", "A",
function (x, y, ...)
{
    cat("AAAAA\n")
}
)
}%dont
tmp <- tempfile()
dumpMethod("plot","A", file=tmp)
## ここで取り除き，ダンプを構文解析できるかどうかを見る
stopifnot(removeMethod("plot", "A"))
source(tmp)
stopifnot(is(getMethod("plot", "A"), "MethodDefinition"))

## dumpMethods() と同じ：
setClass("B", contains="A")
setMethod("plot", "B", function(x,y,...){ cat("B ...\n") })
dumpMethods("plot", file=tmp)
stopifnot(removeMethod("plot", "A"),
          removeMethod("plot", "B"))
source(tmp)
stopifnot(is(getMethod("plot", "A"), "MethodDefinition"),
          is(getMethod("plot", "B"), "MethodDefinition"))
}
\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/GenericFunctions.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{GenericFunctions}
%\alias{GenericFunctions}
%\alias{isGeneric}
%\alias{isGroup}
%\alias{removeGeneric}
%\alias{getGenerics}
%\alias{dumpMethod}
%\alias{findFunction}
%\alias{dumpMethods}
%\alias{removeMethods}
%\alias{signature}
%\alias{setReplaceMethod}
%%% FIXME:  These are basically not documented at all:
%%% -----  isGroup, setReplaceMethod
%\title{Tools for Managing Generic Functions}
%\description{
%  The functions documented here manage collections of methods associated
%  with a generic function, as well as providing information about the
%  generic functions themselves.
%}
%\usage{
%isGeneric(f, where, fdef, getName = FALSE)
%isGroup(f, where, fdef)
%removeGeneric(f, where)
%
%dumpMethod(f, signature, file, where, def)
%findFunction(f, generic = TRUE, where = topenv(parent.frame()))
%dumpMethods(f, file, signature, methods, where)
%signature(\dots)
%
%removeMethods(f, where = topenv(parent.frame()), all = missing(where))
%
%setReplaceMethod(f, \dots, where = topenv(parent.frame()))
%
%getGenerics(where, searchForm = FALSE)
%}
%\section{Summary of Functions}{
%  \describe{
%    \item{\code{isGeneric}:}{
%      Is there a function named \code{f}, and if so, is it a generic?
%
%      The \code{getName} argument allows a function to find the name
%      from a function definition.  If it is \code{TRUE} then the name of
%      the generic is returned, or \code{FALSE} if this is not a generic
%      function definition.
%
%      The behavior of \code{isGeneric} and \code{\link{getGeneric}} for
%      primitive functions is slightly different.  These functions don't
%      exist as formal function objects (for efficiency and historical
%      reasons), regardless of whether methods have been defined for
%      them.  A call to \code{isGeneric} tells you whether methods have
%      been defined for this primitive function, anywhere in the current
%      search list, or in the specified position \code{where}.  In
%      contrast, a call to \code{\link{getGeneric}} will return what the
%      generic for that function would be, even if no methods have been
%      currently defined for it.
%    }
%
%    \item{\code{removeGeneric}, \code{removeMethods}:}{
%      Remove all the methods for the generic function of this
%      name.  In addition, \code{removeGeneric} removes the function
%      itself; \code{removeMethods} restores the non-generic function
%      which was the default method.   If there was no default method,
%      \code{removeMethods} leaves a generic function with no methods.
%    }
%    \item{\code{standardGeneric}:}{
%      Dispatches a method from the current function call for the generic
%      function \code{f}.  It is an error to call
%      \code{standardGeneric} anywhere except in the body of the
%      corresponding generic function.
%
%      Note that \code{\link{standardGeneric}} is a primitive function in
%      the \pkg{base} package
%      for efficiency % << MM: this is just my guess, what *are* the reasons?
%      reasons, but rather documented here where it belongs naturally.
%    }
%    \item{\code{dumpMethod}:}{
%      Dump the method for this generic function and signature.
%    }
%    \item{\code{findFunction}:}{
%      return a list of either the positions on the search list, or the
%      current top-level environment, on which a function object
%      for \code{name} exists.  The returned value is \emph{always} a
%      list, use the first element to access the first visible version
%      of the function.  See the example.
%
%      \emph{NOTE:} Use this rather than \code{\link{find}} with
%      \code{mode="function"}, which is not as meaningful, and has a few
%      subtle bugs from its use of regular expressions.  Also,
%      \code{findFunction} works correctly in the code for a package
%      when attaching the package via a call to \code{\link{library}}.
%    }
%    \item{\code{dumpMethods}:}{
%      Dump all the methods for this generic.
%    }
%    \item{\code{signature}:}{
%      Returns a named list of classes to be matched to arguments of a
%      generic function.
%    }
%    \item{\code{getGenerics}:}{returns the names of the generic
%      functions that have methods defined on \code{where}; this
%      argument can be an environment or an index into the search
%      list.  By default, the whole search list is used.
%
%      The methods definitions are stored with
%      package qualifiers; for example, methods for function
%      \code{"initialize"} might refer to two different functions
%      of that name, on different packages.  The package names
%      corresponding to the method list object are contained in the
%      slot \code{package} of the returned object.  The form of
%      the returned name can be plain (e.g., \code{"base"}), or in
%      the form used in the search list (\code{"package:base"})
%      according to the value of \code{searchForm}}
%
%  }
%}
%
%\arguments{
%  \item{f}{ The character string naming the function. }
%  \item{where}{ The environment, namespace, or search-list position
%  from which to search for objects.  By default, start at the
%  top-level environment of the calling function, typically the global
%  environment (i.e., use the search list), or the namespace of a
%  package from which the call came.  It is important to supply this
%  argument when calling any of these functions indirectly.  With
%  package namespaces, the default is likely to be wrong in such calls.}
%
%  \item{signature}{ The class signature of the relevant method.  A
%    signature is a named or unnamed vector of character strings.  If
%    named, the names must be formal argument names for the generic
%    function.  Signatures are matched to the arguments specified in
%    the signature slot of the generic function (see the Details
%    section of the \code{\link{setMethod}} documentation).
%
%  The \code{signature} argument to \code{dumpMethods} is ignored (it
%  was used internally in previous implementations).}
%
%  \item{file}{ The file or connection on which to dump method definitions. }
%
%  \item{def}{ The function object defining the method; if omitted, the
%    current method definition corresponding to the signature. }
%
%  \item{\dots}{Named or unnamed arguments to form a signature.}
%
%  \item{generic}{In testing or finding functions, should generic
%    functions be included.  Supply as \code{FALSE} to get only
%    non-generic functions.}
%
%  \item{fdef}{Optional, the generic function definition.
%
%   Usually omitted in calls to \code{isGeneric}}
%
%  \item{getName}{If \code{TRUE}, \code{isGeneric} returns the name of
%    the generic.  By default, it returns \code{TRUE}. }
%  \item{methods}{
%    The methods object containing the methods to be dumped.  By default,
%    the methods defined for this generic (optionally on the specified
%    \code{where} location).
%  }
%  \item{all}{in \code{removeMethods}, logical indicating if all
%    (default) or only the first method found should be removed.}
%  \item{searchForm}{In \code{getGenerics}, if \code{TRUE}, the
%    \code{package} slot of the returned result is in the form used
%    by \code{search()}, otherwise as the simple package name (e.g,
%    \code{"package:base"} vs \code{"base"}).
%  }
%}
%
%\section{Details}{
%  \describe{
%    \item{\code{setGeneric}:}{
%      If there is already a non-generic function of this name, it will
%      be used to define the generic unless \code{def} is supplied, and
%      the current function will become the default method for the
%      generic.
%
%      If \code{def} is supplied, this defines the generic function, and
%      no default method will exist (often a good feature, if the
%      function should only be available for a meaningful subset of all
%      objects).
%
%      Arguments \code{group} and \code{valueClass} are retained for
%      consistency with S-Plus, but are currently not used.
%    }
%    \item{\code{isGeneric}:}{
%      If the \code{fdef} argument is supplied, take this as the
%      definition of the generic, and test whether it is really a
%      generic, with \code{f} as the name of the generic.  (This argument
%      is not available in S-Plus.)
%    }
%    \item{\code{removeGeneric}:}{
%      If \code{where} supplied, just remove the version on this element
%      of the search list; otherwise, removes the first version
%      encountered.
%    }
%    \item{\code{standardGeneric}:}{
%      Generic functions should usually have a call to
%      \code{standardGeneric} as their entire body.  They can, however,
%      do any other computations as well.
%
%      The usual \code{setGeneric} (directly or through calling
%      \code{setMethod}) creates a function with a call to
%      \code{standardGeneric}.
%    }
%    \item{\code{dumpMethod}:}{
%      The resulting source file will recreate the method.
%    }
%    \item{\code{findFunction}:}{
%      If \code{generic} is \code{FALSE}, ignore generic functions.
%    }
%    \item{\code{dumpMethods}:}{
%      If \code{signature} is supplied only the methods matching this
%      initial signature are dumped.  (This feature is not found in
%      S-Plus:  don't use it if you want compatibility.)
%    }
%    \item{\code{signature}:}{
%      The advantage of using \code{signature} is to provide a check on
%      which arguments you meant, as well as clearer documentation in
%      your method specification.  In addition, \code{signature} checks
%      that each of the elements is a single character string.
%    }
%    \item{\code{removeMethods}:}{
%      Returns \code{TRUE} if \code{f} was a generic function,
%      \code{FALSE} (silently) otherwise.
%
%      If there is a default method, the function will be re-assigned as
%      a simple function with this definition.
%      Otherwise, the generic function remains but with no methods (so
%      any call to it will generate an error).  In either case, a
%      following call to \code{setMethod} will consistently
%      re-establish the same generic function as before.
%    }
%  }
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{
%  \code{\link{getMethod}} (also for \code{selectMethod}),
%  \code{\link{setGeneric}},
%  \code{\link{setClass}},
%  \code{\link{showMethods}}
%}
%\examples{
%require(stats) # for lm
%
%## get the function "myFun" -- throw an error if 0 or > 1 versions visible:
%findFuncStrict <- function(fName) {
%  allF <- findFunction(fName)
%  if(length(allF) == 0)
%    stop("No versions of ",fName," visible")
%  else if(length(allF) > 1)
%    stop(fName," is ambiguous: ", length(allF), " versions")
%  else
%    get(fName, allF[[1]])
%}
%
%try(findFuncStrict("myFun"))# Error: no version
%lm <- function(x) x+1
%try(findFuncStrict("lm"))#    Error: 2 versions
%findFuncStrict("findFuncStrict")# just 1 version
%rm(lm)
%
%\dontshow{
%## because nosegfault runs standardGeneric w/o the methods package, nothing
%## really gets tested.  The following check that it catches some errors
%mustDie <- function(expr)
%   stopifnot(is(tryCatch(expr, error=function(e)e), "error"))
%
%mustDie(standardGeneric()) # 3 tests of requiring a single string
%mustDie(standardGeneric(NULL))
%mustDie(standardGeneric(""))
%mustDie(standardGeneric("notAGenericFunction"))
%mustDie(standardGeneric("show"))  # a generic, but not called from its body
%}
%
%## method dumping ------------------------------------
%
%setClass("A", representation(a="numeric"))
%setMethod("plot", "A", function(x,y,...){ cat("A meth\n") })
%dumpMethod("plot","A", file="")
%\dontrun{
%setMethod("plot", "A",
%function (x, y, ...)
%{
%    cat("AAAAA\n")
%}
%)
%}%dont
%tmp <- tempfile()
%dumpMethod("plot","A", file=tmp)
%## now remove, and see if we can parse the dump
%stopifnot(removeMethod("plot", "A"))
%source(tmp)
%stopifnot(is(getMethod("plot", "A"), "MethodDefinition"))
%
%## same with dumpMethods() :
%setClass("B", contains="A")
%setMethod("plot", "B", function(x,y,...){ cat("B ...\n") })
%dumpMethods("plot", file=tmp)
%stopifnot(removeMethod("plot", "A"),
%          removeMethod("plot", "B"))
%source(tmp)
%stopifnot(is(getMethod("plot", "A"), "MethodDefinition"),
%          is(getMethod("plot", "B"), "MethodDefinition"))
%}
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%