% File src/library/methods/man/MethodDefinition-class.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{MethodDefinition-class}
\docType{class}
%@%\alias{メソッド定義クラス}
\alias{MethodDefinition-class}
\alias{SealedMethodDefinition-class}
\title{メソッド定義を表現するクラス}
%\title{Classes to Represent Method Definitions}
\description{
  これらのクラスは関数がメソッド定義として保存され使われる
  基本クラス \code{"function"} を拡張する．
}
\section{クラスからのオブジェクト}{
  \code{\link{setMethod}} への呼び出しでメソッドを設定する
  行動はこのクラスのオブジェクトを作る．それらを直接作ることは
  賢明ではない．

  クラス \code{"SealedMethodDefinition"} は
  引数 \code{sealed = TRUE} を持つ
  \code{\link{setMethod}} への呼び出しで作られる．
  これは \code{"MethodDefinition"} と同じ表現を持つ．
}
\section{スロット}{
  \describe{
    \item{\code{.Data}:}{
	クラス \code{"function"} のオブジェクト；
	定義のデータ部分．}
    \item{\code{target}:}{
	 クラス \code{"signature"} のオブジェクト；
	 それに対してメソッドが必要とされるシグネチャ．}
    \item{\code{defined}:}{
	クラス \code{"signature"} のオブジェクト；
	それに対してメソッドが見つけられたシグネチャ．
        もしメソッドが継承されていたならば，これは
	\code{target} と同じではない．}
      \item{\code{generic}:}{
        クラス \code{"character"} のオブジェクト；それに対して
	メソッドが作られた関数．}
  }
}
\section{拡張}{
  データ部分から，クラス \code{"function"}．\cr
  直接，クラス \code{"PossibleMethod"}．\cr
  \code{"function"} から，クラス \code{"OptionalMethods"}．
}
\details{
  メソッド定義オブジェクトは関数がメソッドとしてどのように使われるかの
  付加情報を持つ関数である．
  スロット \code{target} はそれに対してメソッドが選択適用される
  クラスのシグネチャであり，
  スロット \code{defined} はメソッドが元来指定されているシグネチャ
  (つまり \code{\link{setMethod}} へのある呼び出し中に現れるもの)である．
}
\seealso{
  特定の総称的関数に関連したメソッドのセットを定義する
  オブジェクトについてはクラス \code{\linkS4class{MethodsList}}．
  これらのオブジェクト中に保管された個々のメソッド定義は
  クラス\cr
  \code{MethodDefinition} またはその拡張に由来する．
  \code{\link{callNextMethod}} により使われる拡張については
  クラス \code{\linkS4class{MethodWithNext}}．
}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/MethodDefinition-class.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{MethodDefinition-class}
%\docType{class}
%\alias{MethodDefinition-class}
%\alias{SealedMethodDefinition-class}
%\title{Classes to Represent Method Definitions}
%\description{
%  These classes extend the basic class \code{"function"} when
%  functions are to be stored and used as method definitions.
%}
%\section{Objects from the Class}{
%  The action of setting a method by a call to \code{\link{setMethod}} creates an object of this class.  It's
%  unwise to create them directly.
%
%  The class \code{"SealedMethodDefinition"} is created by a call to
%  \code{\link{setMethod}} with argument \code{sealed = TRUE}.  It has
%  the same representation as \code{"MethodDefinition"}.
%}
%\section{Slots}{
%  \describe{
%    \item{\code{.Data}:}{Object of class \code{"function"}; the data
%        part of the definition. }
%    \item{\code{target}:}{Object of class \code{"signature"}; the
%        signature for which the method was wanted. }
%    \item{\code{defined}:}{Object of class \code{"signature"}; the
%        signature for which a method was found.  If the method was
%        inherited, this will not be identical to \code{target}. }
%      \item{\code{generic}:}{Object of class \code{"character"}; the function
%        for which the method was created. }
%  }
%}
%\section{Extends}{
%  Class \code{"function"}, from data part.\cr
%  Class \code{"PossibleMethod"}, directly.\cr
%  Class \code{"OptionalMethods"}, by class \code{"function"}.
%}
%\details{
%  Method definition objects are functions with additional information
%  defining how the function is being used as a method.  The
%  \code{target} slot is the class signature for which the method will
%  be dispatched, and the \code{defined} slot the signature for which
%  the method was originally specified (that is, the one that appeared
%  in some call to \code{\link{setMethod}}).
%}
%\seealso{class \code{\linkS4class{MethodsList}} for the objects
%  defining sets of methods associated with a particular generic
%  function.  The individual method definitions stored in these objects
%  are from class \code{MethodDefinition}, or an extension.
%  Class \code{\linkS4class{MethodWithNext}} for an extension used by
%  \code{\link{callNextMethod}}.
%}
%\keyword{classes}
%
%\encoding{UTF8}
%