% File src/library/methods/man/MethodSupport.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{MethodSupport}
\title{メソッドに対する追加の(サポート)関数}
%\title{Additional (Support) Functions for Methods}
%@%\alias{メソッドに対するサポート関数}
\alias{getMethodsForDispatch}
\alias{cacheMethod}
\alias{resetGeneric}
\alias{listFromMethods}
\description{
  これらは形式的メソッドに関する計算に対する	
  \emph{内部的}サポートのためのルーティンである．
}
\usage{
listFromMethods(generic, where, table)

getMethodsForDispatch(fdef, inherited = FALSE)

cacheMethod(f, sig, def, args, fdef, inherited = FALSE)

resetGeneric(f, fdef, mlist, where, deflt)
}
\section{関数の要約}{
  \describe{
    \item{\code{listFromMethods}:}{
	関数 \code{generic} に対するメソッドを記述するリストオブジェクトで，
	関数か関数名として提供される．
	ユーザのコードに対しては
	メソッドの単純なリストかシグネチャの文字列行列を返す関数
	\code{\link{findMethods}} か \code{\link{findMethodSignatures}}
	が代わりに勧められる．

 もし \code{where} が提供されると，これは
 総称的関数に対するメソッドのテーブルがそこから取られる 
 環境か検索パス位置であるべきである．
 もし \code{table} が提供されると，これはそれ自体そうしたテーブルであると
 仮定される．もしどちらの引数も提供されないと，テーブルは
 直接総称的関数から取られる
 (つまり，この総称的関数に対して定義されたメソッドの現在のセット)．

      関連するテーブル中の全てのメソッドを記述する
      クラス \code{"LinearMethodsList"} のオブジェクトを返す
      (\linkS4class{LinearMethodsList} を見よ)．
    }
    \item{\code{resetGeneric}:}{
      \code{f} という名前の総称的関数に対する環境 \code{where} 中で見つかるか
      引数として明示的に提供された現在定義されているメソッドを
      リセットする．他の引数は最早使われず無視される．

      総称的関数はの内部テーブル中の全ての継承されたメソッドをリセットするという
      副作用のために呼び出される．
      メッソドへの変更とパッケージのロードと切り離しの際自動的に
      呼び出されるため普通直接には呼び出されない．
    }
    \item{\code{cacheMethod}:}{
      この関数とシグネチャに対する定義を
      関数に対するメソッドのメタデータ中に保管する．
      継承を通じて見つかった強制変換メソッドの拡張を補間し，
      \code{\link{callNextMethod}} 情報を持つメソッドをキャッチするために
      使われる．

      メソッドのメタデータはセッションに対するスコープだけなので，
      永続的な効果はない．
    }
    \item{\code{getMethodsForDispatch}:}{
      関数 \code{f} に対するメソッドを表現するメソッドのテーブル
      (R バージョン 2.6.0 以来 \code{\link{environment}})
      を得る．

      ユーザのコードに対しては代わりに
      関数 \code{\link{findMethods}} や \code{\link{findMethodSignatures}} が
      勧められる．これは単純なメソッドのリストか
      シグネチャの文字列行列を返す．
    }
  }
}
\keyword{internal}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/MethodSupport.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{MethodSupport}
%\title{Additional (Support) Functions for Methods}
%\alias{getMethodsForDispatch}
%\alias{cacheMethod}
%\alias{resetGeneric}
%\alias{listFromMethods}
%\description{
%  These are \emph{internal} support routines for computations on formal methods.
%}
%\usage{
%listFromMethods(generic, where, table)
%
%getMethodsForDispatch(fdef, inherited = FALSE)
%
%cacheMethod(f, sig, def, args, fdef, inherited = FALSE)
%
%resetGeneric(f, fdef, mlist, where, deflt)
%}
%\section{Summary of Functions}{
%  \describe{
%    \item{\code{listFromMethods}:}{
%        A list object describing the methods for the function \code{generic}, supplied either as the function or the name of the function.   For user code, the function \code{\link{findMethods}} or \code{\link{findMethodSignatures}} is recommended instead,  returning a simple list of methods or a character matrix of the signatures.
%
% If \code{where} is supplied, this should be an environment or search list position from which a table of methods for the generic will be taken.  If \code{table} is supplied, this is itself assumed to be such a table.  If neither argument is supplied, the table is taken directly from the generic function (that is, the current set of methods defined for this generic).
%
%      Returns an object of class \code{"LinearMethodsList"} (see
%      \linkS4class{LinearMethodsList}) describing all the methods in the
%      relevant table.
%    }
%    \item{\code{resetGeneric}:}{
%      reset the currently defined methods for the generic function named
%      \code{f}, found in environment \code{where} or explicitly supplied
%      as an argument.  Other arguments are obsolete and ignored.
%
%      Called for its side effect of resetting all inherited methods in
%      the generic function's internal table.
%      Normally not called directly, since changes to methods and the
%      loading and detaching  of packages all generate a call automatically.
%    }
%    \item{\code{cacheMethod}:}{
%      Store the definition for this function and signature in the method
%      metadata for the function.  Used to store extensions of coerce
%      methods found through inheritance, and to cache methods with
%      \code{\link{callNextMethod}} information.
%
%      No persistent effect, since the method metadata is session-scope
%      only.
%    }
%    \item{\code{getMethodsForDispatch}:}{
%      Get the table of methods (an \code{\link{environment}} since R
%      version 2.6.0) representing the methods for function \code{f}.
%
%      For user code, the function \code{\link{findMethods}} or
%      \code{\link{findMethodSignatures}} is recommended instead, returning
%      a simple list of methods or a character matrix of the signatures.
%    }
%  }
%}
%\keyword{internal}
%
%\encoding{UTF8}
