% File src/library/methods/man/Methods.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{Methods}
%@%\alias{メソッド}
\alias{Methods}
\title{メソッドに関する一般的情報}
%\title{General Information on Methods}
\description{
  このドキュメントはメソッドがどのように動作するか，そして
  \pkg{methods} パッケージが \R の残りとどのように関わるかに関する
  ある種の一般的なトピックを解説する．
  この情報は通常メソッドとクラスの利用を始めるためには
  必要ではないが，ある程度野心的なプロジェクトや，
  何かが期待されたように動作しない場合に役立つかもしれない．

  節 \dQuote{メソッドはどのように動作するか} は基礎にある機構を解説する；
  節 \dQuote{S3 総称的関数に対するメソッド} は S4 クラスとメソッドが
  古い S3 メソッドと関わる時に適用される規則を与える；
  節 \dQuote{メソッド選択と適用} はクラス定義がどのメソッドが使われるかを
  どのように決めるのかに関するより詳細を与える；
  節 \dQuote{総称的関数} はオブジェクトとしての総称的関数を議論する．
  特にクラス定義に関する追加情報については
  \code{\link{Classes}} を見よ．
}

\section{メソッドはどのように動作するか}{
  総称的関数はそれに他の関数のコレクション
  (メソッド)を関連付け，それらは総称的関数と同じ
  形式的引数を持つ．総称的関数自体についてのより詳細は下の
  節 \dQuote{総称的関数} を見よ．

  各々の \R パッケージはそのパッケージ中でメソッドが
  定義されている各総称的関数に対応するメソッドのメタデータオブジェクト
  を含む．パッケージが \R セッション中にロードされると，
  各総称的関数に対応するメソッドは
  \emph{キャッシュ}される，つまり以前にロードされたパッケージの
  メソッドと並んで総称的関数の環境中に保存される．
  このメソッドの混ぜ合わされたテーブルは，
  適用可能なメソッドを見つけるためにクラス継承と可能性としてグループ総称的関数
  を利用して総称的関数からのメソッドを適用したり選択したりするのに
  使われる．下の節 \dQuote{メソッドの選択と適用} を見よ．
  キャッシング計算は
  各総称的関数のただ一つのバージョンが大局的に可視になることを保証する；
  異なった付加されたパッケージは総称的関数のコピーを含むかもしれないが，
  これらはメソッド選択に関しては同じ働きをする．
  対照的に，それらが異なった \code{package} スロットを持つなら，
  同じ関数名が一つ以上の総称的関数を参照することが
  可能である．
  後者の場合 \R 関数は無関係と見做す．
  総称的関数はは名前とパッケージの組み合わせで定義される．
  下の節 \dQuote{総称的関数} を見よ．

  総称的関数に対するメソッドは，メソッドを定義する
  \code{\link{setMethod}} への呼び出し中の対応する
  \code{signature} に従って保存される．
  シグネチャは一つのクラス名を総称的関数への形式的引数のサブセットの
  各々と関連させる．
  どの形式的引数が利用可能か，そしてそれらが登場する順序は
  総称的関数自体の \code{"signature"} スロットにより決定される．
  既定では，総称的関数のシグネチャは \dots を除く全ての形式的引数
  から成り立ち，関数定義中にそれらが登場する順序を持つ．

  総称的関数のシグネチャ中の後に続く引数は，もしそのシグネチャ中にこれらの
  引数を含む如何なるメソッドもまだ指定されていなければ
  \emph{アクティブで無い}．
  アクティブでない引数はキャッシュされたメソッドのラベリングでは不要で使われない．
  (違いはどのメソッドが選択適用されるかは変えないが，
  しかしアクティブでない引数を無視することは選択適用の効率性を向上させる．)

  総称的関数のシグネチャ中の全ての引数
  は関数が呼び出されると，伝統的な S の遅延評価規則を使う代わりに，評価される．
  従ってシグネチャからシンボリックに処理される必要がない
  任意の引数を\emph{除外}することが重要である
  (関数 \code{\link{substitute}} の第一引数のような)．
  既定表現ではなく実際の引数だけが評価されることを注意する．
  欠損引数は
  クラス \code{"missing"} としてメソッドの選択に登場する．

  キャッシュされたメソッドは環境オブジェクトに保存される．
  付値に対して使われた名前はクラス名とメソッドのシグネチャ中の
  アクティブな引数を連結したものである．
}

\section{S3 総称的関数に対するメソッド}{

S4 メソッドは S3 総称的関数の第一引数に対応する S3 メソッドも持つ
関数に対して必要になるかもしれない
--どちらも正規の R 関数で，
S3 選択適用関数 \code{\link{UseMethod}} への呼び出しか，
真の関数ではなく直接に C コードが使われる
プリミティブ関数のセットの一つであるとする．
どちらの場合も S3 メソッドの選択適用は最初の引数のクラスか
プリミティブな二項演算子の一つへの呼び出し中のどちらかの
引数のクラスを眺める．
S3 メソッドは総称的関数と同じ引数を持つ通常の関数である
(プリミティブ関数に対しては形式的引数は
実際はオブジェクトの一部ではないが，
プリントされたり
\code{\link{args}()} で眺められるときにはシミュレートされる)．
S3 メソッドの\dQuote{シグネチャ}にはメソッドが付値される
名前で特定され，総称的関数の名前に \code{"."} とクラス名が後に続く．
詳細は \link{S3Methods} を見よ．

これらの関数のどれかに S4 クラスに対応するメソッドを実装するには
二つの可能性がある；
S4 メソッドとしてか S4 クラス名を持つ S3 メソッドとしてかである．
S3 メソッドは意図するシグネチャが第一引数を持ち他には何も持たない時だけ
可能である．
この場合推奨できるアプローチは S3 メソッドを定義しそして
S4 メソッドの定義として同一の関数を提供することである．
もし S3 総称的関数が \code{f3(x, ...)} で新しいメソッドに対する
S4 クラスが \code{"myClass"} なら：

 \code{f3.myClass <- function(x, ...) { ..... }}

 \code{setMethod("f3", "myClass", f3.myClass)}

S3 と S4 メソッドを共に定義する理由は以下の通りである：
\enumerate{
  \item S4 メソッドそのものは
    S3 総称的関数が直接呼び出されるときは見えない．
    しかしながらプリント関数と演算子は例外である．
    内部 C コードは
    オブジェクトが S4 オブジェクトの時，そしてその時だけ
    S4 メソッドを探す．例の中では，
    クラス \code{"myFrame"} に対する \code{`[`} メソッドが
    このクラスのオブジェクトに対して常に呼び出される．

    同じ理由から，
    S3 クラスに対して定義された S4 メソッドは
    非 S4 クラスに対する内部コードからは呼び出されない．
    (例中の関数 \code{Math} とクラス \code{"data.frame"} を見よ．)
  \item S3 メソッドはもし
    \emph{任意}の適格な非既定の S4 メソッドがあれば単独では
    呼び出されない．(例中の関数
    \code{f3} とクラス \code{"classA"} の例を見よ．)
}
選択の計算の詳細は下で与えられる．

S4 総称的関数でない既存関数に対して S4 メソッドが定義されると
(既存の関数が S3 総称的であろうとなかろうと)，
S4 総称的関数が既存関数とそれが見つかったパッケージに対して作られる
(より正確には指定されたか通常の関数から推測された暗黙の関数；
\code{\link{implicitGeneric}} を見よ)．
\code{\link{setMethod}} への最初の呼び出しの後にメッセージがプリントされる；
これはエラーではなく単に総称的関数が作られたことの覚書である．
総称的関数を明示的に呼び出し

  \code{setGeneric("f3")}

で作ればメッセージが避けられるが効果は同じである．
既存関数は S4 総称的関数の既定メソッドになる．
プリミティブな関数は同じように動作するが，
S4 総称的関数は明示的には作られない
(下で議論されるように)．


S4 と S3 メソッドは可能な限り一貫性のある継承規則に従うように
デザインされている．S3 クラスは
S3 クラスが正しい パターンを指定する呼び出しと共に
\code{\link{setOldClass}} への呼び出しで登録されていれば
任意の S4 メソッド選択に対して使うことが出来る．
S4 クラスは任意の S3 メソッド選択に対して使うことが出来る；
S4 オブジェクトが検出された時，S3 メソッド選択は
\code{\link{extends}(class(x))} の内容を
S3 継承の同値物として使う
(継承は最初の呼び出しの後にキャッシュされる)．

既存の S3 メソッドは S4 サブクラスに対して期待されるようには
動作しないかもしれない．そうした場合
\code{\link{asS3}} や \code{\link{S3Part}} の様なユーティリティが
役立つかもしれない．
もし S3 メソッドが S4 オブジェクトに対して失敗すると，
\code{asS3(x)} が代わりに渡されるかもしれない；
もし S3 メソッドにより返されるオブジェクトが
S4 オブジェクト中に統合される必要があると，
例中のクラス \code{"myFrame"} に対するメソッド中のように，
\code{S3Part} に対する置き換え関数が役立つかもしれない．

S3 と S4 メソッドの両方を定義する理由をここで説明する．
S3 総称的関数に依然として直接アクセスする呼び出しは
プリミティブ関数の場合を除き S4 メソッドを見ない．
これは S3 総称的関数を移入するが S4 バージョンを
移入しない名前空間からの総称的関数の呼び出しは
S3 メソッドだけを見ることを意味する．
他方で，S3 メソッドは
S4 総称的関数からその既定
(\code{"ANY"}) メソッドの一部としてだけ選択される．
もし継承された S4 の非既定メソッドがあれば，これらは
\emph{任意}の S3 メソッドに優先して選ばれる．

プリミティブ関数として実装された S3 総称的関数
(二項演算子を含む)は S3 メソッドだけの認識への例外である．
これらの関数は内部 C コードから
S4 と S3 メソッドの双方を選択適用する．
S3 にせよ S4 にせよ明示的な総称的関数は無い．
内部コードは，最初の引数または二項演算子の場合はどちらかの
引数が S4 オブジェクトならば S4 メソッドを探す．
もし S4 メソッドが何も見つからなければ S3 メソッドが探される．

S4 メソッドは
S3 総称的関数と S3 クラスに対して定義できるが，
もし関数がプリミティブならば，そうしたメソッドは
問題のオブジェクトが S4 オブジェクトでなければ選択されない．
例えば下の例では，
関数 \code{f3()} に対する
シグネチャ \code{"data.frame"} に対する S4 メソッドは
S3 オブジェクト \code{df1} に対して呼び出される．
プリミティブ関数 \code{`[`} に対する類似の S4 メソッドは
そのオブジェクトに対しては無視されるが，
\code{"data.frame"} を継承する S4 オブジェクト \code{mydf1}
に対して呼び出される．
S3 と S4 メソッドの両方を定義すればこの非一貫性は
除かれる．
}

\section{メソッドの選択と適用：詳細}{

総称的関数への呼び出しが評価される時，
メソッドがシグネチャ中の実際の引数のクラスに対して選択される．
最初にキャッシュされたメソッドテーブルで正確なマッチが
探される；つまり各非欠損引数に対する
\code{class(x)} の文字列値，そして欠損値に対しては \code{"missing"}
で定義されるシグネチャの下に保管されたメソッドである．
総称的関数への呼び出し中の実際の引数に対して如何なるメソッドも
直接には見つからなければ，実際の引数に対するスーパークラス
情報を用いて引数に対して使用できるメソッドをマッチする努力が
なされる．

各クラス定義は新しいクラスの一つまたはそれ以上の
\emph{スーパークラス}を含むかもしれない．
最も単純で最も普通の指定は
\code{\link{setClass}} への呼び出し中の \code{contains=} 引数に
よるものである．
この引数中で命名されたクラスは新しいクラスのスーパークラスである．
スーパークラスを定義する二つの追加の機構が存在する．
\code{\link{setClassUnion}} への呼び出しは合併のメンバーの各々
のスーパークラスである合併クラスを作る．
\code{\link{setIs}} への呼び出しは新しいクラス中に
スーパークラス表現を含む単純なものではない継承関係を作ることが出来る．
引数 \code{coerce} と \code{replace} はスーパークラスへの変換と
スーパークラスに対応する部分を置き換える
メソッドを提供する．
(更に \code{test=} 引数は条件付き継承を可能にする；
条件付き継承は推奨されずメソッド選択中で使われない．)
三つ全ての機構はメソッド選択の目的にとっては同等に
扱われる：それらは特定のクラスの
\emph{直接}のスーパークラスを定義する．
機構についてのより詳細については \code{\link{Classes}} を見よ．

直接のスーパークラス自体は同じ機構のいずれかで定義された
スーパークラスを持つかもしれず，
更に同様に世代を持つかもしれない．
これらの情報全てを一緒にしてこのクラスに対するスーパークラスの
完全なリストを形作る．スーパークラスリストは
\R セッションの間キャッシュされるクラス定義中に含まれる．
リストの各要素は関係の性質を記述する
(詳細は \code{\linkS4class{SClassExtension}} を見よ)．
要素中には関係のパス長を含む
\code{distance} スロットが含まれる：
直接のスーパークラスは \code{1}
(それらを定義した機構とは無関係に)，そしてこれらのクラスの直接の
スーパークラスは \code{2}，云々．
加えて任意のクラスは暗黙のうちに
クラス \code{"ANY"} をスーパークラスとして持つ．
\code{"ANY"} への距離は任意の実際のクラスへの距離よりも
大きいとされる．
欠損引数に対応する特殊なクラス \code{"missing"} は
\code{"ANY"} だけをスーパークラスとして持つ一方，
\code{"ANY"} はスーパークラスを持たない．

クラス定義が作られたり修正された際，スーパークラスは
順序付けられ，最初は距離による全てのスーパークラスの
安定なソートによる．もしスーパークラスのセットが重複していると
(つまり，もしあるクラスが一つ以上の関係を通じて継承
されていると)，もし可能ならばこれらは取り除かれ，
スーパークラスのりストが全ての直接のスーパークラスの
スーパークラスと一貫性を持つようにする．
詳細は継承に冠する参考文献を見よ．

スーパークラスに関する情報はクラス定義がプリントされる時
要約される．

メソッドが継承により選択される際には，
アクテイブなシグネチャ内の各引数に対して，
直接なクラスかそのスーパークラスの一つの組み合わせに直接対応する
全てのメソッドに対するデーブル中で検索が行われる．
例えば，シグネチャ内にただ一つの引数だけがあり
対応するオブジェクトのクラスが
\code{"dgeMatrix"} (推奨パッケージ \code{Matrix} からの)であると仮定する．
このクラスは二つの直接のスーパークラスを持ち，それらを通じて4つの
追加のスーパークラスを持つ．メソッド選択は
これらのクラスの一つか \code{"ANY"} でラベルが付いた直接指定されたメソッド
のテーブル中の全てのメソッドを見つける．

シグネチャ中に複数の引数があるときは，
各引数は類似の継承クラスのリストを作る．
可能なマッチはすると各引数からのクラスの全ての
組み合わせである
(全ての可能な組み合わせの配列を生成する関数 \code{outer}
を思い起こそう)．
検索は今やこのクラスの組み合わせのどれかにマッチする
全てのメソッドを見出す．
各引数に対して，その引数のスーパークラスのリスト中の
位置がどのメソッドまたはメソッド群が
(もし同じクラスが一度以上登場する場合)一番良く
マッチするかを定義する．
ただ一つの引数がある場合，最良のマッチは曖昧さがない．
複数の引数の場合は\emph{全て}の引数に対する
最良のマッチ中にはゼロか一つのマッチがあるかもしれない．

もし最良のマッチがなければ，選択は曖昧であり
どのメソッドが選ばれたかを注意するメッセージと
(辞書式順序で最初のメソッド)そして他のどのようなメソッド
が選択可能であったかをプリントする．
曖昧さは普通ユーザが制御できることではないので，
これは警告ではない．パッケージの作者は
\code{\link{testInheritedMethods}} の呼び出しにより可能な曖昧な
継承について自分のパッケージを吟味すべきである．

継承されたメソッドが選択された時，
選択は総称的関数中にキャッシュされ，
同じ呼び出しを持つ将来の呼び出しは検索を繰り返す必要はない．
不正な選択に繋がる可能性があるので，キャッシュされた継承された
選択はそれ自体将来の継承選択中では使われない．
もし継承性の計算を再び繰り返したければ
(例えば新しくロードしたパッケージがこのセッションですでに使っているよりも
より直接的なメソッドを持つため)，
\code{\link{resetGeneric}} を呼び出す．それらを含むクラスとメソッドは
同じパッケージから由来する傾向があるので，
現在の実装は新しいパッケージがロードされる度全ての総称的関数をリセットしない．

総称的関数への呼び出しを通じて開始されるのとは別に，
メソッド選択は
関数 \code{\link{selectMethod}} の呼び出しにより明示的に
行うことが出来る．

メソッドが一旦選択されると評価器はその中でメソッドが評価される
新しいコンテキストを作る．
コンテキストは総称的関数への呼び出しからの引数で初期化される．
これらの引数は再マッチされない．
総称的関数のシグネチャ内の全ての引数は
評価されている
(現在アクテイブでないものを含み)；
シグネチャ内に無い引数は言語の通常の遅延評価規則に従う．
もし呼び出し中に引数が欠損していたら，
もしあればその既定表現式は
評価されて\emph{いない}．メソッドの選択適用はそうした引数に対して
常にクラス \code{missing} を使うからである．

従って総称的関数への呼び出しは二つのコンテキストを持つ：
一つは関数用で二つ目はメソッド用である．
引数オブジェクトは二番目のコンテキストにコピーされるが，
非標準的な総称的関数中で作られた局所的なオブジェクトはどれも
されない．もう一つの重要な違いは二番目のコンテキストの
(\dQuote{囲み})環境は関数としてのメソッドの環境であり，
従ってそうした環境を用いた全ての \R プログラミングテクニックは
通常の関数としてメソッド定義に適用される．

メソッドの選択と適用のこれ以上の議論については最初の参考文献を見よ．
}

\section{総称的関数}{
原則として総称的関数は
メソッドを選択し選択されたメソッドへの呼び出しを評価する
内部関数である
\code{standardGeneric()} を評価する任意の関数であって良い．
実際には総称的関数は
クラス \code{"function"} のサブクラス由来に加えて
クラス \code{\linkS4class{genericFunction}} を拡張する
特殊なオブジェクトである．
そうしたオブジェクトはそれらのメソッドを処理するのに必要な
情報を定義するスロットを持つ．
それらは又特殊化された環境を持ち，メソッド選択中で使われるテーブルを持つ．

オブジェクト中のスロット \code{"generic"} と \code{"package"} は
総称的関数自体と関数が定義されているパッケージの文字列名である．
クラスと同様に，\R で総称的関数は二つの名前で一意的に定義される．

異なったパッケージに関連する同じ名前の総称的関数が存在しうる
(そうした関数を明快に区別することは常に簡単で無いことは
避けられないが)．
一方で，\R は現在のセッションや他のアクテイブな \R のバージョン
中では，特定の関数とパッケージ名の組み合わせを持つ
総称的関数には唯一の定義が関連付けられることを強要する．

特定の総称的関数に対するメソッドのテーブルは，この意味で，
しばしば幾つもの他のパッケージに広がっている．
与えられた総称的関数に対するメソッドの全体のセットは，
新しいパッケージがロードされるので，セッションの間に
変わるかもしれない．
各テーブルは総称的関数に対して仮定されたシグネチャ中で
一貫していなければならない．

\R は\emph{標準}と\emph{非標準}総称的関数を区別し，
前者はメソッドの選択適用飲みを行う関数本体を持つ．
殆どの部分に対し，区別は単に単純化のためである：
総称的関数がメソッド呼び出しの選択適用だけをすることを
知っていることはある種の効率化を許し，
またある種の不確実さを減らす．

殆どのケースで，総称的関数は対応するパッケージ中の
その名前に対応する可視的な関数である．
\emph{暗黙}の総称的関数と
\R の\emph{プリミティブ}な関数の処理に必要な特殊計算
という二つの例外がある．
もしパッケージが関数を非総称的のままにしたいが
もしそれが総称的であればそうなるであろうような制約を
設けたければ，
パッケージはパッケージ中の関数の暗黙の総称的関数のテーブルを含む
ことが出来る．
そうした暗黙の総称的関数はパッケージのインストールの
過程で作ることが出来，本質的に
総称的関数と可能性としてそれに対するメソッドを定義し
それから関数をその非総称的形式に戻すことでなされる．
(これがどのように行われるかは \link{implicitGeneric} を見よ．)
この機構は主に S4 メソッドを無視したい \R 中のより古い
パッケージ中の関数に対して使われる．
この場合でも，実際の機構はもし何か特別なことが指定されなければならない
場合にだけ必要となる．
全ての関数は自動的に定義される対応する暗黙の総称的バージョンを持つ
(暗黙のうちにであり，暗黙の総称的関数と呼ばれる所以である)．
この関数は非総称的関数と同じ引数を持つ標準的な総称的関数がであり，
非総称的バージョンを既定(そして唯一の)メソッドに持ち，
総称的なシグネチャは
\dots を除く全ての形式的引数である．

暗黙の総称的関数機構はある種の既定定義のアスペクトを上書きするために
だけ必要になる．
一つの理由はシグネチャからある引数を取り除くことである．
字義通りに解釈されたり，
言語の遅延評価がそれに対して必要になったりする引数は
総称的関数のシグネチャに含まれてはなら\emph{無い}．
なぜならシグネチャ中の引数はメソッドを選択するために評価
されるからである．例えば関数
\code{\link{with}} 中の引数 \code{expr} は字義通りに
扱われ従ってシグネチャから除外されなければならない．

もし既存の非総称的な関数が既定メソッドとして不適当なら
暗黙の総称的関数を定義する必要があるかもしれない．
恐らく関数はある種のオブジェクトのクラスだけに適用され，
パッケージのデザイナーは一般的な既定メソッドを持たないことを
好むかもしれない．別の可能性としてデザイナーは
もし関数が総称的ならばある種のクラスに対して適当なメソッドに関する
あるアイデアを持っているかもしれない．
適度に現代的なパッケージでは，
これら全てのケースに対する単純なアプローチは
関数を単に総称的として定義することである．
暗黙の総称的性機構は主に
メソッドパッケージが利用可能であることを要求したくない
より古いパッケージに対して魅力的である．

基本パッケージ中の\emph{プリミティブ}関数として実装されている
関数に対して明快に可視的ではない総称的関数が定義されることがある．
プリミティブ関数はプリントされる時は通常の関数のように
見えるが，
実際は関数オブジェクトではなく
\R の評価器により基礎にある C コードの直接の呼び出しと解釈される
二つのタイプのオブジェクトである．
それらの全ての正当化は効率化であるので，
\R はプリミティブ関数を総称的関数オブジェクトの背後に
隠蔽することを拒む．
殆どのプリミティブ関数に対してメソッドを定義でき，
対応するメタデータオブジェクトがそれを保存するために作られる．
プリミティブ関数の呼び出しは依然として直接に
C コードに向かい，それはある場合には適用可能なメソッドを
チェックする．
\dQuote{ある場合}の定義は，セッション中にロードされた
あるパッケージに対してメソッドが検出されている必要があり，
最初の引数に対して \code{isS4(x)} が \code{TRUE}
(もしくは二項演算子の場合は二番目の引数に対して)であることである．
メソッドが検出されているかどうかを
関係する関数に対して \code{\link{isGeneric}} を呼び出すことで
検査でき，メソッドが検出されているかどうかを
\code{\link{getGeneric}} を呼び出すことで総称的関数を
吟味することが出来る．
総称的関数に関するより詳細は
最初の引用文献と
\emph{R Internals} の第2節を見よ．
}

\section{メソッド定義}{
全てのメソッド定義は
\code{\linkS4class{MethodDefinition}} クラスからのオブジェクトとして
保管される．総称的関数のクラスと同様，このクラスは
通常の \R 関数をある追加のスロット付きで拡張する：
総称的関数の名前とパッケージ，そして二つのシグネチャスロット
\code{"defined"} と \code{"target"} を持つ \code{"generic"} である．
最初のスロットは
メソッドが \code{\link{setMethod}} への呼び出しで作られる時
提供されるシグネチャである．\code{"target"} スロットは
継承メソッドが，上で説明されたように，選択後にキャッシュされると，
コピーが適当な \code{"target"} シグネチャ付きで作られる．
例えば \code{\link{showMethods}} からの出力は
両方のシグネチャを含む．


  効率性と一貫性の理由から
  メソッドの選択適用の機構は引数の再マッチをしないので，
  メソッド定義は総称的関数と同じ形式的引数を持つことが要求される．
}

\examples{
## 登録された S3 クラスを拡張するクラスが
## そのクラスの S3 メソッドを継承する

setClass("myFrame", contains = "data.frame",
    representation(timestamps = "POSIXt"))

df1 <- data.frame(x = 1:10, y = rnorm(10), z = sample(letters,10))

mydf1 <- new("myFrame", df1, timestamps = Sys.time())

## "myFrame" objects inherit "data.frame" S3 methods; e.g., for `[`

mydf1[1:2, ] # データフレームオブジェクト(追加属性を持つ)

## "myFrame" クラスに固有のメソッド


setMethod("[",
    signature(x = "myFrame"),
    function (x, i, j, ..., drop = TRUE)
    {
        S3Part(x) <- callNextMethod()
        x@timestamps <- c(Sys.time(), as.POSIXct(x@timestamps))
        x
    }
)

\donttest{mydf1[1:2, ]}


setClass("myDateTime", contains = "POSIXt")

now <- Sys.time() # class(now) は c("POSIXct", "POSIXt")
nowLt <- as.POSIXlt(now)# class(nowLt) is c("POSIXlt", "POSIXt")

mCt <- new("myDateTime", now)
mLt <- new("myDateTime", nowLt)

## S4 オブジェクトに対する S3 メソッドは S4 継承を用いて選択される
## オブジェクト mCt と mLt は異なった S3Class() 値を持つが，これは使われない
f3 <- function(x)UseMethod("f3") # 継承を説明するための S3 総称的関数

f3.POSIXct <- function(x) "The POSIXct result"
f3.POSIXlt <- function(x) "The POSIXlt result"
f3.POSIXt <- function(x) "The POSIXt result"

stopifnot(identical(f3(mCt), f3.POSIXt(mCt)))
stopifnot(identical(f3(mLt), f3.POSIXt(mLt)))



## S4 オブジェクトはその S4 "継承"に従い S3 メソッドを選択する


setClass("classA", contains = "numeric",
         representation(realData = "numeric"))

Math.classA <- function(x) {(getFunction(.Generic))(x@realData)}
setMethod("Math", "classA", Math.classA)


x <- new("classA", log(1:10), realData = 1:10)

stopifnot(identical(abs(x), 1:10))

setClass("classB", contains = "classA")

y <- new("classB", x)

stopifnot(identical(abs(y), abs(x))) # (バージョン 2.9.0 またはそれ以前はここで失敗する)

## S3 総称的関数：単に説明目的のため
f3 <- function(x, ...) UseMethod("f3")

f3.default <- function(x, ...) "Default f3"

## classA に対する S3 メソッド(のみ)
f3.classA <- function(x, ...) "Class classA for f3"

## 数値に対する S3 と S4 メソッド
f3.numeric <- function(x, ...) "Class numeric for f3"
setMethod("f3", "numeric", f3.numeric)

## classA に対する S3 メソッドと
## classB に対する最近接の継承 S3 メソッドが見つからない

f3(x); f3(y) # どちらも "numeric" メソッドを選択する

## 自然な継承を得るために，同一の S3 と S4 メソッドを定義する
setMethod("f3", "classA", f3.classA)

f3(x); f3(y) # 今や両者は "classA" メソッドを選択する

## S3 オブジェクトに対しては，またはもし S4 総称的関数を含まない
## パッケージから呼びだされるときは S4 と並んで S3 メソッドを定義する必要がある

MathFun <- function(x) { # Math グループに対するよりスマートな "data.frame" メソッド
  for (i in seq(length = ncol(x))[sapply(x, is.numeric)])
    x[, i] <- (getFunction(.Generic))(x[, i])
  x
}
setMethod("Math", "data.frame", MathFun)

## S4 メソッドはデータフレームを含む S4 クラスに対して動作するが，
## データフレームオブジェクトに対してはそうでは無い(S4 オブジェクトではない)

try(logIris <- log(iris)) # 古いメソッドからのエラーを受け取る

## 同じ計算をする S3 メソッドを定義する

Math.data.frame <- MathFun

logIris <- log(iris)




\dontshow{
removeClass("classA"); removeClass("classB"); rm(x,y)
removeGeneric("f3")
removeClass("myDateTime")
removeMethod("Math", "data.frame"); rm(Math.data.frame, MathFun, logIris)
}

}


\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (For the R version: see section 10.6 for method
  selection and section 10.5 for generic functions).

 Chambers, John M.(2009)
 \emph{Developments in Class Inheritance and Method Selection}
 \url{https://statweb.stanford.edu/~jmc4/classInheritance.pdf}.

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (For the original S4 version.)
}
\seealso{
より個別の情報には
  \code{\link{setGeneric}}, \code{\link{setMethod}} そして
  \code{\link{setClass}} を見よ．

メソッド中の \dots の使用に対しては \link{dotsMethods} を見よ．
}
\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/Methods.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Methods}
%\alias{Methods}
%\title{General Information on Methods}
%\description{
%  This documentation section covers some general topics on how methods
%  work and how the \pkg{methods} package interacts with the rest of \R.  The
%  information is usually not needed to get started with methods and
%  classes, but may be helpful for moderately ambitious projects, or when
%  something doesn't work as expected.
%
%  The section \dQuote{How Methods Work} describes the underlying
%  mechanism; \dQuote{S3 Methods and Generic Functions} gives the rules applied when S4
%  classes and methods interact with older S3 methods; \dQuote{Method Selection and Dispatch} provides more
%  details on how class definitions determine which methods are used;
%  \dQuote{Generic Functions} discusses generic functions as objects.
%  For additional information specifically about class definitions, see \code{\link{Classes}}.
%}
%
%\section{How Methods Work}{
%  A generic function  has associated with it a
%  collection of other functions (the methods), all of which have the same
%  formal arguments as the generic.  See the \dQuote{Generic
%    Functions} section below for more on generic functions themselves.
%
%  Each \R package will include  methods metadata objects
%  corresponding to each generic function  for which methods have been
%  defined in that package.
%  When the package is loaded into an \R session, the methods for each
%  generic function are \emph{cached}, that is, stored in the
%  environment of the generic function along with the methods from
%  previously loaded packages.  This merged table of methods is used to
%  dispatch or select methods from the generic, using class inheritance
%  and possibly group generic functions (see
%  \code{\link{GroupGenericFunctions}}) to find an applicable method.
%  See the \dQuote{Method Selection and Dispatch} section below.
%  The caching computations ensure that only one version of each
%  generic function is visible globally; although different attached
%  packages may contain a copy of the generic function, these behave
%  identically with respect to method selection.
%  In contrast, it is possible for the same function name to refer to
%  more than one generic function, when these have different
%  \code{package} slots.  In the latter case, \R considers the
%  functions unrelated:  A generic function is defined by the
%  combination of name and package.  See the \dQuote{Generic Functions}
%  section below.
%
%  The methods for a generic are stored according to the
%  corresponding \code{signature} in the call to \code{\link{setMethod}}
% that defined  the method.  The signature associates one
%  class name with each of a subset of the formal arguments to the
%  generic function.  Which formal arguments are available, and the
%  order in which they appear, are determined by the \code{"signature"}
%  slot of the generic function itself.  By default, the signature of the
%  generic consists of all the formal arguments except \dots, in the
%  order they appear in the function definition.
%
%  Trailing arguments in the signature of the generic will be \emph{inactive}  if no
%  method has yet been specified that included those arguments in its signature.
%  Inactive arguments are not needed or used in labeling the cached
%  methods.  (The distinction does not change which methods are
%  dispatched, but ignoring inactive arguments improves the
%  efficiency of dispatch.)
%
%  All arguments in the signature of the generic function will be evaluated when the
%  function is called, rather than using the traditional lazy
%  evaluation rules of S.  Therefore, it's important to \emph{exclude}
%  from the signature any arguments that need to be dealt with
%  symbolically (such as the first argument to function
%  \code{\link{substitute}}).  Note that only actual arguments are
%  evaluated, not default expressions.
%  A missing argument enters into the method selection as class
%  \code{"missing"}.
%
%  The cached methods are stored in an
%  environment object.  The names used for assignment are a
%  concatenation of the class names for the active arguments in the method signature.
%
%}
%
%\section{Methods for S3 Generic Functions}{
%
%S4 methods may be wanted for functions that also have S3 methods, corresponding to classes for the first
%formal argument of an S3 generic function--either a regular R function in which there is a
%call to the S3 dispatch function, \code{\link{UseMethod}},
%or one of a fixed set of primitive
%functions, which are not true functions but go directly to C code.
%In either case S3 method dispatch looks at the class of the first
%argument or the class of either
%argument in a call to one of the primitive binary operators.
%S3 methods are ordinary functions with the same arguments as the
%generic function (for primitives the formal arguments are not actually
%part of the object, but are simulated when the object is printed or
%viewed by \code{\link{args}()}).
%The \dQuote{signature} of an S3 method is identified  by the name to
%which the method is assigned, composed of the name of the
%generic function, followed by \code{"."}, followed by the name of the class.
%For details, see \link{S3Methods}.
%
%To implement a method for one of these functions corresponding to S4
%classes, there are two possibilities: either an S4 method or an S3 method with the
%S4 class name.
%The S3 method is only possible if the intended signature has the
%first argument and nothing else.
%In this case,
%the recommended approach is to define the S3 method and also supply the
%identical function as the definition of the S4 method.
%If the S3 generic function was \code{f3(x, ...)} and the S4 class for
%the new method was
%\code{"myClass"}:
%
% \code{f3.myClass <- function(x, ...) { ..... }}
%
% \code{setMethod("f3", "myClass", f3.myClass)}
%
%The reasons for defining both S3 and S4 methods are as follows:
%\enumerate{
%  \item An S4 method alone will not be seen if the S3 generic function
%    is called directly.  However, primitive functions and operators
%    are exceptions:  The internal C code will look for S4 methods
%    if and only if the object is an S4 object.  In the examples, the method
%    for \code{`[`} for class \code{"myFrame"} will always be called
%    for objects of this class.
%
%    For the same reason, an S4 method defined for an S3 class will not be called from
%    internal code for a non-S4 object. (See the example for function
%    \code{Math} and
%    class \code{"data.frame"} in the examples.)
%  \item An S3 method alone will not be called if there is \emph{any}
%    eligible non-default S4 method. (See the example for function
%    \code{f3} and class \code{"classA"} in the examples.)
%}
%Details of the selection computations are given below.
%
%When an S4 method is defined for an existing function that is not an
%S4 generic function (whether or not the existing function is an S3 generic),
%an S4 generic function will be created corresponding to the existing
%function and the package in which it is found (more precisely,
%according to the implicit generic function either specified or
%inferred from the ordinary function; see \code{\link{implicitGeneric}}).
%A message is printed after the initial call to
%\code{\link{setMethod}}; this is not an error, just a reminder that
%you have created the generic.
%Creating the generic explicitly by the call
%
%  \code{setGeneric("f3")}
%
%avoids the message, but has the same effect.
%The existing function becomes the default method for
%the S4 generic function.
%Primitive functions work the same way, but
%the S4 generic function is not explicitly created (as discussed below).
%
%
%S4 and S3 method selection are designed to follow compatible rules of
%inheritance, as far as possible.
%S3 classes can be used for any S4 method selection, provided that the
%S3 classes have been registered by a call to
%\code{\link{setOldClass}}, with that call specifying the correct S3
%inheritance pattern.
%S4 classes can be used for any S3 method selection; when an S4 object
%is detected, S3 method selection uses the contents of
%\code{\link{extends}(class(x))} as the equivalent of the S3
%inheritance (the inheritance is cached after the first call).
%
%An existing S3 method may not behave as desired for an S4 subclass, in
%which case utilities such as \code{\link{asS3}} and
%\code{\link{S3Part}} may be useful.  If the S3 method fails on the S4
%object, \code{asS3(x)} may be passed instead; if the object returned
%by the S3 method needs to be incorporated in the S4 object, the
%replacement function for \code{S3Part} may be useful, as in the method
%for class \code{"myFrame"} in the examples.
%
%Here are details explaining the reasons for defining both S3 and S4 methods.
%Calls still accessing the S3 generic function
%directly will not see S4 methods, except in the case of primitive
%functions.
%This means that calls to the generic function from namespaces that
%import the S3 generic but not the S4 version will only see S3
%methods.
%On the other hand, S3 methods will only be selected from the
%S4 generic function as part of its default (\code{"ANY"}) method.
%If there are inherited S4 non-default methods, these will be chosen in
%preference to \emph{any} S3 method.
%
%S3 generic functions implemented as primitive functions (including
%binary operators) are an exception to recognizing only
%S3 methods.
%These functions dispatch both S4 and S3 methods from
%the internal C code.
%There is no explicit generic function, either S3 or S4.
%The internal code looks for S4 methods if the first
%argument, or either of the arguments in the case of a binary operator,
%is an S4 object.
%If no S4 method is found, a search is made for an S3 method.
%
%S4 methods can be defined for an S3 generic function and an S3 class,
%but if the function is a primitive, such methods will not be selected
%if the object in question is not an S4 object.
%In the examples below, for instance,  an S4 method for signature
%\code{"data.frame"} for function \code{f3()} would be called for the
%S3 object \code{df1}.
%A similar S4 method for primitive function
%\code{`[`} would be ignored for that object, but would be called for
%the S4 object \code{mydf1} that inherits from \code{"data.frame"}.
%Defining both an S3 and S4 method removes this inconsistency.
%
%
%}
%\section{Method Selection and Dispatch: Details}{
%
%When a call to a generic function is evaluated, a method is selected corresponding
%to the classes of the actual arguments in the signature.
%First, the cached methods table is searched for an  exact match;
%that is, a method stored under the signature defined by
%the string value of \code{class(x)} for each non-missing
%argument, and \code{"missing"} for each missing argument.
%If no method is found directly for the actual arguments in a call to a
%generic function, an attempt is made to match the available methods to
%the arguments by using the superclass information about the actual classes.
%
%Each class definition may include a list of  one or more
%\emph{superclasses} of the new class.
%The simplest and most common specification is by the \code{contains=} argument in
%the  call to \code{\link{setClass}}.
%Each class named in this argument is a superclass of the new class.
%Two additional mechanisms for defining
%superclasses exist.
%A call to \code{\link{setClassUnion}} creates a union class that
%is a
%superclass of each of the members of the union.
% A call to
%\code{\link{setIs}} can create an inheritance relationship that is not the simple one of
%containing the superclass representation in the new class.
%Arguments \code{coerce} and \code{replace} supply methods to convert
%to the superclass and to replace the part corresponding to the superclass.
%(In addition, a \code{test=} argument allows conditional inheritance;  conditional inheritance is not
%recommended and is not used in method selection.)
%All three mechanisms are treated equivalently for purposes of
%method selection:  they define the \emph{direct} superclasses of a
%particular class.
%For more details on the mechanisms, see \code{\link{Classes}}.
%
%The direct superclasses themselves may
%have superclasses, defined by any of the same mechanisms, and
%similarly through further generations.  Putting all this information together produces
%the full list of superclasses for this class.
%The superclass list is included in the definition of the class that is
%cached during the \R session.
%Each element of the list describes the nature of the relationship (see
%\code{\linkS4class{SClassExtension}} for details).
%Included in the element is a \code{distance} slot containing
%the path length for the relationship:
%\code{1} for direct superclasses (regardless of which mechanism
%defined them), then \code{2} for the direct superclasses of those
%classes, and so on.
%In addition, any class implicitly has class \code{"ANY"} as a superclass.  The
%distance to \code{"ANY"} is treated as larger than the distance to any
%actual class.
%The special class \code{"missing"} corresponding to missing arguments
%has only \code{"ANY"} as a superclass, while \code{"ANY"} has no
%superclasses.
%
%When a class definition is created or modified, the superclasses
%are ordered, first by a stable sort of the all superclasses by
%distance.
%If the set of superclasses has duplicates (that is, if some class is
%inherited through more than one relationship), these are removed, if
%possible, so that the list of superclasses is consistent with the
%superclasses of all direct superclasses.
%See the reference on inheritance for details.
%
%The information about superclasses is summarized when a class
%definition is printed.
%
%When a method is to be selected by inheritance, a search is made in
%the table for all methods directly corresponding to a combination of
%either the direct class or one of its superclasses, for each argument
%in the active signature.
%For an example, suppose there is only one argument in the signature and that the class of
%the corresponding object was \code{"dgeMatrix"} (from the recommended package
%\code{Matrix}).
%This class has two direct superclasses and through these 4 additional superclasses.
%Method selection finds all the methods in the table of directly
%specified methods labeled by one of these classes, or by
%\code{"ANY"}.
%
%When there are multiple arguments in the signature, each argument will
%generate a similar  list of inherited classes.
%The possible matches are now all the combinations of classes from each
%argument (think of the function \code{outer} generating an array of
%all possible combinations).
%The search now finds all the methods matching any of this combination
%of classes.
%For each argument, the position in the list of superclasses of that
%argument's class defines which method or methods (if the same class
%appears more than once) match best.
%When there is only one argument, the best match is unambiguous.
%With more than one argument, there may be zero or one match that is
%among the best matches for \emph{all} arguments.
%
%If there is no best match, the selection is ambiguous and a message is
%printed noting which method was selected (the first method
%lexicographically in the ordering) and what other methods could have
%been selected.
%Since the ambiguity is usually nothing the end user could control,
%this is not a warning.
%Package authors should examine their package for possible ambiguous
%inheritance by calling \code{\link{testInheritedMethods}}.
%
%When the inherited method has been selected, the selection is cached
%in the generic function so that future calls with the same class will
%not require repeating the search.  Cached inherited selections are
%not themselves used in future inheritance searches, since that could result
%in invalid selections.
%If you want inheritance computations to be done again (for example,
%because a newly loaded package has a more direct method than one
%that has already been used in this session), call
%\code{\link{resetGeneric}}.  Because classes and methods involving
%them tend to come from the same package, the current implementation
%does not reset all generics every time a new package is loaded.
%
%Besides being initiated through calls to the generic function, method
%selection can be done explicitly by calling the function
%\code{\link{selectMethod}}.
%
%Once a method has been selected, the evaluator creates a new context
%in which a call to the method is evaluated.
%The context is initialized with the arguments from the call to the
%generic function.
%These arguments are not rematched.  All the arguments in the signature
%of the generic will have been evaluated (including any that are
%currently inactive); arguments that are not in the signature will obey
%the usual lazy evaluation rules of the language.
%If an argument was missing in the call, its default expression if any
%will \emph{not} have been evaluated, since method dispatch always uses
%class \code{missing} for such arguments.
%
%A call to a generic function therefore has two contexts:  one for the
%function and a second for the method.
%The argument objects will be copied to the second context, but not any
%local objects created in a nonstandard generic function.
%The other important distinction is that the parent
%(\dQuote{enclosing}) environment of the second context is the environment
%of the method as a function, so that all \R programming techniques
%using such environments apply to method definitions as ordinary functions.
%
%
%For further discussion of method selection and dispatch,  see the
%first reference.
%
%}
%
%\section{Generic Functions}{
%In principle, a generic function could be any function that evaluates
%a call to \code{standardGeneric()}, the internal function that selects
%a method and evaluates a call to  the selected method.  In practice,
%generic functions are special objects that in addition to being from a
%subclass of class \code{"function"} also extend the class
%\code{\linkS4class{genericFunction}}.  Such objects have slots to define
%information needed to deal with their methods.  They also have
%specialized environments, containing the tables used in method
%selection.
%
%The slots \code{"generic"} and  \code{"package"} in the object are the
%character string names of the generic function itself and of the
%package from which the  function is defined.
%As with classes, generic functions are uniquely defined in \R by the
%combination of the two names.
%There can be generic functions of the same name associated with
%different packages (although inevitably keeping such functions cleanly
%distinguished is not always easy).
%On the other hand, \R will enforce that only one definition of a
%generic function can be associated with a particular combination of
%function and package name, in the current session or other active
%version of \R.
%
%Tables of methods for a particular generic function, in this sense,
%will often be spread over several other packages.
%The total set of methods for a given generic function may change
%during a session, as additional packages are loaded.
%Each table must be consistent in the signature assumed for the generic
%function.
%
%\R distinguishes \emph{standard} and \emph{nonstandard} generic
%functions, with the former having a function body that does nothing
%but dispatch a method.
%For the most part, the distinction is just one of simplicity:  knowing
%that a generic function only dispatches a method call allows some
%efficiencies and also removes some uncertainties.
%
%In most cases, the generic function is the visible function
%corresponding to that name, in the corresponding package.
%There are two exceptions, \emph{implicit} generic
%functions and the special computations required to deal with \R's
%\emph{primitive} functions.
%Packages can contain a table of implicit generic versions of functions
%in the package, if the package wishes to leave a function non-generic
%but to constrain what the function would be like if it were generic.
%Such implicit generic functions are created during the installation of
%the package, essentially by defining the generic function and
%possibly methods for it, and then reverting the function to its
%non-generic form. (See \link{implicitGeneric} for how this is done.)
%The mechanism is mainly used for functions in the older packages in
%\R, which may prefer to ignore S4 methods.
%Even in this case, the actual mechanism is only needed if something
%special has to be specified.
%All functions have a corresponding implicit generic version defined
%automatically (an implicit, implicit generic function one might say).
%This function is a standard generic with the same arguments as the
%non-generic function, with the non-generic version as the default (and only)
%method, and with the generic signature being all the formal arguments
%except \dots.
%
%The implicit generic mechanism is needed only to override some aspect
%of the default definition.
%One reason to do so would be to remove some arguments from the
%signature.
%Arguments that may need to be interpreted literally, or for which the
%lazy evaluation mechanism of the language is needed, must \emph{not}
%be included in the signature of the generic function, since all
%arguments in the signature will be evaluated in order to select a
%method.
%For example, the argument \code{expr} to the function
%\code{\link{with}} is treated literally and must therefore be excluded
%from the signature.
%
%One would also need to define an implicit generic if the existing
%non-generic function were not suitable as the default method.
%Perhaps the function only applies to some classes of objects, and the
%package designer prefers to have no general default method.
%In the other direction, the package designer might have some ideas
%about suitable methods for some classes, if the function were generic.
%With reasonably modern packages, the simple approach in all these
%cases is just to define the function as a generic.
%The implicit generic mechanism is mainly attractive for older packages
%that do not want to require the methods package to be available.
%
%Generic functions will also be defined but not obviously visible for
%functions implemented as \emph{primitive} functions in the base
%package.
%Primitive functions look like ordinary functions when printed but are
%in fact not function objects but objects of two types interpreted by
%the \R evaluator to call underlying C code directly.
%Since their entire justification is efficiency, \R refuses to hide
%primitives behind a generic function object.
%Methods may be defined for most primitives, and corresponding metadata
%objects will be created to store them.
%Calls to the primitive still go directly to the C code, which will
%sometimes check for applicable methods.
%The definition of \dQuote{sometimes} is that methods must have been
%detected for the function in some package loaded in the session and
%\code{isS4(x)} is \code{TRUE} for  the first argument (or for the
%second argument, in the case of binary operators).
%You can test whether methods have been detected by calling
%\code{\link{isGeneric}} for the relevant function and you can examine
%the generic function by calling \code{\link{getGeneric}}, whether or
%not methods have been detected.
%For more on generic functions, see the first reference and also section 2 of \emph{R Internals}.
%
%}
%
%\section{Method Definitions}{
%All method definitions are stored as objects from the
%\code{\linkS4class{MethodDefinition}} class.
%Like the class of generic functions, this class extends ordinary \R
%functions with some additional slots: \code{"generic"}, containing the
%name and package of the generic function, and two signature slots,
%\code{"defined"} and \code{"target"}, the first being the signature supplied when
%the method was defined by a call to \code{\link{setMethod}}.
%The  \code{"target"} slot starts off equal to the \code{"defined"}
%  slot.  When an inherited method is cached after being selected, as
%  described above, a copy is made with the  appropriate \code{"target"}  signature.
%  Output from \code{\link{showMethods}}, for example, includes both
%  signatures.
%
%  Method definitions are required to have the same formal arguments as
%  the generic function, since the method dispatch mechanism does not
%  rematch arguments, for reasons of both efficiency and consistency.
%}
%
%\examples{
%## A class that extends a registered S3 class inherits that class' S3
%## methods.
%
%setClass("myFrame", contains = "data.frame",
%    representation(timestamps = "POSIXt"))
%
%df1 <- data.frame(x = 1:10, y = rnorm(10), z = sample(letters,10))
%
%mydf1 <- new("myFrame", df1, timestamps = Sys.time())
%
%## "myFrame" objects inherit "data.frame" S3 methods; e.g., for `[`
%
%mydf1[1:2, ] # a data frame object (with extra attributes)
%
%## a method explicitly for "myFrame" class
%
%
%setMethod("[",
%    signature(x = "myFrame"),
%    function (x, i, j, ..., drop = TRUE)
%    {
%        S3Part(x) <- callNextMethod()
%        x@timestamps <- c(Sys.time(), as.POSIXct(x@timestamps))
%        x
%    }
%)
%
%\donttest{mydf1[1:2, ]}
%
%
%setClass("myDateTime", contains = "POSIXt")
%
%now <- Sys.time() # class(now) is c("POSIXct", "POSIXt")
%nowLt <- as.POSIXlt(now)# class(nowLt) is c("POSIXlt", "POSIXt")
%
%mCt <- new("myDateTime", now)
%mLt <- new("myDateTime", nowLt)
%
%## S3 methods for an S4 object will be selected using S4 inheritance
%## Objects mCt and mLt have different S3Class() values, but this is
%## not used.
%f3 <- function(x)UseMethod("f3") # an S3 generic to illustrate inheritance
%
%f3.POSIXct <- function(x) "The POSIXct result"
%f3.POSIXlt <- function(x) "The POSIXlt result"
%f3.POSIXt <- function(x) "The POSIXt result"
%
%stopifnot(identical(f3(mCt), f3.POSIXt(mCt)))
%stopifnot(identical(f3(mLt), f3.POSIXt(mLt)))
%
%
%
%## An S4 object selects S3 methods according to its S4 "inheritance"
%
%
%setClass("classA", contains = "numeric",
%         representation(realData = "numeric"))
%
%Math.classA <- function(x) {(getFunction(.Generic))(x@realData)}
%setMethod("Math", "classA", Math.classA)
%
%
%x <- new("classA", log(1:10), realData = 1:10)
%
%stopifnot(identical(abs(x), 1:10))
%
%setClass("classB", contains = "classA")
%
%y <- new("classB", x)
%
%stopifnot(identical(abs(y), abs(x))) # (version 2.9.0 or earlier fails here)
%
%## an S3 generic: just for demonstration purposes
%f3 <- function(x, ...) UseMethod("f3")
%
%f3.default <- function(x, ...) "Default f3"
%
%## S3 method (only) for classA
%f3.classA <- function(x, ...) "Class classA for f3"
%
%## S3 and S4 method for numeric
%f3.numeric <- function(x, ...) "Class numeric for f3"
%setMethod("f3", "numeric", f3.numeric)
%
%## The S3 method for classA and the closest inherited S3 method for classB
%## are not found.
%
%f3(x); f3(y) # both choose "numeric" method
%
%## to obtain the natural inheritance, set identical S3 and S4 methods
%setMethod("f3", "classA", f3.classA)
%
%f3(x); f3(y) # now both choose "classA" method
%
%## Need to define an S3 as well as S4 method to use on an S3 object
%## or if called from a package without the S4 generic
%
%MathFun <- function(x) { # a smarter "data.frame" method for Math group
%  for (i in seq(length = ncol(x))[sapply(x, is.numeric)])
%    x[, i] <- (getFunction(.Generic))(x[, i])
%  x
%}
%setMethod("Math", "data.frame", MathFun)
%
%## S4 method works for an S4 class containing data.frame,
%## but not for data.frame objects (not S4 objects)
%
%try(logIris <- log(iris)) #gets an error from the old method
%
%## Define an S3 method with the same computation
%
%Math.data.frame <- MathFun
%
%logIris <- log(iris)
%
%
%
%
%\dontshow{
%removeClass("classA"); removeClass("classB"); rm(x,y)
%removeGeneric("f3")
%removeClass("myDateTime")
%removeMethod("Math", "data.frame"); rm(Math.data.frame, MathFun, logIris)
%}
%
%}
%
%
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version: see section 10.6 for method
%  selection and section 10.5 for generic functions).
%
% Chambers, John M.(2009)
% \emph{Developments in Class Inheritance and Method Selection}
% \url{https://statweb.stanford.edu/~jmc4/classInheritance.pdf}.
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{
%For more specific information, see
%  \code{\link{setGeneric}}, \code{\link{setMethod}}, and
%  \code{\link{setClass}}.
%
%For the use of \dots in methods, see  \link{dotsMethods}.
%}
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%