% File src/library/methods/man/RClassUtils.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Copyright 2008-2015 The R Foundation
% Distributed under GPL 2 or later

\name{RClassUtils}
%% NOTE: This is {internal} for a good reason

%% FIXME the following are undocumented utilities (Sep 23, 2002)
%@%\alias{クラス定義を管理するユーティリティ}
\alias{completeSubclasses}
\alias{newClassRepresentation}
\alias{print.classRepresentation}
\alias{setExtendsMetaData}
\alias{setSubclassMetaData}
\alias{subclassesMetaName}
\alias{extendsMetaName}
\alias{classPrototypeDef-class}
%%
\alias{.classEnv}
\alias{classLabel}
\alias{testVirtual}
\alias{makePrototypeFromClassDef}
\alias{newEmptyObject}
\alias{completeClassDefinition}
\alias{getAllSuperClasses}
\alias{superClassDepth}
\alias{isVirtualClass}
\alias{assignClassDef}
\alias{newBasic}
\alias{makeExtends}
\alias{reconcilePropertiesAndPrototype}
\alias{tryNew}
\alias{empty.dump}
\alias{showClass}
\alias{showExtends}
\alias{possibleExtends}
\alias{completeExtends}
\alias{classMetaName}
\alias{methodsPackageMetaName}
\alias{metaNameUndo}
\alias{requireMethods}
\alias{checkAtAssignment}
\alias{checkSlotAssignment}
\alias{defaultPrototype}
\alias{isClassDef}
\alias{validSlotNames}
\alias{getDataPart}
\alias{setDataPart}
%% not explicitly documented here
\alias{.BasicClasses}
\alias{.BasicVectorClasses}
\alias{.InitBasicClasses}
\alias{.InitMethodsListClass}
\alias{.setCoerceGeneric}
\alias{conditionalExtension-class}

\title{クラス定義を管理するユーティリティ}
%\title{Utilities for Managing Class Definitions}
\description{
  これらは形式的クラスの定義と使用をサポートする様々な
  関数である．それらの殆どは滅多に直接呼び出すのには適していない．

  他はある程度実験的かつ/または部分的な実装だけである．
  普通のコード開発には \code{\link{setClass}} を参照せよ．
}

\usage{
classLabel(Class)
.classEnv(Class, default = .requirePackage("methods"), mustFind = TRUE)

testVirtual(properties, extends, prototype, where)

makePrototypeFromClassDef(slots, ClassDef, extends, where)

newEmptyObject()

completeClassDefinition(Class, ClassDef, where, doExtends)

getAllSuperClasses(ClassDef, simpleOnly = TRUE)

superClassDepth(ClassDef, soFar, simpleOnly = TRUE)

isVirtualClass(Class, where)

newBasic(Class, ...)

makeExtends(Class, to, coerce, test, replace, by, package, slots,
                 classDef1, classDef2)

reconcilePropertiesAndPrototype(name, properties, prototype,
       superClasses, where)

tryNew(Class, where)

empty.dump()

showClass(Class, complete=TRUE, propertiesAreCalled="Slots")

showExtends(ext, printTo = stdout())

possibleExtends(class1, class2, ClassDef1 = getClassDef(class1),
                 ClassDef2 = getClassDef(class2, where =
                 .classEnv(ClassDef1)))

completeExtends(ClassDef, class2, extensionDef, where)

classMetaName(name)

methodsPackageMetaName(prefix, name, package = "")

metaNameUndo(strings, prefix, searchForm = FALSE)

requireMethods(functions, signature, message, where)

checkAtAssignment(cl, name, valueClass)
checkSlotAssignment(obj, name, value)

defaultPrototype()

isClassDef(object)

validSlotNames(names)

getDataPart(object)
setDataPart(object, value, check = TRUE)

}

\section{関数の要約}{
  \describe{
    \item{\code{testVirtual}:}{
      仮想クラスに対するテスト．
      これらの性質，拡張，そしてプロトタイプを持つ
      クラスが仮想クラスかどうか可能な限り探りだす．
      \code{"VIRTUAL"} を拡張することで仮想的と強制することが出来る．
      
      さもなければ，一つのクラスは
      もしそれがスロットを持たず，非仮想的なクラスを拡張せず，
      そして \code{NULL} プロトタイプを持つ時だけ仮想的である．
    }

    \item{\code{makePrototypeFromClassDef}:}{
      クラス定義が示唆するプロトタイプを作る．

      次の三つの規則がこの順で適用される．
      \enumerate{
        \item もしクラスがスロットを持てば，各スロットに対する
	  プロトタイプが既定で使われるが，
	  \code{ClassDef} 中に明示的に提供されたプロトタイプ中の
	  対応する要素が，もしあれば，代わりに使われる
	  (しかしそれはスロットのクラスに強制変換できる)．
	  これはもしあればデータ部分
	  (\code{".Data"} スロット)を含む．

        \item もしスロットが無いがナルないプロトタイプが
	  指定されると，これが返される．

        \item もし仮想的でないスーパークラス
	  (拡張されたリスト中のクラス)があれば，その
	  プロトタイプが使われる．必要なら取り出される
	  (一つのデータ部分が二つのスーパークラスを持つことは許される；
	  最初のが使われ，他について警告が出る)．
        }
        もし上の三つ全てが失敗するとプロトタイプは \code{NULL}．
    }

    \item{\code{newEmptyObject}:}{
      その中にスロットを設定出来る空のオブジェクトを作る
      ユーティリティ関数．

      現在単に
      クラス \code{"NULL"} の空リストを作る．

      将来のバージョンは現在はスロットもデータもないオブジェクトを
      マークする投手なオブジェクト参照を作り出すべきである．
    }

    \item{\code{completeClassDefinition}:}{
      \code{Class} の定義を
      環境 \code{where} から見えるクラス定義に関して
      補完する．もし
      \code{doExtends} が \code{TRUE} ならば，スーパークラスと
      サブクラス情報を補完する．

      この関数はクラスが定義されたり再定義された時に呼び出される．
    }

    \item{\code{getFromClassDef}:}{
      内部的に定義されたクラス定義の性質の一つを取り出す
      (".Properties" 等)．狭義にユーティリティ関数である．
    }
%%
    \item{\code{getSlots}:}{
      名前付きの文字列ベクトルを返す．
      名前はスロット名であり，値は対応するスロットのクラスである．
      引数 \code{x} はクラス名でもクラス定義オブジェクトでも良い．
    }

    \item{\code{getAllSuperClasses}, \code{superClassDepth}:}{
      このクラス定義が拡張する全てのクラスの名前を得る．

      \code{getAllSuperClasses} はクラス定義を補完するために使われる
      ユーティリティ関数である．
      これはこのクラスから到達可能な全てのスーパークラスを
      拡がり優先順序
      (これはメソッドのマッチングに対して使われる順序である)で返す；
      つまり最初の直接のスーパークラスに，次いで
      その全てのスーパークラス，そしてその次等．
      (この順序はあるスーパークラスが多重継承を持つ場合
      にだけ意味を持つ．)

      \code{getAllSuperClasses} から呼び出される \code{superClassDepth}
      は同じ情報を返すが，
      成分 \code{label} と \code{depth} のりストとしてであり，
      後者は継承ツリー中で各クラスが何世代遡るかに対するものである．
      引数 \code{soFar} はクラス関係のネットワーク中のループを避けるために
      使われる．
    }

    \item{\code{isVirtualClass}:}{
      名前付きクラスは仮想クラスか?

      あるクラスはもし明示的にそうであると宣言されるか，
      また形式的に定義されていないと仮想的である．
    }
%%
    \item{\code{assignClassDef}:}{
      クラス定義を特殊な名前付きオブジェクトへ付値する．
    }

    \item{\code{newBasic}:}{
      基本クラスへの関数 \code{new} の実装は形式的定義を持たない．

      \code{Class="NULL"} を除けば
      (\code{NULL} は属性を持つことが出来ないので許されない)．
      これらのどれも形式的定義を持つことが出来たかもしれず，
      結果のクラスは \code{Class} と設定される．

      引数の解釈に対しては \code{new} を見よ．
    }

    \item{\code{makeExtends}:}{
      引数を拡張機構を定義するリストに変換．
    }

    \item{\code{reconcilePropertiesAndPrototype}:}{
      リストまたは構造を与えられクラスに対するプロトタイプ風にする．

      特に，もしそこに存在すればプロトタイプから取られた
      性質と値中のスロット名に対応する属性を持つ構造を返す，
      クラスに対しては
      \code{new(classi)} から，もしそれが継承していれば
      ストットの \code{classi} から，そしてさもなければ
      \code{NULL}．

      プロトタイプは性質リスト中に無いスロットを含意するかもしれない．
      なぜなら性質は継承スロットを含まないからである
      (これらはクラスがセッション中で使われるまで未解消のままにされる)．
    }

    \item{\code{tryNew}:}{
      このクラスから新しい要素を生成しようとするが，
      もし試みが失敗すると
      (例えばクラスが未定義か仮想的な場合のように)単に \code{NULL} を返す．

      これは実際にオブジェクトを生成する際には非効率的でまた
      良いアイデアではないが，クラスの初期定義には役立つ．
    }

    \item{\code{showClass}:}{
      クラス定義に関する情報をプリントする．

      もし \code{complete} が \code{TRUE} なら，拡張に関する
      非直接的な情報を含む．

      これは
      \code{\link{show}(\link{getClass}(.))} から呼び出されるユーティリティで，
      そしてユーザは典型的にクラス定義を見るためには
      \code{getClass(.)} を使う．
    }

    \item{\code{showExtends}:}{
      拡張のりストの要素をプリントする；
      \code{printTo = FALSE} に対しては成分
      \code{what} と \code{how} のりストを返す；つまり
      例えば \code{\link{promptClass}()} により使われるようなもの．
    }

    \item{\code{possibleExtends}:}{
      class1 が class2 を直接にか非直接に拡張するかどうかを
      示す情報を見つける．

      これは論理値であるか，
      関係を検査そして/または強制変換する様々な関数を含む
      クラス \code{\linkS4class{SClassExtension}} のオブジェクトで
      あり得る．
    }

    \item{\code{classLabel}: }{
        クラスを特定する情報を持つ文字列と，
        もし適当ならばそこからクラスが由来するパッケージを返す．
    }

    \item{\code{.classEnv}: }{% is called from C level  R_check_class_etc()
        典型的には名前空間である環境を返し，
	その中に \code{Class} が定義されている．
	\code{Class} は典型的には
	\code{\link{class}()} (そして従って
        \code{"package"} 属性を含む)または \code{\link{getClass}}
	(または \code{\link{getClassDef}}) の結果である．
    }

    \item{\code{completeExtends}:}{
      以下の推移的な連鎖によりクラス定義中の拡張情報を補完する．

      もし \code{class2} と \code{extensionDef} が含まれていると，
      このクラスが付け加えられる．さもなければ単に現在の
      \code{ClassDef} を使う．

      \code{contains} と \code{subclasses} スロットは共に
      任意の可視の間接的な関係を持つように補完される．
    }

    \item{\code{classMetaName}:}{
     このクラスの定義を補完するオブジェクトの名前．
    }

    \item{\code{methodsPackageMetaName}:}{
      メソッドとクラス情報を定義するメタデータを隠すために
      名前を分断するデバイス．
    }
    \item{\code{metaNameUndo}}{
      その名前が示唆するように，この関数はメタデータオブジェクト名を作るのに
      使われた名前の分断を元に戻し，そして
      クラス \code{\linkS4class{ObjectsWithPackage} のオブジェクトを返す}．
    }

    \item{\code{requireMethods}:}{
      このシグネチャに対して，総称的関数に対するメソッドを移植する
      サブクラスを要求する．

      各総称的関数に対して，
      \code{setMethod} は与えられたメッセージを持つエラーを
      投げるメソッドを定義するために呼び出される．

      関数 \code{requireMethods} はある関数に対するメソッドを移植するために
      それらを拡張する実際のクラスを要求する仮想クラスを許す，
      実際には仮想クラスに対する API を作る．

      さもなければ，対応する関数に対する既定メソッド
      が呼び出され，より役に立たぬエラーメッセージか
      (一層まずいことに)黙って不正確な結果に導く．
    }

    \item{\code{checkSlotAssignment}, \code{checkAtAssignment}:}{
      提供された値がこのスロットに対して許されるかどうかを，クラスの定義を
      用いて，チェックする．
      スロットを付値する C コードから呼び出される．

      特権的なスロット
      (クラス自体と共に定義されたアクセス関数によってだけ設定出来るようなもの)
      に対しては，クラスのデザイナーはアクセス関数中で付値される値を
      検証しそれから
      \code{checkSlotAssignment} の呼び出しを防ぐために.
      \code{slot<-} を引数 \code{check=FALSE} で呼び出す
      ことで効率性を改善することを選択できる，
    }

    \item{\code{defaultPrototype}:}{
      スロットを持つべきクラスに対するプロトタイプは
      仮想的ではなく，又基本クラスの一つを拡張しない．
      その \code{\link{class}} とその (\R 内部)タイプ
      \code{\link{typeof}()} は共に \code{"S4"} である．
    }

    \item{\code{.InitBasicClasses}, \code{.InitMethodsListClass}, \code{.setCoerceGeneric}:}{
      これらの関数はクラスとメソッドの初期化の一部分を実行し，
      そして \code{.onLoad} から(のみ!)呼び出される．
    }

    \item{\code{isClassDef}:}{
      \code{object} はクラスの表現か?
    }

    \item{\code{validSlotNames}:}{
      名前の一つが予約されていない限り \code{names} を返す．
      予約されているとエラーを返す．
      (執筆時 \code{"class"} は唯一の予約スロット名である．)
    }
    \item{\code{getDataPart}, \code{setDataPart}:}{
      \code{object@.Data} を実装するために呼び出されるユーティリティ．
      \code{setDataPart} の呼び出しはまた
      スーパークラスのプロトタイプのデータ部分を併合するために使われる．
    }

  }%end{ describe }
}
\examples{
typeof(defaultPrototype()) #-> "S4"

## .classEnv()
meth.ns <- asNamespace("methods")
if(get4 <- !any("package:stats4" == search()))
   require("stats4")
stopifnot(TRUE
 , identical(.classEnv("data.frame"), meth.ns)
 , identical(.classEnv(class(new("data.frame"))), meth.ns)
 , identical(.classEnv(     "mle"       ), meth.ns) # <- 'stats4' *でない* 
 , identical(.classEnv(class(new("mle"))), asNamespace("stats4"))
 , identical(.classEnv(getClass ("mle") ), asNamespace("stats4"))
 )
if(get4) detach("package:stats4")
}
\keyword{internal}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/RClassUtils.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Copyright 2008-2015 The R Foundation
%% Distributed under GPL 2 or later
%
%\name{RClassUtils}
%%% NOTE: This is {internal} for a good reason
%
%%% FIXME the following are undocumented utilities (Sep 23, 2002)
%\alias{completeSubclasses}
%\alias{newClassRepresentation}
%\alias{print.classRepresentation}
%\alias{setExtendsMetaData}
%\alias{setSubclassMetaData}
%\alias{subclassesMetaName}
%\alias{extendsMetaName}
%\alias{classPrototypeDef-class}
%%%
%\alias{.classEnv}
%\alias{classLabel}
%\alias{testVirtual}
%\alias{makePrototypeFromClassDef}
%\alias{newEmptyObject}
%\alias{completeClassDefinition}
%\alias{getAllSuperClasses}
%\alias{superClassDepth}
%\alias{isVirtualClass}
%\alias{assignClassDef}
%\alias{newBasic}
%\alias{makeExtends}
%\alias{reconcilePropertiesAndPrototype}
%\alias{tryNew}
%\alias{empty.dump}
%\alias{showClass}
%\alias{showExtends}
%\alias{possibleExtends}
%\alias{completeExtends}
%\alias{classMetaName}
%\alias{methodsPackageMetaName}
%\alias{metaNameUndo}
%\alias{requireMethods}
%\alias{checkAtAssignment}
%\alias{checkSlotAssignment}
%\alias{defaultPrototype}
%\alias{isClassDef}
%\alias{validSlotNames}
%\alias{getDataPart}
%\alias{setDataPart}
%%% not explicitly documented here
%\alias{.BasicClasses}
%\alias{.BasicVectorClasses}
%\alias{.InitBasicClasses}
%\alias{.InitMethodsListClass}
%\alias{.setCoerceGeneric}
%\alias{conditionalExtension-class}
%
%\title{Utilities for Managing Class Definitions}
%\description{
%  These are various functions to support the definition and use of
%  formal classes.  Most of them are rarely suitable to be called
%  directly.
%
%  Others are somewhat experimental and/or partially implemented only. Do
%  refer to \code{\link{setClass}} for normal code development.
%}
%
%\usage{
%classLabel(Class)
%.classEnv(Class, default = .requirePackage("methods"), mustFind = TRUE)
%
%testVirtual(properties, extends, prototype, where)
%
%makePrototypeFromClassDef(slots, ClassDef, extends, where)
%
%newEmptyObject()
%
%completeClassDefinition(Class, ClassDef, where, doExtends)
%
%getAllSuperClasses(ClassDef, simpleOnly = TRUE)
%
%superClassDepth(ClassDef, soFar, simpleOnly = TRUE)
%
%isVirtualClass(Class, where)
%
%newBasic(Class, ...)
%
%makeExtends(Class, to, coerce, test, replace, by, package, slots,
%                 classDef1, classDef2)
%
%reconcilePropertiesAndPrototype(name, properties, prototype,
%       superClasses, where)
%
%tryNew(Class, where)
%
%empty.dump()
%
%showClass(Class, complete=TRUE, propertiesAreCalled="Slots")
%
%showExtends(ext, printTo = stdout())
%
%possibleExtends(class1, class2, ClassDef1 = getClassDef(class1),
%                 ClassDef2 = getClassDef(class2, where =
%                 .classEnv(ClassDef1)))
%
%completeExtends(ClassDef, class2, extensionDef, where)
%
%classMetaName(name)
%
%methodsPackageMetaName(prefix, name, package = "")
%
%metaNameUndo(strings, prefix, searchForm = FALSE)
%
%requireMethods(functions, signature, message, where)
%
%checkAtAssignment(cl, name, valueClass)
%checkSlotAssignment(obj, name, value)
%
%defaultPrototype()
%
%isClassDef(object)
%
%validSlotNames(names)
%
%getDataPart(object)
%setDataPart(object, value, check = TRUE)
%
%}
%
%\section{Summary of Functions}{
%  \describe{
%    \item{\code{testVirtual}:}{
%      Test for a Virtual Class.
%      Figures out, as well as possible, whether the class with these
%      properties, extension, and prototype is a virtual class.
%      Can be forced to be virtual by extending \code{"VIRTUAL"}.
%
%      Otherwise, a class is virtual only if it has no slots, extends no
%      non-virtual classes, and has a \code{NULL} Prototype.
%    }
%
%    \item{\code{makePrototypeFromClassDef}:}{
%      Makes the prototype implied by the class definition.
%
%      The following three rules are applied in this order.
%      \enumerate{
%        \item If the class has slots, then the prototype for each slot
%          is used by default, but a corresponding element in the
%          explicitly supplied prototype in \code{ClassDef}, if there is
%          one, is used instead (but it must be coercible to the class of
%          the slot). This includes the data part (\code{".Data"} slot) if
%          there is one.
%
%        \item If there are no slots but a non-null prototype was
%          specified, this is returned.
%
%        \item If there is a non-virtual superclass (a class in the
%          extends list), then its prototype is used.  The data part is
%          extracted if needed (it is allowed to have two superclasses
%          with a data part; the first is used and a warning issued on
%          any others).
%        }
%        If all three of the above fail, the prototype is \code{NULL}.
%    }
%
%    \item{\code{newEmptyObject}:}{
%      Utility function to create an empty object into which slots can be
%      set.
%
%      Currently just creates an empty list with class \code{"NULL"}.
%
%      Later version should create a special object reference that marks
%      an object currently with no slots and no data.
%    }
%
%    \item{\code{completeClassDefinition}:}{
%      Completes the definition of \code{Class}, relative to the class
%      definitions visible from environment \code{where}.  If
%      \code{doExtends} is \code{TRUE}, complete the super- and
%      sub-class information.
%
%      This function is called when a class is defined or re-defined.
%    }
%
%    \item{\code{getFromClassDef}:}{
%      Extracts one of the intrinsically defined class definition
%      properties (".Properties", etc.)  Strictly a utility function.
%    }
%%%
%    \item{\code{getSlots}:}{
%      Returns a named character vector.  The names are the names of the
%      slots, the values are the classes of the corresponding slots.
%      The argument \code{x} can either be the name of
%      a class or the class definition object.
%    }
%
%    \item{\code{getAllSuperClasses}, \code{superClassDepth}:}{
%      Get the names of all the classes that this class definition
%      extends.
%
%      \code{getAllSuperClasses} is a utility function used to complete a
%      class definition.  It returns all the superclasses reachable from
%      this class, in breadth-first order (which is the order used for
%      matching methods); that is, the first direct superclass followed
%      by all its superclasses, then the next, etc.  (The order is
%      relevant only in the case that some of the superclasses have
%      multiple inheritance.)
%
%      \code{superClassDepth}, which is called from
%      \code{getAllSuperClasses}, returns the same information, but as a
%      list with components \code{label} and \code{depth}, the latter for
%      the number of generations back each class is in the inheritance
%      tree.  The argument \code{soFar} is used to avoid loops in the
%      network of class relationships.
%    }
%
%    \item{\code{isVirtualClass}:}{
%      Is the named class a virtual class?
%
%      A class is virtual if explicitly declared to be, and also if the
%      class is not formally defined.
%    }
%%%
%    \item{\code{assignClassDef}:}{
%      assign the definition of the class to the specially named object
%    }
%
%    \item{\code{newBasic}:}{
%      the implementation of the function \code{new} for basic classes
%      that don't have a formal definition.
%
%      Any of these could have a formal definition, except for
%      \code{Class="NULL"} (disallowed because \code{NULL} can't have
%      attributes).  For all cases except \code{"NULL"}, the class of the
%      result will be set to \code{Class}.
%
%      See \code{new} for the interpretation of the arguments.
%    }
%
%    \item{\code{makeExtends}:}{
%      convert the argument to a list defining the extension mechanism.
%    }
%
%    \item{\code{reconcilePropertiesAndPrototype}:}{
%      makes a list or a structure look like a prototype for the given
%      class.
%
%      Specifically, returns a structure with attributes corresponding to
%      the slot names in properties and values taken from prototype if
%      they exist there, from \code{new(classi)} for the class,
%      \code{classi} of the slot if that succeeds, and \code{NULL}
%      otherwise.
%
%      The prototype may imply slots not in the properties list, since
%      properties does not include inherited slots (these are left
%      unresolved until the class is used in a session).
%    }
%
%    \item{\code{tryNew}:}{
%      Tries to generate a new element from this class, but if the attempt
%      fails (as, e.g., when the class is undefined or virtual) just
%      returns \code{NULL}.
%
%      This is inefficient and also not a good idea when actually
%      generating objects, but is useful in the initial definition of
%      classes.
%    }
%
%    \item{\code{showClass}:}{
%      Print the information about a class definition.
%
%      If \code{complete} is \code{TRUE}, include the indirect
%      information about extensions.
%
%      It is the utility called from \code{\link{show}(\link{getClass}(.))},
%      and the user should typically use \code{getClass(.)} for looking
%      at class definitions.
%    }
%
%    \item{\code{showExtends}:}{
%      Print the elements of the list of extensions; for \code{printTo = FALSE},
%      returns a list with components \code{what} and \code{how}; this is
%      used e.g., by \code{\link{promptClass}()}.
%    }
%
%    \item{\code{possibleExtends}:}{
%      Find the information that says whether class1 extends class2,
%      directly or indirectly.
%
%      This can be either a logical value or an object of class
%      \code{\linkS4class{SClassExtension}} containing various
%      functions to test and/or coerce the relationship.
%    }
%
%    \item{\code{classLabel}: }{
%        Returns an informative character string identifying the class
%        and, if appropriate, the package from which the class came.
%    }
%
%    \item{\code{.classEnv}: }{% is called from C level  R_check_class_etc()
%        Returns the environment, typically a namespace, in which the
%        \code{Class} has been defined.  \code{Class} should typically be
%        the result of \code{\link{class}()} (and hence contain a
%        \code{"package"} attribute) or \code{\link{getClass}} (or
%        \code{\link{getClassDef}}).
%    }
%
%    \item{\code{completeExtends}:}{
%      complete the extends information in the class definition, by
%      following transitive chains.
%
%      If \code{class2} and \code{extensionDef} are included, this
%      class relation is to be added.  Otherwise just use the current
%      \code{ClassDef}.
%
%      Both the \code{contains} and \code{subclasses} slots are
%      completed with any indirect relations visible.
%    }
%
%    \item{\code{classMetaName}:}{
%      a name for the object storing this class's definition
%    }
%
%    \item{\code{methodsPackageMetaName}:}{
%      a name mangling device to hide metadata defining method and
%      class information.
%    }
%    \item{\code{metaNameUndo}}{
%      As its name implies, this function undoes the
%      name-mangling used to produce meta-data object names, and
%      returns a object of class \code{\linkS4class{ObjectsWithPackage}}.
%    }
%
%    \item{\code{requireMethods}:}{
%      Require a subclass to implement methods for the generic functions,
%      for this signature.
%
%      For each generic, \code{setMethod} will be called to define a
%      method that throws an error, with the supplied message.
%
%      The \code{requireMethods} function allows virtual classes to
%      require actual classes that extend them to implement methods for
%      certain functions, in effect creating an API for the virtual class.
%
%      Otherwise, default methods for the corresponding function would be
%      called, resulting in less helpful error messages or (worse still)
%      silently incorrect results.
%    }
%
%    \item{\code{checkSlotAssignment}, \code{checkAtAssignment}:}{
%      Check that the value provided is allowed for this slot, by
%      consulting the definition of the class.  Called from the C code
%      that assigns slots.
%
%      For privileged slots (those that can only be set by accessor
%      functions defined along with the class itself), the class designer
%      may choose to improve efficiency by validating the value to be
%      assigned in the accessor function and then calling \code{slot<-}
%      with the argument \code{check=FALSE}, to prevent the call to
%      \code{checkSlotAssignment}.
%    }
%
%    \item{\code{defaultPrototype}:}{
%      The prototype for a class which will have slots, is not a virtual
%      class, and does not extend one of the basic classes. Both its
%      \code{\link{class}} and its (\R internal) type,
%      \code{\link{typeof}()}, are \code{"S4"}.
%    }
%
%    \item{\code{.InitBasicClasses}, \code{.InitMethodsListClass}, \code{.setCoerceGeneric}:}{
%      These functions perform part of the initialization of classes and
%      methods, and are called (only!) from \code{.onLoad}.
%    }
%
%    \item{\code{isClassDef}:}{
%      Is \code{object} a representation of a class?
%    }
%
%    \item{\code{validSlotNames}:}{
%      Returns \code{names} unless one of the names is reserved, in which
%      case there is an error.  (As of writing, \code{"class"} is the
%      only reserved slot name.)
%    }
%    \item{\code{getDataPart}, \code{setDataPart}:}{
%      Utilities called to implement
%      \code{object@.Data}.  Calls to \code{setDataPart} are also used
%      to merge the data part of a superclass prototype.
%    }
%
%  }%end{ describe }
%}
%\examples{
%typeof(defaultPrototype()) #-> "S4"
%
%## .classEnv()
%meth.ns <- asNamespace("methods")
%if(get4 <- !any("package:stats4" == search()))
%   require("stats4")
%stopifnot(TRUE
% , identical(.classEnv("data.frame"), meth.ns)
% , identical(.classEnv(class(new("data.frame"))), meth.ns)
% , identical(.classEnv(     "mle"       ), meth.ns) # <- *not* 'stats4'
% , identical(.classEnv(class(new("mle"))), asNamespace("stats4"))
% , identical(.classEnv(getClass ("mle") ), asNamespace("stats4"))
% )
%if(get4) detach("package:stats4")
%}
%\keyword{internal}
%
%\encoding{UTF8}
%