% File src/library/methods/man/RMethodUtils.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{RMethodUtils}
\title{メソッドのユーティリティ}
%\title{Method Utilities}
%% FIXME:  undocumented utilities (Sep. 23/02)
%@%\alias{メソッドのユーティリティ}
\alias{asMethodDefinition}
\alias{standardGeneric-class}
\alias{standardGenericWithTrace-class}
\alias{nonstandardGeneric-class}
\alias{nonstandardGenericFunction-class}
\alias{nonstandardGroupGenericFunction-class}
\alias{OptionalFunction-class}
\alias{PossibleMethod-class}
\alias{optionalMethod-class}
\alias{derivedDefaultMethod-class}
\alias{internalDispatchMethod-class}
%%
\alias{substituteFunctionArgs}
\alias{makeGeneric}
\alias{makeStandardGeneric}
\alias{generic.skeleton}
\alias{defaultDumpName}
\alias{doPrimitiveMethod}
\alias{conformMethod}
\alias{getGeneric}
\alias{getGroup}
\alias{getGroupMembers}
\alias{getMethodsMetaData}
\alias{assignMethodsMetaData}
\alias{matchSignature}
\alias{findUnique}
\alias{MethodAddCoerce}
\alias{.saveImage}
\alias{cacheMetaData}
\alias{cacheGenericsMetaData}
\alias{setPrimitiveMethods}
\alias{missingArg}
\alias{balanceMethodsList}
\alias{sigToEnv}
\alias{rematchDefinition}
\alias{unRematchDefinition}
\alias{addNextMethod,MethodDefinition-method}
\alias{addNextMethod,MethodWithNext-method}
\alias{addNextMethod}
\alias{.valueClassTest}
\alias{insertClassMethods}
%% Not for the user to know about!
\alias{.ShortPrimitiveSkeletons} %% used from C code
\alias{.EmptyPrimitiveSkeletons}
\description{
  形式的メソッドの定義と使用をサポートするユーティリティ関数．
  これらの関数のほとんどはユーザから直接呼び出されない．
}
\usage{
getGeneric(f, mustFind=FALSE, where, package)

getGroup(fdef, recursive, where)
getGroupMembers(group, recursive = FALSE, character = TRUE)

getMethodsMetaData(f, where)
assignMethodsMetaData (f, value, fdef, where)

makeGeneric(f, fdef, fdefault =, group=list(), valueClass=character(),
            package =, signature = NULL, genericFunction = NULL,
            simpleInheritanceOnly = NULL)

makeStandardGeneric(f, fdef)

generic.skeleton(name, fdef, fdefault)

defaultDumpName(generic, signature)

doPrimitiveMethod(name, def, call= sys.call(sys.parent()),
                  ev = sys.frame(sys.parent(2)))

conformMethod(signature, mnames, fnames, f= , fdef, method)

matchSignature(signature, fun, where)

findUnique(what, message, where)

MethodAddCoerce(method, argName, thisClass, methodClass)

cacheMetaData(where, attach = TRUE, searchWhere = as.environment(where),
              doCheck = TRUE)

cacheGenericsMetaData(f, fdef, attach = TRUE, where, package, methods)

setPrimitiveMethods(f, fdef, code, generic, mlist)

missingArg(symbol, envir = parent.frame(), eval)

sigToEnv(signature, generic)

rematchDefinition(definition, generic, mnames, fnames, signature)
unRematchDefinition(definition)

asMethodDefinition(def, signature, sealed = FALSE, fdef)

addNextMethod(method, f, mlist, optional, envir)

insertClassMethods(methods, Class, value, fieldNames, returnAll)

balanceMethodsList(mlist, args, check = TRUE) # <- deprecated since R 3.2.0
}
\section{関数の要約}{

  \describe{

    \item{\code{getGeneric}:}{
      総称的関数がとしての名前が \code{f} の関数の定義を返す．

      もし定義が見つからなければ，\code{mustFind} の
      値に応じてエラーを出すか \code{NULL} を返す．
      既定ではトップレベルの環境中で探す
      (普通大局的環境であるが，パッケージもコードが関数
      \code{\link{library}} から評価された時は正しく動作するように
      補正される)．

      プリミティブな関数はそれらに対する形式的な総称的関数定義
      が無いので特別に扱われる．
      返される値はこのプリミティブ関数にメソッドを付値するために
      使われる形式的定義である．
      全てのプリミティブ関数がメソッドを持てるわけでは無い；
      もし持てなければ
      \code{getGeneric} は \code{NULL} を返すかエラーを出す．
    }

    \item{\code{getGroup}:}{
      この総称的関数が属するグループを返し，
      環境 \code{where} から探される
      (既定では普通大局的環境)．

      もし \code{recursive=TRUE} ならば，また
      これらのグループの全てのグループを返す．
    }

    \item{\code{getGroupMembers}:}{
      名前が \code{group} のグループ総称的関数の全ての
      メンバーを返す．
      もし\cr
      \code{recursive} が \code{TRUE} でそして
      あるメンバーがグループ総称的ならば，
      それらのメンバーも同様に含む．
      もし \code{character} が \code{TRUE} ならば，
      単に名前の文字列ベクトルを返す；
      さもなければリストを返し，その要素は
      パッケージ促成の名前か
      実際の総称的関数を含むかもしれない(しないかもしれない)．

      総称的関数として定義されていないメンバーは
      返り値には含まれ
      \emph{ない}ことを注意しよう．
      生のデータを見るには
      \code{getGeneric(group)@groupMembers} を使う．
    }

    \item{\code{getMethodsMetaData},
      \code{assignMethodsMetaData},
      \code{mlistMetaName}:}{
      特定のパッケージ中に定義されたメソッドを記録するメタデータを
      取得(\code{getMethodsMetaData})したり付値\cr
      (\code{assignMethodsMetaData})したりする，もしくは
      そのオブジェクトに対する分断された名前を返す
      (\code{mlistMetaName})ユーティリティ．

      付値関数は直接使うべきではない．
      取得関数はこのパッケージ中に付値されたメソッドの出力だけを
      明示的に欲しい時に役立つかもしれない．さもなければ，
      \code{\link{getMethods}} を使う．
    }

    \item{\code{matchSignature}:}{
      シグネチャオブジェクトをマッチする
      (総称的関数オブジェクト \code{fun} のシグネチャ引数の
      部分的もしくは完全な名前付き)，そして全てのクラスの
      \code{fun@signature} で指定された順序のベクトルを返す．
      \code{signature} で指定されないクラスは値が \code{"ANY"}
      であるが，余分の引き続く \code{"ANY"} は取り除かれる．
      入力シグネチャが空なら，返されるシグネチャは
      最初の形式的引数にマッチする単一の \code{"ANY"}
      である(従って返り値は常に空でない)．

      もし提供されたシグネチャ名が適正でなければエラーになる；
      つまり総称的関数のシグネチャスロット中に無いもの．

      もし引数 \code{where} が提供されると，もしクラスのどれかが
      \code{where} から可視ではない形式的定義を持たなければ
      警告が出る．
    }

    \item{\code{MethodAddCoerce}:}{
      明示的にこの引数を \code{methodClass} に強制変換するため
      可能性として一つまたはそれ以上のメソッドを修正する．
      \code{thisClass} から \code{methodClass} へ強制変換するため
      明示的な強制変換が要求された時だけメソッドを修正する．
    }

    \item{\code{findUnique}:}{
      環境 \code{where} とその親環境を用い，
      名前が \code{what} のオブジェクトを持つ環境
      (同値物)のりストを返す．もし一つ以上が見つかれば警告が出る．
      \code{message} が空文字列でない限り
      探しているものを特定するために \code{message} を使う．
    }

    \item{\code{cacheMetaData},
      \code{cacheGenericsMetaData},
      \code{setPrimitiveMethods}:}{
      クラスとメソッド定義が更新されているかどうかに
      関する内部情報を確認するためのユーティリティ．
      普通必要な毎に自動的に呼び出されるべきである
      (例えば，メソッドやクラス定義が変更されたり，
      パッケージが付加されたり切り離された時)．
      プリミティブ関数は公式のモデルではなく C コード中で
      選択適用されるために主として必要とされる．

      関数 \code{setPrimitiveMethods} は特定のプリミティブ関数に対する
      キャッシュ情報をリセットする．直接それを呼び出してはならない．
    }

    \item{\code{missingArg}:}{
      もし提供されたシンボルが提供された環境
      (既定では \code{missingArg} への呼び出しの環境)
      に対応する\emph{呼び出しから}欠損していれば
      \code{TRUE} を返す．
      もし \code{eval} が真なら，検査するシンボル名を得るために
      引数が評価される．
      \code{missingArg} は現在の R の基本パッケージの実装ではなく，
      \sQuote{Blue Book} のセンスの \code{\link{missing}} 関数
      により近いことを注意する．
      しかしながらこれは変数への付値がまだなされていない時にだけ
      動作が信頼出来ることに留意する．
      (メソッドの選択適用では計算は呼び出しの当初になされるので，
      これは上手く行く．)
    }

    \item{\code{balanceMethodsList}:}{
     \code{setMethod()} より呼びだされていたが，
     \R のバージョン3.2.0より\emph{廃止予定}である．
    %%   Called from \code{\link{setMethod}} to ensure that all nodes in
    %%   the list have the same depth (i.e., the same number of levels of
    %%   arguments).  Balance is needed to ensure that all necessary
    %%   arguments are examined when inherited methods are being found and
    %%   added to the \code{allMethods} slot.  No actual recomputation is
    %%   needed usually except when a new method uses a longer signature
    %%   than has appeared before.

    %%   Balance requires that \emph{all} methods be added to the generic
    %%   via \code{setMethod} (how else could you do it?) or by the initial
    %%   \code{setGeneric} call converting the ordinary function.
    }

    \item{\code{sigToEnv}:}{
      シグネチャ(クラスの名前付きリスト)をクラスが名前に
      付値された環境に変換する．
      環境はすると
      シグネチャに対応するメソッドを選択する
      \code{evalArgs=FALSE} の\cr
      \code{\link{MethodsListSelect}} の呼び出しに対して適当になる．
      普通直接には呼び出されない；
      \code{\link{selectMethod}} を見よ.
    }

    \item{\code{.saveImage}:}{
      \code{.onLoad} からのメソッドパッケージの動的な初期化
      で使われるフラグ．
    }

    \item{\code{rematchDefinition},
      \code{unRematchDefinition}:}{
      \code{\link{setMethod}} への呼び出し中で指定された
      メソッドが引数リストを特定すると，
      \code{rematchDefinition} は保管される実際のメソッドを
      構成する．
      \code{rematchDefinition} がどのように動作するかの知識を
      元に，\code{unRematchDefinition} は手順を逆転する；
      もしこの形式に対応しない関数かメソッド定義が
      与えられると，それは単にその引数を返す．
    }

    \item{\code{asMethodDefinition}:}{
      関数定義を与えられた \code{signature} に対応する
      クラス\cr
      \code{\linkS4class{MethodDefinition}} の
      オブジェクトにする
      (既定では空のシグネチャを持つ既定メソッドを生成する)．
      定義は \code{sealed} 引数に従って封印される．
    }

    \item{\code{addNextMethod}:}{
      メソッド定義 \code{method} のシグネチャに対する次の
      メソッドを見つけメソッド定義中のそのメソッドをキャッシュする
      総称的関数
      (クラスを \code{"MethodWithNext"} に昇進させる)．
      引数 \code{mlist} は時代遅れで使われない．
    }

    \item{\code{makeGeneric}:}{
      関数名，オプションのていぎ，そしてオプションの既定メソッドを
      与えて総称的関数オブジェクトを作る．
      他の引数はクラス
      \code{\linkS4class{genericFunction}} のスロットに対する
      オプションの要素を提供する．
    }

    \item{\code{makeStandardGeneric}:}{
      名前 \code{f} に対する
      \code{standardGeneric} を呼び出す適正な関数を作る
      ユーティリティ関数．たとえ実際の定義
      \code{fdef} が本来の関数で無い，つまりプリミティブか内部
      関数でなくても(多かれ少なかれ)動作する．
    }

    \item{\code{conformMethod}:}{
      もし形式的引数 \code{mnames} が関数
      \code{fnames} への形式的引数と一致しなくても，
      \code{conformMethod} はシグネチャと
      引数の二つのセットが適合するかどうかを決定し，
      そして可能性として拡張されたシグネチャを返す．
      関数名 \code{f} はエラーメッセージのために提供される．
      総称的関数 \code{fdef} はマッチングの目的のために
      総称的なシグネチャを提供する．

      メソッドの付値は，もしメソッドと総称的関数が
      同一の形式的引数リストを持てば適合する．
      同様に，もしメソッドが関数の形式的引数の幾つかを
      欠いていても以下の場合には適合する：
      (1) 欠けていない引数は関数の部分集合で，同じ順序で現れる，
      (2) 関数の引数でないメソッドへの引数はない；そして
      (3) 欠けている形式的引数はシグネチャ中に明示的なクラスとして
      現れない．
      
      将来の拡張では除かれた引数が
      メソッドの本体中の局所的に付値された名前か
      関数名として使われることを仮定していないかを
      テストすることが希望されている．
    }

    \item{\code{defaultDumpName}:}{
      メソッドのダンプに対して使われる既定名．
    }


    \item{\code{doPrimitiveMethod}:}{
      環境 \code{ev} 中に定義と呼出しが与えられ実行される
      組み込み関数 \code{name} へのプリミティブな呼び出しを実行する．

      \code{doPrimitiveMethod} への呼び出しは実際のメソッドが
      .Primitive である時に使われる．
      (プリミティブ関数は形式的引数も関数本体も持たず
      通常の関数のようには正しく動作しないからである．)
    }

  }
}
\seealso{\code{\link{setGeneric}}, \code{\link{setClass}},
  \code{\link{showMethods}}.
}
\examples{
getGroup("exp")
getGroup("==", recursive = TRUE)

getGroupMembers("Arith")
getGroupMembers("Math")
getGroupMembers("Ops") # -> そのサブグループ
}
\keyword{internal}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/RMethodUtils.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{RMethodUtils}
%\title{Method Utilities}
%%% FIXME:  undocumented utilities (Sep. 23/02)
%\alias{asMethodDefinition}
%\alias{standardGeneric-class}
%\alias{standardGenericWithTrace-class}
%\alias{nonstandardGeneric-class}
%\alias{nonstandardGenericFunction-class}
%\alias{nonstandardGroupGenericFunction-class}
%\alias{OptionalFunction-class}
%\alias{PossibleMethod-class}
%\alias{optionalMethod-class}
%\alias{derivedDefaultMethod-class}
%\alias{internalDispatchMethod-class}
%%%
%\alias{substituteFunctionArgs}
%\alias{makeGeneric}
%\alias{makeStandardGeneric}
%\alias{generic.skeleton}
%\alias{defaultDumpName}
%\alias{doPrimitiveMethod}
%\alias{conformMethod}
%\alias{getGeneric}
%\alias{getGroup}
%\alias{getGroupMembers}
%\alias{getMethodsMetaData}
%\alias{assignMethodsMetaData}
%\alias{matchSignature}
%\alias{findUnique}
%\alias{MethodAddCoerce}
%\alias{.saveImage}
%\alias{cacheMetaData}
%\alias{cacheGenericsMetaData}
%\alias{setPrimitiveMethods}
%\alias{missingArg}
%\alias{balanceMethodsList}
%\alias{sigToEnv}
%\alias{rematchDefinition}
%\alias{unRematchDefinition}
%\alias{addNextMethod,MethodDefinition-method}
%\alias{addNextMethod,MethodWithNext-method}
%\alias{addNextMethod}
%\alias{.valueClassTest}
%\alias{insertClassMethods}
%%% Not for the user to know about!
%\alias{.ShortPrimitiveSkeletons} %% used from C code
%\alias{.EmptyPrimitiveSkeletons}
%\description{
%  Utility functions to support the definition and use of formal
%  methods.  Most of these functions will not normally be called directly
%  by the user.
%}
%\usage{
%getGeneric(f, mustFind=FALSE, where, package)
%
%getGroup(fdef, recursive, where)
%getGroupMembers(group, recursive = FALSE, character = TRUE)
%
%getMethodsMetaData(f, where)
%assignMethodsMetaData (f, value, fdef, where)
%
%makeGeneric(f, fdef, fdefault =, group=list(), valueClass=character(),
%            package =, signature = NULL, genericFunction = NULL,
%            simpleInheritanceOnly = NULL)
%
%makeStandardGeneric(f, fdef)
%
%generic.skeleton(name, fdef, fdefault)
%
%defaultDumpName(generic, signature)
%
%doPrimitiveMethod(name, def, call= sys.call(sys.parent()),
%                  ev = sys.frame(sys.parent(2)))
%
%conformMethod(signature, mnames, fnames, f= , fdef, method)
%
%matchSignature(signature, fun, where)
%
%findUnique(what, message, where)
%
%MethodAddCoerce(method, argName, thisClass, methodClass)
%
%cacheMetaData(where, attach = TRUE, searchWhere = as.environment(where),
%              doCheck = TRUE)
%
%cacheGenericsMetaData(f, fdef, attach = TRUE, where, package, methods)
%
%setPrimitiveMethods(f, fdef, code, generic, mlist)
%
%missingArg(symbol, envir = parent.frame(), eval)
%
%sigToEnv(signature, generic)
%
%rematchDefinition(definition, generic, mnames, fnames, signature)
%unRematchDefinition(definition)
%
%asMethodDefinition(def, signature, sealed = FALSE, fdef)
%
%addNextMethod(method, f, mlist, optional, envir)
%
%insertClassMethods(methods, Class, value, fieldNames, returnAll)
%
%balanceMethodsList(mlist, args, check = TRUE) # <- deprecated since R 3.2.0
%}
%\section{Summary of Functions}{
%
%  \describe{
%
%    \item{\code{getGeneric}:}{
%      returns the definition of the function named \code{f} as a generic.
%
%      If no definition is found, throws an
%      error or returns \code{NULL} according to the value of
%      \code{mustFind}.  By default, searches in the top-level
%      environment (normally the global environment, but adjusted to
%      work correctly when package code is evaluated from the function
%      \code{\link{library}}).
%
%      Primitive functions are dealt with specially, since there is never
%      a formal generic definition for them.  The value returned is the
%      formal definition used for assigning methods to this primitive.
%      Not all primitives can have methods; if this one can't, then
%      \code{getGeneric} returns \code{NULL} or throws an error.
%    }
%
%    \item{\code{getGroup}:}{
%      returns the groups to which this generic belongs, searching from
%      environment \code{where} (the global environment normally by default).
%
%      If \code{recursive=TRUE}, also all the group(s) of these groups.
%    }
%
%    \item{\code{getGroupMembers}:}{
%      Return all the members of the group generic function named
%      \code{group}.
%      If \code{recursive} is \code{TRUE}, and some members are group
%      generics, includes their members as well.
%      If \code{character} is \code{TRUE}, returns just a character
%      vector of the names; otherwise returns a list, whose elements may
%      (or may not) include either names with a package attribute or
%      actual generic functions.
%
%      Note that members that are not defined as generic functions will
%      \emph{not} be included in the returned value.  To see the raw data,
%      use \code{getGeneric(group)@groupMembers}.
%    }
%
%    \item{\code{getMethodsMetaData},
%      \code{assignMethodsMetaData},
%      \code{mlistMetaName}:}{Utilities to get
%      (\code{getMethodsMetaData}) and assign
%      (\code{assignMethodsMetaData}) the metadata object recording the
%      methods defined in a particular package, or to return the mangled
%      name for that object  (\code{mlistMetaName}).
%
%      The assign function should not be used directly.  The get
%      function may be useful if you want explicitly only the outcome of
%      the methods assigned in this package.  Otherwise, use
%      \code{\link{getMethods}}.
%    }
%
%    \item{\code{matchSignature}:}{
%      Matches the signature object (a partially or completely named
%      subset of the signature arguments of the generic function object
%      \code{fun}), and return a vector of all the classes in the order
%      specified by \code{fun@signature}.  The classes not specified by
%      \code{signature} will be \code{"ANY"} in the value, but extra
%      trailing \code{"ANY"}'s are removed.  When the input signature is
%      empty, the returned signature is a single \code{"ANY"} matching
%      the first formal argument (so the returned value is always
%      non-empty).
%
%      Generates an error if any of the supplied signature names are
%      not legal; that is, not in the signature slot of the generic
%      function.
%
%      If argument \code{where} is supplied, a warning will be issued
%      if any of the classes does not have a formal definition visible
%      from \code{where}.
%    }
%
%    \item{\code{MethodAddCoerce}:}{
%      Possibly modify one or more methods to explicitly coerce this
%      argument to \code{methodClass}, the class for which the method is
%      explicitly defined.  Only modifies the method if an explicit
%      coerce is required to coerce from \code{thisClass} to
%      \code{methodClass}.
%    }
%
%    \item{\code{findUnique}:}{
%      Return the list of environments (or equivalent) having an object named
%      \code{what}, using environment \code{where} and its parent
%      environments.  If more than one is found, a warning message is
%      generated, using \code{message} to identify what was being
%      searched for, unless \code{message} is the empty string.
%    }
%
%    \item{\code{cacheMetaData},
%      \code{cacheGenericsMetaData},
%      \code{setPrimitiveMethods}:}{
%      Utilities for ensuring that the internal information about
%      class and method definitions is up to date.  Should normally be
%      called automatically whenever needed (for example, when a method
%      or class definition changes, or when a package is attached or
%      detached).  Required primarily because primitive functions are
%      dispatched in C code, rather than by the official model.
%
%      The \code{setPrimitiveMethods} function resets the caching
%      information for a particular primitive function.  Don't call it
%      directly.
%    }
%
%    \item{\code{missingArg}:}{
%      Returns \code{TRUE} if the symbol supplied is missing \emph{from
%        the call} corresponding to the environment supplied (by default,
%      environment of the call to \code{missingArg}).  If \code{eval} is
%      true, the argument is evaluated to get the name of the symbol to
%      test.  Note that \code{missingArg} is closer to the
%      \sQuote{Blue Book} sense of the \code{\link{missing}} function,
%      not that of the current R base package implementation.  But beware
%      that it works reliably only if no assignment has yet been made to
%      the argument.  (For method dispatch this is fine, because
%      computations are done at the beginning of the call.)
%    }
%
%    \item{\code{balanceMethodsList}:}{
%      Used to be called from \code{setMethod()} and is \emph{deprecated}
%      since \R version 3.2.0.
%    %%   Called from \code{\link{setMethod}} to ensure that all nodes in
%    %%   the list have the same depth (i.e., the same number of levels of
%    %%   arguments).  Balance is needed to ensure that all necessary
%    %%   arguments are examined when inherited methods are being found and
%    %%   added to the \code{allMethods} slot.  No actual recomputation is
%    %%   needed usually except when a new method uses a longer signature
%    %%   than has appeared before.
%
%    %%   Balance requires that \emph{all} methods be added to the generic
%    %%   via \code{setMethod} (how else could you do it?) or by the initial
%    %%   \code{setGeneric} call converting the ordinary function.
%    }
%
%    \item{\code{sigToEnv}:}{
%      Turn the signature (a named vector of classes) into an environment
%      with the classes assigned to the names.  The environment is then
%      suitable for calling \code{\link{MethodsListSelect}}, with
%      \code{evalArgs=FALSE}, to select a method corresponding to the
%      signature.  Usually not called directly: see
%      \code{\link{selectMethod}}.
%    }
%
%    \item{\code{.saveImage}:}{
%      Flag, used in dynamically initializing the methods package from
%      \code{.onLoad}.
%    }
%
%    \item{\code{rematchDefinition},
%      \code{unRematchDefinition}:}{
%      If the specified method in a call to \code{\link{setMethod}}
%      specializes the argument list (by replacing \dots), then
%      \code{rematchDefinition} constructs the actual method stored.
%      Using knowledge of how \code{rematchDefinition} works,
%      \code{unRematchDefinition} reverses the procedure; if given a
%      function or method definition that does not correspond to this
%      form, it just returns its argument.
%    }
%
%    \item{\code{asMethodDefinition}:}{
%      Turn a function definition into an object of class
%      \code{\linkS4class{MethodDefinition}}, corresponding to the
%      given \code{signature} (by default generates a default method
%      with empty signature).  The definition is sealed according to
%      the \code{sealed} argument.
%    }
%
%    \item{\code{addNextMethod}:}{
%      A generic function that finds the next method for
%      the signature of the method definition \code{method}  and caches
%      that method in the method definition (promoting the class to
%      \code{"MethodWithNext"}.  Note that argument \code{mlist} is
%      obsolete and not used.
%    }
%
%    \item{\code{makeGeneric}:}{
%      Makes a generic function object corresponding to the given
%      function name, optional definition and optional default method.
%      Other arguments supply optional elements for the slots of class
%      \code{\linkS4class{genericFunction}}.
%    }
%
%    \item{\code{makeStandardGeneric}:}{
%      a utility function that makes a valid function calling
%      \code{standardGeneric} for name \code{f}.  Works (more or less)
%      even if the actual definition, \code{fdef}, is not a proper
%      function, that is, it's a primitive or internal.
%    }
%
%    \item{\code{conformMethod}:}{
%      If the formal arguments, \code{mnames}, are not identical to the
%      formal arguments to the function, \code{fnames},
%      \code{conformMethod} determines whether the signature and the two
%      sets of arguments conform, and returns the signature, possibly
%      extended.  The function name, \code{f} is supplied for error
%      messages. The generic function, \code{fdef}, supplies the
%      generic signature  for matching purposes.
%
%      The method assignment conforms if method and generic function have
%      identical formal argument lists.  It can also conform if the
%      method omits some of the formal arguments of the function but: (1)
%      the non-omitted arguments are a subset of the function arguments,
%      appearing in the same order; (2) there are no arguments to the
%      method that are not arguments to the function; and (3) the omitted
%      formal arguments do not appear as explicit classes in the
%      signature.  A future extension hopes to test also that the
%      omitted arguments are not assumed by being used as locally assigned
%      names or function names in the body of the method.
%    }
%
%    \item{\code{defaultDumpName}:}{
%      the default name to be used for dumping a method.
%    }
%
%
%    \item{\code{doPrimitiveMethod}:}{
%      do a primitive call to builtin function \code{name} the definition
%      and call provided, and carried out in the environment \code{ev}.
%
%      A call to \code{doPrimitiveMethod} is used when the actual method
%      is a .Primitive.  (Because primitives don't behave correctly as
%      ordinary functions, not having either formal arguments nor a
%      function body).
%    }
%
%  }
%}
%\seealso{\code{\link{setGeneric}}, \code{\link{setClass}},
%  \code{\link{showMethods}}.
%}
%\examples{
%getGroup("exp")
%getGroup("==", recursive = TRUE)
%
%getGroupMembers("Arith")
%getGroupMembers("Math")
%getGroupMembers("Ops") # -> its sub groups
%}
%\keyword{internal}
%
%\encoding{UTF8}
%