% File src/library/methods/man/SClassExtension-class.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{SClassExtension-class}
\docType{class}
%@%\alias{継承(拡大)関係を表すクラス}
\alias{SClassExtension-class}
\title{継承(拡大)関係を表すクラス}
%\title{Class to Represent Inheritance (Extension) Relations }

\description{
  このクラスからのオブジェクトは単一の
  \sQuote{is} 関係を表す；これらのオブジェクトのりストは
  与えられたクラスの
  全ての拡張(スーパークラス)とサブクラスを表す．
  このオブジェクトは関係がどのように定義され，そして
  強制変換，検査また対応する置き換えられるかに関する情報を含む．}
  
\section{クラスからのオブジェクト}{
  このクラスからのオブジェクトは
  直接の呼び出しから，そして \code{\link{setClass}} への呼び出し
  中の \code{contains=} 情報から，そして
  \code{\link{setClassUnion}} により作られた合併クラスから
  \code{\link{setIs}} で生成される．
  最後のケースでは情報は合併クラスの
  \emph{サブクラス}定義に保管される
  (合併が封印クラスを含むことを許して)．
}

\section{スロット}{
  \describe{
    \item{\code{subClass}, \code{superClass}:}{
      拡張されるクラス：\code{\link{setIs}} への
      \code{from} と and \code{to} 引数に対応する．}
    \item{\code{package}:}{そのクラスが所属するパッケージ．}
    \item{\code{coerce}:}{
      関係により含意される as() 計算を実行する関数．
      これらの関数は直接使われるべきでは
      \emph{無い}ことを注意する．
      それらは \code{strict=TRUE} を伴う
      \code{\link{as}} 関数だけを扱い，
      完全なメソッドがこれから機械的に作られる．}
    \item{\code{test}:}{
      関係が成立するかどうかをテストする関数．
      \code{\link{setIs}} へ明示的に指定された \code{test} に
      対する場合を除き，この関数は自明なものである．}
    \item{\code{replace}:}{
      \code{as(x, Class) <- value} を実装するのに使われるメソッド．}
    \item{\code{simple}:}{
      \code{"logical"} フラグで，もしこれが
      一つのクラスが別の定義中に含まれるか，または
      クラスが仮想クラスを拡張すると明示的に述べられている
      という単純な関係であれば \code{TRUE}．
      単純な拡張に対しては三つのメソッドが自動的に
      生成される．}
    \item{\code{by}:}{
      もしこの関係が推移的に構成されていたならば，
      サブクラスからの最初の中間のクラス．}
    \item{\code{dataPart}:}{
      \code{"logical"} フラグで，もし拡張クラスが実際に
      サブクラスのデータ部分ならば \code{TRUE}．
      この場合拡張クラスは基本クラスである
      (つまり，あるタイプ)．}
    \item{\code{distance}:}{
      二つのクラス感の距離で，
      直接含まれるクラスに対しては 1 で，さもなければ間の世代
      数がプラスされる．}  }
}

\section{メソッド}{
  シグネチャ中にクラス \code{"SClassExtension"} を持つ
  メソッドは定義されていない．
}
\seealso{
  \code{\link{is}},
  \code{\link{as}}，そして
  \code{\linkS4class{classRepresentation}} クラス．
}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/SClassExtension-class.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{SClassExtension-class}
%\docType{class}
%\alias{SClassExtension-class}
%\title{Class to Represent Inheritance (Extension) Relations }
%\description{  An object from this class represents a single \sQuote{is}
%  relationship; lists of these objects are used to represent all the
%  extensions (superclasses) and subclasses for a given class.  The
%  object contains information about how the relation is defined and
%  methods to coerce, test, and replace correspondingly. }
%\section{Objects from the Class}{
%  Objects from this class are generated by \code{\link{setIs}},
%  from direct calls and from the \code{contains=} information in a call to \code{\link{setClass}}, and from class unions created by \code{\link{setClassUnion}}.
%  In the last case, the information is stored in defining the \emph{subclasses} of the union class (allowing unions to contain sealed classes).
%}
%\section{Slots}{
%  \describe{
%    \item{\code{subClass}, \code{superClass}:}{The classes being
%      extended: corresponding to the \code{from}, and \code{to}
%      arguments to \code{\link{setIs}}. }
%    \item{\code{package}:}{The package to which that class belongs. }
%    \item{\code{coerce}:}{A function to carry out the as() computation
%    implied by the relation.  Note that these functions should
%    \emph{not} be used directly.  They only deal with the
%    \code{strict=TRUE} calls to the \code{\link{as}} function, with
%    the full method constructed from this mechanically. }
%    \item{\code{test}:}{The function that would test whether the
%    relation holds.  Except for explicitly specified \code{test}
%    arguments to \code{\link{setIs}}, this function is trivial. }
%    \item{\code{replace}:}{The method used to implement \code{as(x,
%    Class) <- value}.}
%    \item{\code{simple}:}{A \code{"logical"} flag, \code{TRUE} if this
%    is a simple relation, either because one class is contained in the
%    definition of another, or because a class has been explicitly
%    stated to extend a virtual class.  For simple extensions, the
%    three methods are generated automatically.}
%    \item{\code{by}:}{If this relation has been constructed
%    transitively, the first intermediate class from the subclass. }
%    \item{\code{dataPart}:}{A \code{"logical"} flag, \code{TRUE} if
%  the extended class is in fact the data part of the subclass.  In
%  this case the extended class is a basic class (i.e., a type). }
%    \item{\code{distance}:}{The distance between the two classes,
%    1 for directly contained classes, plus the number of generations between otherwise. }  }
%}
%
%\section{Methods}{
%  No methods defined with class \code{"SClassExtension"} in the
%  signature.
%}
%\seealso{
%  \code{\link{is}},
%  \code{\link{as}}, and the
%  \code{\linkS4class{classRepresentation}} class.
%}
%\keyword{classes}
%
%\encoding{UTF8}
%