% File src/library/methods/man/StructureClasses.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{StructureClasses}
\title{基本構造に対応するクラス}
%\title{Classes Corresponding to Basic Structures}
\docType{class}
%
%@%\alias{基本構造に対応するクラス}
\alias{structure-class}
\alias{matrix-class}
\alias{array-class}
\alias{ts-class}
% Group Methods of these
\alias{Math,structure-method}
\alias{Ops,structure,vector-method}
\alias{Ops,structure,structure-method}
\alias{Ops,structure,array-method}
\alias{Ops,vector,structure-method}
\alias{Ops,array,structure-method}
\alias{Ops,array,array-method}
\alias{initialize,array-method}
\alias{initialize,matrix-method}
\alias{initialize,ts-method}
\alias{initialize,mts-method}
\alias{show,ts-method}
%
\description{
  仮想クラス \code{structure} とそれを拡張するクラスは
  配列と時系列の様な S3 言語構造の形式的クラス類似物である．
}
\usage{
## 次のクラス名はメソッドのシグネチャ中に
## as() や is() 表現中のクラスと，VIRTUAL とコメントされた
## クラスを除き，new() への呼び出し中に登場できる

"matrix"
"array"
"ts"

"structure" ## VIRTUAL
}
\section{クラスからのオブジェクト}{
  オブジェクトは \code{new(Class, ...)} の形式の呼び出しで
  作ることが出来る，ここで
  \code{Class} は特定のクラスの引用符付きの名前で
  (例えば \code{"matrix"})，他の引数はもしあれば
  対応する関数への引数と解釈される，例えば関数
  \code{matrix()} に対するもの．
  多重のクラスに対して動作するようにデザインされた
  恐らくクラス名と渡される引数付きのソフトウェアを
  書くのでなければ，これらの関数を直接呼び出すことに対する
  特別な利点はない．

  クラス \code{"matrix"} と \code{"array"} から作られた
  オブジェクトは控え目に言っても普通でない状態が続いている．
それらはこれらのクラスからのオブジェクトに見えるが，
  S3 や S4 クラスオブジェクトとしての内部構造を持たない．
  特にそれらは
  \code{"class"} 属性を持たずクラスを持つオブジェクトとは
  認識されない
  (つまり \code{\link{is.object}} と
  \code{\link{isS4}} は共にそうしたオブジェクトに対して
  \code{FALSE} を返す)．
  しかしながらこれらの擬似クラスに対する
  メソッド(S4 と S3 双方)が定義でき，
  新しいクラス(S4 と S3 双方)はそれらを継承できる．

  オブジェクトがあたかも対応するクラス由来であるかのように
  依然として振る舞う
  (とにかく多くの場合)ことは \R の基本コード中に組み込まれた
  そうしたオブジェクトを認識する特別なコードに由来する．
  多くの目的に対してこれらのクラスを普通のように
  扱うことは幸運にも動作する．
  特殊な扱いの一つの結果がこれらの二つのクラスを
  S4 クラスのデータ部分に使うことが\emph{出来る}ことである；
  例えば \code{"matrix"} のサブクラスである S4 クラスを作る
  \code{\link{setGeneric}} への呼び出し中で
  \code{contains = "matrix"} を用い避けることが出来ることである．
  全てが完全に動作する保証はないが，幾つかのクラスが
  この形式で成功裡に書かれている．

  \code{"matrix"} や \code{"array"} を含むクラスは
  そのクラスを持つ
  \code{.Data} スロットを持つことを注意する．これは
  オブジェクトのタイプを指示する擬似クラスとして以外の
  \code{.Data} の唯一の用法である．
  この場合オブジェクトのタイプは含まれる行列か配列の
  タイプになる．一般的な議論は \code{\link{Classes}} を見よ．

  クラス \code{"ts"} は
  \code{\link{setOldClass}} 機構を用いて S4 として
  登録されている本質的に S3 クラスである．
  バージョン 2.7.0 の \R はこれを純粋の
  S4 クラスとして扱っていた．
  これは原則的に良いアイデアであったが，実際には
  サブクラスの定義を許さず他の本質的な問題を抱えていた．
  (例えば，
  \code{"tsp"} パラメータをスロットとして設定することは，
  組み込みの実装はスロットがデータの長さに関して一時的に
  非一貫的であることを認めないためにしばしば失敗する．
  また S4 クラスはクラス
  \code{"mts"} に対する S3 継承の正しい指定を妨げた．)

  時系列オブジェクトは，行列や配列とは対照的に，
  S4 スタイルの定義を使い正当な
  S3 クラス \code{"ts"} を持つ
  (これがどのようになされるかは
  \code{\link{setOldClass}} のドキュメントの例を見よ)．
  パッケージ \pkg{stats} 中の
  \code{"mts"} の S3 継承は同様に登録されている．
  これらのクラスは，
  \code{"matrix"} と \code{"array"} と同様に，
  新しい S4 クラスに対するスーパークラスとして
  殆どの例で適正であるべきである．

  これらのクラスの全ては
  可能な限り基本生成関数
  \code{\link{matrix}}, \code{\link{array}} そして \code{\link{ts}}
  と同じ引数を受け入れる
  \code{\link{initialize}} に対する特別な S4 メソッドを
  持つ．制限は一つより多くの非仮想的なスーパークラスを持つ
  クラスは
  \code{\link{new}} への呼び出し中でそのスーパークラスからの
  オブジェクトを受け入れなければならないということである；
  従ってそうしたクラス
  (ある種の言語では \dQuote{mixin} と呼ばれる)は特別な引数を
  持たない \code{\link{initialize}} に対する既定メソッドを使う．

}
\section{拡張}{
  個別のクラスは全て \code{"structure"} により
  直接にクラス \code{"structure"} そして
  クラス \code{"vector"} を拡張する．
}
\section{メソッド}{
  \describe{
    \item{coerce}{
      任意のオブジェクトをこれらのクラスに強制変換するメソッドを
      対応する基本関数を呼び出すことにより定義できる．
      例えば \code{as(x, "matrix")} は \code{as.matrix(x)} を呼び出す．
      もし \code{as()} の呼び出しで \code{strict = TRUE} ならば，
      メソッドは全ての他のスロットと \code{dim} と \code{dimnames} 以外の
      属性を取り除こうとする．
    }
    \item{Ops}{
      グループメソッド(例えば \code{\link{S4groupGeneric}} を見よ)
      は構造とベクトル
      (特殊例として配列と行列)に対して定義され，
      参考文献中のようにベクトル構造を実装する．
      本質的に，ベクトルと結びついた構造は
      結果のオブジェクトが同じ長さを持つ限り構造を保つ．
      他の構造と結び付けられた構造は，
      構造を定義するスロットに何が起きるべきか決定する
      自動的な方法は無いため，
      構造を取り除く．

      これらのメソッドは構造クラスのどれかか
      クラス \code{"vector"} を継承するクラスを含むパッケージが
      ロードされると活性化される．
    }
  }
}
\seealso{別のモデルを強要するクラス \linkS4class{nonStructure}，
  そこではもし任意の数学変換または操作が基本クラスのどれかを
  拡張するクラスに適用されると全てのスロットが取り除かれる．
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)

  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole (オリジナルのベクトル構造に対して).
}
\examples{
showClass("structure")

## 少し調べてみる：
showClass("ts")
(ts0 <- new("ts"))
str(ts0)

showMethods("Ops") # これらのクラスからの6種類のメソッド，もしかすると更に多く
}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/StructureClasses.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{StructureClasses}
%\title{Classes Corresponding to Basic Structures}
%\docType{class}
%%
%\alias{structure-class}
%\alias{matrix-class}
%\alias{array-class}
%\alias{ts-class}
%% Group Methods of these
%\alias{Math,structure-method}
%\alias{Ops,structure,vector-method}
%\alias{Ops,structure,structure-method}
%\alias{Ops,structure,array-method}
%\alias{Ops,vector,structure-method}
%\alias{Ops,array,structure-method}
%\alias{Ops,array,array-method}
%\alias{initialize,array-method}
%\alias{initialize,matrix-method}
%\alias{initialize,ts-method}
%\alias{initialize,mts-method}
%\alias{show,ts-method}
%%
%\description{
%  The virtual class \code{structure} and classes that
%  extend it are formal classes analogous to S language structures such
%  as arrays and time-series.
%}
%\usage{
%## The following class names can appear in method signatures,
%## as the class in as() and is() expressions, and, except for
%## the classes commented as VIRTUAL, in calls to new()
%
%"matrix"
%"array"
%"ts"
%
%"structure" ## VIRTUAL
%}
%\section{Objects from the Classes}{
%  Objects can be created by calls of the form \code{new(Class, ...)},
%  where \code{Class} is the quoted name of the specific class (e.g.,
%  \code{"matrix"}), and the other arguments, if any, are interpreted as
%  arguments to the corresponding function, e.g., to function
%  \code{matrix()}.  There is no particular advantage over calling those
%  functions directly, unless you are writing software designed to work
%  for multiple classes, perhaps with the class name and the arguments
%  passed in.
%
%  Objects created from the classes \code{"matrix"} and \code{"array"}
%  are unusual, to put it mildly, and have been for some time.  Although
%  they may appear to be objects from these classes, they do not have the
%  internal structure of either an S3 or S4 class object.  In particular,
%  they have no \code{"class"} attribute and are not recognized as
%  objects with classes (that is, both \code{\link{is.object}} and
%  \code{\link{isS4}} will return \code{FALSE} for such objects).
%  However, methods (both S4 and S3) can be defined for these
%  pseudo-classes and new classes (both S4 and S3) can inherit from them.
%
%  That the objects still behave as if they came from the corresponding
%  class (most of the time, anyway) results from special code
%  recognizing such objects being built into the base code of \R.
%  For most purposes, treating the classes in the usual way will work,
%  fortunately.  One consequence of the special treatment is that these
%  two classes\emph{may} be used as the data part of an S4 class; for
%  example, you can get away with \code{contains = "matrix"} in a call
%  to \code{\link{setGeneric}} to create an S4 class that is a subclass
%  of \code{"matrix"}.  There is no guarantee that everything will work
%  perfectly, but a number of classes have been written in this form
%  successfully.
%
%  Note that a class containing \code{"matrix"} or \code{"array"} will
%  have a  \code{.Data} slot with that class.  This is the only use of
%  \code{.Data} other than as a pseudo-class indicating the type of the
%  object.  In this case the type of the object will be the type of the
%  contained matrix or array. See \code{\link{Classes}} for a general
%  discussion.
%
%  The class \code{"ts"}  is basically an S3 class
%  that has been registered with S4, using the
%  \code{\link{setOldClass}} mechanism.  Versions of \R through 2.7.0
%  treated this class as a pure S4 class, which was in principal a good
%  idea, but in practice did not allow subclasses to be defined and had
%  other intrinsic problems.  (For example, setting the
%  \code{"tsp"} parameters as a slot often fails because the built-in
%  implementation does not allow the slot to be temporarily
%  inconsistent with the length of the data. Also, the S4 class
%  prevented the correct specification of the S3 inheritance for class
%  \code{"mts"}.)
%
%  Time-series objects, in contrast to matrices and arrays, have a valid
%  S3 class, \code{"ts"}, registered  using an S4-style definition (see the
%  documentation for \code{\link{setOldClass}} in the examples section
%  for an abbreviated listing of how this is done.  The S3
%  inheritance of \code{"mts"} in package \pkg{stats} is also
%  registered.
%  These classes, as well as \code{"matrix"} and \code{"array"} should
%  be valid in most examples as superclasses for new S4 class
%  definitions.
%
%  All of these classes have special S4 methods for
%  \code{\link{initialize}} that accept the same arguments as the basic
%  generator functions, \code{\link{matrix}},
%  \code{\link{array}}, and \code{\link{ts}}, in so far as possible.
%  The limitation is that a class that has more than one non-virtual
%  superclass must accept objects from that superclass in the call to
%  \code{\link{new}}; therefore, a such a class (what is called a
%  \dQuote{mixin} in some languages) uses the default method for
%  \code{\link{initialize}}, with no special arguments.
%
%}
%\section{Extends}{
%  The specific classes all extend class \code{"structure"}, directly, and
%  class \code{"vector"}, by class \code{"structure"}.
%}
%\section{Methods}{
%  \describe{
%    \item{coerce}{Methods are defined to coerce arbitrary objects to
%      these classes, by calling the corresponding basic function, for
%      example, \code{as(x, "matrix")} calls \code{as.matrix(x)}.
%      If \code{strict = TRUE} in the call to \code{as()}, the method
%      goes on to delete all other slots and attributes other than the
%      \code{dim} and \code{dimnames}.
%    }
%    \item{Ops}{Group methods (see, e.g., \code{\link{S4groupGeneric}})
%      are defined for combinations of structures and vectors (including
%      special cases for array and matrix), implementing the concept of
%      vector structures as in the reference.  Essentially, structures
%      combined with vectors retain the structure as long as the
%      resulting object has the same length.  Structures combined with
%      other structures remove the structure, since there is no
%      automatic way to determine what should happen to the slots
%      defining the structure.
%
%      Note that these methods will be activated when a package is loaded
%      containing a class that inherits from any of the structure
%      classes or class \code{"vector"}.
%    }
%  }
%}
%\seealso{Class \linkS4class{nonStructure}, which enforces the
%  alternative model, in which all slots are dropped if any math
%  transformation or operation is applied to an object from a class
%  extending one of the basic classes.
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole (for the original vector structures).
%}
%\examples{
%showClass("structure")
%
%## explore a bit :
%showClass("ts")
%(ts0 <- new("ts"))
%str(ts0)
%
%showMethods("Ops") # six methods from these classes, but maybe many more
%}
%\keyword{classes}
%
%\encoding{UTF8}
%