% File src/library/methods/man/as.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{as}
%@%\alias{クラスに属することを強制}
\alias{as}
\alias{as<-}
\alias{coerce}
\alias{coerce<-}
\alias{setAs}
\alias{coerce-methods}
\alias{coerce,ANY,array-method}
\alias{coerce,ANY,call-method}
\alias{coerce,ANY,character-method}
\alias{coerce,ANY,complex-method}
\alias{coerce,ANY,environment-method}
\alias{coerce,ANY,expression-method}
\alias{coerce,ANY,function-method}
\alias{coerce,ANY,integer-method}
\alias{coerce,ANY,list-method}
\alias{coerce,ANY,logical-method}
\alias{coerce,ANY,matrix-method}
\alias{coerce,ANY,name-method}
\alias{coerce,ANY,numeric-method}
\alias{coerce,ANY,single-method}
\alias{coerce,ANY,ts-method}
\alias{coerce,ANY,vector-method}
\alias{coerce,ANY,NULL-method}
\title{オブジェクトがあるクラスに属することを強制する}
%\title{Force an Object to Belong to a Class}
\description{
  これらの関数はオブジェクトを与えられたクラスに
  強制変換することを許す関係を管理する．
}
\usage{
as(object, Class, strict=TRUE, ext)

as(object, Class) <- value

setAs(from, to, def, replace, where = topenv(parent.frame()))

}
\section{関数の要約}{
  \describe{
    \item{\code{as}:}{
      このオブジェクトを与えられた
      \code{Class} に強制変換したバージョンを返す．
      付値の左辺側からの置き換え中で使われた時は
      オブジェクトの \code{Class} に対応する部分が
      \code{value} で置き換えられる．

      いずれかの形式の
      \code{as()} の操作は強制変換メソッドの定義に依存する．
      メソッドは二つのクラスが継承で関係付けられているときは自動的に
      定義される；つまり
      クラスの一方が他方のサブクラスである時．
      詳細は下の継承の節を見よ．

      強制変換メソッドはまた基本クラスに対して予め定義されている
      (全てのベクトルタイプ，関数そして幾つかの他のもの)．
      これらの一覧には \code{showMethods(coerce)} を見よ．

      これらのメソッドの二つのソースを超えて，
      更なるメソッドが
      \code{setAs} 関数の呼び出しにより定義されている．

    }

    \item{\code{setAs}:}{
      クラス \code{from} のオブジェクトをクラス
      \code{to} へ強制変換するためのメソッドを定義する；
      引数 \code{def} は直接的な強制変換を提供し，もしあれば
      \code{replace} 引数は置き換え用を定義する．
      詳細は下の\dQuote{関数 'as' と 'setAs' がどのように動作するか}節
      を見よ．
    }

    \item{\code{coerce}, \code{coerce<-}:}{
      \code{from} を
      \code{to} と同じクラスに強制変換する．

      これらの関数は明示的に呼び出されるべきではない．
      関数 \code{\link{setAs}} はそれらに対するメソッドを
      使用する \code{as} 関数のために作る．
    }

  }
}
\arguments{
  \item{object}{任意の \R オブジェクト．}
  \item{Class}{
    \code{object} が強制変換されるべきクラス名．}
  \item{strict}{論理フラグ．もし \code{TRUE} ならば返されるオブジェクトは
    厳密に目標クラスからのものでなければならない
    (クラスが仮想的でない限り，その場合は
    オブジェクトは最も近い実際のクラスからのものになる．
    特にもしそのクラスが仮想的クラスを直接拡張していれば
    オリジナルのオブジェクトになる)．

    もし \code{strict = FALSE} ならば，目標クラスの任意の単純な拡張が
    それ以上の変更無しで返される．単純な拡張とは簡単に言えば
    既存クラスに単にスロットを加えたものである．}
  \item{value}{
    \code{object} を修正するのに使われる値
    (下の議論を見よ)．
    クラス \code{Class} のオブジェクトを提供すべきである；
    しかしそれを過信するのは賢明ではない．}

  \item{from, to}{
    強制変換メソッド \code{def} と \code{replace} がその間で
    強制変換を実行するクラス．
    }
  \item{def}{引数が一つの関数．これは
    クラス \code{from} からのオブジェクトを受け取り
    クラス \code{to} のオブジェクトを返すことが好ましい．
    変換は引数名が \code{from} であるようなものである；
    もし別の引数名が使われると，
    \code{setAs} は
    \code{from} を代入しようと試みる．}
  \item{replace}{
    もし提供されると，
    \code{as} が付値の左辺で使われる際の置き換えメソッドとして使われる
    関数．二つの引数 \code{from, value} の関数でなければならないが，
    \code{setAs} はもし引数が異なれば代入しようと試みる．}
  \item{where}{
    結果のメソッドをその中に保存する位置もしくは環境．
    殆どの応用に対してこの引数を省略し，ソースコード中に
    トップレベルで評価される
    \code{setAs} への呼び出しを含めることが勧められる；
    つまり，R セッション中では
    \code{\link{source}} への呼び出しに等しい何かか，または
    パッケージに対する R ソースコードの一部分として．}
  \item{ext}{
    どのように \code{Class} がオブジェクトのクラスで
    拡張されるかを定義するオプションのオブジェクト
    (\code{\link{possibleExtends}} が返すような)．
    この引数は内部的に使われる
    (非公開クラスに対する本質的情報を提供するために)が，それを直接使いたくなる
    ことは恐らく無い．
  }
}

\section{継承と強制変換}{

  オブジェクトは一つのクラスから別のクラスへのオブジェクトへ
  自動的にか \code{as} 関数への明示的な呼び出しで変換できる．
  自動変換は特殊であり，このオブジェクトのクラスが別のクラス
  を拡張するというデザイナーの保証に基づく．
  最も普通のケースは一つまたはそれ以上のクラスが
  \code{setClass} への \code{contains=} 引数中に提供されることで，
  その場合新しいクラスはそれ以前のクラスの各々を拡張する
  (普通の言い回しでは以前のクラスは
  新しいクラスの \emph{superclasses} であり
  それらの各々の \emph{subclass} である)．

  この継承の形式は
  \R の\emph{単純}な継承と呼ばれる．
  詳細は \code{\link{setClass}} を見よ．
  継承はまた \code{\link{setIs}} の呼び出しで明示的に定義できる．
  二つのバージョンは強制変換に対して僅かに異なる含意を持つ．
  単純な継承は継承スロットがサブクラスとスーパークラスで同じように動作することを
  意味する．二つのクラスが単純な継承で結びついている場合は常に
  対応する強制変換メソッドが直接と
  \code{as} の置き換え使用の双方に対して定義される．
  単純な継承のケースでは
  これらのメソッドは明白な計算を行う：
  それらはスーパークラス定義中のそれらに対応するオブジェクト中の
  スロットを取り出したり置き換えたりする．

  暗黙のうちに定義された強制変換メソッドは
  \code{setAs} への呼び出しで書き換えることが出来る；
  しかしながら暗黙のメソッドは
  各々のサブクラス-スーパークラスの対に対して定義され，
  従ってこれらの各々を継承に依るのではなく明示的に
  書き換える必要があることを注意する．

  継承が \code{setIs} への呼び出しで定義されるときは，強制変換メソッドは
  明示的に提供され，自動的には生成されない．
  継承は(下の節で解説されるように \code{from} 引数に)適用される．
  非継承的な関係に対するメソッドも
  \code{setAs} を使って提供することも可能ではあるが，
  その時はまたこれらは継承することが出来る．

  単純と明示的な継承の間の差異に関するこれ以上については
  \code{\link{setIs}} を見よ．
}

\section{関数 'as' と 'setAs' がどのように動作するか}{
  関数 \code{as} は \code{object} を
  クラス \code{Class} のオブジェクトに変換する．そのために
  S4 クラスとメソッドを使う\dQuote{強制変換メソッド}を適用するが，
  幾らか特別な仕方でである．
  強制変換メソッドは関数
  \code{coerce} に対するメソッドであるか，置き換えケースでは
  関数 \code{`coerce<-`} である．
  これらの関数はメソッドシグネチャ中の二つの引数
  \code{from} と \code{to} を持ち，オブジェクトのクラスと
  希望の強制変換先のクラスに対応する．
  これらの関数は直接呼び出してはならないが，
  直接または置き換えに対して \code{as} を使用されるメソッドの
  テーブルを保管するのに使われる．
  この節では直接的なケースを解説するが，
  注意がある箇所を除けば置き換えケースも
  \code{coerce} と the \code{def} 引数の代わりに
  \code{`coerce<-`} と \code{setAs} への \code{replace} 引数を用いて
  同じ仕方で動作する．

  \code{object} がすでに希望のクラスでないことを仮定すると，
  \code{as} は先ず
  シグネチャ\cr
  \code{c(from = class(object), to = Class)} に対する
  関数 \code{coerce} に対するメソッドのテーブル中の
  メソッドをメソッド選択がその最初の探索で行うのと同じ方法で
  探す．
  正確に言うと，これは直接と継承メソッドの双方のテーブルを意味するが，
  継承はこの場合は特殊である
  (下を見よ)．

  もし如何なるメソッドも見つからなければ
  \code{as} は何かを探す．
  最初に，もし \code{Class} か \code{class(object)} が他方のスーパークラス
  ならば，クラス定義は強制変換メソッドを作るのに必要な情報を含む．
  サブクラスがスーパークラスを含む普通のケース
  (つまり全てのそのスロットを含む)では，メソッドは継承スロットを
  取り出すか置き換える．
  単純でない拡張(\code{\link{setIs}} への呼び出しの結果)は
  通常明示的なメソッドを含むが，置き換えに対しては含まないかもしれない．

  もしサブクラス/スーパークラス関係がメソッドを提供しなければ
  \code{as} は継承メソッドを探すが
  引数 \code{from} に対してだけで引数 \code{to} に対しては適用されない
  (結果が指定された \code{Class} 以外の他のクラスからのものになることは
  好ましくないことに恐らく同意するであろう)．
  従って \code{selectMethod("coerce", sig, useInherited= c(from=TRUE, to= FALSE))}
  \code{as()} で使われるメソッド選択を複製する．

  ほとんどすべてのケースでこのようにして見つけられたメソッドは
  強制変換メソッそのテーブル中にキャッシュされる
  (例外は検査を備えたサブクラス関係で，これは適正であるが勧められない)．
  従って詳細な計算は
  \code{class(object)} から \code{Class} への強制変換が最初に起きた時だけ
  なされるべきである．

  \code{coerce} は標準的な総称的関数では無いことを注意する．
  これは直接呼び出されることを意図していない．
  間違って不正な継承メソッドをキャッシュすることを防ぐために，
  呼び出しは
  \code{as} への同値な呼び出しに振り向けられる．
  またこの関数に対する \code{\link{selectMethod}} への呼び出しは
  \code{as} が選ぶメソッドを表していないかもしれない．
  もし対応する
  \code{as} への呼び出しがこのセッションで先に起きている時だけ
  結果を信頼できる．

  この説明を背景として，関数
  \code{setAs} はかなりわかりやすい計算を行う：
  それはメソッドの本体を定義する \code{def} 引数を用い， 
  シグネチャ \code{c(from, to)} を持つ
  関数 \code{coerce} に対するメソッドを構成し設定する．
  \code{def} として提供された関数は
  引数を一つ持つか(強制変換されるオブジェクトと解釈される)
  または二つの引数
  (\code{from} オブジェクトと \code{to} クラス)を持つことが出来る．
  どちらの場合も，
  \code{setAs} は二つの引数の関数の関数を構成し，
  二つ目は \code{to} クラスの名前が既定値になる．
  メソッドはオブジェクトを \code{from} 引数とし
  \code{to} 引数を持たずに \code{as} から呼び出され，
  この引数に対する既定値は意図された
  \code{to} クラスの名前であり，従って
  メソッドはメッセージ中でこの情報を使うことが出来る．

  \code{as} 関数の直接バージョンはまた既定値が \code{TRUE}
  の引数 \code{strict=} を持つ．
  他の関数に対するメソッドの評価の間の呼び出しは
  この引数を \code{FALSE} に設定する．
  この違いは強制変換されるオブジェクトが
  \code{to} クラスの単純なサブクラスからのものであるときは
  意味を持つ：
  この場合もし \code{strict=FALSE} ならば何もする必要はない．
  殆どのユーザーが書いた強制変換メソッドに対しては，
  二つのクラスがサブクラス/スーパークラスを持たない時は，
  \code{strict=} 引数は無関係である．

  \code{setAs} への \code{replace} 引数は
  \code{`coerce<-`} に対するメソッドを提供する．
  全ての置き換えメソッドの場合と同様に，メソッドの最後の
  引数は付値の右辺値に対する名前
  \code{value} を持たなければならない．
  \code{coerce} メソッドの場合と同様に，最初の二つの引数は
  \code{from, to} である；
  置き換えケースには \code{strict=} オプションは無い．

  関数 \code{coerce} はそうしたメソッドに対する保管庫として
  存在し，
  \code{as} 関数により上で説明されたように選択される．
  実際には
  \code{standardGeneric} を用いたメソッドの選択適用
  は \code{to} 引数に関する継承を用い不正確な
  継承メソッドを作り出すかもしれない；
  説明されたようにこれは
  \code{as} に対して用いられるロジックではない．
  不正なメソッドを選択しキャッシュ防ぐために，
  \code{coerce} への呼び出しは現在
  警告と共に \code{as} への呼び出しにマップされる．
}

\section{基本的な強制変換メソッド}{
  任意のオブジェクトを基本的なデータタイプの一つに
  強制変換するためのメソッドが予め定義されている．
  例えば \code{as(x, "numeric")} は既存の
  \code{as.numeric} 関数を使う．
  これらの組み込みメソッドは
  \code{showMethods("coerce")} で一覧できる．
}

\seealso{
  もし \code{try(as(x, cl))} を使おうと思うならば代わりに
  \code{\link{canCoerce}(x, cl)} を考慮しよう．
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\examples{
## \link{setClass} からのクラス "track" の定義を使う

\dontshow{
setClass("track",
         representation(x="numeric", y="numeric"))
setClass("trackCurve",
         representation("track", smooth = "numeric"))
}

setAs("track", "numeric", function(from) from@y)

t1 <- new("track", x=1:20, y=(1:20)^2)

as(t1, "numeric")

## 次の例は以下を示す：
##  1. 幾つかのクラスに対して setAs を同時に定義する仮想クラス．
##  2. 継承情報を使う as() 

setClass("ca", representation(a = "character", id = "numeric"))

setClass("cb", representation(b = "character", id = "numeric"))

setClass("id")
setIs("ca", "id")
setIs("cb", "id")


setAs("id", "numeric", function(from) from@id)

CA <- new("ca", a = "A", id = 1)
CB <- new("cb", b = "B", id = 2)

setAs("cb", "ca", function(from, to )new(to, a=from@b, id = from@id))

as(CB, "numeric")

\dontshow{
## エラーが起こるべき(引数一つの関数であるべきだった)
try(setAs("track", "numeric", function(x, y,z)x@y))
}
}
\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/as.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{as}
%\alias{as}
%\alias{as<-}
%\alias{coerce}
%\alias{coerce<-}
%\alias{setAs}
%\alias{coerce-methods}
%\alias{coerce,ANY,array-method}
%\alias{coerce,ANY,call-method}
%\alias{coerce,ANY,character-method}
%\alias{coerce,ANY,complex-method}
%\alias{coerce,ANY,environment-method}
%\alias{coerce,ANY,expression-method}
%\alias{coerce,ANY,function-method}
%\alias{coerce,ANY,integer-method}
%\alias{coerce,ANY,list-method}
%\alias{coerce,ANY,logical-method}
%\alias{coerce,ANY,matrix-method}
%\alias{coerce,ANY,name-method}
%\alias{coerce,ANY,numeric-method}
%\alias{coerce,ANY,single-method}
%\alias{coerce,ANY,ts-method}
%\alias{coerce,ANY,vector-method}
%\alias{coerce,ANY,NULL-method}
%\title{Force an Object to Belong to a Class}
%\description{
%  These functions manage the relations that allow coercing an object to
%  a given class.
%}
%\usage{
%as(object, Class, strict=TRUE, ext)
%
%as(object, Class) <- value
%
%setAs(from, to, def, replace, where = topenv(parent.frame()))
%
%}
%\section{Summary of Functions}{
%  \describe{
%    \item{\code{as}:}{
%      Returns the version of this object coerced to be the given
%      \code{Class}.  When used in the replacement form on the left of
%      an assignment, the portion of the object corresponding to
%      \code{Class} is replaced by \code{value}.
%
%      The operation of \code{as()} in either form depends on the
%      definition of coerce methods.  Methods are defined automatically
%      when the two classes are related by inheritance; that is, when
%      one of the classes is a subclass of the other.  See the section
%      on inheritance  below for details.
%
%      Coerce methods are also predefined for basic classes (including all
%      the types of vectors, functions and a few others). See
%      \code{showMethods(coerce)} for a list of these.
%
%      Beyond these two sources of methods, further methods are defined
%      by calls to the \code{setAs} function.
%
%    }
%
%    \item{\code{setAs}:}{
%      Define methods for coercing an object of class \code{from} to be of class \code{to}; the \code{def} argument provides for direct coercing and the \code{replace} argument, if included, provides for replacement.  See the \dQuote{How} section below for details.
%    }
%
%    \item{\code{coerce}, \code{coerce<-}:}{
%      Coerce \code{from} to be of the same class as \code{to}.
%
%      These functions should not be called explicitly.  The function
%      \code{\link{setAs}} creates methods for them for the
%      \code{as} function to use.
%    }
%
%  }
%}
%\arguments{
%  \item{object}{any \R object.}
%  \item{Class}{the name of the class to which \code{object} should be
%    coerced. }
%  \item{strict}{logical flag.  If \code{TRUE}, the returned object
%    must be strictly from the target class (unless that class is a
%    virtual class, in which case the object will be from the closest
%    actual class, in particular the original object, if that class extends the
%    virtual class directly).
%
%    If \code{strict = FALSE}, any simple extension of the target class
%    will be returned, without further change.  A simple extension is,
%    roughly, one that just adds slots to an existing class.}
%  \item{value}{The value to use to modify \code{object} (see the
%    discussion below).  You should supply an object with class
%    \code{Class}; some coercion is done, but you're unwise to rely on
%    it.}
%
%  \item{from, to}{The classes between which the coerce methods
%      \code{def} and \code{replace} perform coercion.
%    }
%  \item{def}{function of one argument.  It will get an object from
%    class \code{from} and had better return an object of class
%    \code{to}. The convention is that
%    the name of the argument is \code{from}; if another argument name
%    is used, \code{setAs} will attempt to substitute \code{from}. }
%  \item{replace}{if supplied, the function to use as a replacement
%    method, when \code{as} is used on the left of an assignment.
%    Should be a function of two arguments, \code{from, value},
%    although \code{setAs} will attempt to substitute if the arguments differ.}
%  \item{where}{the position or environment in which to store the
%    resulting methods. For most applications, it is recommended to
%    omit this argument and to include the call to \code{setAs} in source code that is evaluated at the top level; that is, either in an R session by something equivalent to a call to \code{\link{source}}, or as part of the R source code for a package.}
%  \item{ext}{the optional object
%    defining how \code{Class} is extended by the class of the
%    object (as returned by \code{\link{possibleExtends}}).
%    This argument is used internally (to provide essential
%    information for non-public classes), but you are unlikely to want
%    to use it directly.
%  }
%}
%
%\section{Inheritance and Coercion}{
%
% Objects from one class can turn into objects from another class
%  either automatically or by an explicit call to the \code{as}
%  function.  Automatic conversion is special, and comes from the
%  designer of one class of objects asserting that this class extends
%  another class.  The most common case is that one or more class names
%  are supplied in the \code{contains=} argument to \code{setClass}, in
%  which case the new class extends each of the earlier classes (in the
%  usual terminology, the earlier classes are \emph{superclasses} of
%  the new class and it is a \emph{subclass} of each of them).
%
%This form of inheritance is called \emph{simple} inheritance in \R.
%See \code{\link{setClass}} for details.
%Inheritance can also be defined explicitly by a call to
%\code{\link{setIs}}.
%The two versions have slightly different implications for coerce methods.
%Simple inheritance implies that inherited slots behave identically in the subclass and the superclass.
%Whenever two classes are related by simple inheritance, corresponding coerce methods
%are defined for both direct and replacement use of \code{as}.
%In the case of simple inheritance, these methods do the obvious
%computation:  they extract or replace the slots in the object that
%correspond to those in the superclass definition.
%
%The implicitly defined coerce methods may be overridden by a call
%to \code{setAs}; note, however, that the implicit methods are defined for each
%subclass-superclass pair, so that you must override each of these
%explicitly, not rely on inheritance.
%
%When inheritance is defined by a call to \code{setIs}, the coerce methods are provided explicitly, not generated automatically.
%Inheritance will apply (to the \code{from} argument, as described in  the section below).
%You could also supply methods via \code{setAs} for non-inherited relationships, and now these also can be inherited.
%
%For further on the distinction between simple and explicit inheritance, see \code{\link{setIs}}.
%
%}
%\section{How Functions 'as' and 'setAs' Work}{
%  The function \code{as}  turns \code{object} into an object
%  of class \code{Class}.  In doing so, it applies a \dQuote{coerce
%    method}, using S4
%  classes and methods, but in a somewhat special way.
%Coerce methods are methods for the function \code{coerce} or, in the
%replacement case the function \code{`coerce<-`}.
%These functions have two arguments in method signatures, \code{from}
%and \code{to}, corresponding to the class of the object and the
%desired coerce class.
%These functions must not be called directly, but are used to store
%tables of methods for the use of \code{as}, directly and for
%replacements.
%In this section we will describe the direct case, but except where
%noted the replacement case works the same way, using \code{`coerce<-`}
%and the \code{replace} argument to \code{setAs}, rather than
%\code{coerce} and the \code{def} argument.
%
%Assuming the \code{object} is not already of the desired class,
%\code{as} first looks for a method in the table of methods
% for the function
%  \code{coerce} for the signature \code{c(from = class(object), to =
%    Class)}, in the same way method selection would do its initial lookup.
%To be precise, this means the table of both direct and inherited
%methods, but inheritance is used specially in this case (see below).
%
%If no method is found, \code{as} looks for one.
%First, if either \code{Class} or \code{class(object)} is a superclass
%of the other, the class definition will contain the information needed
%to construct a coerce method.
%In the usual case that the subclass contains the superclass (i.e., has
%all its slots), the method is constructed either by extracting or
%replacing the inherited slots.
%Non-simple extensions (the result of a call to \code{\link{setIs}})
%will usually contain explicit methods, though possibly not for replacement.
%
% If no subclass/superclass relationship provides a method, \code{as}
% looks for an inherited method, but applying, inheritance for the argument \code{from} only, not for
%  the argument \code{to} (if you think about it, you'll probably agree
%  that you wouldn't want the result to be from some class other than the
%  \code{Class} specified). Thus,
%  \code{selectMethod("coerce", sig, useInherited= c(from=TRUE, to= FALSE))}
%  replicates the method selection used by \code{as()}.
%
%In nearly all cases the method found in this way will be cached in the
%table of coerce methods (the exception being subclass relationships with a test, which
%are legal but discouraged).
%So the detailed calculations should be done only on the first
%occurrence of a coerce from \code{class(object)} to \code{Class}.
%
%Note that  \code{coerce} is not a standard generic function.  It is
%not intended to be called directly.  To prevent accidentally caching
%an invalid inherited method, calls are routed to an equivalent call to
%\code{as}, and a warning is issued.  Also, calls to
%\code{\link{selectMethod}} for this function may not represent the
%method that \code{as} will choose.  You can only trust the result if
%the corresponding call to \code{as} has occurred previously in this
%session.
%
%  With this explanation as background, the function \code{setAs} does a
%  fairly obvious computation:  It constructs and sets a method for the function
%  \code{coerce} with signature \code{c(from, to)}, using the \code{def}
%  argument to define the body of the method.  The function supplied as
%  \code{def} can have one argument (interpreted as an object to be
%  coerced) or two arguments (the \code{from} object and the \code{to}
%  class).  Either way, \code{setAs} constructs a function of two
%  arguments, with the second defaulting to the name of the \code{to}
%  class.  The method will be called from \code{as} with the object
%  as the \code{from} argument and no \code{to} argument, with the default for this argument being the name of the intended
%  \code{to} class, so the method can use this information in messages.
%
%The direct version of the \code{as} function also has a \code{strict=} argument that defaults to \code{TRUE}.
%Calls during the evaluation of methods for other functions will set this argument to \code{FALSE}.
%The distinction is relevant when the object being coerced is from a simple subclass of the \code{to} class; if \code{strict=FALSE} in this case, nothing need be done.
%For most user-written coerce methods, when the two classes have no subclass/superclass, the \code{strict=} argument is irrelevant.
%
%The \code{replace} argument to \code{setAs} provides a method for
%\code{`coerce<-`}.
%As with all replacement methods, the last argument of the method must
%have the name \code{value} for the object on the right of the
%assignment.
%As with the \code{coerce} method, the first two arguments are
%\code{from, to}; there is no \code{strict=} option for the replace case.
%
%  The function \code{coerce} exists as a repository for
%  such methods, to be selected as described above by the \code{as}
%  function.  Actually dispatching the methods using
%  \code{standardGeneric} could produce incorrect inherited methods, by using
%   inheritance on the
%  \code{to} argument; as mentioned, this is not the logic used for
%  \code{as}.
%  To prevent selecting and caching invalid methods, calls to
%  \code{coerce} are
%  currently mapped into calls to \code{as}, with a warning message.
%}
%
%
%\section{Basic Coercion Methods}{
%  Methods are pre-defined for coercing any object to one of the basic
%  datatypes.  For example, \code{as(x, "numeric")} uses the existing
%  \code{as.numeric} function.  These built-in methods can be listed by
%  \code{showMethods("coerce")}.
%}
%
%\seealso{
%  If you think of using \code{try(as(x, cl))}, consider
%  \code{\link{canCoerce}(x, cl)} instead.
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\examples{
%## using the definition of class "track" from \link{setClass}
%
%\dontshow{
%setClass("track",
%         representation(x="numeric", y="numeric"))
%setClass("trackCurve",
%         representation("track", smooth = "numeric"))
%}
%
%setAs("track", "numeric", function(from) from@y)
%
%t1 <- new("track", x=1:20, y=(1:20)^2)
%
%as(t1, "numeric")
%
%## The next example shows:
%##  1. A virtual class to define setAs for several classes at once.
%##  2. as() using inherited information
%
%setClass("ca", representation(a = "character", id = "numeric"))
%
%setClass("cb", representation(b = "character", id = "numeric"))
%
%setClass("id")
%setIs("ca", "id")
%setIs("cb", "id")
%
%
%setAs("id", "numeric", function(from) from@id)
%
%CA <- new("ca", a = "A", id = 1)
%CB <- new("cb", b = "B", id = 2)
%
%setAs("cb", "ca", function(from, to )new(to, a=from@b, id = from@id))
%
%as(CB, "numeric")
%
%\dontshow{
%## should generate an error (should have been a function of one argument)
%try(setAs("track", "numeric", function(x, y,z)x@y))
%}
%}
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%