% File src/library/methods/man/callGeneric.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{callGeneric}
%@%\alias{メソッドから総称的関数を呼び出す}
\alias{callGeneric}
\title{メソッドから現在の総称的関数を呼び出す}
%\title{Call the Current Generic Function from a Method}
\description{
  \code{callGeneric} の呼び出しはメソッド定義の内部にだけ
  現れることが出来る．
  そうするとそれは現在の総称的関数への呼び出しを行う．
  この呼び出しの結果は
  \code{callGeneric} の値である．
  これは任意のメソッドから呼び出すことができるが，
  グループ総称的関数に対するメソッド中で有用であり
  典型的に使われる．
}
\usage{
callGeneric(...)
}
\arguments{
  \item{\dots}{
    オプションで，その次の呼び出し中の関数への引数．

    \code{callGeneric} への呼び出し中に如何なる引数も
    含まれなければ，その効果は関数を現在の引数で
    呼び出すことである．
    これが実際に意味することは詳細説明を見よ．
  }
}
\details{
  現在の総称的関数の名前とパッケージはメソッド定義オブジェクト
  の環境に保管される．
  この名前は検索され対応する関数が呼び出される．

  \code{callGeneric} へ引数を渡さない文は総称的関数を
  現在の引数で呼び出すことはより正確には次のようになる．
  現在の呼び出し中に欠損していた引数は
  依然として欠損している
  (\code{"missing"} はメソッドシグネチャ中の適正なクラスであることを
  思い出そう)．
  オリジナルの呼び出し中に現れる形式的引数，例えば
  \code{x} に対しては
  \code{x = x} に同値な対応する引数が生成された呼び出し中にある．
  実際には，これは総称的関数が同じ実際の引数を見るが
  引数は唯一回だけ評価されることを意味する．

  引数無しで \code{callGeneric} を使うことは，
  シグネチャ中の引数の一つが現在のメソッド中で変更されており
  従って異なったメソッドが選択されない限り，無限の再帰を作りやすい．
}
\value{
  新しい呼び出しが返す値．
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\seealso{\code{\link{GroupGenericFunctions}} for other information
  about group generic functions; \link{Methods} for the general behavior
  of method dispatch
}
\examples{
## グループ総称的関数 Ops に対するシグネチャ 
## signature( e1="structure", e2="vector") のメソッド
function (e1, e2)
{
    value <- callGeneric(e1@.Data, e2)
    if (length(value) == length(e1)) {
        e1@.Data <- value
        e1
    }
    else value
}

## もっと多くの例には
\dontrun{
showMethods("Ops", includeDefs = TRUE)
}

}

\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/callGeneric.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{callGeneric}
%\alias{callGeneric}
%\title{Call the Current Generic Function from a Method}
%\description{
%  A call to \code{callGeneric} can only appear inside a method
%  definition.  It then results in a call to the current generic
%  function.  The value of that call is the value of \code{callGeneric}.
%  While it can be called from any method, it is useful and typically
%  used in methods for group generic functions.
%}
%\usage{
%callGeneric(...)
%}
%\arguments{
%  \item{\dots}{
%    Optionally, the arguments to the function in its next call.
%
%    If no arguments are included in the call to \code{callGeneric}, the
%    effect is to call the function with the current arguments.
%    See the detailed description for what this really means.
%  }
%}
%\details{
%  The name and package of the current generic function is stored in the
%  environment of the method definition object.  This name is looked up
%  and the corresponding function called.
%
%  The statement that passing no arguments to \code{callGeneric} causes
%  the generic  function to be called with the current arguments is
%  more precisely as follows.  Arguments that were missing in the current
%  call are still missing (remember that \code{"missing"} is a valid
%  class in a method signature).  For a formal argument, say \code{x}, that
%  appears in the original call, there is a corresponding argument in the
%  generated call equivalent to \code{x = x}.  In effect, this
%  means that the generic function sees the same actual arguments, but
%  arguments are evaluated only once.
%
%  Using \code{callGeneric} with no arguments is prone to creating
%  infinite recursion, unless one of the arguments in the signature has
%  been modified in the current method so that a different method is selected.
%}
%\value{
%  The value returned by the new call.
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{\code{\link{GroupGenericFunctions}} for other information
%  about group generic functions; \link{Methods} for the general behavior
%  of method dispatch
%}
%\examples{
%## the method for group generic function Ops
%## for signature( e1="structure", e2="vector")
%function (e1, e2)
%{
%    value <- callGeneric(e1@.Data, e2)
%    if (length(value) == length(e1)) {
%        e1@.Data <- value
%        e1
%    }
%    else value
%}
%
%## For more examples
%\dontrun{
%showMethods("Ops", includeDefs = TRUE)
%}
%
%}
%
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
