% File src/library/methods/man/className.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2011-2 R Core Team
% Distributed under GPL 2 or later

\name{className}
%@%\alias{対応パッケージを含むクラス名}
\alias{className}
\alias{multipleClasses}
\alias{className-class}
\title{対応するパッケージを含むクラス名}
%\title{Class names including the corresponding package}
\description{
関数 \code{className()} はクラスの適正な参照を生成し，
クラス定義を含むパッケージの名前を含む．
クラス \code{"className"} からの返されたオブジェクトは
，例えば \code{\link{setMethod}} を呼び出す時に，
クラスの多重定義が存在する場合に
クラスを参照する曖昧さの無い方法である．

関数
\code{"multipleClasses"} は異なったパッケージからの
同じ名前を持つクラスの多重定義に関する情報を返す．
}
\usage{

className(class, package)

multipleClasses(details = FALSE)
}
\arguments{

  \item{class, package}{
クラスとそしてオプションでそれが所属するパッケージの名前の文字列．
もし \code{package} が欠損し
\code{class} 引数がパッケージスロットを持てば，
それが使われる(特にこの場合には
クラス \code{"className"} からのオブジェクトを渡すと
それ自体を返すが，もし二番目の引数が提供されるとパッケージスロットが
変更される)．

もしパッケージ引数やスロットがなければ，
クラスに対する定義が存在しなければならずパッケージを
定義するのに使われる．
もし多重定義があれば，一つが選ばれ他の可能性を与える
警告がプリントされる．
}

  \item{details}{
もし既定の \code{FALSE} ならば，
\code{multipleClasses()} は多重定義を持つ現在知られている
クラスへの文字列ベクトルを返す．

もし \code{TRUE} ならば，これらのクラス定義の名前付きリスト
が返される．リストの各要素はそれ自体
対応するクラス定義のりストであり，
リスト名としてパッケージ名を持つ．
同一のクラス定義は\dQuote{多重}定義とは考えられないことを注意する
(下の詳細の議論を見よ)．
}
}
\details{
内部的に使われるクラス定義のテーブルは
同じ名前を持つが異なったパッケージに由来する
多重定義を管理できる．
もし同一のクラス定義が現れると，
唯一つのクラス定義が保持される；
これは \code{\link{setOldClass}} の呼び出し中で指定されている
S3 クラスに関して最もしばしば起きる．
真のクラス対しては，
もし二つのパッケージが偶々独立に同じ名前を使っていると
一般に多重クラス定義が不可避になる．

同じ名前を持つ別のパッケージ中のクラス定義を勝手に
書き換えることは普通悪いアイデアである．
\R は二つの定義を保持し使う
(バージョン 2.14.0 の様に)が，曖昧さは常に可能である．
既存クラスを拡張子するが異なった名前を持つ新しいクラスを定義するのが
より賢明である．
}
\value{
\code{className()} への呼び出しはクラス
\code{"className"} のオブジェクトを返す．

\code{multipleClasses()} への呼び出しはクラス定義の文字列ベクトルか
名前付きリストを返す．
どちらのケースも
\code{0} より大きい返り値の長さの検査することは
多重に定義されたクラスの存在のチェックである．
}

\section{クラスからのオブジェクト}{
クラス \code{"className"} は \code{"character"} を拡張し
スロット \code{"package"} を持ち，またクラス
\code{"character"} である．
}

\examples{
\dontrun{
className("vector") # パッケージ "methods" から見つかる
className("vector", "magic") # OK, クラスは存在しないものの


className("An unknown class") # エラーを起こす
}
}
\keyword{ classes }
\keyword{ programming }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/className.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2011-2 R Core Team
%% Distributed under GPL 2 or later
%
%\name{className}
%\alias{className}
%\alias{multipleClasses}
%\alias{className-class}
%\title{
%Class names including the corresponding package
%}
%\description{
%The function \code{className()} generates a
%valid references to a class, including the name of the package
%containing the class definition.  The object returned, from class \code{"className"}, is the
%unambiguous way to refer to a class, for example when calling
%\code{\link{setMethod}}, just in case multiple definitions of the
%class exist.
%
%Function
%\code{"multipleClasses"} returns information about multiple
%definitions of classes with the
%same name from different packages.
%}
%\usage{
%
%className(class, package)
%
%multipleClasses(details = FALSE)
%}
%\arguments{
%
%  \item{class, package}{
%The character string name of a class and, optionally, of the package
%to which it belongs.  If argument \code{package} is missing and the
%\code{class} argument has a package slot, that is used  (in
%particular, passing in an object from class \code{"className"} returns
%itself in this case, but changes the package slot if the second
%argument is supplied).
%
%If there is no package argument or slot, a
%definition for the class must exist and will be used to define the
%package.  If there are multiple definitions, one will be chosen and a
%warning printed giving the other possibilities.
%}
%
%  \item{details}{
%If \code{FALSE}, the default, \code{multipleClasses()} returns a
%character vector of those classes currently known with multiple
%definitions.
%
%If \code{TRUE}, a named list of those class definitions is returned.
%Each element of the list is itself a list of the corresponding class
%definitions, with the package names as the names of the list.  Note
%that identical class definitions will not be considered
%\dQuote{multiple} definitions (see the discussion of the details below).
%}
%}
%\details{
%The table of class definitions used internally can maintain multiple
%definitions for classes with the same name but coming from different
%packages.
%If identical class definitions are encountered, only one class
%definition is kept; this occurs most often with S3 classes that have
%been specified in calls to \code{\link{setOldClass}}.  For true
%classes, multiple class definitions are unavoidable in general if two
%packages happen to have used the same name, independently.
%
%Overriding a class definition in another package with the same name deliberately is usually a bad
%idea.
%Although \R attempts to keep and use the two definitions (as of
%version 2.14.0), ambiguities are always possible.  It is more
%sensible to define a new class that extends an existing class but has
%a different name.
%}
%\value{
%A call to \code{className()} returns an object from class
%\code{"className"}.
%
%A call to \code{multipleClasses()} returns either a character
%vector or a named list of class definitions.  In either case, testing
%the length of the returned value for being greater than \code{0} is a
%check for the existence of multiply defined classes.
%}
%
%\section{Objects from the Class}{
%The class \code{"className"} extends \code{"character"} and has a slot
%\code{"package"}, also of class \code{"character"}.
%}
%
%\examples{
%\dontrun{
%className("vector") # will be found, from package "methods"
%className("vector", "magic") # OK, even though the class doesn't exist
%
%
%className("An unknown class") # Will cause an error
%}
%}
%\keyword{ classes }
%\keyword{ programming }
%
%\encoding{UTF8}
%