% File src/library/methods/man/classRepresentation-class.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{classRepresentation-class}
\docType{class}
%@%\alias{クラスオブジェクト}
\alias{classRepresentation-class}
\title{クラスオブジェクト}
%\title{Class Objects }
\description{
  これらはオブジェクトのクラスの定義を保持するオブジェクトである．
  これらは関数
  \code{\link{setClass}} の呼び出しによりメタデータとして
  構成され保存される．
  恐らく個別のスロットを眺める以外にはそれらを直接操作
  してはならない．}

\section{スロット}{
  \describe{
    \item{\code{slots}:}{
      このクラス中のスロットの名前付きリスト；
      リストの要素はスロットが所属する(または拡張する)クラス
      であり，リストの名前は対応するスロット名を与える．}
    \item{\code{contains}:}{
      このクラスが
      \sQuote{含む}クラスの名前付きリスト；
      リストの要素は
      \code{\linkS4class{SClassExtension}} のオブジェクトである．
      リストは直接の拡張か全ての現在知られている拡張
      かもしれない(詳細を見よ)．}
    \item{\code{virtual}:}{
      論理フラグ，もしこれが仮想クラスならば \code{TRUE} に
      設定される．}
    \item{\code{prototype}:}{
      このクラスに対する標準的なプロトタイプを表す
      オブジェクト；つまり
      このクラスに対する特別な引数無しの
      \code{\link{new}} の呼び出しにより返されるデータとスロット．
      プロトタイプオブジェクトを直接にいじくらないこと．}
    \item{\code{validity}:}{
      オプションの，このクラスからのオブジェクトの
      妥当性を検査するのに使われる関数．
      \code{\link{validObject}} を見よ.}
    \item{\code{access}:}{
      制御情報にアクセスする．現在使われない．}
    \item{\code{className}:}{
      クラスの名前の文字列．}
    \item{\code{package}:}{
      クラスが属するパッケージ名の文字列．
      ほとんど常にクラスに対するメタデータが保管されているパッケージ
      であるが，継承情報構成のような操作では
      内部的なパッケージ名規則．}
    \item{\code{subclasses}:}{
      このクラスを拡張することが知られているクラスの名前付きリスト；
      リストの要素はクラス \code{\linkS4class{SClassExtension}} の
      オブジェクトである．リストは現在
      クラス定義を完成する時だけ埋められる
      (詳細を見よ)．}
    \item{\code{versionKey}:}{
      クラス \code{"externalptr"} のオブジェクト；
      いつかは恐らくある種のバージョン情報を含むであろうが，
      現在は使われない．}
    \item{\code{sealed}:}{
      クラス \code{"logical"} のオブジェクト；
      このクラスは封印されているか?
      もしそうならどんな修正も許されない．}
  }
}
\details{
  クラス定義はメタデータとして様々なパッケージに保存される．
  追加のメタデータは継承に関する情報を提供する
  (\code{\link{setIs}} への呼び出しの結果)．
  クラス定義自体により含意される継承情報
  (クラスは一つまたはそれ以上のクラスを含むので)
  は同様に自動的に構成される．

  あるクラスが
  R セッション中で使われると，この情報は
  クラス定義を完成させるために集められる．
  完成したものは
  はクラス \code{"classRepresentation"} の二番目のオブジェクト
  であり，セッションに対してまたは情報を変更する何かが起きるまで
  キャッシュされる．
  \code{\link{getClass}} への呼び出しはクラスの完成された定義
  を返す；\code{\link{getClassDef}} の呼び出しは保管された定義を
  返す(未完成の)．

  特に完成されたものはクラスに対する
  上向きと下向きを指し示す
  継承情報をスロット \code{contains} と
  \code{subclasses} にそれぞれ描き込む．
  これは原則としてこれらは追加のサブクラスとスーパークラス
  を定義するかもしれないので，
  この情報はインストールされたパッケージに依存する可能性がある
  ことを注意することが重要である．
}
\seealso{
  クラス定義中の情報を提供するには関数 \code{\link{setClass}}
  を見よ．
  クラス情報のより基本的な議論には \link{Classes}．
}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/classRepresentation-class.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{classRepresentation-class}
%\docType{class}
%\alias{classRepresentation-class}
%\title{Class Objects }
%\description{  These are the objects that hold the definition of
%  classes of objects.  They are constructed and stored as meta-data by
%  calls to the function \code{\link{setClass}}.  Don't manipulate them
%  directly, except perhaps to look at individual slots. }
%
%\section{Slots}{
%  \describe{
%    \item{\code{slots}:}{A named list of the slots in this class; the
%      elements of the list are the classes to which the slots must
%      belong (or extend), and the names of the list gives the
%      corresponding slot names.}
%    \item{\code{contains}:}{A named list of the classes this class
%      \sQuote{contains}; the elements of the list are objects of
%      \code{\linkS4class{SClassExtension}}. The list may be only the
%      direct extensions or all the currently known extensions (see the
%      details).}
%    \item{\code{virtual}:}{Logical flag, set to \code{TRUE} if this is
%      a virtual class.}
%    \item{\code{prototype}:}{The object that represents the standard
%      prototype for this class; i.e., the data and slots returned by a
%      call to \code{\link{new}} for this class with no special
%      arguments.  Don't mess with the prototype object directly.}
%    \item{\code{validity}:}{Optionally, a function to be used to test
%      the validity of objects from this class.
%      See \code{\link{validObject}}.}
%    \item{\code{access}:}{Access control information.  Not currently used.}
%    \item{\code{className}:}{The character string name of the class.}
%    \item{\code{package}:}{The character string name of the package to
%      which the class belongs.  Nearly always the package on which the
%      metadata for the class is stored, but in operations such as
%      constructing inheritance information, the internal package name
%      rules.}
%    \item{\code{subclasses}:}{A named list of the classes known to
%      extend this class'; the elements of the list are objects of class
%      \code{\linkS4class{SClassExtension}}.  The list is currently only
%      filled in when completing the class definition (see the details).}
%    \item{\code{versionKey}:}{Object of class \code{"externalptr"};
%      eventually will perhaps hold some versioning information, but not
%      currently used. }
%    \item{\code{sealed}:}{Object of class \code{"logical"}; is this
%      class sealed?  If so, no modifications are allowed. }
%  }
%}
%\details{
%  Class definitions are stored as metadata in various packages.
%  Additional metadata supplies information on inheritance (the result of
%  calls to \code{\link{setIs}}).  Inheritance information implied by the
%  class definition itself (because the class contains one or more other
%  classes) is also constructed automatically.
%
%  When a class is to be used in an R session, this information is
%  assembled to complete the class definition.  The completion is a
%  second object of class \code{"classRepresentation"}, cached for the
%  session or until something happens to change the information.  A call
%  to \code{\link{getClass}} returns the completed definition of a class;
%  a call to \code{\link{getClassDef}} returns the stored definition
%  (uncompleted).
%
%  In particular, completion fills in the upward- and downward-pointing
%  inheritance information for the class, in slots \code{contains} and
%  \code{subclasses} respectively.  It's in principle important to note
%  that this information can depend on which packages are installed,
%  since these may define additional subclasses or superclasses.
%}
%\seealso{
%  See function \code{\link{setClass}} to supply the information in the
%  class definition.
%  See \link{Classes} for a more basic discussion of class information.
%}
%\keyword{classes}
%
%\encoding{UTF8}
%