\name{classesToAM}
\alias{classesToAM}
%@%\alias{スーパークラスに対する隣接行列}
\title{クラス定義のスーパークラスに対する隣接行列を計算}
%\title{Compute an Adjacency Matrix for Superclasses of Class Definitions}
\description{
クラス名のベクトルかクラス定義のリストを与えて，
関数はこれらのクラスのスーパークラスの隣接行列を返す；
つまり，クラス名が行名と列名で，
もし列 j 中のクラスが行 i 中のクラスの直接のスーパークラス
ならば 1 で，さもなければ 0 になる．

行列はクラス定義のスロット
\code{contains} が含意する情報を持つが，更なる解析に対して
しばしばより便利な形式でである；
例えば隣接行列はパッケージや他のソフトウェア中で
関係のグラフ表現を構成するのに使われる．
}
\usage{
classesToAM(classes, includeSubclasses = FALSE,
       abbreviate = 2)
}
\arguments{
  \item{classes}{
      クラス名の文字列ベクトルかリストで，その要素は
      クラス名でもクラス定義でも良い．
      リストは，例えば，クラス名に対するパッケージスロットを
      含むために便利である．
}
  \item{includeSubclasses}{
      論理フラグ；もし \code{TRUE} ならば，行列は
      スーパークラスと並んで指定されたクラスの全ての既知の
      サブクラスを含む．
      引数はまた \code{classes} と同じ長さの
      全てのクラスではなくあるサブクラスを含むための
      論理値ベクトルでも良い．
}
    \item{abbreviate}{
        返される行列の行と/または列ラベルの省略形を制御する：
	値 0, 1, 2 または 3 は行も列も省略しない，行を省略，列を省略，
	そして行も列も省略する，ことを意味する．
	クラス名は一文字より長くなりがちであるため，既定の 2 は
	広がったプリントを作るために行列のプリントに対して
	有用である．
	値 0 か 3 はグラフを作るのに適している

(3 はある種のグラフプロット用ソフトウェアは
	非常に小さいフォントサイズのラベルを作りやすいのを
	避ける)．
      }
}
\details{
  クラスの各々に対して，計算は
  クラス定義から全てのスーパークラス名を獲得し，
  これらのクラス定義中のエッジを見つける；
  つまり距離1の全てのスーパークラス．
  隣接行列の対応する要素は1に設定される．

  個別のクラス定義に対する隣接行列は融合される．
  二つの可能な非一貫性に注意する．どちらも可能性として
  異なったパッケージからの同じ名前のクラスがある場合を除き
  問題を惹き起こすべきではない．
  エッジは各スーパークラス定義から計算されるので，
  情報は距離 > 1 の拡張要素からの可能な推測を上書きする
  (そしてそうあるべきである)．
  引数中の引き続く行列が融合された時は，
  計算は現在非一貫性をチェックしない
  ---これは可能性のある同じ名前の重複クラスが混乱を招くかもしれない
  部位である．
  将来のバージョンは一貫性のチェックを含むかもしれない．
}
\value{
  解説されたように要素が
  0 か 1 の行列で，
  非ゼロの値は列に対応するクラスが
  対応する行のクラスの直接のスーパークラスであることを
  指示する．行と列の名前はクラス名である
  (パッケージスロット無しの)．
}


\seealso{
  背景にあるクラス定義からの情報については
  \code{\link{extends}} と \linkS4class{classRepresentation}．
}
\examples{

## "standardGeneric" と "derivedDefaultMethod" の
## スーパークラスとサブクラス
am <- classesToAM(list(class(show), class(getMethod(show))), TRUE)
am

\dontrun{
## 次の関数は Bioconductor パッケージ Rgraphviz に依存する
plotInheritance <- function(classes, subclasses = FALSE, ...) {
    if(!require("Rgraphviz", quietly=TRUE))
      stop("Only implemented if Rgraphviz is available")
    mm <- classesToAM(classes, subclasses)
    classes <- rownames(mm); rownames(mm) <- colnames(mm)
    graph <-  new("graphAM", mm, "directed", ...)
    plot(graph)
    cat("Key:\n", paste(abbreviate(classes), " = ", classes, ", ",
        sep = ""),  sep = "", fill = TRUE)
    invisible(graph)
}

## "graph" パッケージのクラス継承のプロット
require(graph)
plotInheritance(getClasses("package:graph"))

}
}

\keyword{classes}
\keyword{programming}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%\name{classesToAM}
%\alias{classesToAM}
%\title{
%Compute an Adjacency Matrix for Superclasses of Class Definitions
%}
%\description{
%Given a vector of class names or a list of class definitions, the
%function returns an adjacency matrix of the superclasses of these
%classes; that is, a matrix with class names as the row and column
%names and with element [i, j] being 1 if the class in column j is a
%direct superclass of the class in row i, and 0 otherwise.
%
%The matrix has the information implied by the \code{contains} slot of
%the class definitions, but in a form that is often more convenient for
%further analysis; for example, an adjacency matrix is used in packages
%and other software to construct graph representations of relationships.
%}
%\usage{
%classesToAM(classes, includeSubclasses = FALSE,
%       abbreviate = 2)
%}
%\arguments{
%  \item{classes}{
%      Either a character vector of class names or a list, whose
%      elements can be either class names or class definitions.  The
%      list is convenient, for example, to include the package slot for
%      the class name. See the examples.
%}
%  \item{includeSubclasses}{
%      A logical flag; if \code{TRUE}, then the matrix will include all
%      the known subclasses of the specified classes as well as the
%      superclasses.  The argument can also be a logical vector of the
%      same length as \code{classes}, to include subclasses for some
%      but not all the classes.
%}
%    \item{abbreviate}{
%        Control of the abbreviation of the row and/or  column labels of
%        the matrix returned: values 0, 1, 2, or 3 abbreviate neither,
%        rows, columns or both.  The default, 2, is useful for printing
%        the matrix, since class names tend to be more than one
%        character long, making for spread-out printing.  Values of 0
%        or 3 would be appropriate for making a graph (3 avoids the
%        tendency of some graph plotting software to produce labels in
%        minuscule font size).
%      }
%}
%\details{
%  For each of the classes, the calculation gets all the superclass
%  names from the class definition, and finds the edges in those classes'
%  definitions; that is, all the superclasses at distance 1.  The
%  corresponding elements of the adjacency matrix are set to 1.
%
%  The adjacency matrices for the individual class definitions are
%  merged.  Note two possible kinds of inconsistency, neither of which
%  should cause problems except possibly with identically named classes from
%  different packages.  Edges are computed from each superclass
%  definition, so that information overrides a possible inference from
%  extension elements with distance > 1 (and it should).  When
%  matrices from successive classes in the argument are merged, the
%  computations do not currently check for inconsistencies---this is
%  the area where possible multiple classes with the same name could
%  cause confusion.  A later revision may include consistency checks.
%}
%\value{
%  As described, a matrix with entries 0 or 1, non-zero values
%  indicating that the class corresponding to the column is a direct
%  superclass of the class corresponding to the row.  The row and
%  column names are the class names (without package slot).
%}
%
%
%\seealso{
%  \code{\link{extends}} and \linkS4class{classRepresentation} for the underlying information from the class
%  definition.
%}
%\examples{
%
%## the super- and subclasses of "standardGeneric"
%## and "derivedDefaultMethod"
%am <- classesToAM(list(class(show), class(getMethod(show))), TRUE)
%am
%
%\dontrun{
%## the following function depends on the Bioconductor package Rgraphviz
%plotInheritance <- function(classes, subclasses = FALSE, ...) {
%    if(!require("Rgraphviz", quietly=TRUE))
%      stop("Only implemented if Rgraphviz is available")
%    mm <- classesToAM(classes, subclasses)
%    classes <- rownames(mm); rownames(mm) <- colnames(mm)
%    graph <-  new("graphAM", mm, "directed", ...)
%    plot(graph)
%    cat("Key:\n", paste(abbreviate(classes), " = ", classes, ", ",
%        sep = ""),  sep = "", fill = TRUE)
%    invisible(graph)
%}
%
%## The plot of the class inheritance of the package "graph"
%require(graph)
%plotInheritance(getClasses("package:graph"))
%
%}
%}
%
%\keyword{classes}
%\keyword{programming}
%
%\encoding{UTF8}
%