% File src/library/methods/man/dotsMethods.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{dotsMethods}
%@%\alias{メソッドシグネチャ中のドット使用}	
\alias{dotsMethods}
\title{メソッドシグネチャ中の \code{...} の使用}
%\title{The Use of \code{...} in Method Signatures}
\description{
  \R 関数中の \dQuote{\dots} 引数は
  ゼロ，一つまたはそれ以上の実際の引数(つまり，オブジェクト)に
  マッチするという意味で特別に扱われる，
  \dQuote{\dots} を総称的関数のシグネチャとして認める
  機構が \R に加えられてきた．
  そうした関数に対して定義されたメソッドは
  \dQuote{\dots} にマッチする\emph{全ての}引数が
  指定されたクラス由来かそのクラスのサブクラス由来である時
  選択され呼び出される．
}

\section{シグネチャ中の "..." の使用}{
  \R のバージョン 2.8.0 以来，S4 メソッドが
  特殊引数 \dQuote{\dots} に対応する選択適用出来るようになった．
  現在 \dQuote{\dots} は他の形式的引数と混用は出来ない：
  総称的関数のシグネチャは
  \dQuote{\dots} だけか，または
  \dQuote{\dots} を含まないかである．
  (この制限は将来除かれるかもしれない．)

  適当な総称的関数をあたえた時，メソッドが
  通常のように \code{\link{setMethod}} の呼び出しで指定される．
  メソッド定義は
  \dQuote{\dots} に対応する全ての引数が
  メソッドシグネチャ中かまたはそのクラスを拡張するクラスからの
  ものと仮定して書かれるべきである
  (つまり，そのクラスのサブクラス)．

  典型的にはメソッドは
  \dQuote{\dots} を別の関数に引き渡すかまたは
  引数のリストを作りその上で繰り返す．下の例を見よ．

  一つより多い既存のクラスに対して適当な
  計算があるならば，便利なアプローチは
  \code{\link{setClassUnion}} の呼び出しを用いてこれらのクラスの
  合併クラスを定義することである．下の例を見よ．

}
\section{メソッド選択と "..." に対する選択適用}{
  一般的な議論は \link{Methods} を見よ．
  以下はそのドキュメントの
  \dQuote{メソッド選択と提供}節を読んでいることを前提としている．

  \dQuote{\dots} に関するメソッド選択は
  \code{\link{setMethod}} の呼び出し中の単一のクラスで指定される．
  もし \dQuote{\dots} の全ての実際の引数がこのクラスを持てば，
  対応するメソッドは直接選択される．

  さもなければ，各引数のクラスとそのクラスのスーパークラス
  が \dQuote{\dots} 引数の最初から始めて計算される．
  最初の引数に対しては適格なメソッドは任意のクラスに対するものである．
  引き続くそれまでに考慮されていないクラスを導入する
  各々の引数に対しては適格なメソッドは
  更に引数のクラスかスーパークラスにマッチするものに
  制限される．
  もし適格なクラスがそれ以上存在しなければ繰り返しは中断され，
  もし存在すれば，既定メソッドが選択される．

  繰り返しの最後で，
  一つまたはそれ以上のメソッドが適合するかもしれない．
  もし複数あれば，選択は実際の引数に最も距離が近いメソッドを探す．
  任意の継承メソッドはある距離に対応し，
  クラス定義の \code{contains} スロットから利用できる．
  同じクラスが一つ以上の引数に対して起こり得るので，
  それに伴う複数の距離が存在し得る．
  それらを結びつけるのは任意であることが避けられない：
  現在の計算は最少の距離を使う．
  従って，例えばもしあるメソッドが一つの引数に直接に，
  一つが最初の世代のスーパークラスにそして別のが
  二代目のスーパークラスにマッチすれば，距離は
  0, 1 そして 2 である．現在の選択計算はこのメソッドに対しては
  距離 0 を使う．特にこの選択基準は引数クラスの一つまたはそれ以上と
  正確にマッチするメソッドを使う傾向がある．

  通常のメソッド選択を使うのと同様に，同じ距離を持つ
  複数のメソッドが存在し得る．
  警告メッセージが出され
  メソッドの一つが選ばれる
  (最初に出会ったもの，これはこの場合かなり任意である)．

  計算は全ての引数を吟味するが，選択適用の本質的なコストは
  引数中の\emph{異なった}クラス数と共に上昇するが，
  引数の数が大きい時には引数の数より恐らくかなり小さくなることを注意する．
}

\section{実装の詳細}{
  \dQuote{\dots} に関するメソッド選択適用は \R の
  バージョン 2.8.0 で導入された．
  対応する選択と適用の最初の実装は
  新しい機構を研究中の間の融通性のため
  R 関数を用いてであった．
  この実装では
  \code{setGeneric} のローカルバージョンが総称的関数の環境中に
  挿入される．
  ローカルバージョンはメソッドを
  上の基準に従い選択され，そのメソッドを総称的関数の環境から
  呼び出す．
  これは
  \dQuote{\dots} が含まれていない時は C による実装により
  取られる挙動と少し異なる．
  必要な余分の計算時間を別として，
  C バージョンによって構成される特別な文脈
  (これは R コードでは正確には復元できない)とは異なり，
  メソッドは真の関数呼び出し中で評価される．
  しかしながら，異なった計算結果が得られたような状況は
  これまで遭遇していないし，
  非常にありそうもない．

  \dQuote{\dots} 以外の引数に対するメソッド選択適用は
  全てのメソッドのテーブル中で継承メソッドをソートすることで
  \emph{キャッシュ}され，そこではそれは
  実引数中のクラスの組み合わせを持つ次の選択に際して見出される．
  (しかし継承探索に対しては使われない)．
  \dQuote{\dots} に基づくメソッドもキャッシュされるが，
  しかし全くすぐには見つからない．
  注意されたように，選ばれたメソッドは
  \dQuote{\dots} 引数中に登場するクラスのセットにだけ依存する．
  これらのクラスの各々は一度もしくはそれ以上現れることが出来，
  実際の引数のクラスの多くの組み合わせが
  同じ実効的なシグネチャに対して登場する．
  選択の計算は先ず遭遇した異なったクラスを計算しソートする．
  これはメソッドのテーブル中にキャッシュされるラベルを与え，
  継承クラスの最初の生起後の更なる探索を避ける．
  \code{\link{showMethods}} への呼び出しは
  そうした継承メソッドを展示する．

  意図するところは
  \dQuote{\dots} 特性はそれらに対する十分な経験が得られた時に
  標準的 C コードに付け加えられるということである．
  同時に \dQuote{\dots} とシグネチャ中の他の引数の
  コンビネーションがサポートされるかもしれない．
}

\examples{
cc <- function(...)c(...)

setGeneric("cc")

setMethod("cc", "character", function(...)paste(...))

setClassUnion("Number", c("numeric", "complex"))

setMethod("cc", "Number", function(...) sum(...))

setClass("cdate", contains = "character", representation(date = "Date"))

setClass("vdate", contains = "vector", representation(date = "Date"))

cd1 <- new("cdate", "abcdef", date = Sys.Date())

cd2 <- new("vdate", "abcdef", date = Sys.Date())

stopifnot(identical(cc(letters, character(), cd1),
           paste(letters, character(), cd1))) # "character" メソッド

stopifnot(identical(cc(letters, character(), cd2),
                    c(letters, character(), cd2)))
# 既定，"vdate" は "character" を拡張しないから

stopifnot(identical(cc(1:10, 1+1i), sum(1:10, 1+1i))) # "Number" メソッド

stopifnot(identical(cc(1:10, 1+1i, TRUE), c(1:10, 1+1i, TRUE))) # 既定

stopifnot(identical(cc(), c())) # どの引数も既定メソッドを意味しない

setGeneric("numMax", function(...)standardGeneric("numMax"))

setMethod("numMax", "numeric", function(...)max(...))
# 複素数値データには使えない
setMethod("numMax", "Number", function(...) paste(...))
# 複素引数内では選択されるべきではない

stopifnot(identical(numMax(1:10, pi, 1+1i), paste(1:10, pi, 1+1i)))
stopifnot(identical(numMax(1:10, pi, 1), max(1:10, pi, 1)))

try(numMax(1:10, pi, TRUE)) # エラーになるべき：既定メソッドが無い

## paste() の総称的バージョン，"..." 引数に対して選択適用：
setGeneric("paste", signature = "...")

setMethod("paste", "Number", function(..., sep, collapse) c(...))

stopifnot(identical(paste(1:10, pi, 1), c(1:10, pi, 1)))

\dontshow{
for(gen in c("numMax", "cc", "paste")) removeGeneric(gen)
for(cl in c("Number", "vdate", "cdate")) removeClass(cl)
}
}

\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\seealso{
メソッドの一般的議論は
\link{Methods} とそこからのリンクを見よ．
}
\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/dotsMethods.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dotsMethods}
%\alias{dotsMethods}
%\title{The Use of \code{...} in Method Signatures}
%\description{
%  The \dQuote{\dots} argument in \R functions is treated specially, in that it
%  matches zero, one or more actual arguments (and so, objects).  A
%  mechanism has been added to \R to allow \dQuote{\dots} as the signature of a
%  generic function.  Methods defined for such functions will be
%  selected and called when \emph{all}  the arguments matching \dQuote{\dots}
%  are from the specified class or from some subclass of that class.
%}
%
%\section{Using "..." in a Signature}{
%  Beginning with version 2.8.0 of \R, S4 methods can be dispatched
%  (selected and called) corresponding to the special argument \dQuote{\dots}.
%  Currently, \dQuote{\dots} cannot be mixed with other formal arguments:
%  either the signature of the generic function is \dQuote{\dots} only, or it
%  does not contain \dQuote{\dots}.  (This restriction may be lifted in a future
%  version.)
%
%  Given a suitable generic function, methods are specified in the
%  usual way by a call to \code{\link{setMethod}}.  The method
%  definition must be written expecting all the arguments corresponding
%  to \dQuote{\dots} to be from the class specified in the method's signature,
%  or from a class that extends that class (i.e., a subclass of that
%  class).
%
%  Typically the methods will pass \dQuote{\dots} down to another function or
%  will create a list of the arguments and iterate over that.  See the
%  examples below.
%
%  When you have a computation that is suitable for more than one existing
%  class, a convenient approach may be to define a union of these
%  classes by a call to \code{\link{setClassUnion}}. See the example
%  below.
%
%}
%\section{Method Selection and Dispatch for "..."}{
%  See \link{Methods} for a general discussion.  The following assumes
%  you have read the \dQuote{Method Selection and Dispatch} section of
%  that documentation.
%
%  A method selecting on \dQuote{\dots} is specified by a single class in the
%  call to \code{\link{setMethod}}.  If all the actual arguments
%  corresponding to \dQuote{\dots} have this class, the corresponding method is
%  selected directly.
%
%  Otherwise, the class of each argument and that class' superclasses are
%  computed, beginning with the first \dQuote{\dots} argument.  For the first
%  argument, eligible methods are those for any of the classes.   For
%  each succeeding argument that introduces a class not considered previously, the eligible methods are further
%  restricted to those matching the argument's class or
%  superclasses. If no further eligible classes exist, the iteration
%  breaks out and the default method, if any, is selected.
%
%  At the end of the iteration, one or more methods may be eligible.
%  If more than one, the selection looks for the method with the least
%  distance to the actual arguments.  For each argument, any inherited
%  method corresponds to a distance, available from the \code{contains}
%  slot of the class definition.  Since the same class can arise for
%  more than one argument, there may be several distances associated
%  with it.  Combining them is inevitably arbitrary:  the current
%  computation uses the minimum distance.  Thus, for example, if a
%  method matched one argument directly, one as  first generation
%  superclass and another as a second generation superclass, the
%  distances are 0, 1 and 2.  The current selection computation would
%  use distance 0 for this
%  method.  In particular, this selection criterion tends to use a method that
%  matches exactly one or more of the arguments' class.
%
%  As with ordinary method selection, there may be multiple methods
%  with the same distance.  A warning  message is issued and one of the
%  methods is chosen (the first encountered, which in this case is
%  rather arbitrary).
%
%  Notice that, while the computation examines all arguments, the
%  essential cost of dispatch goes up with the number of
%  \emph{distinct} classes among the arguments, likely to be much
%  smaller than the number of arguments when the latter is large.
%
%}
%
%\section{Implementation Details}{
%  Methods dispatching on \dQuote{\dots} were introduced in version 2.8.0 of
%  \R.  The initial implementation of the corresponding selection and
%  dispatch is in an R function, for flexibility while the new
%  mechanism is being studied.  In this implementation, a local version
%  of \code{setGeneric} is inserted in the generic function's
%  environment.  The local version selects a method according to the
%  criteria above and calls that method, from the environment of the
%  generic function.  This is slightly different from the action taken
%  by the C implementation when \dQuote{\dots} is not involved.  Aside from the
%  extra computing time required, the method is evaluated in a true
%  function call, as opposed to the special context constructed by the
%  C version (which cannot be exactly replicated in R code.)  However,
%  situations in which different computational results would
%  be obtained have not been encountered so far, and seem very
%  unlikely.
%
%  Methods dispatching on arguments other than \dQuote{\dots} are \emph{cached} by storing
%  the inherited method in the table of all methods, where it will be
%  found on the next selection with the same combination of classes
%  in the actual arguments (but not used for inheritance searches).
%  Methods based on \dQuote{\dots} are also cached, but not found quite
%  as immediately.  As noted, the selected method depends only on the
%  set of classes that occur in the \dQuote{\dots} arguments.  Each of
%  these classes can appear one or more times, so many combinations of
%  actual argument classes will give rise to the same effective
%  signature.  The selection computation first computes and sorts the
%  distinct classes encountered.  This gives a label that will be
%  cached in the table of all methods, avoiding any further search for
%  inherited classes after the first occurrence.  A call to
%  \code{\link{showMethods}} will expose such inherited methods.
%
%  The intention is that the \dQuote{\dots} features will be added to the
%  standard C code when enough experience with them has been obtained.
%  It is possible that at the same time, combinations of \dQuote{\dots} with
%  other arguments in signatures may be supported.
%}
%
%\examples{
%cc <- function(...)c(...)
%
%setGeneric("cc")
%
%setMethod("cc", "character", function(...)paste(...))
%
%setClassUnion("Number", c("numeric", "complex"))
%
%setMethod("cc", "Number", function(...) sum(...))
%
%setClass("cdate", contains = "character", representation(date = "Date"))
%
%setClass("vdate", contains = "vector", representation(date = "Date"))
%
%cd1 <- new("cdate", "abcdef", date = Sys.Date())
%
%cd2 <- new("vdate", "abcdef", date = Sys.Date())
%
%stopifnot(identical(cc(letters, character(), cd1),
%           paste(letters, character(), cd1))) # the "character" method
%
%stopifnot(identical(cc(letters, character(), cd2),
%                    c(letters, character(), cd2)))
%# the default, because "vdate" doesn't extend "character"
%
%stopifnot(identical(cc(1:10, 1+1i), sum(1:10, 1+1i))) # the "Number" method
%
%stopifnot(identical(cc(1:10, 1+1i, TRUE), c(1:10, 1+1i, TRUE))) # the default
%
%stopifnot(identical(cc(), c())) # no arguments implies the default method
%
%setGeneric("numMax", function(...)standardGeneric("numMax"))
%
%setMethod("numMax", "numeric", function(...)max(...))
%# won't work for complex data
%setMethod("numMax", "Number", function(...) paste(...))
%# should not be selected w/o complex args
%
%stopifnot(identical(numMax(1:10, pi, 1+1i), paste(1:10, pi, 1+1i)))
%stopifnot(identical(numMax(1:10, pi, 1), max(1:10, pi, 1)))
%
%try(numMax(1:10, pi, TRUE)) # should be an error:  no default method
%
%## A generic version of paste(), dispatching on the "..." argument:
%setGeneric("paste", signature = "...")
%
%setMethod("paste", "Number", function(..., sep, collapse) c(...))
%
%stopifnot(identical(paste(1:10, pi, 1), c(1:10, pi, 1)))
%
%\dontshow{
%for(gen in c("numMax", "cc", "paste")) removeGeneric(gen)
%for(cl in c("Number", "vdate", "cdate")) removeClass(cl)
%}
%}
%
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{
%For the general discussion of methods, see  \link{Methods} and links
%from there.
%}
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%