% File src/library/methods/man/evalSource.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2010-2 R Core Team
% Distributed under GPL 2 or later

\name{evalSource}
%@%\alias{ソースファイルからの関数定義を使う}
\alias{evalSource}
\alias{insertSource}
\alias{sourceEnvironment-class}
\title{パッケージを再インストールせずにソースファイルからの関数定義を使う}
%\title{Use Function Definitions from a Source File without Reinstalling a Package}
\description{
ソースファイルからの関数 と/または メソッドの定義を
\code{\link{trace}} 機構を使いパッケージに挿入される．
典型的には，これは大きなパッケージを再インストールすること無しに
幾つかの関数の修正バージョンのテストやデバッグを許す．
}
\usage{
evalSource(source, package = "", lock = TRUE, cache = FALSE)

insertSource(source, package = "", functions = , methods = ,
           force = )

}
\arguments{
  \item{source}{
新しい関数とメソッド定義を見つけるために
\code{evalSource} により構文解析と評価がされるファイル．

\code{insertSource} への引数は
\code{evalSource} への先の呼び出しが返す
クラス \code{"sourceEnvironment"} のオブジェクトであって良い．
詳細はクラスに関する節を見よ．
}
  \item{package}{
オプションで，新しいコードが対応しその中にそれが挿入されるパッケージの
名前．もし欠損していればパッケージを推測することが試みられるが，
それを提供するのが安全なアプローチである．
検索パスに付加されていないパッケージの場合は，パッケージ名を
提供する必要がある．
}
  \item{functions, methods}{
オプションで，挿入に使われる関数名の文字列．
\code{functions} 引数に提供された名前はソース中に関数として
定義されていると期待されている．
\code{methods} 引数中に提供された名前に対して，
メソッドのテーブルが期待されている
(\code{\link{setMethod}} の呼び出しにより作られるような，
詳細節を見よ)；このテーブルからのメソッドは
\code{insertSource} により挿入される．
どちらのケースでも，改定された関数やメソッドは
ロードされた対応するパッケージ中のバージョンから
異なる時だけ挿入される．

もし \code{what} が省略されると，ソースファイルファイルの
評価の結果はパッケージの中身と比較される(詳細節を見よ)．
}
\item{lock, cache}{
\code{evalSource} により取られる行動を制御するオプションの
引数．
もし \code{lock} が \code{TRUE} ならば，返されるオブジェクト
中の環境はロックされ，従って全てのその拘束もロックされる．
もし \code{cache} が \code{FALSE} ならば，メソッドと
クラス定義の通常のキャッシュは
\code{source} ファイルの評価中は抑制される．

既定の設定が一般に推奨され，
ソースファイルのスナップショットとしての
オブジェクトの信憑性をサポートするために
\code{lock} し，そして次に
後でトレース機構を用い \code{insertSource} により
メソッド定義が挿入出来るようにする．
}
\item{force}{
もし \code{FALSE} なら，現在環境中にある関数だけが
\code{\link{trace}} を用い再定義される．
もし \code{TRUE} なら，他の
オブジェクト/関数は単純に付値される．
既定では，もし \code{functions} も \code{methods} 引数どちらも
提供されなければ \code{TRUE}．
}

}
\details{
\code{source} ファイルは構文解析され評価されるが，
既定ではメソッドとその中に含まれるクラス定義の
実際のキャッシュは抑制されるため，
関数とメソッドは逆転できるような仕方でテストできる．
もしすべてが上手くいけば，結果は
付値されたオブジェクトとソースファイル中の
メソッドとクラス定義に対応するメタデータを含む環境である．

この環境から，もしそれが持てばその名前空間中に，
現在のセッション中か
\code{\link{untrace}} の呼び出しでオリジナルのバージョンに戻すまで
使われるために，オブジェクトがパッケージに挿入される．
挿入は回復を可能にするため
\code{\link{trace}} の内部バージョンの呼び出しで行われる．

トレース機構が使われるため，関数タイプのオブジェクト，
関数自体か S4 メソッド，だけが挿入される．

\code{functions} と \code{methods} 引数が共に省略された時は，
\code{insertSource} は
\code{source} ファイルの評価結果から適当なオブジェクトを選択する．

全てのケースで，パッケージ中の対応するオブジェクトと
異なるソースファイル中のオブジェクトだけが
挿入される．\dQuote{differ} の定義は引数リスト
(既定の表現式を含む)か関数本体が同一ではないものである．
メソッドのケースでは，パッケージ中の対応するシグネチャ
に対する特定のメソッドを持たない必要がある：
比較はそのシグネチャに対して選択されるメソッドに対して行われる．

計算は提供されるソースファイルがオリジナルの
パッケージソース中と同じであることを何も必要がないが，
それがパッケージを改訂する時だけありそうでかつ意味を持つ．
計算ではソースファイルを比較しない：
\code{source} の評価で生成されたオブジェクトはオブジェクト
としてパッケージの中身と比較される．
}
\value{
クラス \code{"sourceEnvironment"} のオブジェクトで，
\code{"environment"} のサブクラス(クラスに関する節を見よ)．
環境はソースファイルの評価の結果である
\emph{全て}のオブジェクトを含む．
クラスは又生成時間，ソースファイルそしてパッケージ名
に対するスロットを持つ．
将来の拡張はこれらのオブジェクトをバージョン管理や
他のコードツールに対して使うかもしれない．

返されるオブジェクトはデバッグ中
(そのトピックに関する節を見よ)か
将来の \code{insertSource} への将来の呼び出し中の
\code{source} 引数として使うことが出来る．
もしある改訂された関数だけが最初の呼び出しで挿入
されていると，他は環境とオプションで適当な
\code{functions} そして/または \code{methods} 引数により，
ソースファイルを再評価すること無く後の呼び出し中で挿入できる．
}

\section{デバッグ}{
一旦 \code{insertSource} により関数かメソッドがパッケージ中に
挿入されてしまうと，それは標準のデバッグツールで
吟味できる；
例えば \code{\link{debug}} か
\code{\link{trace}} の様々なバージョン．

\code{\link{trace}} の呼び出しは追加の引数
\code{edit = env} を取るべきで，ここで \code{env} は
\code{evalSource} の呼び出しにより返される値である．
トレース機構が
ソースファイルからの改訂バージョンのインストールに
使われており，引数を提供すると
トレースされるのはオリジナルではなくこのバージョンであることが
確証される．下の例を見よ．

トーレースをオフにするがソースバージョンを維持するには，
例の中のように\cr
\code{trace(x, edit = env)} を使う．
パッケージからのオリジナルバージョンに戻るには
\code{untrace(x)} を使う．
}

\section{クラス {"sourceEnvironment"}}{% <-- cannot yet use \code{} inside \section{}
このクラスからのオブジェクトは，
関数と \code{evalSource} から生成されたメソッドのバージョンを取り出す
環境として扱うことが出来る．
オブジェクトはまた以下のスロットを持つ：
\describe{
\item{\code{packageName}:}{
    ソースコードが対応するパッケージの名前の文字列．
}
\item{\code{dateCreated}:}{
    ソースファイルが評価された日時
    (普通呼び出し \code{\link{Sys.time}} から)．
}
\item{\code{sourceFile}:}{
    使われたソースファイルの名前の文字列．
}
環境の使用は
\code{dateCreated} を変更しないことを注意する．
}
}

\seealso{
基礎にある機構については \code{\link{trace}}，
そして又少し似た目的に対して使われる \code{edit=} 引数；
伝統的なデバッグスタイルを志向するテクニックに対しては
この関数と又
\code{\link{debug}} と \code{\link{setBreakpoint}}．
現在の関数は既存パッケージに対するソースの幾つかを
修正するケースを直接に目指しているが，
同様にソースにデバッグコードを挿入することにも使える
(もし含まれるデバッグが自明ではない時より有用である)．
詳細節で述べられたように，ソースファイルはオリジナルのパッケージ
ソース中のものと同じである必要はない．
}
\examples{
\dontrun{
## パッケージ P0 がソースファイル "all.R" を持つと仮定する
## 先ずソースを評価し，それから summary() 用のメソッドの
## 改訂バージョンを挿入する
  env <- insertSource("./P0/R/all.R", package = "P0",
     methods = "summary")
## そしてソースからのバージョンをトレース
## してメソッドの一つをテストする
  trace("summary", signature = "myMat", browser, edit = env)
## テスト後に browser() 呼び出しを取り去るがソースは残す
  trace("summary", signature = "myMat", edit = env)
## そしてソースファイルを再評価せずに
## 全ての(他の)改訂した関数とメソッドを挿入する．
## パッケージ名はオブジェクトの env に含まれる．
  insertSource(env)
}
}
\keyword{ programming }
\keyword{methods }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/evalSource.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2010-2 R Core Team
%% Distributed under GPL 2 or later
%
%\name{evalSource}
%\alias{evalSource}
%\alias{insertSource}
%\alias{sourceEnvironment-class}
%\title{
%Use Function Definitions from a Source File without Reinstalling a Package
%}
%\description{
%Definitions of functions and/or methods from a source file are
%inserted into a package, using the \code{\link{trace}} mechanism.
%Typically, this allows testing or debugging modified versions of a few
%functions without reinstalling a large package.
%}
%\usage{
%evalSource(source, package = "", lock = TRUE, cache = FALSE)
%
%insertSource(source, package = "", functions = , methods = ,
%           force = )
%
%}
%\arguments{
%  \item{source}{
%A file to be parsed and evaluated by \code{evalSource} to find the new
%function and method definitions.
%
%The argument to \code{insertSource} can be an object of class \code{"sourceEnvironment"}
%returned from a previous call
%to \code{evalSource}   If a file name is passed to \code{insertSource}
%it calls \code{evalSource} to obtain the corresponding object.  See
%the section on the class for details.
%
%}
%  \item{package}{
%Optionally, the name of the package to which the new code corresponds
%and into which it will be
%inserted.  Although the computations will attempt to infer the package
%if it is omitted, the safe approach is to supply it.  In the case of a
%package that is not attached to the search list, the package name must
%be supplied.
%}
%  \item{functions, methods}{
%Optionally, the character-string names of the functions to be
%used in the insertion.  Names supplied in the \code{functions}
%argument are expected to be defined as functions in the source.
%For names supplied in the \code{methods} argument, a table of methods
%is expected (as generated by calls to \code{\link{setMethod}}, see the
%details section); methods from this table will be inserted by
%\code{insertSource}.  In both cases, the revised function or method is
%inserted only if it differs from the version in the corresponding
%package as loaded.
%
%If \code{what} is omitted, the results of evaluating the source file
%will be compared to the contents of the package (see the details section).
%}
%\item{lock, cache}{
%Optional arguments to control the actions taken by \code{evalSource}.
%If \code{lock} is \code{TRUE}, the environment in the object returned
%will be locked, and so will all its bindings.
%If \code{cache} is \code{FALSE}, the normal caching of method and
%class definitions will be suppressed during evaluation of the
%\code{source} file.
%
%The default settings are generally recommended, the \code{lock} to
%support the credibility of the object returned as a snapshot of the
%source file, and the second so that method definitions can be inserted
%later by \code{insertSource} using the trace mechanism.
%}
%\item{force}{
%If \code{FALSE}, only functions currently in the environment will be
%redefined, using \code{\link{trace}}.  If \code{TRUE}, other
%objects/functions will be simply assigned.  By default, \code{TRUE} if
%neither the \code{functions} nor the \code{methods} argument is supplied.
%}
%
%}
%\details{
%The \code{source} file is parsed and evaluated, suppressing by default
%the actual caching of method and class definitions contained in it, so
%that functions and methods can be tested out in a reversible way.
%The result, if all goes well, is an environment containing the
%assigned objects and metadata corresponding to method and class definitions
%in the source file.
%
%From this environment, the objects are inserted into the package, into
%its namespace if it has one, for use during the current session or
%until reverting to the original version by a call to
%\code{\link{untrace}}.
%The insertion is done by calls to the internal version of
%\code{\link{trace}}, to make reversion possible.
%
%Because the trace mechanism is used, only function-type objects will
%be inserted, functions themselves or S4 methods.
%
%When the \code{functions} and \code{methods} arguments are both
%omitted, \code{insertSource} selects all suitable objects from the
%result of evaluating the \code{source} file.
%
%In all cases,
%only objects in the source file that differ from
%the corresponding objects in the package are inserted.
%The definition of \dQuote{differ} is that either the argument list
%(including default expressions) or the body of the function is not
%identical.
%Note that in the case of a method, there need be no specific method
%for the corresponding signature in the package: the comparison is made
%to the method that would be selected for that signature.
%
%Nothing in the computation requires that the source file supplied be
%the same file as in the original package source, although that case is
%both likely and sensible if one is revising the package.  Nothing in
%the computations compares source files:  the objects generated by
%evaluating \code{source} are compared as objects to the content of the package.
%}
%\value{
%An object from class \code{"sourceEnvironment"}, a subclass of
%\code{"environment"} (see the section on the class)
%The environment contains the versions
%of \emph{all}  object resulting from evaluation of the source file.
%The class also has slots for the time of creation, the source file
%and the package name.
%Future extensions may use these objects for versioning or other code tools.
%
%
%The object returned can be used in debugging (see the section on that
%topic) or as the \code{source}
%argument in a future call to \code{insertSource}.  If only some of the
%revised functions were inserted in the first call, others can be
%inserted in a later call without re-evaluating the source file, by
%supplying the environment and optionally suitable \code{functions}
%and/or \code{methods} argument.
%}
%
%\section{Debugging}{
%Once a function or method has been inserted into a package by
%\code{insertSource}, it can be studied by the standard debugging tools;
%for example, \code{\link{debug}} or the various versions of
%\code{\link{trace}}.
%
%Calls to \code{\link{trace}} should take the extra argument \code{edit
%= env}, where \code{env} is the value returned by the call to
%\code{evalSource}.
%The trace mechanism has been used to install the revised version from
%the source file, and supplying the argument ensures that it is this
%version, not the original, that will be traced.  See the example
%below.
%
%To turn tracing off, but retain the source version, use \code{trace(x,
%edit = env)} as in the example.  To return to the original version
%from the package, use \code{untrace(x)}.
%}
%
%\section{Class {"sourceEnvironment"}}{% <-- cannot yet use \code{} inside \section{}
%Objects from this class can be treated as environments, to extract the
%version of functions and methods generated by \code{evalSource}.
%The objects also have the following slots:
%\describe{
%\item{\code{packageName}:}{ The character-string name of the package
%    to which the source code corresponds.
%}
%\item{\code{dateCreated}:}{ The date and time that the source file was
%    evaluated (usually from a call to \code{\link{Sys.time}}).
%}
%\item{\code{sourceFile}:}{ The character-string name of the source file
%    used.
%}
%Note that using the environment does not change the \code{dateCreated}.
%}
%}
%
%\seealso{
%\code{\link{trace}} for the underlying mechanism, and also for the
%\code{edit=} argument that can be used for somewhat similar purposes;
%that function and also \code{\link{debug}} and
%\code{\link{setBreakpoint}}, for techniques more oriented to
%traditional debugging styles.
%The present function is directly intended for the case that one is
%modifying some of the source for an existing package, although it can
%be used as well by inserting debugging code in the source (more useful
%if the debugging involved is non-trivial).  As noted in the details
%section, the source
%file need not be the same one in the original package source.
%}
%\examples{
%\dontrun{
%## Suppose package P0 has a source file "all.R"
%## First, evaluate the source, and from it
%## insert the revised version of methods for summary()
%  env <- insertSource("./P0/R/all.R", package = "P0",
%     methods = "summary")
%## now test one of the methods, tracing  the version from the source
%  trace("summary", signature = "myMat", browser, edit = env)
%## After testing, remove the browser() call but keep the source
%  trace("summary", signature = "myMat", edit = env)
%## Now insert all the (other) revised functions and methods
%## without re-evaluating the source file.
%## The package name is included in the object env.
%  insertSource(env)
%}
%}
%\keyword{ programming }
%\keyword{methods }
%
%\encoding{UTF8}
%