% File src/library/methods/man/findClass.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{findClass}
\title{クラスを用いた計算}
%\title{Computations with Classes}
\alias{removeClass}
%@%\alias{クラスを用いた計算}
\alias{resetClass}
\alias{isClass}
\alias{getClasses}
\alias{findClass}
\alias{sealClass}
\description{
  クラス定義を見つけ操作する関数．
}
\usage{
isClass(Class, formal=TRUE, where)

getClasses(where, inherits = missing(where))

findClass(Class, where, unique = "")

removeClass(Class, where,
            resolve.msg = getOption("removeClass.msg", default=TRUE))

resetClass(Class, classDef, where)

sealClass(Class, where)

}
\arguments{
  \item{Class}{
    クラス名の文字列．関数は普通
    文字列の代わりにクラス定義を取る．
    特定のパッケージ中で定義されたクラスに制限するには
    文字列の \code{\link{packageSlot}} を設定する．}
  \item{where}{
    その中で定義を修正したり削除する \code{\link{environment}}．
    既定では呼び出し関数のトプレベル環境
    (通常の計算に対しては大局的環境であるが，
    パッケージに対してはソース中のパッケージの環境下名前空間．)

    クラス定義を探索する際，
    \code{where} はどこで探すかを定義し，
    既定ではこの関数を呼び出したものの環境か
    名前空間から探す．
  }
  \item{formal}{
    形式的定義が必要かどうかをを指示する \code{\link{logical}}．}
  \item{unique}{
    もし \code{findClass} がクラスのユニークな位置を期待するならば，
    \code{unique} は探索の目的を説明する文字列
    (そして警告やエラーメッセージに使われる)．
    既定では，多重位置が可能で関数は常にリストを返す．
  }
  \item{inherits}{
    \code{getClasses} の呼び出し中で，
    返り値は \code{where} の全ての親環境を含むか，それとも
    その環境だけか?  
    既定ではもし \code{where} が省略されていれば \code{TRUE}
    で，さもなければ \code{FALSE}．
  }
  \item{resolve.msg}{
    もし \code{Class} が複数の名前空間に見つかり
    一つが選ばれるならば，\R がその決定を
    \code{\link{message}()} するかどうかを指示する
    \code{\link{logical}}．}
  \item{classDef}{
    \code{resetClass} に対して，オプションのクラス定義
    (しかし普通 \code{Class} はクラス定義で，
    \code{classDef}) を省略するほうが好ましい．
  }
}

\details{
  これらは形式的なクラス定義をテストし操作する関数である．
  以下に簡単な解説が与えられる．
  紹介とより詳細は参考文献を見よ．

  \describe{
    \item{\code{removeClass}:}{
      このクラスの定義を，もしこの引数が与えられていれば
      環境 \code{where} から取り除く；さもなければ
      \code{removeClass} は
      \code{removeClass} の呼び出しのトップレベル環境から初めて定義を探し，
      (最初に)見つかった定義を取り除く．
    }
    \item{\code{isClass}:}{
      これは形式的に定義されたクラスの名前か?
      (引数 \code{formal} は互換性のためにあり無視される．)
    }
    \item{\code{getClasses}:}{
      \code{where} について定義された全てのクラスの名前．
      もし引数無しで呼び出されると，
      呼び出し関数から可視の全てのクラス
      (もしトップレベルから呼び出されると，検索リスト上にある
      任意の環境中の凡てのクラス)．
      \code{inherits} 引数は特定の環境とその親を探索するのに
      使うことができるが，通常は既定の設定が希望するものである．
    }
    \item{\code{findClass}:}{
      \code{Class} のクラス定義が見つかる環境または検索リスト上の
      位置のリスト．
      もし \code{where} が提供されると，これは
      そこで探索が行われる環境
      (または名前空間)である；さもなければ
      呼び出しのトップレベルの環境が使われる．
      もし \code{unique} が文字列として提供されると，
      \code{findClass} は単一の環境下位置を返す．
      既定では，これは常にリストである．
      呼び出し関数は，例えば，最初の要素を
      \code{\link{get}} のような関数に対する位置や環境
      として選択すべきである．

      もし \code{unique} が文字列として提供されると，
      \code{findClass} はもし一つより多くの定義が可視なら
      警告を出す(呼び出しの目的を特定する文字列を使い)，
      そしてもし定義が見つからなければエラーを生成する．
    }
    \item{\code{resetClass}:}{
      クラスの内部定義をリセットする．
      クラスの完全な定義が
      \code{setClass} へのオリジナルな呼び出し中で指定された
      表現とスーパークラスから再計算される．

      この関数はクラス定義のアスペクトが
      変更された時に呼び出される．
      このクラスが拡張するクラスの定義を変更する場合は
      それを明示的に呼び出す必要がある．
      (しかしセッションの途中でそれを行うことは，
      既存のオブジェクトを不適切化するかもしれないので
      危険である)．
    }
    \item{\code{sealClass}:}{
      指定クラスの現在の定義をそれ以上の変更を防ぐために封印する．
      呼び出し \code{setClass} 中のクラスを封印することは可能であるが，
      時として更なる変更がなされる必要ががある
      (例えば \code{setIs} の呼び出しを用いて)．
      もしそうなら，全ての関連する変更がなされた後に
      \code{sealClass} を呼び出す．
    }
  }
}

\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョン．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョン．)
}
\seealso{
  \code{\link{setClassUnion}},
  \code{\link{Methods}},
  \code{\link{makeClassRepresentation}}
}
%% should add Examples section
\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/findClass.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{findClass}
%\title{Computations with Classes}
%\alias{removeClass}
%\alias{resetClass}
%\alias{isClass}
%\alias{getClasses}
%\alias{findClass}
%\alias{sealClass}
%\description{
%  Functions to find and manipulate class definitions.
%}
%\usage{
%isClass(Class, formal=TRUE, where)
%
%getClasses(where, inherits = missing(where))
%
%findClass(Class, where, unique = "")
%
%removeClass(Class, where,
%            resolve.msg = getOption("removeClass.msg", default=TRUE))
%
%resetClass(Class, classDef, where)
%
%sealClass(Class, where)
%
%}
%\arguments{
%  \item{Class}{character string name for the class.  The functions will
%    usually take a class definition instead of the string.  To restrict
%    the class to those defined in a particular package, set the
%    \code{\link{packageSlot}} of the character string.}
%  \item{where}{the \code{\link{environment}} in which to modify or
%    remove the definition.  Defaults to the top-level environment of the
%    calling function (the global environment for ordinary computations,
%    but the environment or namespace of a package in the source for a
%    package).
%
%    When searching for class definitions, \code{where} defines where to
%    do the search, and the default is to search from the top-level
%    environment or namespace of the caller to this function.
%  }
%  \item{formal}{\code{\link{logical}} indicating if a formal definition
%    is required.}
%  \item{unique}{if \code{findClass} expects a unique location for the
%    class, \code{unique} is a character string explaining the purpose
%    of the search (and is used in warning and error messages).  By
%    default, multiple locations are possible and the function always
%    returns a list.
%  }
%  \item{inherits}{in a call to \code{getClasses}, should the value
%    returned include all parent environments of \code{where}, or that
%    environment only?  Defaults to \code{TRUE} if \code{where} is
%    omitted, and to \code{FALSE} otherwise.
%  }
%  \item{resolve.msg}{\code{\link{logical}} indicating if \R should
%    \code{\link{message}()} its decision if \code{Class} is found in
%    multiple namespaces and one is chosen.}
%  \item{classDef}{ For \code{resetClass}, the optional class
%    definition (but usually it's better for \code{Class} to be the
%    class definition, and to omit \code{classDef}).
%  }
%}
%
%\details{
%  These are the functions that test and manipulate formal class
%  definitions.  Brief documentation is provided below.  See the
%  references for an introduction and for more details.
%
%  \describe{
%    \item{\code{removeClass}:}{
%      Remove the definition of this class, from the environment
%      \code{where} if this argument is supplied; if not,
%      \code{removeClass} will search for a definition, starting in the
%      top-level environment of the call to \code{removeClass}, and
%      remove the (first) definition found.
%    }
%    \item{\code{isClass}:}{
%      Is this the name of a formally defined class? (Argument
%      \code{formal} is for compatibility and is ignored.)
%    }
%    \item{\code{getClasses}:}{
%      The names of all the classes formally defined on \code{where}.  If
%      called with no argument, all the classes visible from the
%      calling function (if called from the top-level, all the classes
%      in any of the environments on the search list).  The
%      \code{inherits} argument can be used to search a particular
%      environment and all its parents, but usually the default setting
%      is what you want.
%    }
%    \item{\code{findClass}:}{
%      The list of environments or positions on the search list in
%      which a class definition of \code{Class} is found.  If
%      \code{where} is supplied, this is an environment (or namespace)
%      from which the search takes place; otherwise the top-level
%      environment of the caller is used.  If \code{unique} is supplied
%      as a character string, \code{findClass} returns a single
%      environment or position.  By default, it always returns a list.
%      The calling function should select, say, the first element as a
%      position or environment for functions such as \code{\link{get}}.
%
%      If \code{unique} is supplied as a character string,
%      \code{findClass} will warn if there is more than one definition
%      visible (using the string to identify the purpose of the call),
%      and will generate an error if no definition can be found.
%    }
%    \item{\code{resetClass}:}{
%      Reset the internal definition of a class.  Causes the complete
%      definition of the class to be re-computed, from the
%      representation and superclasses specified in the original
%      call to \code{setClass}.
%
%      This function is called when aspects of the class definition are
%      changed.  You would need to call it explicitly if you changed the
%      definition of a class that this class extends (but doing that in
%      the  middle of a session is living dangerously, since it may
%      invalidate existing objects).
%    }
%    \item{\code{sealClass}:}{ Seal the current definition of the specified
%      class, to prevent further changes.  It is possible to seal a class
%      in the call to \code{setClass}, but sometimes further changes have
%      to be made (e.g., by calls to \code{setIs}).  If so, call
%      \code{sealClass} after all the relevant changes have been made.
%    }
%  }
%}
%
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{
%  \code{\link{setClassUnion}},
%  \code{\link{Methods}},
%  \code{\link{makeClassRepresentation}}
%}
%%% should add Examples section
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%