% File src/library/methods/man/findMethods.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2008-2015 R Core Team
% Distributed under GPL 2 or later

\name{findMethods}
%@%\alias{メソッドの記述}
\alias{findMethods}
\alias{findMethodSignatures}
\alias{hasMethods}
\alias{getMethods}
\alias{listOfMethods-class}
\title{総称的関数に対して定義されたメソッドの記述}
%\title{Description of the Methods Defined for a Generic Function}
\description{
  関数 \code{findMethods} は総称的関数に対する
  テーブル中で定義されているメソッド
  (メソッドの選択に対して使われるような)を吟味や表示のために
  リストに変換する．リストは実際はクラス
  \code{listOfMethods} に由来する
  (下のクラスを説明する節を見よ)．

  リストはもし引数が提供されていれば
  環境 \code{where} 中で定義されたメソッドに限られ，
  そしてもし引数が提供されていれば
  メソッドシグネチャ中に一つまたはそれ以上の \code{classes}
  で指定されたで定義されたものを含むもメソッドに限られる．

  メソッド選択適用に対して使われる実際のテーブル
  (環境)を見るのは
  \code{\link{getMethodsForDispatch}} を呼び出す．
  \code{findMethods} が返すリストの名前はテーブル中の
  オブジェクトの名前である．

  関数 \code{findMethodSignatures} はその行が対応するメソッドの
  シグネチャからのクラス名がである文字列行列である；
  これは \code{findMethods} が返すリストからか，
  \code{findMethods} と同じ引数を与えてそうしたリスト自体を
  計算して操作する．

  関数は \code{hasMethods}
  \code{TRUE} か \code{FALSE} を，
  関数 \code{f} に対する空でないメソッドのテーブルが
  環境中にあるかまたは検索位置
  \code{where} 
  (またはもし \code{where} が欠損していれば一般的に総称的関数に対して)
  にあるかに応じて返す．

  既定関数 \code{getMethods} は
  \code{findMethods} に対するより古い代替物で，
  以前にメソッド選択適用に対して使われた
  クラス \code{MethodsList} のオブジェクトの形式の情報を返す．
  このオブジェクトのクラスは一般に廃止予定で
  将来の R のバージョンでは無くなるため，
  これは推奨できない．
}
\usage{
findMethods(f, where, classes = character(), inherited = FALSE,
      package = "")

findMethodSignatures(..., target = TRUE, methods = )

hasMethods(f, where, package)

## \code{table = FALSE} に対しては 2010 に廃止予定になり 2015 に廃止された
getMethods(f, where, table = FALSE)
}
\arguments{
  \item{f}{総称的関数またはそれの名前の文字列．}
  \item{where}{オプションで，メソッドのメタデータを探索する
    環境または検索リスト上の位置．

    もし \code{where} が欠損していると，\code{findMethods}
    は総称的関数自体中のメソッドの現在のテーブルを使い，
    そして \code{hasMethods} は検索リスト中の
    どこかのメタデータを探索する．
  }
  \item{table}{
      \code{getMethods} の呼び出し中で
      もし \code{TRUE} ならば返り値は
      選択適用に対して使われるテーブルであり，
      現在までに発見された継承メソッドを含む．
      内部的に使われるが，既定の結果は今は使われない
      \code{mlist} オブジェクトであるため，
      既定はいつか変更される可能性が高い．
    }
  \item{classes}{
    もし提供されると，シグネチャが提供されたクラスの少なくとも一つを
    含むメソッドだけが返される値に含まれる．}
  \item{inherited}{
    論理値フラグ；もし
    \code{TRUE} ならば，継承も直接定義されたものも全てのメソッド
    のテーブル使われる；さもなければ
    明示的に定義されたメソッドだけ．
    オプションの \code{TRUE} は
    \code{where} が欠損している時だけ意味がある．}

  \item{...}{
    \code{findMethodSignatures} の呼び出し中で，
    \code{findMethods} に与えられるかもしれない任意の引数．}
  \item{target}{
    \code{findMethodSignatures} へのオプションのフラグ；
    もし \code{TRUE} ならば，使われるシグネチャは
    目的のシグネチャである
    (メソッドがそれに対して選択されるクラス)；
    もし \code{FALSE} ならば，
    それらは定義されているシグネチャになる．
    違いは \code{inherited} が \code{TRUE} の時だけ意味を持つ．}
  \item{methods}{
    \code{findMethodSignatures} の呼び出し中では，オプションの
    メソッドリストで，おそらく
    先の \code{findMethods} の呼び出しにより返されたもの．
    もし欠損していれば，この関数は \dots 引数で呼び出される．}
  \item{package}{
    \code{hasMethods} の呼び出し中では，総称的関数に対する
    パッケージ名
    (例えばプリミティブ関数に対しては \code{"base"})．
    もし欠損していればこれは，もしあれば，関数名の
    \code{"package"} 属性か，または
    総称的関数のパッケージスロットからか推測される．
    \sQuote{Details} を見よ．}
}

\details{
  定義されたメソッドのテーブルを
  総称的関数か
  \code{where} で指定された環境中に保管されたメタデータオブジェクト
  から取得する．\code{getMethods} の呼び出し中では，テーブル中の情報
  は \code{table} 引数がある場合を除き，
  返り値を生成するために上で説明されたように変換される．

  他の関数と違い，\code{hasMethods} は
  この名前の総称的関数が現在見つからなくても使うことが出来る．
  この場合 \code{package} は引数として提供されるか，または
  パッケージ名はメソッドテーブルの特定化の一部であるので
  \code{f} の属性として含まれる．
 }

\section{メソッドのリストに対するクラス}{
クラス \code{"listOfMethods"} はメソッドを
メソッド定義の名前付きリストとして返す
(またはプリミティブ関数，下のスロットの解説を見よ)．
名前はそこからメソッドの選択適用が計算された環境中の
対応するオブジェクトの保管に使われた文字列である．
現在の実装はメソッドシグネチャ中の対応するクラスの名前を使い，
もしシグネチャ中に複数の引数が含まれていれば
\code{"#"} で分離される．
}

\section{スロット}{

  \describe{
    \item{\code{.Data}:}{
        クラス \code{"list"} のオブジェクト．メソッド定義．

  総称的関数はプリミティブ関数に対応するときは，
  これらはプリミティブ関数自体を既定メソッドとして含むかもしれないことを
   注意する．
  (基本的にプリミティブ関数は
   現在メソッド定義として拡張できない普通ではない
   R オブジェクトであるため．)
  他の情報を導くために返されたリストを使う計算は
  この可能性を考慮する必要がある．
  例えば \code{findMethodSignatures} の実装を見よ．
 }
    \item{\code{arguments}:}{
        クラス \code{"character"} のオブジェクト．総称的関数のシグネチャ
	中の形式的引数の名前．}
    \item{\code{signatures}:}{
      クラス \code{"list"} のオブジェクト．個別のメソッドの
      シグネチャのリスト．これは現在
      \code{names} を分離記号 \code{"#"} で分割した結果である．

  もしオブジェクトが
  \code{findMethods} により返された時のようにテーブルから構成されていれば，
  シグネチャは全て同じ長さを持つ．
  しかしながら，一般性のために文字列行列よりもリストが使われる．
  下の例のような \code{findMethodSignatures} の呼び出しは
  常に行列形式に変換する．}
    \item{\code{generic}:}{
        クラス \code{"genericFunction"} のオブジェクト．
        これらのメソッドに対応する総称的関数．
	このスロットを関数参照を許すように一般化する計画がある．}
    \item{\code{names}:}{
        クラス \code{"character"} のオブジェクト．
        注意された名前は
	\code{"#"} で分離されたクラス名である．}
  }
}
\section{拡張}{

クラス \code{"\linkS4class{namedList}"}，直接に．

クラス \code{"\linkS4class{list}"}，クラス \code{"namedList"}
を使い，距離 2．

クラス \code{"\linkS4class{vector}"}，クラス \code{"namedList"}
を使い，距離 3．
}


\seealso{ \code{\link{showMethods}}, \code{\link{selectMethod}}, \link{Methods} }
\examples{
mm <-  findMethods("Ops")
findMethodSignatures(methods = mm)
}
\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/findMethods.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2008-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{findMethods}
%\alias{findMethods}
%\alias{findMethodSignatures}
%\alias{hasMethods}
%\alias{getMethods}
%\alias{listOfMethods-class}
%\title{Description of the Methods Defined for a Generic Function}
%\description{
%  The function \code{findMethods} converts the methods defined in a table for a generic
%  function (as used for selection of methods) into a list, for study or
%  display.  The list is actually from the class \code{listOfMethods}
%  (see the section describing the class, below).
%
%
%  The list will be limited
%  to the methods defined in environment \code{where} if that argument is
%  supplied and limited to those including one or more of the
%  specified \code{classes} in the method signature if that argument is
%  supplied.
%
%To see the actual table (an environment) used
%  for methods dispatch, call \code{\link{getMethodsForDispatch}}.
%The names of the list returned by \code{findMethods} are the names of
%the objects in the table.
%
%  The function \code{findMethodSignatures} returns a character matrix
%  whose rows are the class names from the signature of the corresponding
%  methods; it operates either from a list returned by
%  \code{findMethods}, or by computing such a list itself, given the same
%  arguments as \code{findMethods} .
%
%  The function \code{hasMethods} returns \code{TRUE} or \code{FALSE}
%  according to whether there is a non-empty table of methods for
%  function \code{f} in the environment or search position \code{where}
%  (or for the generic function generally if \code{where} is missing).
%
%  The defunct function \code{getMethods} is an older alternative to
%  \code{findMethods} , returning information in the form of an object of
%  class \code{MethodsList}, previously used for method dispatch.  It is
%  not recommended, since this class of objects is deprecated generally
%  and will disappear in a future version of R.
%}
%\usage{
%findMethods(f, where, classes = character(), inherited = FALSE,
%      package = "")
%
%findMethodSignatures(..., target = TRUE, methods = )
%
%hasMethods(f, where, package)
%
%## Deprecated in 2010 and defunct in 2015 for \code{table = FALSE}:
%getMethods(f, where, table = FALSE)
%}
%\arguments{
%  \item{f}{A generic function or the character-string name of one.}
%  \item{where}{Optionally, an environment or position on the search list
%    to look for methods metadata.
%
%    If \code{where} is missing,  \code{findMethods} uses the current
%    table of methods in the generic function itself, and
%    \code{hasMethods} looks for metadata anywhere in the search list.
%  }
%  \item{table}{ If \code{TRUE} in a call to \code{getMethods} the
%      returned value is the table used for dispatch, including
%      inherited methods discovered to date.  Used internally, but
%      since the default result is the now unused \code{mlist} object,
%      the default will likely be changed at some point.
%    }
%  \item{classes}{If supplied, only methods whose signatures contain at
%    least one of the supplied classes will be included in the value
%    returned.}
%  \item{inherited}{Logical flag; if \code{TRUE}, the table of all
%    methods, inherited or defined directly, will be used; otherwise,
%    only the methods explicitly defined.  Option \code{TRUE} is
%    meaningful only if \code{where} is missing.}
%
%  \item{...}{In the call to \code{findMethodSignatures}, any arguments
%    that might be given to \code{findMethods}.}
%  \item{target}{Optional flag to \code{findMethodSignatures}; if
%    \code{TRUE}, the signatures used are the target signatures (the
%    classes for which the method will be selected); if \code{FALSE},
%    they will be the signatures are defined.  The difference is only
%    meaningful if \code{inherited} is \code{TRUE}.}
%  \item{methods}{In the call to \code{findMethodSignatures}, an optional
%    list of methods, presumably returned by a previous call to
%    \code{findMethods}.  If missing, that function will be call with the
%    \dots arguments.}
%
%  \item{package}{In a call to \code{hasMethods}, the package name for
%    the generic function (e.g., \code{"base"} for primitives).  If
%    missing this will be inferred either from the \code{"package"}
%    attribute of the function name, if any, or from the package slot of
%    the generic function.  See \sQuote{Details}.}
%}
%\details{
%
%  The functions obtain a table of the defined methods, either from the
%  generic function or from the stored metadata object in the environment
%  specified by \code{where}.  In a call to \code{getMethods}, the information in the table is converted
%  as described above to produce the returned value, except with the
%  \code{table} argument.
%
%
%  Note that \code{hasMethods}, but not the other functions, can be used
%  even if no generic function of this name is currently found.  In this
%  case \code{package} must either be supplied as an argument or included
%  as an attribute of \code{f}, since the package name is part of the
%  identification of the methods tables.
%
% }
%\section{The Class for lists of methods}{
%The class \code{"listOfMethods"} returns the methods as a named list
%of method definitions (or a primitive function, see the slot
%documentation below).  The names
%are the strings used to store the corresponding objects in the
%environment from which method dispatch is computed.
%The current implementation uses the names of the corresponding classes
%in the method signature, separated by \code{"#"} if more than one
%argument is involved in the signature.
%}
%\section{Slots}{
%
%  \describe{
%    \item{\code{.Data}:}{Object of class \code{"list"} The method
%        definitions.
%
% Note that these may include the primitive function
%  itself as  default method,
%  when the generic corresponds to a primitive. (Basically, because
%  primitive functions are abnormal R objects, which cannot currently be
%  extended as method definitions.) Computations that use the returned
%  list to derive other information need to take account of this
%  possibility. See the implementation of \code{findMethodSignatures}
%  for an example.
% }
%    \item{\code{arguments}:}{Object of class \code{"character"}.  The
%        names of the formal arguments in the signature of the generic function. }
%    \item{\code{signatures}:}{Object of class \code{"list"}. A list of
%      the signatures of the individual methods.  This is currently the
%    result of splitting the \code{names} according to the \code{"#"}
%    separator.
%
%  If the object has been constructed from a table, as when returned by
%\code{findMethods}, the signatures will all have the same length.
%However, a list rather than a character matrix is used for
%generality.  Calling \code{findMethodSignatures} as in the example
%below will always convert to the matrix form.}
%    \item{\code{generic}:}{Object of class \code{"genericFunction"}.
%        The generic function corresponding to these methods.  There
%        are plans to generalize this slot to allow reference to the function.}
%    \item{\code{names}:}{Object of class \code{"character"}.  The
%        names as noted are the class names separated by \code{"#"} .}
%  }
%}
%\section{Extends}{
%
%Class \code{"\linkS4class{namedList}"}, directly.
%
%Class \code{"\linkS4class{list}"}, by class \code{"namedList"}, distance 2.
%
%Class \code{"\linkS4class{vector}"}, by class \code{"namedList"}, distance 3.
%}
%
%
%\seealso{ \code{\link{showMethods}}, \code{\link{selectMethod}}, \link{Methods} }
%\examples{
%mm <-  findMethods("Ops")
%findMethodSignatures(methods = mm)
%}
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%