% File src/library/methods/man/fixPrevious.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{fixPre1.8}
%@%\alias{オブジェクトをフィックス}
\alias{fixPre1.8}
\title{バージョン 1.8 以前の R でセーブされたオブジェクトをフィックスする}
%\title{Fix Objects Saved from R Versions Previous to 1.8}
\description{
  バージョン 1.8.0 の Rからオブジェクトのクラスは
  クラスが定義されているパッケージの識別子を含んでいる．
  関数 \code{fixPre1.8} はこの情報を欠いているオブジェクトを
  フィックスし再付値する
  (典型的にそれらは以前のバージョンの R を用いて
  セーブされたファイルからロードされているため)．
}
\usage{
fixPre1.8(names, where)
}
\arguments{
  \item{names}{
    フィックスまたは再付値される全てのオブジェクトの名前の文字列ベクトル．}
\item{where}{
    オブジェクトとクラス定義をそこから探索する環境．
    既定では
    \code{fixPre1.8} 呼び出しのトップ環境で，関数が対話的に使われていれば
    大局的環境．}
}
\details{
 名前のオブジェクトがそれが見つかった場所に保存される．
 そのクラス属性は
  R 1.8 が要求する完全な形式に変更される；
  さもなければオブジェクトの内容は変更されるべきではない．

オブジェクトは以下の条件が成り立つ時だけフィックスされ再付値される：
\enumerate{
\item 名前のオブジェクトが存在する．
\item それは定義されたクラスからのものである
  (実際のクラス属性を持たない基本データタイプではない)．
\item オブジェクトは以前のバージョンの R からのものに見える．
\item クラスが現在定義されている．
\item オブジェクトは現在のクラス定義と一貫性がある．
}
二番目を除くどれかの条件が成り立たなければ警告が出る．

\code{fixPre1.8} は現在クラス属性中の変更\emph{だけ}をフィックスすることを
注意する．
特に，それは以前のバージョンの R でインストールされた
バイナリーバージョンのパッケージを，もしそれらが相容れない
特性をもっていてもフィックスしない．
そうしたパッケージはソースから再インストールされなければならず，
これは R のバージョンの主要な変更がされた場合は
常に賢明なアプローチである．

}
\value{
  実際は再付値された全てのオブジェクトの名前．
}
\keyword{classes}
\keyword{programming}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/fixPrevious.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{fixPre1.8}
%\alias{fixPre1.8}
%\title{Fix Objects Saved from R Versions Previous to 1.8}
%\description{
%  Beginning with R version 1.8.0, the class of an object contains the
%  identification of the package in which the class is defined.  The
%  function \code{fixPre1.8} fixes and re-assigns objects missing that information
%  (typically because they were loaded from a file saved with a previous
%  version of R.)
%}
%\usage{
%fixPre1.8(names, where)
%}
%\arguments{
%  \item{names}{ Character vector of the names of all the objects to be
%    fixed and re-assigned.}
%\item{where}{The environment from which to look for the objects, and
%    for class definitions.  Defaults to the top environment of the
%    call to \code{fixPre1.8}, the global environment if the function
%    is used interactively.}
%}
%\details{
% The named object will be saved where it was found.  Its class
%    attribute will be changed to the full form required by R 1.8;
%    otherwise, the contents of the object should be unchanged.
%
%Objects will be fixed and re-assigned only if all the following
%conditions hold:
%\enumerate{
%\item The named object exists.
%\item It is from a defined class (not a basic datatype which
%    has no actual class attribute).
%\item The object appears to be from an earlier version of R.
%\item The class is currently defined.
%\item The object is consistent with the current class definition.
%}
%If any condition except the second fails, a warning message is
%generated.
%
%Note that \code{fixPre1.8} currently fixes \emph{only} the change in
%class attributes.  In particular, it will not fix binary versions of
%packages installed with earlier versions of R if these use
%incompatible features.  Such packages must be re-installed from
%source, which is the wise approach always when major version changes
%occur in R.
%
%}
%\value{
%  The names of all the objects that were in fact re-assigned.
%}
%\keyword{classes}
%\keyword{programming}
%
%\encoding{UTF8}
%