% File src/library/methods/man/genericFunction-class.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{genericFunction-class}
\docType{class}
%@%\alias{総称的関数オブジェクト}
\alias{genericFunction-class}
\alias{groupGenericFunction-class}
\title{総称的関数オブジェクト}
%\title{Generic Function Objects }
\description{
  総称的関数(\code{genericFunction} を拡張するオブジェクト)は拡張された
  オブジェクトで，
  この関数に対してメソッドを作り選択適用するのに使われる情報を含む．
  それらはまた関数やメソッドに関連するパッケージを特定する．
}
\section{クラスからのオブジェクト}{
  総称的関数は
  \code{\link{setGeneric}} や \code{\link{setGroupGeneric}} により，
  して間接的に
  \code{\link{setMethod}} により作られ付値される．

  期待されるであろうように
  \code{\link{setGeneric}} と \code{\link{setGroupGeneric}} はそれぞれ
  クラス\cr
  \code{"genericFunction"}
  と \code{"groupGenericFunction"} の
  オブジェクトを作る．
}
\section{スロット}{
  \describe{
    \item{\code{.Data}:}{
        クラス \code{"function"} のオブジェクト．総称的関数の関数定義で
	，普通 \code{\link{standardGeneric}} の呼び出しとして自動的に作られる．}
    \item{\code{generic}:}{
        クラス \code{"character"} のオブジェクトで，総称的関数の名前．}
    \item{\code{package}:}{
        クラス \code{"character"} のオブジェクトで，
        関数定義が属するパッケージ名
        (そして必ずしも総称的関数が保存されている場所では\emph{無い})．
	もしパッケージが
	\code{setGeneric} の呼び出しで明示的に指定されないと，
	それは普通対応する非総称的な関数が存在するパッケージである．}
    \item{\code{group}:}{
        クラス \code{"list"} のオブジェクトで，この総称的関数が属する
	グループかグループ群．既定では空．}
    \item{\code{valueClass}:}{
        クラス \code{"character"} のオブジェクト；もし
	空の文字列でなければ，一つまたはそれ以上のクラスを特定する．
        この関数に対する全てのメソッドが
	これらのクラス(またはそれらを拡張するクラス)からのオブジェクトを返すことが保証する
	． }
    \item{\code{signature}:}{
        クラス
	\code{"character"} のオブジェクトで，この総称的関数に対する
	メソッドのシグネチャ中に登場できる形式的引数名のベクトル．
        既定ではこれは \dots に対するもの除く全ての形式的引数である．
        効率性のためには順序が肝要である：
	メソッドを指定する際に最も普通に使われる引数が
	最初に来るべきである．}
    \item{\code{default}:}{
        クラス\code{"optionalMethod"} のオブジェクト
        (クラス \code{"function"} と \code{"NULL"} の合併)で，
	もしあればこの関数に対する既定メソッドを含む．
        メソッドの選択適用の初期化するために自動的に生成され使われる．}
    \item{\code{skeleton}:}{
        クラス\code{"call"} のオブジェクトで，
	メソッドの選択適用で内部的に使われるスロット．
	それを直接使うことを期待しない．}
  }
}
\section{拡張}{
  クラス \code{"function"}，データ部分から．\cr
  クラス \code{"OptionalMethods"}，クラス \code{"function"} により．\cr
  クラス \code{"PossibleMethod"}，クラス \code{"function"} により．
}
\section{メソッド}{
  総称的関数オブジェクトは形式的メソッドを作り選択適用する際に使われる；
  オブジェクトからの情報はメソッドリストオブジェクトを作り，この
  総称的関数に対する既存のメソッドを併合し更新するのに使われる．
}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/genericFunction-class.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{genericFunction-class}
%\docType{class}
%\alias{genericFunction-class}
%\alias{groupGenericFunction-class}
%\title{Generic Function Objects }
%\description{
%  Generic functions (objects from or extending class
%  \code{genericFunction}) are extended function objects,
%  containing information used in creating and dispatching methods for
%  this function.  They also identify the package associated with the
%  function and its methods.
%}
%\section{Objects from the Class}{
%  Generic functions are created and assigned by
%  \code{\link{setGeneric}} or \code{\link{setGroupGeneric}} and, indirectly, by
%  \code{\link{setMethod}}.
%
%  As you might expect \code{\link{setGeneric}} and
%  \code{\link{setGroupGeneric}} create objects of class
%  \code{"genericFunction"} and \code{"groupGenericFunction"} respectively.
%}
%\section{Slots}{
%  \describe{
%    \item{\code{.Data}:}{Object of class \code{"function"}, the
%        function definition of the generic, usually created
%        automatically as a call to \code{\link{standardGeneric}}. }
%    \item{\code{generic}:}{Object of class \code{"character"}, the
%        name of the generic function. }
%    \item{\code{package}:}{Object of class \code{"character"}, the
%        name of the package to which the function definition belongs
%        (and \emph{not} necessarily where the generic function is
%        stored). If the package is not specified explicitly in the
%        call to \code{setGeneric}, it is usually the package on which
%        the corresponding non-generic function exists. }
%    \item{\code{group}:}{Object of class \code{"list"}, the group or
%        groups to which this generic function belongs.  Empty by default. }
%    \item{\code{valueClass}:}{Object of class \code{"character"}; if
%        not an empty character vector, identifies one or more classes.  It is
%        asserted that all methods for this function return objects
%        from these class (or from classes that extend them). }
%    \item{\code{signature}:}{Object of class \code{"character"}, the
%        vector of formal argument names that can appear in the
%        signature of methods for this generic function.  By default,
%        it is all the formal arguments, except for \dots.  Order
%        matters for efficiency:  the most commonly used arguments in
%        specifying methods should come first. }
%    \item{\code{default}:}{Object of class \code{"optionalMethod"}
%        (a union of classes \code{"function"} and \code{"NULL"}), containing
%        the default method for this function if any.  Generated
%        automatically and used to initialize method dispatch. }
%    \item{\code{skeleton}:}{Object of class \code{"call"}, a slot used
%        internally in method dispatch.  Don't expect to use it
%        directly.}
%  }
%}
%\section{Extends}{
%  Class \code{"function"}, from data part.\cr
%  Class \code{"OptionalMethods"}, by class \code{"function"}.\cr
%  Class \code{"PossibleMethod"}, by class \code{"function"}.
%}
%\section{Methods}{
%  Generic function objects are used in the creation and dispatch of
%  formal methods; information from the object is used to create methods
%  list objects and to merge or update the existing methods for this
%  generic.
%}
%\keyword{classes}
%
%\encoding{UTF8}
%