% File src/library/methods/man/getClass.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{getClass}
%@%\alias{クラス定義を得る}
\alias{getClass}
\alias{getClassDef}
\title{クラス定義を得る}
%\title{Get Class Definition }
\description{
  クラスの定義を得る．
}
\usage{
getClass   (Class, .Force = FALSE, where,
            resolve.msg = getOption("getClass.msg", default=TRUE))
getClassDef(Class, where, package, inherits = TRUE,
            resolve.msg = getOption("getClass.msg", default=TRUE))
}
\arguments{
  \item{Class}{
      クラス名の文字列で，しばしば下の
      \code{"package"} 属性を持つ．}
  \item{.Force}{
    もし \code{TRUE} ならばクラス名が未定義なら \code{NULL} を返す；
    さもなければ未定義のクラスはエラーになる．}
  \item{where}{
    定義の探索をそこから始める環境；既定ではトップレベルの環境
    (大局的環境)から始まり検索パスに沿って進行する．}
  \item{package}{
      定義を含むと主張されるパッケージの名前．
      もしこれが空でない文字列ならばクラスを探す最初の場所として
      \code{where} の代わりに使われる．
      パッケージはロードされていなければならないが付加されている
      必要はないことを注意する．既定では
      \code{Class} 引数のパッケージ属性がもしあれば使われる．
      もし \code{Class} があるオブジェクトに対する \code{class(x)}
      に由来すれば普通パッケージ属性がある．
    }
  \item{inherits}{
    論理値；クラス定義は任意の囲み環境と同様にキャッシュから
    検索されるべきか? もし \code{FALSE} ならば環境
    \code{where} 中の定義だけが返される．}
  \item{resolve.msg}{
    \code{Class} が複数の名前．中で見つかり一つが選択された時
    \R がその決定を \code{\link{message}()} すべきかどうかを指示する
    \code{\link{logical}}．}
}
\details{
  クラス定義はパッケージの名前空間かそれらが定義された他の
  環境中のメタデータオブジェクト中に保管される．
  パッケージがロードされた時，パッケージ中の
  クラス定義は内部テーブルにキャッシュされる．
  従って，\code{inherits} が \code{FALSE} でない限り
  \code{getClassDef} の殆どの呼び出しはキャッシュ中でクラスを見つけるか
  それを全く見つけることが出来ない．
  \code{inherits} が \code{FALSE} の場合は
  \code{package} か \code{where} で定義された環境だけが探索される．

  クラスのキャッシュは同じクラス名の別個の環境への多重定義を
  許すが，勿論パッケージ属性かパッケージ名が呼び出し中で
  与えられなければならないという制限付きである．

}
\value{
  クラスを定義するオブジェクト．
  もしクラス定義が見つからなければ \code{getClassDef} は \code{NULL}
  を返すが，\code{getClassDef} を呼び出す \code{getClass} は
  エラーを生成するか，もし
  \code{.Force} が \code{TRUE} ならばクラスに対する単純な定義を返す．
  後者の場合は内部的に使われるが，ユーザのコード中では典型的に
  無意味である．

  null でない値はクラス
  \code{\linkS4class{classRepresentation}} のオブジェクトである．
  全ての合理的な目的に対して，これを
  修正のためではなく情報の取り出しにだけ使うこと：
  クラス定義の作成や修正には関数
  \code{\link{setClass}} と \code{\link{setIs}} を使う．
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルな S4 バージョンに対して．)
}
\seealso{
  \link{Classes},
  \code{\link{setClass}},
  \code{\link{isClass}}.
}
\examples{
getClass("numeric") ## 組み込みクラス

cld <- getClass("thisIsAnUndefinedClass", .Force = TRUE)
cld ## NULL プロトタイプ
## もし本当に関心があれば：
utils::str(cld)
## これらはエラーを生成するものの：
try(getClass("thisIsAnUndefinedClass"))
try(getClassDef("thisIsAnUndefinedClass"))
}
\keyword{programming}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/getClass.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{getClass}
%\alias{getClass}
%\alias{getClassDef}
%\title{Get Class Definition }
%\description{
%  Get the definition of a class.
%}
%\usage{
%getClass   (Class, .Force = FALSE, where,
%            resolve.msg = getOption("getClass.msg", default=TRUE))
%getClassDef(Class, where, package, inherits = TRUE,
%            resolve.msg = getOption("getClass.msg", default=TRUE))
%}
%\arguments{
%  \item{Class}{ the character-string name of the class, often with a
%      \code{"package"} attribute as noted below under \code{package}.}
%  \item{.Force}{ if \code{TRUE}, return \code{NULL} if the class is
%    undefined; otherwise, an undefined class results in an error.}
%  \item{where}{ environment from which to begin the search for the definition; by default,
%    start at the top-level (global) environment and proceed through
%    the search list.}
%  \item{package}{ the name of the package asserted to hold the
%      definition.  If it is a non-empty string it is used instead of
%      \code{where}, as the first place to look for the class.
%      Note that the package must be loaded but need not be attached.  By
%      default, the package attribute of the \code{Class} argument is
%      used, if any.  There will usually be a package attribute if
%      \code{Class} comes from \code{class(x)} for some object.
%    }
%  \item{inherits}{logical; should the class definition be retrieved from
%    any enclosing environment and also from the cache?  If \code{FALSE}
%    only a definition in the environment \code{where} will be returned.}
%  \item{resolve.msg}{\code{\link{logical}} indicating if \R should
%    \code{\link{message}()} its decision if \code{Class} is found in
%    multiple namespaces and one is chosen.}
%}
%\details{
%  Class definitions are stored in metadata objects in a package
%  namespace or other environment where they are defined.  When
%  packages are loaded, the class definitions in the package are cached in an internal
%  table.  Therefore, most calls to \code{getClassDef} will find the
%  class in the cache or fail to find it at all, unless \code{inherits}
%  is \code{FALSE}, in which case only the environment(s) defined by
%  \code{package} or \code{where} are searched.
%
%  The class cache allows for multiple definitions of the
%  same class name in separate environments, with of course the
%  limitation that the package attribute or package name must be
%  provided in the call to
%
%}
%\value{
%  The object defining the class. If the class definition is not found,
%  \code{getClassDef} returns \code{NULL}, while \code{getClass}, which
%  calls \code{getClassDef}, either generates an error or, if
%  \code{.Force} is \code{TRUE}, returns a simple definition for the
%  class.  The latter case is used internally, but is not typically
%  sensible in user code.
%
%  The non-null returned value is an object of class
%  \code{\linkS4class{classRepresentation}}.  For all reasonable
%  purposes, use this object only to extract information, rather than trying
%  to modify it: Use functions such as \code{\link{setClass}} and
%  \code{\link{setIs}} to create or modify class definitions.
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{
%  \link{Classes},
%  \code{\link{setClass}},
%  \code{\link{isClass}}.
%}
%\examples{
%getClass("numeric") ## a built in class
%
%cld <- getClass("thisIsAnUndefinedClass", .Force = TRUE)
%cld ## a NULL prototype
%## If you are really curious:
%utils::str(cld)
%## Whereas these generate errors:
%try(getClass("thisIsAnUndefinedClass"))
%try(getClassDef("thisIsAnUndefinedClass"))
%}
%\keyword{programming}
%\keyword{classes}
%
%\encoding{UTF8}
%