% File src/library/methods/man/getMethod.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{getMethod}
%@%\alias{メソッド定義の獲得とテスト}
\alias{getMethod}
\alias{findMethod}
\alias{existsMethod}
\alias{selectMethod}
\alias{hasMethod}
\title{メソッド定義を得る，テストする}
%\title{ Get or Test for the Definition of a Method }
\description{
  与えられた総称的関数とシグネチャに対応するメソッドを探す関数．
  関数
  \code{getMethod} と \code{selectMethod} はメソッドを返す；関数
  \code{existsMethod} と \code{hasMethod} はその存在をテストする．
  どちらのケースも最初の関数は直接の定義だけを受け入れ，そして
  二番目は継承を用いる．
  全てのケースで，探索は総称的関数自体中か
  引数 \code{where} で指定されるパッケージ/環境中で行われる．

  関数
  \code{findMethod} はこの関数とシグネチャに対するメソッドを含む検索パス
  (もしくは引数 \code{where} で指定されるパッケージ) 中のパッケージを返す．
}
\usage{
getMethod(f, signature=character(), where, optional = FALSE,
          mlist, fdef)

existsMethod(f, signature = character(), where)

findMethod(f, signature, where)

selectMethod(f, signature, optional = FALSE, useInherited =,
             mlist = , fdef = , verbose = , doCache = )

hasMethod(f, signature=character(), where)

}
\arguments{
  \item{f}{総称的関数またはその文字列名．}
  \item{signature}{
    引数 \code{f} にマッチするクラスのシグネチャ．下の詳細を見よ．
  }
  \item{where}{メソッドを探す位置または環境：
    既定では総称的関数自体中に定義されたメソッドのテーブルが
    使われる．}

  \item{optional}{
    もし
    \code{selectMethod} 中の選択が適正なメソッドを見つけられなければ
    この引数が \code{TRUE} で無い限りエラーが生じる．その場合，
    如何なるメソッドもマッチしなければ
    \code{NULL} が返される．}
  \item{mlist, fdef, useInherited, verbose, doCache}{
      内部的に使われる \code{getMethod} と \code{selectMethod} への
      オプションの引数．これらは避けたほうが良い：
      あるものは期待通りに動作するがしないものもあり，
      どれもが関数の普通の使用では必要とされない．
    }

}
\details{
  引数 \code{signature} は総称的関数の形式的引数に対応するクラスを指定する；
    正確に言えば，総称的関数の
    \code{signature} スロットに対応するもの．
    引数はクラスを特定する文字列ベクトルであってよく，名前付きでも
    無しでも良い．
    もし提供されれば名前は総称的関数のシグネチャ中に含まれる
    形式的引数の名前にマッチする．
    このシグネチャは普通 \dots を除く全ての引数である．
    しかしながら，総称的関数は許される引数のサブセットだけ，
    または異なった順序で取った引数を用いて指定することが出来る．

    もしそのシグネチャに対して何か特別なことを行う総称的関数を
    扱っているのならば，混乱を避けるためにシグネチャ中の引数に名前を
    付けることは良いアイデアである．
    どんな場合も，シグネチャ中の要素は
    関数呼び出し中の引数マッチング中で使われるのと
    同じ規則で形式的シグネチャにマッチされる
    (\code{\link{match.call}} を見よ)．

    シグネチャ中の文字列はクラス名，
    \code{"missing"} または \code{"ANY"} であって良い．
    メソッド選択におけるこれらの意味については \link{Methods} を見よ．
    シグネチャ中で提供されない引数は暗黙のうちに
    クラス \code{"ANY"} に対応する；特に，
    空のシグネチャを与えることは既定メソッドを
    探すことを意味する．

  \code{getMethod} の呼び出しは特定の関数とシグネチャに対するメソッドを
  返す．他の \code{get} 関数と同様に，
  引数 \code{where} は関数がどこを探すか
  (既定では検索リストのあらゆる所)を制御し，引数 \code{optional}
  はもしメソッドが見つからない時
  \code{NULL} を返すかエラーを発生するかを制御する．メソッドの探索は
  継承を利用しない．

  関数
  \code{selectMethod} は又関数とシグネチャを与えてメソッドを探すが，
  メソッド選択適用機構の完全な利用を行う，つまり
  対応するシグネチャに対する選択適用に於けるように継承メソッドと
  グループ総称的関数を考慮するが，条件付き継承は使われない．
  \code{getMethod} と同様に，\code{selectMethod}
  はもしメソッドが見つからなければ，
  引数 \code{optional} に依存して，
  \code{NULL} を返すかエラーを生成する．
  
  関数 \code{existsMethod} と \code{hasMethod} はメソッドが見つかるか否かで
  \code{TRUE} か \code{FALSE} を返し，
  最初は \code{getMethod} に対応し(継承無し)二番目は
  \code{selectMethod} に対応する．

}
\value{
  \code{selectMethod} または \code{getMethod} の呼び出しは，
  もし見つかれば選択されたメソッドを返す．
  (このクラスは \code{function} を拡張するため，結果が希望するものであれば
  関数を直接に使うことが出来る．)
  さもなければ，もし
  \code{optional} が \code{FALSE} ならばエラーが発生し，そして
  もし \code{optional} が \code{TRUE} ならば \code{NULL} が返される．

  返されるメソッドオブジェクトは
  プリミティブ関数に対する既定メソッドがそれ自体プリミティブであることが
  必要で\emph{無い限り}
  \code{\linkS4class{MethodDefinition}} オブジェクトである．
  従って検索の失敗に対する唯一の信頼できるテストは
  \code{is.null()} である．

}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\seealso{
  メソッドの選択適用の詳細は \code{\link{Methods}}；
  メソッドと総称的関数オブジェクトを操作する
  他の関数については \code{\link{GenericFunctions}}；
  メソッド定義を表現するクラスについては
  \code{\linkS4class{MethodDefinition}}．}
\examples{
setGeneric("testFun", function(x)standardGeneric("testFun"))
setMethod("testFun", "numeric", function(x)x+1)
hasMethod("testFun", "numeric")
\dontrun{[1] TRUE}
hasMethod("testFun", "integer") #継承
\dontrun{[1] TRUE}
existsMethod("testFun", "integer")
\dontrun{[1] FALSE}
hasMethod("testFun") # 既定メソッド
\dontrun{[1] FALSE}
hasMethod("testFun", "ANY")
\dontrun{[1] FALSE}
\dontshow{
stopifnot(isGeneric("testFun"),
          hasMethod("testFun", "numeric"),
          hasMethod("testFun", "integer"),
          !existsMethod("testFun", "integer"),
          !hasMethod("testFun"),
          !hasMethod("testFun", "ANY") )
removeGeneric("testFun")
}
}
\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/getMethod.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{getMethod}
%\alias{getMethod}
%\alias{findMethod}
%\alias{existsMethod}
%\alias{selectMethod}
%\alias{hasMethod}
%\title{ Get or Test for the Definition of a Method }
%\description{
%  Functions to look for a method corresponding to a given generic function and signature.
%  The functions \code{getMethod} and \code{selectMethod} return the method; the functions
%  \code{existsMethod} and \code{hasMethod} test for its existence.  In both
%  cases the first function only gets direct definitions and the second
%  uses inheritance.  In all cases, the search is in the generic function itself or in
%  the package/environment specified by argument \code{where}.
%
%  The function \code{findMethod} returns the package(s) in the search
%  list (or in the packages specified by the \code{where} argument) that
%  contain a method for this function and signature.
%}
%\usage{
%getMethod(f, signature=character(), where, optional = FALSE,
%          mlist, fdef)
%
%existsMethod(f, signature = character(), where)
%
%findMethod(f, signature, where)
%
%selectMethod(f, signature, optional = FALSE, useInherited =,
%             mlist = , fdef = , verbose = , doCache = )
%
%hasMethod(f, signature=character(), where)
%
%}
%\arguments{
%  \item{f}{A  generic function or the character-string name of one.}
%  \item{signature}{the signature of classes to match to the arguments
%    of \code{f}.  See the details below.
%
%  }
%  \item{where}{The position or environment in which to look for the
%    method(s):  by default, the table of methods defined in the generic function itself is used.}
%
%  \item{optional}{If the selection in \code{selectMethod} does not find a valid method
%    an error is generated, unless this argument is \code{TRUE}.  In that
%    case, the value returned is \code{NULL} if no method matches.}
%  \item{mlist, fdef, useInherited, verbose, doCache}{Optional
%      arguments  to  \code{getMethod} and \code{selectMethod} for
%      internal use.  Avoid
%      these: some will work as expected and others will not, and none of them is required for normal use of the functions.
%    }
%
%}
%\details{
%  The \code{signature} argument specifies classes, corresponding to formal arguments of the generic function; to be precise, to the \code{signature} slot of the generic function object.
%    The argument may be a vector of strings identifying
%    classes, and may be named or not.  Names, if supplied, match the
%    names of those formal arguments included in the signature of the
%    generic.  That signature is normally all the arguments except
%    \dots.  However, generic functions can be specified with only a
%    subset of the arguments permitted, or with the signature taking
%    the arguments in a different order.
%
%    It's a good idea to name the arguments in the signature to avoid
%    confusion, if you're dealing with a generic that does something
%    special with its signature.   In any case, the elements of the
%    signature are matched to the formal signature by the same rules
%    used in matching arguments in function calls (see
%    \code{\link{match.call}}).
%
%    The strings in the signature may be class names, \code{"missing"}
%    or \code{"ANY"}.  See \link{Methods} for the meaning of these in
%    method selection.  Arguments not supplied in the signature
%    implicitly correspond to class \code{"ANY"}; in particular, giving
%    an empty signature means to look for the default method.
%
%  A call to \code{getMethod} returns the method for a particular
%  function and signature.  As with other \code{get} functions,
%  argument \code{where} controls where the function looks (by default
%  anywhere in the search list) and argument \code{optional} controls
%  whether the function returns \code{NULL} or generates an error if
%  the method is not found.  The search for the method makes no use of
%  inheritance.
%
%  The function \code{selectMethod} also looks for a method given the
%  function and signature, but makes full use of the method dispatch
%  mechanism; i.e., inherited methods and group generics are taken into
%  account just as they would be in dispatching a method for the
%  corresponding signature, with the one exception that conditional
%  inheritance is not used.  Like \code{getMethod}, \code{selectMethod}
%  returns \code{NULL} or generates an error if
%  the method is not found, depending on the argument \code{optional}.
%
%  The functions \code{existsMethod} and \code{hasMethod} return
%  \code{TRUE} or \code{FALSE} according to whether a method is found,
%  the first corresponding to \code{getMethod} (no inheritance) and the
%  second to \code{selectMethod}.
%
%}
%\value{
%  The call to \code{selectMethod} or \code{getMethod} returns  the selected method, if
% one is found.
%  (This class extends \code{function}, so you can use the result
%  directly as a function if that is what you want.)
%  Otherwise an error is thrown if \code{optional} is \code{FALSE}  and  \code{NULL} is returned if
%  \code{optional} is \code{TRUE}.
%
%The returned method object is a
%  \code{\linkS4class{MethodDefinition}} object, \emph{except} that the default method for a primitive function is required to be the primitive itself.
%Note therefore that the only reliable test that the search failed is \code{is.null()}.
%
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{\code{\link{Methods}} for the details of method
%  selection; \code{\link{GenericFunctions}} for other functions
%  manipulating methods and generic function objects;
%  \code{\linkS4class{MethodDefinition}} for the class that represents
%  method definitions.}
%\examples{
%setGeneric("testFun", function(x)standardGeneric("testFun"))
%setMethod("testFun", "numeric", function(x)x+1)
%hasMethod("testFun", "numeric")
%\dontrun{[1] TRUE}
%hasMethod("testFun", "integer") #inherited
%\dontrun{[1] TRUE}
%existsMethod("testFun", "integer")
%\dontrun{[1] FALSE}
%hasMethod("testFun") # default method
%\dontrun{[1] FALSE}
%hasMethod("testFun", "ANY")
%\dontrun{[1] FALSE}
%\dontshow{
%stopifnot(isGeneric("testFun"),
%          hasMethod("testFun", "numeric"),
%          hasMethod("testFun", "integer"),
%          !existsMethod("testFun", "integer"),
%          !hasMethod("testFun"),
%          !hasMethod("testFun", "ANY") )
%removeGeneric("testFun")
%}
%}
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%