% File src/library/methods/man/getPackageName.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{getPackageName}
%@%\alias{パッケージに関連する名前}
\alias{getPackageName}
\alias{setPackageName}
\alias{packageSlot}
\alias{packageSlot<-}
\title{与えられたパッケージに関連する名前}
%\title{The Name associated with a Given Package}
\description{
  下の関数は特定の環境か検索リスト上の位置に関連するパッケージか，
  または特定の関数を含むパッケージのパッケージを作る．
  これらは主として複数パッケージ上のオブジェクトを
  区別するために必要な計算をサポートするために使われる．
}
\usage{
getPackageName(where, create = TRUE)
setPackageName(pkg, env)

packageSlot(object)
packageSlot(object) <- value
}
\arguments{
  \item{where}{
    希望のパッケージに関連する環境または検索リスト上の位置．}
  \item{object}{
    文字列名を与えるオブジェクト，プラスオブジェクトが存在するパッケージ．}
  \item{value}{パッケージ名．}
   \item{create}{
     フラグ，もし推測できなければパッケージ名を作るか?
     もし \code{TRUE} で空でないパッケージ名が見つからなければ，
     現在の日付と時間がパッケージ名に使われ，
     そして警告が出る．
     もし環境がロックされていなければ作られた名前は環境中に保管される．}
  \item{pkg, env}{
    \code{pkg} 中の文字列を
    環境 \code{env} 中のクラスとメソッド定義を設定する全ての
    計算に対する内部パッケージ名にする．}
}
\details{
  パッケージ名は普通パッケージのロード中に
  \link{INSTALL} スクリプトか \code{\link{library}} 関数により
  インストールされる．
  (現在，名前は \code{.packageName} オブジェクトとして保存されるが
  将来の保証はない．)
}
\value{
  \code{getPackageName} はパッケージの文字列名を返す
  (検索リスト中で見つかった余分の \code{"package:"} 無しで)．

  \code{packageSlot} はパッケージの名前スロットを返す，または設定する
  (現在属性で形式的なスロットではないがいつか変更されるかもしれない)．

  \code{setPackageName} は
  さもなければパッケージ名を持たない環境中にパッケージ名を
  確立するのに使うことが出来る．
  これは任意の環境中にクラス/メソッドを
  作るのを許すが，しかし普通は
  標準的な \R のプログラミングツール
  (\code{\link{package.skeleton}} 等)でパッケージを作るのが好ましい．
}

\seealso{ \code{\link{search}}, \code{\link{packageName}} }

\examples{
## 次の全ては普通 "base" を返す
getPackageName(length(search()))
getPackageName(baseenv())
getPackageName(asNamespace("base"))
getPackageName("package:base")

}
\keyword{ programming }% at least one, from doc/KEYWORDS

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/getPackageName.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{getPackageName}
%\alias{getPackageName}
%\alias{setPackageName}
%\alias{packageSlot}
%\alias{packageSlot<-}
%\title{The Name associated with a Given Package}
%\description{
%  The functions below produce the package associated with a particular
%  environment or position on the search list, or of the package
%  containing a particular function.  They are primarily used to support
%  computations that need to differentiate objects on multiple packages.
%}
%\usage{
%getPackageName(where, create = TRUE)
%setPackageName(pkg, env)
%
%packageSlot(object)
%packageSlot(object) <- value
%}
%\arguments{
%  \item{where}{the environment or position on the search list
%    associated with the desired package.}
%  \item{object}{object providing a character string name, plus the
%    package in which this object is to be found.}
%  \item{value}{the name of the package.}
%   \item{create}{flag, should a package name be created if none can be
%     inferred?  If \code{TRUE} and no non-empty package name is found,
%     the current date and time are used as a package name, and a
%     warning is issued. The created name is stored in the environment
%     if that environment is not locked.}
%  \item{pkg, env}{make the string in \code{pkg} the internal
%    package name for all computations that set class and method
%    definitions in environment \code{env}.}
%}
%\details{
%  Package names are normally installed during loading of the package,
%  by the \link{INSTALL} script or by the \code{\link{library}}
%  function.  (Currently, the name is stored as the object
%  \code{.packageName} but don't trust this for the future.)
%}
%\value{
%  \code{getPackageName} returns the character-string name of the package
%  (without the extraneous \code{"package:"} found in the search list).
%
%  \code{packageSlot} returns or sets the package name slot (currently
%  an attribute, not a formal slot, but this may change someday).
%
%  \code{setPackageName} can be used to establish a package name in an
%  environment that would otherwise not have one.  This
%  allows you to create classes and/or methods in an arbitrary
%  environment, but it is usually preferable to create packages by the
%  standard \R programming tools (\code{\link{package.skeleton}}, etc.)
%}
%
%\seealso{ \code{\link{search}}, \code{\link{packageName}} }
%
%\examples{
%## all the following usually return "base"
%getPackageName(length(search()))
%getPackageName(baseenv())
%getPackageName(asNamespace("base"))
%getPackageName("package:base")
%
%}
%\keyword{ programming }% at least one, from doc/KEYWORDS
%
%\encoding{UTF8}
%