% File src/library/methods/man/hasArg.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{hasArg}
%@%\alias{呼び出し中の引数を探す}
\alias{hasArg}
\title{呼び出し中の引数を探す}
%\title{Look for an Argument in the Call}
\description{
  もし \code{name} が呼び出し中の引数，
  関数への形式的引数かまたは \code{...} の成分， 
  に対応すれば \code{TRUE} を，
  そしてさもなければ \code{FALSE} を返す．
}
\usage{
hasArg(name)
}
\arguments{
  \item{name}{
    引用化されていない名前か文字列としての可能な引数の名前．}
}
\details{
  例えば 表現式 \code{hasArg(x)} は二つの例外を次の除いて
  \code{!missing(x)} に似ている．
  先ず \code{hasArg} は \code{x} が呼び出し関数の形式的引数ではないが
  \code{...} のそれであれば名前が \code{x} の引数を探す．次に
  \code{hasArg} はもし名前を引数として与えられれば決してエラーを
  発生しないが \code{missing(x)} は
  \code{x} が形式的引数でなければエラーを発生する．
}
\value{
  上で説明されたように常に \code{TRUE} か \code{FALSE}．
}
\seealso{ \code{\link{missing}} }

\examples{
ftest <- function(x1, ...) c(hasArg(x1), hasArg("y2"))

ftest(1) ## c(TRUE, FALSE)
ftest(1, 2)  ## c(TRUE, FALSE)
ftest(y2 = 2)   ## c(FALSE, TRUE)
ftest(y = 2)    ## c(FALSE, FALSE) (部分マッチなし)
ftest(y2 = 2, x = 1)  ## c(TRUE, TRUE) 部分的に x1 にマッチ
}
\keyword{ programming }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/hasArg.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{hasArg}
%\alias{hasArg}
%\title{Look for an Argument in the Call}
%\description{
%  Returns \code{TRUE} if \code{name} corresponds to an argument in the
%  call, either a formal argument to the function, or a component of
%  \code{...}, and \code{FALSE} otherwise.
%}
%\usage{
%hasArg(name)
%}
%\arguments{
%  \item{name}{The name of a potential argument, as an unquoted name or
%    character string.}
%}
%\details{
%  The expression \code{hasArg(x)}, for example, is similar to
%  \code{!missing(x)}, with two exceptions.  First,  \code{hasArg} will look for
%  an argument named \code{x} in the call if \code{x} is not a formal
%  argument to the calling function, but \code{...} is.  Second,
%  \code{hasArg} never generates an error if given a name as an argument,
%  whereas \code{missing(x)} generates an error if \code{x} is not a
%  formal argument.
%}
%\value{
%  Always \code{TRUE} or \code{FALSE} as described above.
%}
%\seealso{ \code{\link{missing}} }
%
%\examples{
%ftest <- function(x1, ...) c(hasArg(x1), hasArg("y2"))
%
%ftest(1) ## c(TRUE, FALSE)
%ftest(1, 2)  ## c(TRUE, FALSE)
%ftest(y2 = 2)   ## c(FALSE, TRUE)
%ftest(y = 2)    ## c(FALSE, FALSE) (no partial matching)
%ftest(y2 = 2, x = 1)  ## c(TRUE, TRUE) partial match x1
%}
%\keyword{ programming }
%
%\encoding{UTF8}
%