% File src/library/methods/man/implicitGeneric.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{implicitGeneric}
%@%\alias{総称的関数の暗黙のバージョンの管理}
\alias{implicitGeneric}
\alias{setGenericImplicit}
\alias{prohibitGeneric}
\alias{registerImplicitGenerics}
\alias{implicit generic}
\title{総称的関数の暗黙のバージョンを管理する}
%\title{Manage Implicit Versions of Generic Functions}
\description{
  現在総称的関数でない関数を一貫性のある総称的バージョンに強制するのに
  使われる暗黙の総称的関数を作るまたはアクセスする．
  関数 \code{implicitGeneric()} は暗黙の総称的バージョンを返し，
  \code{setGenericImplicit()} は総称的関数を暗黙化し，
  \code{prohibitGeneric()} は関数を総称的にするのを防止し，そして
  \code{registerImplicitGenerics()} は現在のセッションの
  キャッシュテーブルに暗黙の総称的定義のセットを保存する．
}
\usage{
implicitGeneric(name, where, generic)
setGenericImplicit(name, where, restore = TRUE)
prohibitGeneric(name, where)
registerImplicitGenerics(what, where)
}

\arguments{
  \item{name}{関数の文字列名．}
  \item{where}{
    暗黙の総称的関数を登録するパッケージか環境．
    この関数を自分自身のトップレベルから使う時はこの引数は
    普通省略可能である(そしてそうあるべきである)．}
  \item{generic}{
    オプションのキャッシュされる総称的関数定義であるが，
    普通省略可能であるされる．詳細節を見よ．}
  \item{restore}{
    現在の後に非総称的な関数のバージョンを回復すべきか．}
  \item{what}{
    \code{registerImplicitGenerics()} に対して．
    登録される暗黙の総称的関数のオプションのテーブルであるが，
    ほとんど常に無視される．下の詳細節を見よ．}
}
\details{
  一つのパッケージに保管された関数のバージョンを使い，
  複数のパッケージが同じ関数のメソッドを定義することがある．
  これら全ての関数はユーザが関数を呼び出す時統括され統一的に
  選択適用されるべきである．
  一貫性のために関数の総称的バージョンはユニークな定義を持つべきである
  (メソッドのシグネチャ中に同じ引数，
  値クラス等のオプションのスロットに対する同じ値，そして
  関数自体の同じ標準的か非標準的な定義)．

  オリジナルの関数がすでに S4 総称的であれば何の問題もない．
  暗黙の総称的関数機構は関数を所有するパッケージ中の
  バージョンが総称的で\emph{無い}時は一貫性を強要する．
  もし \code{\link{setGeneric}()} の呼び出しが別のパッケージ中の
  関数を総称的にするときは，機構は提案される新しい総称的関数を
  その関数の暗黙の総称的バージョンと比較する．
  もし二つが一致すれば全てがうまく行く．
  もし一致せず，そして関数が別のパッケージに属していれば，
  新しい総称的関数はそのパッケージに関連付けられない．
  代わりに警告が出され，そして別個の総称的関数が作られ，そのパッケージスロットは
  関数の非総称的バージョンを所有するパッケージではなく現在のパッケージに設定される．
  その効果は新しいパッケージは依然としてこの関数に対するメソッドを定義するが，
  それは総称的関数の異なった定義を強制するため，
  他のパッケージ中のメソッドを共有しない．
  
  ほとんどすべてのケースで取るべき正しい方法は
  関数の名前\emph{だけ}を与えて
  \code{\link{setGeneric}("foo")} を呼び出すことである；
  これは自動的に暗黙の総称的バージョンを使う．
  もしこのバージョンが気に入らなければ，
  最良の解決法は
  他のパッケージの所有者を説得同意させ関数の
  非既定的性質を定義するコードを挿入してもらうことである
  (たとえ所有者が \code{foo()} を既定で総称的にしたくなくても)．

  任意の関数に対して，暗黙の総称的関数型は
  \code{\dots} を除く全ての形式的引数がメソッドのシグネチャ中に
  許される標準的な総称的関数である．
  もしこれが関数に対する適当な総称的関数ならば，
  如何なるアクションも不要である．
  さもなければ，最良の機構は
  関数を所有するパッケージのコード中に総称的関数を設定し，そして
  それから暗黙の総称的関数を記録するために
  \code{setGenericImplicit()} を呼び出し，それから
  非総称的なバージョンを回復することである．例を見よ．

  パッケージは暗黙の総称的関数に対するメソッドも同様に定義できる；
  暗黙の総称的関数が真の総称的関数にされると，これらのメソッドも
  含まれる．

  メソッドを予め定義する以外に，
  非既定の暗黙の総称的関数を持つ普通の理由は
  非既定のシグネチャを提供することで，
  \emph{それ}に対する普通の理由はある引数の遅延評価を許すことにある．
  例を見よ．総称的関数のシグネチャ中の全ての引数は
  関数がメソッドの選択が必要な時に評価されていなければならない．
  (しかしこれらの引数は既定表現が定義されていても無くても欠損することが
  出来る；シグネチャ中の引数に対してすらも常に \code{missing(x)} を
  吟味することが出来る．)

  もし自分の関数を誰かが総称的にすることを完全に拒否したければ
  \code{prohibitGeneric()} を呼び出す．
}
\value{
  関数 \code{implicitGeneric()} は暗黙の総称的関数定義を返す
  (そしてそれを構築しなければならないならその定義を最初にキャッシュする)．

  他の関数はそれらの副作用のために存在し有用なものは何も返さない．
}
\seealso{\code{\link{setGeneric}}}
\examples{

### 関数 \link{with}() をどのように総称的関数にしたか:

## シグネチャ中に "data" だけがあるように
## with() を使いたい二つ目の引数，'expr' が文字通りに使われる．

## 内部的な 'methods' コードは次と同値なことを行うように
## with() を拡張していることを注意する
\dontrun{
setGeneric("with", signature = "data")
## もし希望すればここで
## "with" に対するメソッドを予め定義することも出来た．

## 準備ができれば，総称的関数を暗黙バージョンとして保管し，
## オリジナルの setGenericImplicit("with") を回復する

## (この例は関数 with() が存在する時だけ動作するが，
## それは基本パッケージ中にある．)}

implicitGeneric("with")
}

\keyword{programming}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/implicitGeneric.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{implicitGeneric}
%\alias{implicitGeneric}
%\alias{setGenericImplicit}
%\alias{prohibitGeneric}
%\alias{registerImplicitGenerics}
%\alias{implicit generic}
%\title{Manage Implicit Versions of Generic Functions}
%\description{
%  Create or access implicit generic functions, used to enforce
%  consistent generic versions of functions that are not currently
%  generic.  Function \code{implicitGeneric()} returns the implicit
%  generic version, \code{setGenericImplicit()} turns a generic implicit,
%  \code{prohibitGeneric()} prevents your function from being made
%  generic, and \code{registerImplicitGenerics()} saves a set of implicit
%  generic definitions in the cached table of the current session.
%}
%\usage{
%implicitGeneric(name, where, generic)
%setGenericImplicit(name, where, restore = TRUE)
%prohibitGeneric(name, where)
%registerImplicitGenerics(what, where)
%}
%
%\arguments{
%  \item{name}{ Character string name of the function.}
%  \item{where}{ Package or environment in which to register the implicit
%    generics.  When using the functions from the top level of your own
%    package source, this argument can usually be omitted (and should
%    be).}
%  \item{generic}{ Optionally, the generic function definition to be
%    cached, but usually omitted.   See Details section.}
%  \item{restore}{Should the non-generic version of the function be
%    restored after the current.}
%  \item{what}{For \code{registerImplicitGenerics()}, Optional table of
%    the implicit generics to register, but nearly always omitted.   See
%    Details section.}
%}
%\details{
%  Multiple packages may define methods for the same function, using the
%  version of a function stored in one package.  All these methods should
%  be marshaled and dispatched consistently when a user calls the
%  function.  For consistency, the generic version of the function must
%  have a unique definition (the same arguments allowed in methods
%  signatures, the same values for optional slots such as the value
%  class, and the same standard or non-standard definition of the
%  function itself).
%
%  If the original function is already an S4 generic, there is no
%  problem.  The implicit generic mechanism enforces consistency when the
%  version in the package owning the function is \emph{not} generic.  If
%  a call to \code{\link{setGeneric}()} attempts to turn a function in
%  another package into a generic, the mechanism compares the proposed
%  new generic function to the implicit generic version of that
%  function. If the two agree, all is well. If not, and if the function
%  belongs to another package, then the new generic will not be
%  associated with that package.  Instead, a warning is issued and a
%  separate generic function is created, with its package slot set to the
%  current package, not the one that owns the non-generic version of the
%  function. The effect is that the new package can still define methods
%  for this function, but it will not share the methods in other
%  packages, since it is forcing a different definition of the generic
%  function.
%
%  The right way to proceed in nearly all cases is to call
%  \code{\link{setGeneric}("foo")}, giving \emph{only} the name of the
%  function; this will automatically use the implicit generic version.
%  If you don't like that version, the best solution is to convince the
%  owner of the other package to agree with you and to insert code to
%  define the non-default properties of the function (even if the owner
%  does not want \code{foo()} to be a generic by default).
%
%  For any function, the implicit generic form is a standard generic in
%  which all formal arguments, except for \code{\dots}, are allowed in
%  the signature of methods. If that is the suitable generic for a
%  function, no action is needed. If not, the best mechanism is to set up
%  the generic in the code of the package owning the function, and to
%  then call \code{setGenericImplicit()} to record the implicit generic
%  and restore the non-generic version.  See the example.
%
%  Note that the package can define methods for the implicit generic as
%  well; when the implicit generic is made a real generic, those methods
%  will be included.
%
%  Other than predefining  methods, the usual reason for having a
%  non-default implicit generic is to provide a non-default signature,
%  and the usual reason for \emph{that} is to allow lazy evaluation of
%  some arguments.  See the example.  All arguments in the signature of a
%  generic function must be evaluated at the time the function needs to
%  select a method.  (But those arguments can be missing, with or without
%  a default expression being defined; you can always examine
%  \code{missing(x)} even for arguments in the signature.)
%
%  If you want to completely prohibit anyone from turning your function
%  into a generic, call \code{prohibitGeneric()}.
%}
%\value{
%  Function \code{implicitGeneric()} returns the implicit generic
%  definition (and caches that definition the first time if it has to
%  construct it).
%
%  The other functions exist for their side effect and return nothing
%  useful.
%}
%\seealso{\code{\link{setGeneric}}}
%\examples{
%
%### How we would make the function \link{with}() into a generic:
%
%## Since the second argument, 'expr' is used literally, we want
%## with() to only have "data" in the signature.
%
%## Note that 'methods'-internal code now has already extended  with()
%## to do the equivalent of the following
%\dontrun{
%setGeneric("with", signature = "data")
%## Now we could predefine methods for "with" if we wanted to.
%
%## When ready, we store the generic as implicit, and restore the original
%setGenericImplicit("with")
%
%## (This example would only work if we "owned" function with(),
%##  but it is in base.)}
%
%implicitGeneric("with")
%}
%
%\keyword{programming}
%\keyword{methods}
%
%\encoding{UTF8}
%