% File src/library/methods/man/initialize-methods.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{initialize-methods}
\docType{methods}
\title{あるクラスからの新しいオブジェクトを初期化するメソッド}
%\title{Methods to Initialize New Objects from a Class}
%@%\alias{{クラスからの新しいオブジェクトの初期化メソッド}
\alias{initialize-methods}
\alias{initialize,ANY-method}
\alias{initialize,traceable-method}
\alias{initialize,signature-method}
\alias{initialize,environment-method}
\alias{initialize,.environment-method}
\description{
  特定のクラスからのオブジェクトを作るための
  関数 \code{\link{new}} への引数は
  そのクラスへの関数 \code{initialize} に対するメソッドの定義により
  そのクラスに対して特別に解釈される．
  このドキュメントは幾つかの既存のメソッドを解説し，そして
  新しい物をどのように書くかを概説する．
}
\section{メソッド}{
  \describe{
    \item{\code{signature(.Object = "ANY")}}{
      \code{initialize} に対する既定メソッドは名前付きまたは名前無しの
      引数を取る．
      引数名はこのクラス定義中のスロット名でなければならず，そして
      対応する引数は
      スロットに対する適正なオブジェクトでなければならない
      (つまり，スロットに対して指定されたのとおなじクラスか，または
      そのクラスのスーパークラス)．もしオブジェクトが
      スーパークラス由来ならば，それは厳格には強制変換されず，従って
      普通それはその現在のクラスを保つ
      (特に \code{\link{as}(object, Class, strict = FALSE)})．

      名前無しの引数はこのクラスのオブジェクト，そのスーパークラスの
      オブジェクト，またはそのサブクラスの一つ
      でなければならない
      (クラス，このクラスが拡張しているクラス，または
      このクラスを拡張しているクラスから)．
      もしオブジェクトがスーパークラス由来ならば，
      これは普通オブジェクト中のスロットのどれかを定義する．
      もしオブジェクトがサブクラスからならば，現在のクラスに
      強制変換される．

      名前無し引数はそれらが登場する順序で最初に処理される．
      それから名前付きの引数が処理される．
      従って，スロットに対する
      明示的な値は常にスーパークラスかサブクラスから推測される
      任意の値を上書きする．
    }

    \item{\code{signature(.Object = "traceable")}}{
      \code{traceable} を拡張するクラスのオブジェクトは
      デバッグのトレースを実装するために使われる
      (クラス \linkS4class{traceable} と \code{\link{trace}} を見よ)．

      これらのクラスに対する \code{initialize} メソッドは
      \code{def, tracer, exit, at, print} という特殊な引数を取る．
      これらの最初はオリジナルな定義として使われるオブジェクトである
      (例えば関数)．他は
      \code{\link{trace}} への引数に対応する．
    }

    \item{\code{signature(.Object = "environment")}, \code{signature(.Object = ".environment")}}{
      環境に対する \code{initialize} メソッドは環境を初期化するために
      使われるオブジェクトの名前付きリストを取る．
      \code{"environment"} のサブクラスは
      \code{".environment"} を通じて初期化メソッドを継承し，
      新しい環境を確保する追加の効果を持つ．
      もしそうしたサブクラスに対する自分自身のメソッドを定義するならば，
      既存のメソッドを \code{\link{callNextMethod}} を使って呼び出すか，または
      自分のメソッド中で環境を確保することを忘れない．
      環境は参照であり自動的には複製されないからである．
    }

    \item{\code{signature(.Object = "signature")}}{
      これは内部的な使用専用のメソッドである．
      これはオプションの \code{functionDef} 引数で
      引数名を定義する\code{signature} スロットを持つ総称的関数を
      提供する．詳細は \link{Methods} を見よ．
    }
  }
}
\section{初期化メソッドを書く}{
  初期化メソッドは他の言語中の生成関数に対応する
  一般的な機構を提供する．

  \code{\link{initialize}} への引数は \code{.Object} と
  \dots である．ほとんど常に \code{initialize} は \code{new}
  から呼び出され，直接にではない．
  \code{.Object} 引数はそうするとクラスからのプロトタイプオブジェクトである．

  二つのテクニックがしばしば
  \code{initialize} メソッドに対して適当である：
  特殊な引数名と \code{callNextMethod} である．

  (既定の)スロット名よりもユーザにより自然な引数名が欲しいかもしれない．
  これらは \code{.Object} (常に)と \dots (オプション)に追加される
  自分のメソッド定義への形式的引数である．
  例えば，上で解説されたクラス
  \code{"traceable"} に対するメソッドは次のような形式の
  \code{\link{setMethod}} への呼び出しで作られる：

\preformatted{    setMethod("initialize", "traceable",
      function(.Object, def, tracer, exit, at, print) \dots
    )
}

  この例では，他の引数のどれもが意味を持たず，そして
  結果のメソッドは他の引数が与えられるとエラーを惹き起こす．

  もし新しいクラスが別のクラスを拡張すると，
  このスーパークラス(特殊メソッドか既定)に対するメソッドを初期化したいかもしれない．
  例えば 特殊引数 \code{x} を持つが，同時にユーザが
  スロットを独自に設定できるようにしたい自分のクラスに対する
  メソッドを定義したいと仮定する．
  もし \code{x} がスロット情報を上書きしたければ，
  メソッド定義の冒頭は次の様なものになるかもしれない：

\preformatted{    function(.Object, x, ...) \{
      Object <- callNextMethod(.Object, ...)
      if(!missing(x)) \{ # x に何かをする
}

  また，最初に \code{x} を解釈しそれから次のメソッドを呼びだすことで，
  継承メソッドを上書きすることを選択できたであろう．

}
\keyword{methods}
\keyword{programming}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/initialize-methods.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{initialize-methods}
%\docType{methods}
%\title{Methods to Initialize New Objects from a Class}
%\alias{initialize-methods}
%\alias{initialize,ANY-method}
%\alias{initialize,traceable-method}
%\alias{initialize,signature-method}
%\alias{initialize,environment-method}
%\alias{initialize,.environment-method}
%\description{
%  The arguments to function \code{\link{new}} to create an object from a
%  particular class can be interpreted specially for that class, by the
%  definition of a method for function \code{initialize} for the class.
%  This documentation describes some existing methods, and also outlines
%  how to write new ones.
%}
%\section{Methods}{
%  \describe{
%    \item{\code{signature(.Object = "ANY")}}{
%      The default method for \code{initialize} takes either named or
%      unnamed arguments.  Argument names must be the names of slots in
%      this class definition, and the corresponding arguments must be
%      valid objects for the slot (that is, have the same class as
%      specified for the slot, or some superclass of that class).  If the
%      object comes from a superclass, it is not coerced strictly, so
%      normally it will retain its current class (specifically,
%      \code{\link{as}(object, Class, strict = FALSE)}).
%
%      Unnamed arguments must be objects of this class, of one of its
%      superclasses, or one of its subclasses (from the class, from a
%      class this class extends, or from a class that extends this
%      class). If the object is from a superclass, this normally defines
%      some of the slots in the object.  If the object is from a
%      subclass, the new object is that argument, coerced to the current
%      class.
%
%      Unnamed arguments are processed first, in the order they appear.
%      Then named arguments are processed.  Therefore, explicit values
%      for slots always override any values inferred from superclass or
%      subclass arguments.
%    }
%
%    \item{\code{signature(.Object = "traceable")}}{
%      Objects of a class that extends \code{traceable} are used to
%      implement debug tracing (see class \linkS4class{traceable} and
%      \code{\link{trace}}).
%
%      The \code{initialize} method for these classes takes special
%      arguments \code{def, tracer, exit, at, print}.  The first of these
%      is the object to use as the original definition (e.g., a
%      function).  The others correspond to the arguments to
%      \code{\link{trace}}.
%    }
%
%    \item{\code{signature(.Object = "environment")}, \code{signature(.Object = ".environment")}}{
%      The \code{initialize} method for environments takes a named list
%      of objects to be used to initialize the environment.  Subclasses
%      of \code{"environment"} inherit an initialize method through
%      \code{".environment"}, which has the additional effect of
%      allocating a new environment.  If you define your own method for
%      such a subclass, be sure either to call the existing method via
%      \code{\link{callNextMethod}} or allocate an environment in your
%      method, since environments are references and are not duplicated
%      automatically.
%    }
%
%    \item{\code{signature(.Object = "signature")}}{
%      This is a method for internal use only.
%      It takes an optional \code{functionDef} argument to provide a
%      generic function with a \code{signature} slot to define the
%      argument names.  See \link{Methods} for details.
%    }
%  }
%}
%\section{Writing Initialization Methods}{
%  Initialization methods provide a general mechanism corresponding to
%  generator functions in other languages.
%
%  The arguments to \code{\link{initialize}} are \code{.Object} and
%  \dots. Nearly always, \code{initialize} is called from \code{new},
%  not directly.  The \code{.Object} argument is then the
%  prototype object from the class.
%
%  Two techniques are often appropriate for \code{initialize} methods:
%  special argument names and \code{callNextMethod}.
%
%  You may want argument names that are more natural to your users than
%  the (default) slot names.  These will be the formal arguments to
%  your method definition, in addition to \code{.Object} (always) and
%  \dots (optionally).  For example, the method for class
%  \code{"traceable"} documented above would be created by a call to
%  \code{\link{setMethod}} of the form:
%
%\preformatted{    setMethod("initialize", "traceable",
%      function(.Object, def, tracer, exit, at, print) \dots
%    )
%}
%
%  In this example, no other arguments are meaningful, and the resulting
%  method will throw an error if other names are supplied.
%
%  When your new class extends another class, you may want to call the
%  initialize method for this superclass (either a special method or the
%  default).  For example, suppose you want to define a method for your
%  class, with special argument \code{x}, but you also want users to be
%  able to set slots specifically.  If you want \code{x} to override the
%  slot information, the beginning of your method definition might look
%  something like this:
%
%\preformatted{    function(.Object, x, ...) \{
%      Object <- callNextMethod(.Object, ...)
%      if(!missing(x)) \{ # do something with x
%}
%
%  You could also choose to have the inherited method override, by first
%  interpreting \code{x}, and then calling the next method.
%
%}
%\keyword{methods}
%\keyword{programming}
%
%\encoding{UTF8}
%