% File src/library/methods/man/is.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{is}
%@%\alias{オブジェクトはあるクラスからのものか?}
\alias{is}
\alias{extends}
\alias{setIs}
\title{オブジェクトはあるクラスからのものか?}
%\title{Is an Object from a Class?}
\description{
  オブジェクトとクラス (\code{is}) の間，または二つのクラス
  (\code{extends})間の継承関係をテストし，
  そうした関係を確立する(\code{setIs}関数で，
  \code{\link{setClass}}) に対する
  \code{contains=} 引数への明示的な別法である．
}
\section{関数の要約}{
  \describe{
    \item{\code{is}:}{
      二つの引数を用い，\code{object} が
      \code{class2} からのものとして扱えるかをテストする．

      引数が一つならこのオブジェクトのクラスの全てのスーパークラスを返す．
    }
    \item{\code{extends}:}{
      最初のクラスは二番目のクラスを拡張するか?
      呼び出しはもし拡張がテストを含めば
      \code{maybe} を返す．

      引数一つで呼び出されると，値は
      \code{class1} のスーパークラスのベクトルである．
      もし引数 \code{fullInfo} が \code{TRUE} ならば，呼び出しは
      クラス \code{\linkS4class{SClassExtension}} のオブジェクトの
      名前付きリストを返す；さもなければ単にスーパークラスの名前．
    }
    \item{\code{setIs}:}{
      \code{class1} を
      \code{class2} の拡張(サブクラス)として定義する．
      もし \code{class2} が既存の合併クラスのような仮想的クラスならば，
      もし含意される継承メソッドが
      \code{class1} に対して動作するならば
      呼び出しには二つの引数だけが提供される必要がある．
      下の詳細節を見よ．

      別法として，
      スーパークラスに強制変換しスーパークラスに対応する
      部分を置き換えるメソッドを定義する
      引数 \code{coerce} と \code{replace} が提供されなければならない．
      下の詳細節と他の節で議論されているように，
      この形式はその別法である
      \code{\link{setAs}} への対応する呼出しほどは勧められない．

      引数 \code{test} は条件付き継承を許し，
      そこでは \code{is()} の結果はクラス定義で決定されるのではなく
      各オブジェクトに対してテストされる．
      この形式はそれが避けられる時は勧められない；特に
      条件付き継承は選択適用に対するメソッドを選ぶのに使われ
      \emph{ない}ことを注意する．
    }
  }
}
\usage{
is(object, class2)

extends(class1, class2, maybe = TRUE, fullInfo = FALSE)

setIs(class1, class2, test=NULL, coerce=NULL, replace=NULL,
      by = character(), where = topenv(parent.frame()), classDef =,
      extensionObject = NULL, doComplete = TRUE)
}
\arguments{
  \item{object}{任意の \R オブジェクト．}
  \item{class1, class2}{
    その間で \code{is} 関係の定義が調べられるクラスの名前，または
    (より効率的に)クラスに対するクラス定義オブジェクト．}

  \item{maybe, fullInfo}{
    \code{extends} の呼び出し中で，\code{maybe} はもし
    関係が条件付きならば返される値．
    \code{class2} が欠損した呼び出し中では，
    \code{fullInfo} はフラグで，もし
    \code{TRUE} ならば，単にクラス名だけではなく，
    クラス \code{classExtension} のオブジェクトのリスト
    が返されるようにする．}

  \item{coerce, replace}{
    In a call to
    \code{setIs} の呼び出し中で，オブジェクトを
    \code{class2} に強制変換し，オブジェクトを
    \code{is(object, class2)} が
    \code{value} に一致するように変換するためにオプションで
    提供される.  下の詳細節を見よ．}

  \item{test}{
    \code{setIs} の呼び出し中で，この関数を使うことで\emph{条件付き}
    関係が定義される．
    条件付き関係は推奨出来ずメソッド選択中に含められない．
    下の詳細説を見よ．

  残りの引数は内部的使用且つ/または普通省略される．
  }

  \item{extensionObject}{
    \code{test, coerce, replace, by} 引数の代替物；
    関係を記述するクラス\cr
    \code{SClassExtension} からのオブジェクト．
    (内部的呼び出しで使われる．)}

  \item{doComplete}{
    \code{TRUE} の時，クラス定義は間接的な関係でも増補される
    (内部的呼び出しで使われる．)}
  \item{by}{
    \code{setIs} の呼び出し中で，中間のクラスの名前．
    強制変換は先ずこのクラスに強制変換されそこから目標のクラスに変換される．
    (中間の強制変換は適正でなければならない．)}
  \item{where}{
    \code{setIs} への呼び出し中で，関係を定義するメタデータをどこに
    保存するか．既定はセッションのトップレベルに対しては大局的環境か
    そこで評価されたソースファイル．
    呼び出しがパッケージのソース中のファイルのトップレベル中で起きた時は，
    既定値はパッケージの名前空間または環境．
    他の使用はトリッキーであり，自分が何をしているのか真に理解していない限り
    普通良いアイデアではない．}
  \item{classDef}{
    \code{class} に対するオプションのクラス定義で，
    \code{\link{setClass}} の呼び出しによるクラスの初期定義の
    過程で \code{setIs} が呼びだされる時に内部的に必要とされる．
    何のためにそれをするのか真に理解していない限りこの引数を
    \emph{使わないこと}．
  }
}

\section{詳細}{
  別のクラスを継承するようにあるクラスを手配することはプログラミングの
  鍵となる道具である．
  \R では三つの基本的なテクニックがある，最初の二つは
  \dQuote{単純}な継承と呼ばれるものを提供し，好まれる形式である：
  %%
  \enumerate{
  \item
    \code{\link{setClass}} の呼び出し中の \code{contains=} 引数により．
      これは最も普通の機構でありまたそうあるべきである．
      これは新しいクラスが既存クラスの全ての構造を含み，
      そして特に同じクラスが指定された全てのスロットを持つように按配する．
      結果のクラス拡張は
      \code{単純}であるように定義され，
      メソッド定義に対して重要な含意を持つ
      (下のこのトピックに関する節を見よ)．

  \item
      \code{class1} を
      \code{\link{setClassUnion}} への呼び出しでサブクラスを
      新しい合併クラスのメンバーにするか，または
      \code{setIs} の呼び出しで既存の合併クラスのクラスか
      既存の仮想的クラスの新しいサブクラスとしてを付け加える
      ことで，仮想クラスのサブクラスにする．
      どちらのケースでも，合併クラスか他のスーパークラスに対して定義された
      メソッドがサブクラスに対して正しく動作することが意図されている．
      これはサブクラスの構造中のある類似性に依存するかもしれず，単に
      スーパークラスメソッドが全てのサブクラスに適用される
      総称的関数の言葉で定義されるかもしれない．
      これらの関係はまた一般に単純である．


  \item
      \code{coerce} と \code{replace} 引数を \code{setAs} に与える．
      \R は任意の継承関係を認め，
      \code{\link{setAs}} への呼び出しによる強制変換機構の定義
      と同じ機構を使う．両者の違いは単に
      \code{\link{setAs}} は変換が起きるためには \code{\link{as}} の
      呼び出しが必要なのに対して，
      \code{\link{setIs}} の呼び出しの後にはオブジェクトは自動的に
      スーパークラスに変換されることである．

      自動特性は危険な部分で，主な理由は結果が
      可能性として動作しないメソッドを継承するサブクラスになることである．
      下の継承に関する節を見よ．もし含まれる二つのクラスが
      実際には大量のメソッドのコレクションを継承しなければ，
      危険は相対的に僅かかもしれない．

      スーパークラスがサブクラスが既定か離れている継承メソッドだけを
      継承していれば，問題はより起こりがちである．
      この場合，一般的な助言は強い反対意見がない限り代わりに
      \code{\link{setAs}} 機構を使うことである．
      さもなければ継承されたメソッドのどれかを
      書き換える用意をせよ．
  }

  この注意を与えて，この節の残りは
  \code{coerce=} と \code{replace=} 引数が
  \code{setIs} に与えられた時何が起こるかを解説する．

  \code{coerce} と \code{replace} 引数は
  \code{class1} オブジェクトを
  \code{class2} をどのように強制変換するか，そして
  どのように \code{class2} に対応するサブクラスオブジェクトをの部分を
  置き換えるかを定義する関数である．
  これらの最初は
  \code{from} であるべき引数が一つの関数で，
  二番目は二つの引数
  (\code{from}, \code{value}) の関数である．詳細については
  下の強制変換に関する節を見よ．

  \code{by} が使用された時，強制変換のプロセスは先ず
  このクラスにそれから \code{class2} に変換される．
  \code{by} 引数を直接使うことはありそうもないが，
  クラスに関するキャッシュされた情報を定義するのに使われる．

  \code{setIs} により(不可視で)返される値は
  \code{class1} の改訂されたクラス定義である．
}

\section{強制変換，置き換え，そしてテスト関数}{

  \code{coerce} 引数は
  \code{class1} オブジェクトを \code{class2} オブジェクトに変える関数である．
  \code{replace} 引数は \code{class1} オブジェクト (最初の引数) を，
  \code{class2} (\code{value} として与えられる，第二引数)に
  対応するその部分を置き換えるために修正する引数が二つの
  関数である．換言すれば，それは表現式
  \code{as(object, class2) <- value} を実装する置き換えメソッドとして
  作用する．

  \code{coerce} と \code{replace} 関数を考える最も簡単な方法は
  \code{class1} が第二のクラスのスロットを含むことで
  普通の意味で \code{class2} を含む場合を考えることである．
  (繰り返すと，この状況では
  \code{setIs} を呼び出さないが，類似からそれをする時
  何が起きるかを示す．)

  この場合 \code{coerce} 関数は単に
  \code{class2} オブジェクトを，対応する
  \code{class1} オブジェクトから対応するスロットを取り出すことで
  作る．\code{replace} 関数は \code{class1} オブジェクト中で
  \code{class2} に対応するスロットを置き換え，そして
  修正されたオブジェクトをその値として返す．

  これらの関数の追加の議論については，
   \code{\link{setAs}} 関数のドキュメントを見よ．
   (不幸にもその関数への \code{def} 引数はここでの
   \code{coerce} に対応する．)

  もし関数が \code{test} 引数として与えられると，継承関係はまた
  条件付きであり得る．これは与えられたオブジェクトが関係
  \code{is(object, class2)} を満足するかどうかで
  \code{TRUE} か \code{FALSE} を返す引数一つの関数であるべきである．
  条件付き関係は，それらが正当性を決定するためにオブジェクト毎の
  計算を必要とするために，一般的には推奨できない．
  それらは普通の関係程は効率的に適用できず，そして
  それらを使うコードをより解釈困難にする傾向がある．
  \emph{注意：条件付き継承はメソッドの選択適用には使われない．}
  条件付きスーパークラスに対するメソッドは継承されない．
  代わりに，条件付き関係をテストするサブクラスに対するメソッド
  が定義されるべきである．
}
\section{継承メソッド}{
  特定のシグネチャ
  (関数の一つまたはそれ以上の形式的引数にマッチするクラス)
  に対して書かれたメソッドは自然に
  引数に対応するオブジェクトは対応するクラス由来と扱うことが出来る．
  オブジェクトはクラスに対する全てのスロットと利用可能なメソッドを持つ．

  メソッドを選択し適用するコードは
  この仮定が正しいことを保証する．
  もし継承が
  \dQuote{単純}ならば，つまり
  \code{\link{setClass}} の呼び出し中の
  一つまたはそれ以上の code{contains=} 引数の使用で定義されるならば，
  余分の作業は一般的に不要である．
  クラスは同じ定義を使いスーパークラスから継承される．

  継承が \code{setIs} の一般的な呼び出しで定義される時は，
  余分の計算が必要になる．この形式の継承は
  サブクラスがスーパークラスのスロットを単に含ま\emph{無い}ことを
  意味するが，代わりに強制変換と/または置き換えメソッドの
  明示的な呼び出しを必要とする．
  正確な計算を保証するためには，継承メソッドは
  メソッドの本体が評価される前に
  \code{\link{as}} の呼び出しを補う．

  この場合に生成された \code{\link{as}} の呼び出しは
  引数 \code{strict = FALSE} を持ち，それが全ての適当なスロットを
  持つ限り，余分の情報を
  変換されたオブジェクト中に残すことが出来ることを意味する．
  (単純なサブクラスオブジェクトが変更なしに使われることを
  許すのはこのオプションである．)
  強制変換メソッドを書くときには，このオプションの長所を
  利用したくなるかもしれない．

  単純でない拡張を通じて継承されたメソッドは
  曖昧さや予期せぬ選択に導くことがあり得る．
  もし \code{class2} が少数の適用可能なメソッドだけを持つ
  特殊化されたクラスならば，継承関係の作成は
  \code{class1} の挙動にほとんど影響を与えないかもしれない．
  しかしもし \code{class2} が多くのメソッドを持つクラスならば，
  \code{class1} に対してある望ましくないメソッドを継承し，ある場合には
  期待されるメソッドを継承することに失敗することに
  気づくかもしれない．
  下の二つ目の例では，クラス
  \code{"factor"} からの単純でない継承はそのクラスにより
  S3 メソッドを継承するとされるかもしれない．
  しかし S3 クラスは曖昧であり，実際
  \code{"factor"} ではなく \code{"character"} である．

  ある種の総称的関数に対しては，単純でない拡張により継承されたメソッドは
  不正であるかまたは十分不正の可能性があり，
  従って総称関数はそうした継承を除外するように定義されてきている．
  例えば \code{\link{initialize}} メソッドは目標クラスのオブジェクトを
  返さなければならない；
  これは拡張が単純ならば引数オブジェクトに何の変更も加えられないので
  簡単であるが，本質的に不可能である．
  この理由から，総称的関数は継承に対して単純な拡張だけを
  強要する．
  この機構については \code{\link{setGeneric}} の
  \code{simpleInheritanceOnly} 引数を見よ．
  新しい総称的関数を定義する際はこの機構を使うことが出来る．

  単純でない継承を認める関数に対して問題が起きれば，
  二つの基本的な選択がある．
  \code{setIs} 呼び出しから戻り
  \code{\link{setAs}} の呼び出しで定義される明示的な強制変換を
  設定する；又は好ましくない継承メソッドを上書きする
  \code{class1} を含む明示的なメソッドを定義する．
  深刻な問題が起きている時は最初の選択がより安全である．

}
\seealso{
  \code{\link{inherits}} は S4 と非 S4 オブジェクト双方に対して
  ほとんど常に \code{is} に同値であり少々速い．
  非同等性は
  関係の中に自明でない \code{test=} がある条件付きスーパークラス
  を持つクラスに適用される(普通でなく推奨できない)：
  これらに対して \code{is} は関係をテストするが
  \code{inherits} は定義から S4 オブジェクトに対する条件付き
  継承を無視する．


  \code{\link{selectSuperClasses}(cl)} は
  \code{extends(cl)} と類似のセマンティックスを持つ．
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\examples{
\dontshow{
## 二つのスロットを持つ簡単な例
setClass("track",
         representation(x="numeric", y="numeric"))
## これを拡張するクラス，追加でもうひとつのスロットを持つ
}
## coerce= と replace= 引数を持つ setIs() の二つの例
## 最初の例はどのクラスも新しい継承により区別されるべき多くの
## 継承メソッドを持たぬため，かなり上手く動作する．

## 二番目の例は新しいスーパークラス "factor" がそうなるべきではない
## メソッドを継承させるため上手く動作しない．

## 最初の例：
## クラス定義(クラス "track" に対する \link{setClass} を見よ)
setClass("trackCurve", contains = "track",
         representation( smooth = "numeric"))
## "trackCurve" に類似のクラスであるが，
## "y" と "smooth" スロットに行列を許す異なった構造を持つ
setClass("trackMultiCurve",
         representation(x="numeric", y="matrix", smooth="matrix"),
         prototype = structure(list(), x=numeric(), y=matrix(0,0,0),

                               smooth= matrix(0,0,0)))
## y と smooth スロットを一列の行列にすることで
## クラス "trackCurve" からのオブジェクトを自動的に "trackMultiCurve" に変換する
setIs("trackCurve",
      "trackMultiCurve",
      coerce = function(obj) {
        new("trackMultiCurve",
            x = obj@x,
            y = as.matrix(obj@y),
            smooth = as.matrix(obj@smooth))
      },
      replace = function(obj, value) {
        obj@y <- as.matrix(value@y)
        obj@x <- value@x
        obj@smooth <- as.matrix(value@smooth)
        obj})


\dontshow{
removeClass("trackMultiCurve")
removeClass("trackCurve")
removeClass("track")
}

## 第二の例：
## "character" へのスロットを追加するクラス
setClass("stringsDated", contains = "character",
         representation(stamp="POSIXt"))

## 明示的な強制変換で因子に自動的に強制変換
setIs("stringsDated", "factor",
      coerce = function(from) factor(from@.Data),
      replace= function(from, value) {
                  from@.Data <- as.character(value); from })
\dontshow{
set.seed(750)
}
ll <- sample(letters, 10, replace = TRUE)
ld <- new("stringsDated", ll, stamp = Sys.time())

levels(as(ld, "factor"))
levels(ld) # NULL になるはず--上の継承に対する節のコメントを見よ．

## 対照的に，"factor" を単純に拡張するクラスは
## そうした曖昧さを持たない
setClass("factorDated", contains = "factor",
         representation(stamp="POSIXt"))
fd <- new("factorDated", factor(ll), stamp = Sys.time())
identical(levels(fd), levels(as(fd, "factor")))
}
\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/is.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{is}
%\alias{is}
%\alias{extends}
%\alias{setIs}
%\title{Is an Object from a Class?}
%\description{
%  Functions to test inheritance relationships between an object and a
%  class (\code{is}) or between two classes (\code{extends}), and to
%  establish such relationships (\code{setIs}, an explicit alternative
%  to the \code{contains=} argument to \code{\link{setClass}}).
%}
%\section{Summary of Functions}{
%  \describe{
%    \item{\code{is}:}{
%      With two arguments, tests whether \code{object} can be treated as from
%      \code{class2}.
%
%      With one argument, returns all the super-classes of this object's class.
%    }
%    \item{\code{extends}:}{
%      Does the first class extend the second class?
%      The call returns \code{maybe} if the extension includes a test.
%
%      When called with one argument, the value is a vector of the
%      superclasses of \code{class1}.  If argument \code{fullInfo}  is
%      \code{TRUE}, the call returns a named list of objects of class
%      \code{\linkS4class{SClassExtension}}; otherwise, just the names of
%      the superclasses.
%    }
%    \item{\code{setIs}:}{
%      Defines \code{class1} to be an extension (subclass) of
%      \code{class2}.
%      If \code{class2} is an existing virtual class, such as a class
%      union, then only the two classes need to be supplied in the
%      call, if the implied inherited methods work for \code{class1}.
%      See the details section below.
%
%      Alternatively, arguments \code{coerce} and \code{replace} should
%      be supplied, defining methods to coerce to the superclass and to
%      replace the part corresponding to the superclass. As discussed in
%      the details and other sections below, this form is often less
%      recommended than the corresponding call to \code{\link{setAs}}, to
%      which it is an alternative.
%
%      Argument \code{test} allows conditional inheritance, in which
%      the \code{is()} result is tested for each object rather than
%      being determined by the class definition.  This form is
%      discouraged when it can be avoided; in particular, note that
%      conditional inheritance is \emph{not} used to select methods for
%      dispatch.
%    }
%  }
%}
%\usage{
%is(object, class2)
%
%extends(class1, class2, maybe = TRUE, fullInfo = FALSE)
%
%setIs(class1, class2, test=NULL, coerce=NULL, replace=NULL,
%      by = character(), where = topenv(parent.frame()), classDef =,
%      extensionObject = NULL, doComplete = TRUE)
%}
%\arguments{
%  \item{object}{any \R object.}
%  \item{class1, class2}{
%    the names of the classes between which \code{is} relations are to be
%    examined defined, or (more efficiently) the class definition
%    objects for the classes.}
%
%  \item{maybe, fullInfo}{
%    In a call to \code{extends}, \code{maybe} is the value returned if
%    a relation is conditional. In a call with \code{class2} missing,
%    \code{fullInfo} is a flag, which if \code{TRUE} causes a list of
%    objects of class \code{classExtension} to be returned, rather than
%    just the names of the classes.}
%
%  \item{coerce, replace}{
%    In a call to \code{setIs}, functions optionally supplied to coerce the object to
%    \code{class2}, and to alter the object so that \code{is(object, class2)}
%    is identical to \code{value}.  See the details section below.}
%
%  \item{test}{
%    In a call to \code{setIs}, a \emph{conditional} relationship is
%    defined by supplying this function.  Conditional relations are
%    discouraged and are not included in selecting methods.  See the details section below.
%
%  The remaining arguments are for internal use and/or usually omitted.}
%
%  \item{extensionObject}{ alternative to the \code{test, coerce,
%    replace, by} arguments; an object from class
%    \code{SClassExtension} describing the relation.  (Used in internal calls.)}
%
%  \item{doComplete}{when \code{TRUE}, the class definitions will be
%    augmented with indirect relations as well.  (Used in internal calls.)}
%  \item{by}{
%    In a call to \code{setIs}, the name of an intermediary class.
%    Coercion will proceed by first coercing to this class and from there
%    to the target class.  (The intermediate coercions have to be valid.)}
%  \item{where}{
%    In a call to \code{setIs}, where to store the metadata defining the
%    relationship.  Default is the global environment for calls from the
%    top level of the session or a source file evaluated there.  When the
%    call occurs in the top level of a file in the source of a package,
%    the default will be the namespace or environment of the package.
%    Other uses are tricky and not usually a good idea, unless you really
%    know what you are doing.}
%  \item{classDef}{
%    Optional class definition for \code{class} , required internally
%    when \code{setIs} is called during the initial definition of the
%    class by a call to \code{\link{setClass}}. \emph{Don't} use this
%    argument, unless you really know why you're doing so.}
%}
%
%\section{Details}{
%  Arranging for a class to inherit from another class is a key tool in
%  programming.  In \R, there are three basic techniques, the first two
%  providing what is called  \dQuote{simple} inheritance, the preferred form:
%  %%
%  \enumerate{
%  \item
%    By the \code{contains=} argument in a call to \code{\link{setClass}}.  This
%      is and should be the most common mechanism.  It arranges that the new
%      class contains all the structure of the existing class, and in
%      particular all the slots with the same class specified.  The
%      resulting class extension is defined to be \code{simple}, with
%      important implications for method definition (see the section on
%      this topic below).
%
%  \item
%     Making \code{class1} a subclass of a virtual class
%      either by a call to \code{\link{setClassUnion}} to make the
%      subclass a member of a new class union, or by a call to
%      \code{setIs} to add a class to an existing class union or as a new
%      subclass of an existing virtual class.  In either case, the
%      implication should be that methods defined for the class union or
%      other superclass all work correctly for the subclass.  This may
%      depend on some similarity in the structure of the subclasses or
%      simply indicate that the superclass methods are defined in terms
%      of generic functions that apply to all the subclasses.  These
%      relationships are also generally simple.
%
%
%  \item
%    Supplying \code{coerce}  and \code{replace} arguments to \code{setAs}.
%      \R allows arbitrary inheritance relationships, using the same
%      mechanism for defining coerce methods by a call to
%      \code{\link{setAs}}.  The difference between the  two is simply
%      that \code{\link{setAs}} will require a call to \code{\link{as}}
%      for a conversion to take place, whereas after the call to
%      \code{\link{setIs}}, objects will be automatically converted to
%      the superclass.
%
%      The automatic feature is the dangerous part, mainly because it
%      results in the subclass potentially inheriting methods that do
%      not work.  See the section on inheritance below.  If the two
%      classes involved do not actually inherit a large collection of
%      methods, as in the first example below, the danger may be
%      relatively slight.
%
%      If the superclass inherits methods where the subclass has only a
%      default or remotely inherited method, problems are more likely.
%      In this case, a general
%      recommendation is to use the \code{\link{setAs}} mechanism
%      instead, unless there is a strong counter reason. Otherwise, be prepared to
%      override some of  the methods inherited.
%  }
%
%  With this caution given, the rest of this section describes what
%  happens when \code{coerce=} and \code{replace=} arguments are supplied
%  to \code{setIs}.
%
%  The \code{coerce} and \code{replace} arguments are functions that
%  define how to coerce a \code{class1} object to \code{class2}, and
%  how to replace the part of the subclass object that corresponds to
%  \code{class2}.  The first of these is a function of one argument
%  which should be \code{from}, and the second of two arguments
%  (\code{from}, \code{value}).  For details, see the section on coerce
%  functions below .
%
%  When \code{by} is specified, the coerce process first coerces to
%  this class and then to \code{class2}.  It's unlikely you
%  would use the \code{by} argument directly, but it is used in defining
%  cached information about classes.
%
%  The value returned (invisibly) by
%  \code{setIs} is the revised class definition of \code{class1}.
%}
%
%\section{Coerce, replace, and test functions}{
%
%  The  \code{coerce} argument is a function that turns a
%  \code{class1} object into a \code{class2} object.  The
%  \code{replace} argument is a function of two arguments that modifies a \code{class1}
%  object (the first argument) to replace the part of it that
%  corresponds to \code{class2} (supplied as \code{value}, the second
%  argument).  It then returns the modified object as the value of the
%  call.  In other words, it acts as a replacement method to
%  implement the expression \code{as(object, class2) <- value}.
%
%  The easiest way to think of the  \code{coerce} and \code{replace}
%  functions is by thinking of the case that  \code{class1}
%  contains \code{class2} in the usual sense, by including the slots of
%  the second class.  (To repeat, in this situation you would not call
%  \code{setIs}, but the analogy shows what happens when you do.)
%
%  The \code{coerce} function in this case would just make a
%  \code{class2} object by extracting the corresponding slots from the
%  \code{class1} object. The \code{replace} function would replace in
%  the \code{class1} object the slots corresponding to \code{class2},
%  and return the modified object as its value.
%
%  For additional discussion of these functions, see
%  the documentation of the
%   \code{\link{setAs}} function.  (Unfortunately, argument
%   \code{def} to that function corresponds to argument \code{coerce} here.)
%
%  The inheritance relationship can also be conditional, if a function is supplied as the
%  \code{test} argument.  This should be a function of one argument
%  that returns \code{TRUE} or \code{FALSE} according to whether the
%  object supplied satisfies the relation \code{is(object, class2)}.
%  Conditional relations between
%  classes are discouraged in general because they require a per-object
%  calculation to determine their validity. They cannot be applied
%  as efficiently as ordinary relations and tend to make the code that
%  uses them harder to interpret.  \emph{NOTE:  conditional inheritance
%    is not used to dispatch methods.}  Methods for conditional
%  superclasses will not be inherited.  Instead, a method for the
%  subclass should be defined that tests the conditional relationship.
%}
%\section{Inherited methods}{
%  A method written for a particular signature (classes matched to one
%  or more formal arguments to the function) naturally assumes that the
%  objects corresponding to the arguments can be treated as coming from
%  the corresponding classes.  The objects will have all the slots and
%  available methods for the classes.
%
%  The code that selects and dispatches the methods ensures that this
%  assumption is correct.  If the inheritance was \dQuote{simple}, that
%  is, defined by one or more uses of the \code{contains=} argument in
%  a call to \code{\link{setClass}}, no extra work is generally
%  needed.  Classes are inherited from the superclass, with the same
%  definition.
%
%  When inheritance is defined by a general call to
%  \code{setIs}, extra computations are required.  This form of
%  inheritance implies that the subclass does \emph{not} just contain
%  the slots of the superclass, but instead requires the explicit call
%  to the coerce and/or replace method.  To ensure correct computation,
%  the inherited method is supplemented by calls to \code{\link{as}}
%  before the body of the method is evaluated.
%
%  The calls to \code{\link{as}} generated in this case have the
%  argument \code{strict = FALSE}, meaning that extra information can
%  be left in the converted object, so long as it has all the
%  appropriate slots.  (It's this option that allows simple subclass
%  objects to be used without any change.)  When you are writing your
%  coerce method, you may want to take advantage of that option.
%
%  Methods inherited through non-simple extensions can result in ambiguities
%  or unexpected selections.  If \code{class2} is a specialized class
%  with just a few applicable methods, creating the inheritance
%  relation may have little effect on the behavior of \code{class1}.
%  But if \code{class2} is a class with many methods, you may
%  find that you now inherit some undesirable methods for
%  \code{class1}, in some cases, fail to inherit expected methods.
%  In the second example below, the non-simple inheritance from class
%  \code{"factor"} might be assumed to inherit S3 methods via that
%  class.  But the S3 class is ambiguous, and in fact is
%  \code{"character"} rather than \code{"factor"}.
%
%  For some generic functions, methods inherited by non-simple
%  extensions are either known to be invalid or sufficiently likely to
%  be so that the generic function has been defined to exclude such
%  inheritance.  For example \code{\link{initialize}} methods must
%  return an object of the target class; this is straightforward if the
%  extension is simple, because no change is made to the argument
%  object, but is essentially impossible.  For this reason, the generic
%  function insists on only simple extensions for inheritance.  See the
%  \code{simpleInheritanceOnly} argument to \code{\link{setGeneric}}
%  for the mechanism.  You can use this mechanism when defining new
%  generic functions.
%
%  If you get into problems with functions that do allow non-simple
%  inheritance, there are two basic choices.  Either
%  back off from the \code{setIs} call and settle for explicit coercing
%  defined by a call to \code{\link{setAs}}; or, define explicit
%  methods involving \code{class1} to override the bad inherited
%  methods.  The first choice is the safer, when there are serious
%  problems.
%
%}
%\seealso{
%  \code{\link{inherits}} is nearly always equivalent to
%  \code{is}, both for S4 and non-S4 objects, and is somewhat faster.
%  The non-equivalence applies to classes that have conditional
%  superclasses, with a non-trivial \code{test=} in the relation (not
%  common and discouraged):  for these, \code{is} tests for the
%  relation but \code{inherits} by definition ignores conditional
%  inheritance for S4 objects.
%
%
%  \code{\link{selectSuperClasses}(cl)} has similar semantics as
%  \code{extends(cl)}, typically returning subsets of the latter.
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\examples{
%\dontshow{
%## A simple class with two slots
%setClass("track",
%         representation(x="numeric", y="numeric"))
%## A class extending the previous, adding one more slot
%}
%## Two examples of setIs() with coerce= and replace= arguments
%## The first one works fairly well, because neither class has many
%## inherited methods do be disturbed by the new inheritance
%
%## The second example does NOT work well, because the new superclass,
%## "factor", causes methods to be inherited that should not be.
%
%## First example:
%## a class definition (see \link{setClass} for class "track")
%setClass("trackCurve", contains = "track",
%         representation( smooth = "numeric"))
%## A class similar to "trackCurve", but with different structure
%## allowing matrices for the "y" and "smooth" slots
%setClass("trackMultiCurve",
%         representation(x="numeric", y="matrix", smooth="matrix"),
%         prototype = structure(list(), x=numeric(), y=matrix(0,0,0),
%
%                               smooth= matrix(0,0,0)))
%## Automatically convert an object from class "trackCurve" into
%## "trackMultiCurve", by making the y, smooth slots into 1-column matrices
%setIs("trackCurve",
%      "trackMultiCurve",
%      coerce = function(obj) {
%        new("trackMultiCurve",
%            x = obj@x,
%            y = as.matrix(obj@y),
%            smooth = as.matrix(obj@smooth))
%      },
%      replace = function(obj, value) {
%        obj@y <- as.matrix(value@y)
%        obj@x <- value@x
%        obj@smooth <- as.matrix(value@smooth)
%        obj})
%
%
%\dontshow{
%removeClass("trackMultiCurve")
%removeClass("trackCurve")
%removeClass("track")
%}
%
%## Second Example:
%## A class that adds a slot to "character"
%setClass("stringsDated", contains = "character",
%         representation(stamp="POSIXt"))
%
%## Convert automatically to a factor by explicit coerce
%setIs("stringsDated", "factor",
%      coerce = function(from) factor(from@.Data),
%      replace= function(from, value) {
%                  from@.Data <- as.character(value); from })
%\dontshow{
%set.seed(750)
%}
%ll <- sample(letters, 10, replace = TRUE)
%ld <- new("stringsDated", ll, stamp = Sys.time())
%
%levels(as(ld, "factor"))
%levels(ld) # will be NULL--see comment in section on inheritance above.
%
%## In contrast, a class that simply extends "factor"
%## has no such ambiguities
%setClass("factorDated", contains = "factor",
%         representation(stamp="POSIXt"))
%fd <- new("factorDated", factor(ll), stamp = Sys.time())
%identical(levels(fd), levels(as(fd, "factor")))
%}
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%