% File src/library/methods/man/refClass.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2010-2013 R Core Team
% Distributed under GPL 2 or later

\name{LocalReferenceClasses}
\title{参照クラスに基づく局地化オブジェクト}
%\title{Localized Objects based on Reference Classes}
%@%\alias{参照クラスに基づく局地化オブジェクト}
\alias{LocalReferenceClasses}
\alias{localRefClass-class}
\alias{$<-,localRefClass-method} %$
\description{
局所参照クラスはオブジェクトを局所フレームに孤立させる
修正された \link{ReferenceClasses} である．
従ってそれらは変更を呼び出し環境に伝播しかえさ\emph{無い}．
同時に，それらは参照欄のセマンティックスを局所的に使い，
標準的な \R オブジェクトに適用される自動的な複製を避ける．

現在の実装は特別な構成を持たない．
局所参照クラスを作るため，\code{\link{setRefClass}()} を\cr
\code{"localRefClass"} を含む
\code{contains=} 引数と共に呼び出す．下の例を見よ．

局所参照クラスは本質的に \R の正規の機能的なクラスに対するように
操作する；つまり，変更は付値で行われ局所的なフレーム中で起こる．
本質的な違いは置き換え操作(例中の \code{twiddle} 欄への変更の様に)は，
形式的クラスに対してや，属性を持つデータに対してや又はそして
名前付きリスト中の様に，オブジェクト全体の複製を起こさない．
目的は他の欄への可能性として頻繁な変更と共には
変更されないある種の欄中の大きなオブジェクトを認めることにあるが，
大きな欄のコピーはしない．

}
\usage{
\special{setRefClass(Class, fields = , contains = c("localRefClass",....),
     methods =, where =, ...)}
}

\details{
オブジェクトの局所化は現在の実装では部分的にしか自動化されていない．
\code{$<-} 演算子を使った置き換え表現式は安全である．%$

しかしながら，クラスの参照メソッド自体が例えば \code{<<-} を使って
欄を修正すると，
任意のそうしたメソッドが呼び出される前にオブジェクトが
関連するフレームに対して局所的であることを確認する必要がある．
さもなければ標準的な参照クラス挙動が依然として優勢になる．

局所性を保証する二つの方法がある．
直接的な方法は特殊なメソッド
\code{x$ensureLocal()} をオブジェクトに対して起動することである．
他の方法は欄を
\code{x$field <- ...} により明示的に修正することである．
参照に対する局所性を与える安直なコピーを惹き起こすためには，
各オブジェクトに対してこれらの一つまたは他が一回使われるだけで
十分である．下の例では，両方の機構を示す．

どのようになされるにせよ，局所化は
任意のメソッドが変更を行う\emph{前}に起きなければならない．
(任意の環境下で成功を保証するのは困難かもしれないが，
結局はコードツールの利用は少なくとも大部分このプロセス
を自動化すべきである．)

}

\author{
  John Chambers
}

\examples{
## クラス "myIter" は実(ビッグ)データに対する BigData 欄を持ち
## そしてそれが弄る(ある理由から)ある種のパラメータに対する "twiddle" 欄を持つ

myIter <- setRefClass("myIter", contains = "localRefClass",
  fields = list(BigData = "numeric", twiddle = "numeric"))

tw <- rnorm(3)
x1 <- myIter(BigData = rnorm(1000), twiddle = tw) # OK, not REALLY big

twiddler <- function(x, n) {
  x$ensureLocal() # 詳細を見よ．この例では本当は不要
  for(i in seq(length = n)) {
      x$twiddle <- x$twiddle + rnorm(length(x$twiddle))
      ## そして何かをする ....
      ## gdb で詮索する等により x$BigData がコピーされていないことが分かる
  }
  return(x)
}

x2 <- twiddler(x1, 10)

stopifnot(identical(x1$twiddle, tw), !identical(x1$twiddle, x2$twiddle))

}
\keyword{ programming }
\keyword{ classes }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/refClass.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2010-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{LocalReferenceClasses}
%\title{Localized Objects based on Reference Classes}
%\alias{LocalReferenceClasses}
%\alias{localRefClass-class}
%\alias{$<-,localRefClass-method} %$
%\description{
%Local reference classes are modified \link{ReferenceClasses} that
%isolate the objects to the local frame.  Therefore, they do \emph{not}
%propagate changes back to the calling environment.   At the same time,
%they use the reference field semantics locally, avoiding the automatic
%duplication applied to standard \R objects.
%
%The current implementation has no special construction.  To create a
%local reference class, call \code{\link{setRefClass}()} with a
%\code{contains=} argument that includes \code{"localRefClass"}.  See
%the example below.
%
%Local reference classes operate essentially as do regular, functional
%classes in \R; that is, changes are made by assignment and take place
%in the local frame.
%The essential difference is that replacement operations (like the
%change to the \code{twiddle} field in the example) do not cause
%duplication of the entire object, as would be the case for a formal
%class or for data with attributes or in a named list.
%The purpose is to allow large objects in some fields that are not
%changed along with potentially frequent changes to other fields, but
%without copying the large fields.
%
%}
%\usage{
%\special{setRefClass(Class, fields = , contains = c("localRefClass",....),
%     methods =, where =, ...)}
%}
%
%\details{
%Localization of objects is only partially automated in the current implementation.
%Replacement expressions using the \code{$<-} operator are safe. %$
%
%However, if reference methods for the class themselves modify fields,
%using \code{<<-}, for example, then 
%one must ensure that the object is local to the relevant frame before
%any such method is called.
%Otherwise, standard reference class behavior still prevails.
%
%There are two ways to ensure locality.  The direct way is to invoke
%the special
%method \code{x$ensureLocal()} on the object.
%The other way is to modify a field explicitly by \code{x$field <- ...}
%It's
%only necessary that  one or the other of these happens
%once for each object, in order to trigger the shallow copy that
%provides locality for the references.  In the example below, we show
%both mechanisms.
%
%However it's done, localization must occur
%\emph{before} any methods make changes.  (Eventually, some use of code
%tools should at least largely automate this process, although it may
%be difficult to guarantee success under arbitrary circumstances.)
%}
%
%\author{
%  John Chambers
%}
%
%\examples{
%## class "myIter" has a BigData field for the real (big) data
%## and a "twiddle" field for some parameters that it twiddles
%## ( for some reason)
%
%myIter <- setRefClass("myIter", contains = "localRefClass",
%  fields = list(BigData = "numeric", twiddle = "numeric"))
%
%tw <- rnorm(3)
%x1 <- myIter(BigData = rnorm(1000), twiddle = tw) # OK, not REALLY big
%
%twiddler <- function(x, n) {
%  x$ensureLocal() # see the Details.  Not really needed in this example
%  for(i in seq(length = n)) {
%      x$twiddle <- x$twiddle + rnorm(length(x$twiddle))
%      ## then do something ....
%      ## Snooping in gdb, etc will show that x$BigData is not copied
%  }
%  return(x)
%}
%
%x2 <- twiddler(x1, 10)
%
%stopifnot(identical(x1$twiddle, tw), !identical(x1$twiddle, x2$twiddle))
%
%}
%\keyword{ programming }
%\keyword{ classes }
%
%\encoding{UTF8}
%