% File src/library/methods/man/method.skeleton.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{method.skeleton}
%@%\alias{新しいメソッドに対する骨格ファイル}
\alias{method.skeleton}
\title{新しいメソッドに対する骨格ファイルを作る}
%\title{Create a Skeleton File for a New Method}
\description{
  この関数は
  与えられた総称的関数とシグネチャに対するメソッドを定義する
  \code{\link{setMethod}} の呼び出しを含むソースファイルを書く．
  既定ではメソッド定義は呼び出し中に埋め込まれているが，
  外部(先に付値された)関数にすることも出来る．
}
\usage{
method.skeleton(generic, signature, file, external = FALSE, where)
}
\arguments{
  \item{generic}{
      総称的関数の文字列名，または総称的関数自体．
      最初の場合，
      結果の \code{\link{setMethod}} 呼び出しに対してそうであるように，
      関数は現在総称的で無くても良い．
      }
  \item{signature}{
      \code{\link{setMethod}} に与えられるようなメソッドのシグネチャ．}
  \item{file}{
      出力ファイルの文字列名，または買い込み可能なコネクション．
      既定では総称的関数名とシグネチャ中のクラスが
      アンダースコア文字で連結される，
      ファイル名は普通 \code{".R"} で終わる．}

    複数のメソッド骨格を一つのファイルに書き込むには，
    先ずファイルコネクションを開きそれからそれを
    複数呼び出し中の \code{method.skeleton()} に渡す．
  \item{external}{
      メソッドに対する関数定義が
      ソースファイル中に付値された別個のオブジェクトであるべきか，
      または \code{\link{setMethod}} への呼び出し中にインラインで埋め込まれるべきかを
      制御するフラグ．
    もし文字列として与えられると，これは外部関数に対する名前として使われる；
    既定では名前は総称的関数とシグネチャをアンダースコア文字で連結する．}
  \item{where}{関数をその中で探す環境；既定では
    \code{method.skeleton} の呼び出しのトップレベル環境．}
}
\value{
  不可視の \code{file} 引数であるが，関数はその副作用のために使われる．
}
\seealso{\code{\link{setMethod}}, \code{\link{package.skeleton}}
}
\examples{
\dontshow{oWD <- setwd(tempdir())}
setClass("track", representation(x ="numeric", y="numeric"))
method.skeleton("show", "track")            ## show_track.R を書き込む
method.skeleton("Ops", c("track", "track")) ## "Ops_track_track.R" を書き込む

## 複数のメソッド骨格を一つのファイルに書き込む
con <- file("./Math_track.R", "w")
method.skeleton("Math", "track", con)
method.skeleton("exp", "track", con)
method.skeleton("log", "track", con)
close(con)
\dontshow{setwd(oWD)}
}
\keyword{programming}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/method.skeleton.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{method.skeleton}
%\alias{method.skeleton}
%\title{Create a Skeleton File for a New Method}
%\description{
%  This function writes a source file containing a call to
%  \code{\link{setMethod}} to define a method for the generic function
%  and signature supplied.  By default the method definition is in line
%  in the call, but can be made an external (previously assigned) function.
%}
%\usage{
%method.skeleton(generic, signature, file, external = FALSE, where)
%}
%\arguments{
%  \item{generic}{the character string name of the generic function, or
%      the generic function itself.  In the first case, the function
%      need not currently be a generic, as it would not for the
%      resulting call to \code{\link{setMethod}}.}
%  \item{signature}{the method signature, as it would be given to \code{\link{setMethod}}}
%  \item{file}{a character string name for the output file, or a
%      writable connection.  By default the generic function name and
%      the classes in the signature are concatenated, with separating
%      underscore characters.  The file name should normally end in \code{".R"}. }
%
%    To write multiple method skeletons to one file, open the file
%    connection first and then pass it to \code{method.skeleton()} in
%    multiple calls.
%  \item{external}{flag to control whether the function definition for
%      the method should be a separate external object assigned in the
%      source file, or included in line in the call to
%      \code{\link{setMethod}}.
%    If supplied as a character string, this will be used as the name
%    for the external function; by default the name concatenates the
%    generic and signature names, with separating underscores.}
%  \item{where}{The environment in which to look for the function; by default,
%    the top-level environment of the call to \code{method.skeleton}.}
%}
%\value{
%  The \code{file} argument, invisibly, but the function is used for its side effect.
%}
%\seealso{\code{\link{setMethod}}, \code{\link{package.skeleton}}
%}
%\examples{
%\dontshow{oWD <- setwd(tempdir())}
%setClass("track", representation(x ="numeric", y="numeric"))
%method.skeleton("show", "track")            ## writes show_track.R
%method.skeleton("Ops", c("track", "track")) ## writes "Ops_track_track.R"
%
%## write multiple method skeletons to one file
%con <- file("./Math_track.R", "w")
%method.skeleton("Math", "track", con)
%method.skeleton("exp", "track", con)
%method.skeleton("log", "track", con)
%close(con)
%\dontshow{setwd(oWD)}
%}
%\keyword{programming}
%\keyword{methods}
%
%\encoding{UTF8}
%