% File src/library/methods/man/methodUtilities.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{methodUtilities}
%@%\alias{メソッドと S-Plus 互換性のためのユーティリティ関数}
\alias{functionBody}
\alias{functionBody<-}
\alias{allNames}
\alias{getFunction}
\alias{existsFunction}
\alias{el}
\alias{elNamed}
\alias{el<-}
\alias{elNamed<-}
\alias{formalArgs}
\alias{Quote}
\alias{showDefault}
\alias{initMethodDispatch}
\alias{methodSignatureMatrix}
\title{メソッドと S-Plus 互換性のためのユーティリティ関数}
%\title{Utility Functions for Methods and S-Plus Compatibility}
\description{
  これは現在 \pkg{methods} パッケージ中にある\emph{内部的}ユーティリティで，
  パッケージが必要とするユーティリティ
  (例えば名前による要素のマッチング)，または
  S-Plus との互換性を加える，または両者を提供する．
}
\usage{
functionBody(fun=sys.function(sys.parent()))

allNames(x)

getFunction(name, generic=TRUE, mustFind=TRUE, where)

el(object, where)

elNamed(x, name, mustFind=FALSE)

formalArgs(def)

Quote(expr)

showDefault(object, oldMethods = TRUE)

initMethodDispatch(where = topenv(parent.frame()))

methodSignatureMatrix(object, sigSlots = c("target", "defined"))
}
\section{関数の要約}{
  \describe{
    \item{\code{allNames}:}{
      名前の文字列(\code{names()} とは異なり決して
      \code{NULL} を返さない)．
    }
    \item{\code{getFunction}:}{
      オブジェクトを関数として見つける．
    }
    \item{\code{el}:}{
      \code{el(object, i)} は
      \code{object[i][[1]]} と同値である
      (そして典型的に
      object[[i]] で置き換え可能であるべきである)．
    }
    \item{\code{elNamed}:}{
      名前に対応するベクトルの要素を得る．
      \code{\link{[}}，\code{\link{[[}} そして \code{\link{$}} 演算子と異なり，
      この関数は
      要素名に正確にマッチ(部分マッチをしない)するために \code{name} を必要とする．
    }
    \item{\code{formalArgs}:}{
      この関数の形式的引数の名前を返す．
    }
    \item{\code{existsFunction}:}{
      この名前の関数は存在するか?  もし \code{generic} が
      \code{FALSE} ならば，総称的関数はカウントされない．
    }
    \item{\code{findFunction}:}{
      そこに \code{name} に対する関数定義が存在する検索リストの
      全ての添字を返す．

      もし \code{generic} が \code{FALSE} ならば，総称的関数を無視する．
    }
    \item{\code{showDefault}:}{
      ユーティリティで，\code{show} メソッドが自動プリントにより
      呼び出されるようにする(\code{print.default} を使い)ために使われる．

      引数 \code{oldMethods} はこのオブジェクトに対して旧式の
      プリントメソッドを使うかどうかを制御する．
      もし直接に呼び出されると，これは既定で \code{TRUE} であるが，
      自動プリントに対する \pkg{methods} パッケージから呼び出されると
      \code{FALSE} である(潜在的な再帰を避けるため)．
    }
    \item{\code{initMethodDispatch}:}{
      内部的なメソッド選択適用コードをオンにする．
      名前空間のロードに対して呼び出される．
      又，もし選択適用がオフにされていると
      (非常に大胆だが呼び出し \code{isMethodsDispatchOn(FALSE)} を使い)，
      この関数の呼び出しは選択適用を再び元に戻す．
    }
    \item{\code{methodSignatureMatrix}:}{
      指定したスロットの中身を行とする行列を返す．
      スロットは同じ長さの名前付き文字列でなければならない．
      基本的に \code{"MethodDefinition"} オブジェクトのシグネチャを
      プリント用に行列に変換するために使われる．
    }
    \item{\code{Quote}:}{
      \code{\link{quote}()} と同義で廃止予定を考えている．
    }
  }
}
\keyword{internal}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/methodUtilities.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{methodUtilities}
%\alias{functionBody}
%\alias{functionBody<-}
%\alias{allNames}
%\alias{getFunction}
%\alias{existsFunction}
%\alias{el}
%\alias{elNamed}
%\alias{el<-}
%\alias{elNamed<-}
%\alias{formalArgs}
%\alias{Quote}
%\alias{showDefault}
%\alias{initMethodDispatch}
%\alias{methodSignatureMatrix}
%\title{Utility Functions for Methods and S-Plus Compatibility}
%\description{
%  These are \emph{internal} utilities, currently in the \pkg{methods}
%  package, that either provide some functionality needed by the package
%  (e.g., element matching by name), or add compatibility with S-Plus, or both.
%}
%\usage{
%functionBody(fun=sys.function(sys.parent()))
%
%allNames(x)
%
%getFunction(name, generic=TRUE, mustFind=TRUE, where)
%
%el(object, where)
%
%elNamed(x, name, mustFind=FALSE)
%
%formalArgs(def)
%
%Quote(expr)
%
%showDefault(object, oldMethods = TRUE)
%
%initMethodDispatch(where = topenv(parent.frame()))
%
%methodSignatureMatrix(object, sigSlots = c("target", "defined"))
%}
%\section{Summary of Functions}{
%  \describe{
%    \item{\code{allNames}:}{
%      the character vector of names (unlike \code{names()}, never
%      returns \code{NULL}).
%    }
%    \item{\code{getFunction}:}{
%      find the object as a function.
%    }
%    \item{\code{el}:}{\code{el(object, i)} is equivalent to
%      \code{object[i][[1]]} (and should typically be replaceable by object[[i]]).
%    }
%    \item{\code{elNamed}:}{
%      get the element of the vector corresponding to name.  Unlike the
%      \code{\link{[}}, \code{\link{[[}}, and \code{\link{$}} operators, this function
%      requires \code{name} to match the element name exactly (no partial
%      matching).
%    }
%    \item{\code{formalArgs}:}{
%      Returns the names of the formal arguments of this function.
%    }
%    \item{\code{existsFunction}:}{
%      Is there a function of this name?  If \code{generic} is
%      \code{FALSE}, generic functions are not counted.
%    }
%    \item{\code{findFunction}:}{
%      return all the indices of the search list on which a function
%      definition for \code{name} exists.
%
%      If \code{generic} is \code{FALSE}, ignore generic functions.
%    }
%    \item{\code{showDefault}:}{
%      Utility, used to enable \code{show} methods to be called by the
%      automatic printing (via \code{print.default}).
%
%      Argument \code{oldMethods} controls whether old-style print
%      methods are used for this object.  It is \code{TRUE} by default
%      if called directly, but \code{FALSE} when called from the
%      \pkg{methods} package for automatic printing (to avoid potential
%      recursion).
%    }
%    \item{\code{initMethodDispatch}:}{
%      Turn on the internal method dispatch code.  Called on loading
%      the namespace.  Also, if dispatch has been turned off (by calling
%      \code{.isMethodsDispatchOn(FALSE)}---a very gutsy thing to do),
%      calling this function should turn dispatch back on again.
%    }
%    \item{\code{methodSignatureMatrix}:}{
%      Returns a matrix with the contents of the specified slots as
%      rows.  The slots should be named character strings of the same
%      length.  Basically used to turn the signatures of a
%      \code{"MethodDefinition"} object into a matrix for printing.
%    }
%    \item{\code{Quote}:}{is a synonym of \code{\link{quote}()} and
%      considered deprecated.
%    }
%  }
%}
%\keyword{internal}
%
%\encoding{UTF8}
%