% File src/library/methods/man/methods-defunct.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{methods-defunct}
%@%\alias{パッケージ methods 中の廃止された関数}
\alias{methods-defunct}
\alias{getAllMethods}
\alias{mlistMetaName}
\alias{removeMethodsObject}
\alias{getAccess}
\alias{getClassName}
\alias{getClassPackage}
\alias{getExtends}
\alias{getProperties}
\alias{getPrototype}
\alias{getSubclasses}
\alias{getVirtual}
\alias{seemsS4Object}
\alias{allGenerics}
\alias{trySilent}
\alias{traceOn}
\alias{traceOff}
\title{パッケージ \pkg{methods} 中の廃止された関数}
%\title{Defunct Functions in Package \pkg{methods}}
\description{
パッケージ \pkg{methods} 中の廃止された関数．
}
\usage{
% Removed in 2.8.0
getAccess(ClassDef)
getClassName(ClassDef)
getClassPackage(ClassDef)
getExtends(ClassDef)
getProperties(ClassDef)
getPrototype(ClassDef)
getSubclasses(ClassDef)
getVirtual(ClassDef)

getAllMethods(f, fdef, where)
mlistMetaName (name, package)
removeMethodsObject(f, where)

seemsS4Object(object)

% Removed in 2.9.0
allGenerics()

% Removed in 2.11.0
trySilent(expr)

% Removed in 3.0.0
traceOn(what, tracer=browseAll, exit=NULL)
traceOff(what)
}
\details{
  関数の最初のブロックはスロットへの直接のアクセスか，
  高水準の代替物の使用に置き換えられるべきである．

  関数と対応するスロットは以下のようである：
  \tabular{ll}{
    \code{getAccess} \tab \code{"access"} \cr
    \code{getClassName} \tab \code{"className"} \cr
    \code{getClassPackage} \tab \code{"package"} \cr
    \code{getExtends} \tab \code{"contains"} \cr
    \code{getProperties} \tab \code{"slots"} \cr
    \code{getPrototype} \tab \code{"prototype"} \cr
    \code{getSubclasses} \tab \code{"subclasses"} \cr
    \code{getVirtual} \tab \code{"virtual"}
  }

  \code{getAllMethods} は
  \code{\link{getMethods}} の挙動を複製していた．これは代わりに
  \code{getAllMethods} の古い挙動を近似的に得るために呼び出されるべきであった．
  しかしながら，より良い代わりは
  \code{\link{findMethods}} の使用で，これはより簡単な構造を返す．

  \code{mlistMetaName} は
  特定の総称的関数に対するメソッドの \code{MethodsList} 表現を
  保管するオブジェクトに対するややこしい名前を返す
  ユーティリティであった．

  \code{removeMethodsObject} は
  \code{f} に対するメソッドを含むメタデータオブジェクトを取り除く．

  \code{seemsS4Object} は \code{\link{isS4}} に似ており
  \R 2.4.0 中の S4 ビットの導入により取って代わられた．

  \code{allGenerics} は \code{\link{getGenerics}} に取って代わられた．

  \code{trySilent(ex)} は
  \code{\link{try}(e, silent=TRUE)} の廃止予定の同値物であった；
  \R プログラミングではそれは典型的には
  \code{\link{tryCatch}(ex, error = function(e) e)} のような
  ものを扱うには代わりにより効率的で柔軟である．

  関数 \code{traceOn} と \code{traceOff} は
  関数 \code{\link{trace}} と \code{\link{untrace}} の
  拡張バージョンで置き換えられてきている．
}

\seealso{
  \code{\link{Defunct}}
}
\keyword{internal}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/methods-defunct.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{methods-defunct}
%\alias{methods-defunct}
%\alias{getAllMethods}
%\alias{mlistMetaName}
%\alias{removeMethodsObject}
%\alias{getAccess}
%\alias{getClassName}
%\alias{getClassPackage}
%\alias{getExtends}
%\alias{getProperties}
%\alias{getPrototype}
%\alias{getSubclasses}
%\alias{getVirtual}
%\alias{seemsS4Object}
%\alias{allGenerics}
%\alias{trySilent}
%\alias{traceOn}
%\alias{traceOff}
%\title{Defunct Functions in Package \pkg{methods}}
%\description{
%  Defunct functions in package \pkg{methods}.
%}
%\usage{
%% Removed in 2.8.0
%getAccess(ClassDef)
%getClassName(ClassDef)
%getClassPackage(ClassDef)
%getExtends(ClassDef)
%getProperties(ClassDef)
%getPrototype(ClassDef)
%getSubclasses(ClassDef)
%getVirtual(ClassDef)
%
%getAllMethods(f, fdef, where)
%mlistMetaName (name, package)
%removeMethodsObject(f, where)
%
%seemsS4Object(object)
%
%% Removed in 2.9.0
%allGenerics()
%
%% Removed in 2.11.0
%trySilent(expr)
%
%% Removed in 3.0.0
%traceOn(what, tracer=browseAll, exit=NULL)
%traceOff(what)
%}
%\details{
%  The first block of functions should be replaced by direct access to
%  the slots, or by use of higher-level alternatives.
%
%  The functions and corresponding slots are:
%  \tabular{ll}{
%    \code{getAccess} \tab \code{"access"} \cr
%    \code{getClassName} \tab \code{"className"} \cr
%    \code{getClassPackage} \tab \code{"package"} \cr
%    \code{getExtends} \tab \code{"contains"} \cr
%    \code{getProperties} \tab \code{"slots"} \cr
%    \code{getPrototype} \tab \code{"prototype"} \cr
%    \code{getSubclasses} \tab \code{"subclasses"} \cr
%    \code{getVirtual} \tab \code{"virtual"}
%  }
%
%  \code{getAllMethods} replicated the behavior of
%  \code{\link{getMethods}}, which should be called instead to obtain
%  approximately the old behavior of \code{getAllMethods}.  However, a
%  better substitution is to use \code{\link{findMethods}}, which
%  returns a simpler structure.
%
%  \code{mlistMetaName} was a utility to  return the mangled
%  name for the object that stored the \code{MethodsList}
%  representation of the methods for a particular generic function,
%  typically in the environment of a package.  These objects are no
%  longer used.
%
%  \code{removeMethodsObject} removed the metadata object containing
%  methods for \code{f}.
%
%  \code{seemsS4Object} was similar to \code{\link{isS4}} and superseded
%  by the introduction of the S4 bit in \R 2.4.0.
%
%  \code{allGenerics} is superseded by \code{\link{getGenerics}}.
%
%  \code{trySilent(ex)} was a deprecated equivalent of \code{\link{try}(e,
%    silent=TRUE)}; in \R programming it is typically more efficient and
%  flexible to work with something like \code{\link{tryCatch}(ex,
%    error = function(e) e)} instead.
%
%  The functions \code{traceOn} and \code{traceOff} have been replaced by
%  extended versions of the functions \code{\link{trace}} and
%  \code{\link{untrace}}.
%}
%
%\seealso{
%  \code{\link{Defunct}}
%}
%\keyword{internal}
%
%\encoding{UTF8}
%