% File src/library/methods/man/new.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{new}
%@%\alias{クラスからオブジェクトを生成する}
\alias{new}
\alias{initialize}
\title{クラスからオブジェクトを生成する}
%\title{ Generate an Object from a Class }
\description{
  クラスの名前か定義とオブジェクト中に含められるオプションのデータを
  与え，\code{new} はそのクラスからのオブジェクトを返す．
}
\usage{
new(Class, ...)

initialize(.Object, ...)
}
\arguments{
  \item{Class}{クラスの名前か
    \code{\link{character}} 文字列
    (通常のケース)，またはクラスを記述するオブジェクト
    (つまり \code{getClass} が返すもの)．}
  \item{\dots}{新しいオブジェクト中に含められるデータ．
    クラス定義中のスロットに対応する名前付き引数．
    名前無しの引数はこのクラスが拡張するクラスからのオブジェクトで
    なければならない．}
  \item{.Object}{オブジェクト：詳細節を見よ．}
}
\details{
  関数 \code{new} はクラス定義からプロトタイプオブジェクトをコピーすることから
  始める．それから，もしあれば情報が
  \code{\dots} 引数に従い挿入される．
  R のバージョン 2.4 現在，プロトタイプオブジェクト，そして
  従って
  \code{new()} が返す全てのオブジェクトは，プロトタイプがその基本タイプを
  持つ時基本タイプの一つを
  拡張するクラスを例外として \code{"S4"} である．
  \code{\link{typeof}(object)} に依存するユーザ関数は
  可能なタイプとして \code{"S4"} を処理することに注意すべである．

  最初の引数の\emph{名前} \code{"Class"} は
  \code{"Class"} が任意の形式的クラス中の好ましくないスロット名
  であることを必須とすることを注意する：
  \code{new("myClass", Class = <value>)} は使える．

  \code{\dots} 引数の解釈は，もし総称的関数 \code{"initialize"} に
  対する適当なメソッドが定義されていれば，特定のクラスに特殊化出来る．
  \code{new} 関数は \code{initialize} を
  \code{initialize} への \code{.Object} 引数としてプロトタイプから
  生成されたオブジェクトと共に呼び出される．

  既定では，
  \code{\dots} 中の名前のない引数はスーパークラスからのオブジェクトと
  解釈され，名前付き引数は対応する名前付きスロット中に付値される
  オブジェクトと解釈される．このように，
  明示的なスロットは引数が現れる順序と無関係に，同じスロットに対する
  継承情報を上書きする．

  \code{initialize} メソッドは
  \code{\dots} をそれらの第二引数として持つべきではない
  (例を見よ)．新しいオブジェクトを記述する自然なパラメータが
  スロット名では無い時初期化メソッドがしばしば書かれる．
  もしそうしたメソッドを定義するならば，
  自分のクラスの将来のサブクラスに対する含意を注意する．
  もしこれらが追加のスロットを持ち，自分の
  \code{initialize} メソッドが
  \code{\dots} を形式的引数として持つならば，
  メソッドはそうした引数を
  \code{\link{callNextMethod}} を使って渡すべきである．
  もし自分のメソッドがこの引数を持たなければ，
  サブクラスがそれ自体のメソッドを持つか，または
  付け加えられたスロットが
  \code{new} への引数として以外の方法でユーザにより指定されなければならない．

  \code{initialize} メソッドに対する例としては，
  とりわけ既存メソッドに対する \code{\link{initialize-methods}}
  クラス \code{"traceable"} と \code{"environment"} を見よ．
  そこの \code{"environment"} のサブクラスに関するコメントを見よ；
  これらに対する任意の \code{initialize} メソッドは新しい環境を
  確保することが確実であるべきである．

  メソッドは目標のクラスからのオブジェクトを返すことが要求されるので，
  \code{initialize} に対するメソッドは単純な継承によってのみ継承される．
  \code{\link{setGeneric}} に対する
  \code{simpleInheritanceOnly} 引数と，
  一般的な概念に対する \code{\link{setIs}} 中の議論を見よ．

  \code{"numeric"} 等の基本ベクトルクラスは暗黙のうちに定義されるので
  これらのクラスに対して \code{new} を使うことが出来ることを注意する．
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\seealso{ クラス定義の概観は \link{Classes}，そして
  S3 クラスとの関連に対しては \code{\link{setOldClass}}．}

\examples{
## \link{setClass} からのクラス "track" を使う

\dontshow{
setClass("track",
         representation(x="numeric", y="numeric"))
setClass("trackCurve",
         representation("track", smooth = "numeric"))

ydata <- stats::rnorm(10); ysmooth <- 1:10
}

## 次で指定される二つのスロットを持つ新しいオブジェクト
t1 <- new("track", x = seq_along(ydata), y = ydata)

# スーパークラスからのオブジェクトと，次のスロットを含む新しいオブジェクト
t2 <- new("trackCurve", t1, smooth = ysmooth)

### 初期化のためのメソッドを定義，
### 新しいオブジェクトが等しい長さの x と y スロットを持つことを保証する．

setMethod("initialize",
          "track",
          function(.Object, x = numeric(0), y = numeric(0)) {
            if(nargs() > 1) {
              if(length(x) != length(y))
                stop("specified x and y of different lengths")
              .Object@x <- x
              .Object@y <- y
            }
            .Object
          })

### x に対する既定値を組み込んでいないため，次の例はエラーになる
### (x は numeric(0) になる), 
### 初期化のためのより洗練されたメソッドを使うことができたであろうが

try(new("track", y = sort(stats::rnorm(10))))

## 先の初期化メソッドを実装するより良い方法．
## 何故か?  既定の初期化メソッドを呼び出すため callNextMethod を使い，
## "track" を拡張するクラスが new() 関数の一般的な書式を使うことを禁止しない．
## 先のバージョンでは，それら自体の初期化メソッドを欠いていない限り，
## それらは x と y を new への引数としてだけ使える

setMethod("initialize", "track", function(.Object, ...) {
    .Object <- callNextMethod()
    if(length(.Object@x) != length(.Object@y))
     stop("specified x and y of different lengths")
    .Object
  })

}
\keyword{programming}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/new.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{new}
%\alias{new}
%\alias{initialize}
%\title{ Generate an Object from a Class }
%\description{
%  Given the name or the definition of a class, plus optionally data
%  to be included in the object, \code{new} returns an object from that
%  class.
%}
%\usage{
%new(Class, ...)
%
%initialize(.Object, ...)
%}
%\arguments{
%  \item{Class}{either the name of a class, a \code{\link{character}}
%    string, (the usual case) or the object describing the class (e.g.,
%    the value returned by \code{getClass}).}
%  \item{\dots}{data to include in the new object.  Named arguments
%    correspond to slots in the class definition. Unnamed arguments must
%    be objects from classes that this class extends.}
%  \item{.Object}{ An object:  see the Details section.}
%}
%\details{
%  The function \code{new} begins by copying the prototype object from
%  the class definition.  Then information is inserted according to the
%  \code{\dots} arguments, if any.  As of version 2.4 of R, the type of
%  the prototype object, and therefore of all objects returned by
%  \code{new()}, is \code{"S4"} except for classes that extend
%  one of the basic types, where the prototype has that basic type.  User
%  functions that depend on \code{\link{typeof}(object)} should be
%  careful to handle \code{"S4"} as a possible type.
%
%  Note that the \emph{name} of the first argument, \code{"Class"}
%  entails that \code{"Class"} is an undesirable slot name in any formal
%  class: \code{new("myClass", Class = <value>)} will not work.
%
%  The interpretation of the \code{\dots} arguments can be specialized to
%  particular classes, if an appropriate method has been defined for the
%  generic function \code{"initialize"}.  The \code{new} function calls
%  \code{initialize} with the object generated from the prototype as the
%  \code{.Object} argument to \code{initialize}.
%
%  By default, unnamed arguments in the \code{\dots} are interpreted as
%  objects from a superclass, and named arguments are interpreted as
%  objects to be assigned into the correspondingly named slots.  Thus,
%  explicit slots override inherited information for the same slot,
%  regardless of the order in which the arguments appear.
%
%  The \code{initialize} methods do not have to have \code{\dots} as
%  their second argument (see the examples).  Initialize methods are
%  often written when the natural parameters describing the new object
%  are not the names of the slots.  If you do define such a method,
%  note the implications for future subclasses of your class.  If these
%  have additional slots, and your \code{initialize} method has
%  \code{\dots} as a formal argument, then your method should pass such
%  arguments along via \code{\link{callNextMethod}}.  If your method
%  does not have this argument, then either a subclass must have its
%  own method or else the added slots must be specified by users in
%  some way other than as arguments to \code{new}.
%
%  For examples of \code{initialize} methods, see
%  \code{\link{initialize-methods}} for existing methods for
%  classes \code{"traceable"} and \code{"environment"}, among
%  others. See the comments there on subclasses of
%  \code{"environment"}; any \code{initialize} methods for these should
%  be sure to allocate a new environment.
%
%  Methods for \code{initialize} can be inherited only by simple
%  inheritance, since it is a requirement that the method return an
%  object from the target class.  See the
%  \code{simpleInheritanceOnly} argument to \code{\link{setGeneric}} and
%  the discussion in \code{\link{setIs}} for the general concept.
%
%  Note that the basic vector classes, \code{"numeric"}, etc. are
%  implicitly defined, so one can use \code{new} for these classes.
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{ \link{Classes} for an overview of defining class, and
%  \code{\link{setOldClass}} for the relation to S3 classes. }
%
%\examples{
%## using the definition of class "track" from \link{setClass}
%
%\dontshow{
%setClass("track",
%         representation(x="numeric", y="numeric"))
%setClass("trackCurve",
%         representation("track", smooth = "numeric"))
%
%ydata <- stats::rnorm(10); ysmooth <- 1:10
%}
%
%## a new object with two slots specified
%t1 <- new("track", x = seq_along(ydata), y = ydata)
%
%# a new object including an object from a superclass, plus a slot
%t2 <- new("trackCurve", t1, smooth = ysmooth)
%
%### define a method for initialize, to ensure that new objects have
%### equal-length x and y slots.
%
%setMethod("initialize",
%          "track",
%          function(.Object, x = numeric(0), y = numeric(0)) {
%            if(nargs() > 1) {
%              if(length(x) != length(y))
%                stop("specified x and y of different lengths")
%              .Object@x <- x
%              .Object@y <- y
%            }
%            .Object
%          })
%
%### the next example will cause an error (x will be numeric(0)),
%### because we didn't build in defaults for x,
%### although we could with a more elaborate method for initialize
%
%try(new("track", y = sort(stats::rnorm(10))))
%
%## a better way to implement the previous initialize method.
%## Why?  By using callNextMethod to call the default initialize method
%## we don't inhibit classes that extend "track" from using the general
%## form of the new() function.  In the previous version, they could only
%## use x and y as arguments to new, unless they wrote their own
%## initialize method.
%
%setMethod("initialize", "track", function(.Object, ...) {
%    .Object <- callNextMethod()
%    if(length(.Object@x) != length(.Object@y))
%     stop("specified x and y of different lengths")
%    .Object
%  })
%
%}
%\keyword{programming}
%\keyword{classes}
%
%\encoding{UTF8}
%