% File src/library/methods/man/nonStructure-class.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-12 R Core Team
% Distributed under GPL 2 or later

\name{nonStructure-class}
\docType{class}
%@%\alias{基本タイプに対する非構造的S4クラス}
\alias{nonStructure-class}
\alias{Math,nonStructure-method}
\alias{Math2,nonStructure-method}
\alias{Ops,vector,nonStructure-method}
\alias{Ops,nonStructure,vector-method}
\alias{Ops,nonStructure,nonStructure-method}

\title{基本タイプに対する非構造的 S4 クラス}
%\title{A non-structure S4 Class for basic types }
\description{ 基本ベクトルクラスの一つを拡張するために定義された S4 クラスは，
  もしそれらが構造として動作するならば，
  クラス \code{\linkS4class{structure}} を含まなければならない；
  つまりもしそれらが数学関数や演算の下で
  それらのクラス挙動をそれらの長さが未変更である限り保つべきであれば．
  一方で，もしそれらのクラスが単にその構造だけでなくオブジェクト中の
  値に依存するならば，それらは任意のそうした変換の下でそのクラスを
  失うべきである．後者の場合，それらは
  \code{nonStructure} を含むように定義されるべきである．

  もしこれらの戦略のどれもが適用されなければ，
  クラスは \code{\link{Ops}}, \code{\link{Math}} そして/または
  他の総称的関数に対する
  それ自体のある種のメソッドを必要とする可能性が高い．
  普通良いアイデアで無いことは既定の基礎コードに落とす
  ような計算を認めることである．
  これはそうしたクラスの殆どの定義と一貫性が無い．}

\section{メソッド}{
  演算子と数学関数
  (グループ \code{\link{Ops}}, \code{\link{Math}} そして \code{\link{Math2}})
  に対するメソッドが定義されている．  
  全てのケースで結果は適当なタイプの通常のベクトルである．
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.
}
\seealso{
         \code{\linkS4class{structure}}
}
\examples{
setClass("NumericNotStructure", contains = c("numeric","nonStructure"))
xx <- new("NumericNotStructure", 1:10)
xx + 1 # ベクトル
log(xx) # ベクトル
sample(xx) # ベクトル
\dontshow{removeClass("NumericNotStructure")
}
}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/nonStructure-class.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-12 R Core Team
%% Distributed under GPL 2 or later
%
%\name{nonStructure-class}
%\docType{class}
%\alias{nonStructure-class}
%\alias{Math,nonStructure-method}
%\alias{Math2,nonStructure-method}
%\alias{Ops,vector,nonStructure-method}
%\alias{Ops,nonStructure,vector-method}
%\alias{Ops,nonStructure,nonStructure-method}
%
%\title{A non-structure S4 Class for basic types }
%\description{ S4 classes that are defined to extend one of the basic
%  vector classes should contain the class
%  \code{\linkS4class{structure}} if they behave like structures; that
%  is, if they should retain their class behavior under math functions
%  or operators, so long as their length is unchanged.
%  On the other hand, if their class depends on the values in the
%  object, not just its structure, then they should lose that class
%  under any such transformations.  In the latter case, they should be
%  defined to contain \code{nonStructure}.
%
% If neither of these strategies applies, the class likely needs some
% methods of its own for \code{\link{Ops}}, \code{\link{Math}}, and/or
% other generic functions. What is not usually a good idea is to allow
% such computations to drop down to the default, base code.  This is
% inconsistent with most definitions of such classes.}
%
%\section{Methods}{
% Methods are defined for operators and math functions (groups
% \code{\link{Ops}}, \code{\link{Math}} and  \code{\link{Math2}}.  In
% all cases the result is an ordinary vector of the appropriate type.
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.
%}
%\seealso{
%         \code{\linkS4class{structure}}
%}
%\examples{
%setClass("NumericNotStructure", contains = c("numeric","nonStructure"))
%xx <- new("NumericNotStructure", 1:10)
%xx + 1 # vector
%log(xx) # vector
%sample(xx) # vector
%\dontshow{removeClass("NumericNotStructure")
%}
%}
%\keyword{classes}
%
%\encoding{UTF8}
%