% File src/library/methods/man/promptClass.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{promptClass}
%@%\alias{形式的クラスのドキュメントに対するシェルを生成}
\alias{promptClass}
\title{形式的クラスのドキュメントに対するシェルを生成する}
%\title{Generate a Shell for Documentation of a Formal Class}
\description{
  全ての関連するスロットとメソッド情報を収集し，
  Rd 処理のための最少のマークアップを持つ；
  現在 QC のための機能は無い．
}
\usage{
promptClass(clName, filename = NULL, type = "class",
            keywords = "classes", where = topenv(parent.frame()),
            generatorName = clName)
}
\arguments{
  \item{clName}{ドキュメントされるクラスの名前を与える文字列．}
  \item{filename}{
    普通ドキュメントシェルが書き込まれるべきコネクションまたは
    ファイル名．
    既定では名前がクラスドキュメントに対するトピック名であるファイルで，
    \code{".Rd"} が続く．\code{NA} でも良い(下を見よ)．}
  \item{type}{出力ファイル中で宣言されるドキュメントタイプ．}
  \item{keywords}{
    ドキュメントのシェル中に含まれるキーワード．
    キーワード \code{"classes"} はそれらの一つでなければならない．}
  \item{where}{
    クラスとそれを使うメソッドの定義をどこで探すか．
    %%FIXME: By default, anywhere in the current search list.
  }
  \item{generatorName}{
    このクラスに対する生成関数に対する名前；
    もし生成関数が作られ\emph{そして}クラス名と異なる名前で
    保存された時だけ必要．
  }
}
\details{
  クラス定義は検索パス上で見つけられる．
  その定義を使い拡張されたクラスとスロットの情報が決定される．

  加えて，このクラスに対するメソッドを持つ現在利用可能な総称的関数が
  見つけられる(\code{\link{getGenerics}} を使う)．
  これらのメソッドはクラス定義と同じ環境にある必要はない；
  特に，出力のこの部分はどのパッケージが現在検索パス上にあるかに依存する．

  他のプロンプトスタイルの関数のように，
  \code{filename} が \code{NA} で無い限り，ドキュメントシェルは
  ファイルに書き込まれそしてこれに対するメッセージが与えられる．
  クラスの\emph{意味}に関する情報を与えるにはファイルを編集する必要がある．
  \code{promptClass} の出力は形式的定義とそれがどのように
  使われるかに関するメタデータからの情報だけを含むことが出来る．

  もし \code{filename} が \code{NA} ならば，ドキュメントシェルの
  リストスタイルの表現が作られ返される．シェルをファイルに書き込むことは
  \code{cat(unlist(x), file = filename, sep = "\\n")} に相当する，
  ここで \code{x} はリストスタイルの表現である．

  もし生成関数がクラス名か
  オプションの \code{generatorName} に付値されて見つかれば，
  その関数に対するドキュメント骨格がファイルに付け加えられる．
}
\value{
  もし \code{filename} が \code{NA} ならば，ドキュメントシェルの
  リストスタイルの表現．さもなければ，書き込まれたファイルの名前が
  不可視で返される．
}
\author{
  VJ Carey \email{stvjc@channing.harvard.edu} と John Chambers
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\seealso{
  関数のドキュメントに対しては \code{\link{prompt}}，メソッドの定義の
  ドキュメントに対しては
  \code{\link{promptMethods}}．

  編集されたドキュメントの処理に対しては
  \code{R CMD \link{Rdconv}} を使うか，パッケージの
  \file{man} サブディレクトリ中に編集されたファイルを置く．
}
\examples{
\dontshow{
## setClass から
## 二つのスロットを持つ簡単なクラス
setClass("track",
         representation(x="numeric", y="numeric"))
## 前のを拡張するクラス，もう一つのスロットを加える
setClass("trackCurve",
         representation("track", smooth = "numeric"))
## A class similar to
"trackCurve" に類似のクラスだが，異なった構造を持つ
## "y" と "smooth" スロットに対する行列を許す
setClass("trackMultiCurve",
         representation(x="numeric", y="matrix", smooth="matrix"),
         prototype = list(x=numeric(), y=matrix(0,0,0), smooth= matrix(0,0,0)))

setIs("trackMultiCurve", "trackCurve",
  test = function(obj) {ncol(slot(obj, "y")) == 1},
  coerce = function(obj) { new("trackCurve", x = slot(obj, "x"),
        y = as.numeric(slot(obj,"y")), smooth = as.numeric(slot(obj, "smooth")))})

## setMethod から
require(graphics)

setMethod("plot", "track",
 function(x, y, ...) plot(slot(x, "y"), y,  ...)
)
setMethod("plot", c("trackCurve", "missing"),
function(x, y, ...) {
  plot(as(x, "track"))
  if(length(slot(x, "smooth") > 0))
    lines(slot(x, "x"), slot(x, "smooth"))
  }
)

promptClass("trackMultiCurve", stdout())

promptClass("track", stdout())
}
\dontrun{> promptClass("track")
ファイル "track-class.Rd" にクラスドキュメントのシェルが書き込まれている．
}
\dontshow{removeMethods("plot")
}}

\keyword{programming}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/promptClass.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{promptClass}
%\alias{promptClass}
%\title{Generate a Shell for Documentation of a Formal Class}
%\description{
%  Assembles all relevant slot and method information for a class, with
%  minimal markup for Rd processing; no QC facilities at present.
%}
%\usage{
%promptClass(clName, filename = NULL, type = "class",
%            keywords = "classes", where = topenv(parent.frame()),
%            generatorName = clName)
%}
%\arguments{
%  \item{clName}{a character string naming the class to be documented.}
%  \item{filename}{usually, a connection or a character string giving the
%    name of the file to which the documentation shell should be written.
%    The default corresponds to a file whose name is the topic name for
%    the class documentation, followed by \code{".Rd"}.  Can also be
%    \code{NA} (see below).}
%  \item{type}{the documentation type to be declared in the output file.}
%  \item{keywords}{the keywords to include in the shell of the
%    documentation.  The keyword \code{"classes"} should be one of
%    them.}
%  \item{where}{where to look for the definition of the class and of
%    methods that use it.
%    %%FIXME: By default, anywhere in the current search list.
%  }
%  \item{generatorName}{the name for a generator function for this
%    class; only required if a generator function was created
%    \emph{and} saved under a name different from the class name.
%  }
%}
%\details{
%  The class definition is found on the search list.  Using that
%  definition, information about classes extended and slots is
%  determined.
%
%  In addition, the currently available generics with methods for this
%  class are found (using \code{\link{getGenerics}}).  Note that these
%  methods need not be in the same environment as the class definition; in
%  particular, this part of the output may depend on which packages are
%  currently in the search list.
%
%  As with other prompt-style functions, unless \code{filename} is
%  \code{NA}, the documentation shell is written to a file, and a message
%  about this is given.  The file will need editing to give information
%  about the \emph{meaning} of the class.  The output of
%  \code{promptClass} can only contain information from the metadata
%  about the formal definition and how it is used.
%
%  If \code{filename} is \code{NA}, a list-style representation of the
%  documentation shell is created and returned.  Writing the shell to a
%  file amounts to \code{cat(unlist(x), file = filename, sep = "\\n")},
%  where \code{x} is the list-style representation.
%
%  If a generator function is found assigned under the class name or
%  the optional \code{generatorName}, skeleton documentation for that
%  function is added to the file.
%}
%\value{
%  If \code{filename} is \code{NA}, a list-style representation of the
%  documentation shell.  Otherwise, the name of the file written to is
%  returned invisibly.
%}
%\author{
%  VJ Carey \email{stvjc@channing.harvard.edu} and John Chambers
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{
%  \code{\link{prompt}} for documentation of functions,
%  \code{\link{promptMethods}} for documentation of method definitions.
%
%  For processing of the edited documentation, either use
%  \code{R CMD \link{Rdconv}},
%  or include the edited file in the \file{man} subdirectory of a
%  package.
%}
%\examples{
%\dontshow{
%## from setClass
%## A simple class with two slots
%setClass("track",
%         representation(x="numeric", y="numeric"))
%## A class extending the previous, adding one more slot
%setClass("trackCurve",
%         representation("track", smooth = "numeric"))
%## A class similar to "trackCurve", but with different structure
%## allowing matrices for the "y" and "smooth" slots
%setClass("trackMultiCurve",
%         representation(x="numeric", y="matrix", smooth="matrix"),
%         prototype = list(x=numeric(), y=matrix(0,0,0), smooth= matrix(0,0,0)))
%
%setIs("trackMultiCurve", "trackCurve",
%  test = function(obj) {ncol(slot(obj, "y")) == 1},
%  coerce = function(obj) { new("trackCurve", x = slot(obj, "x"),
%        y = as.numeric(slot(obj,"y")), smooth = as.numeric(slot(obj, "smooth")))})
%
%## from setMethod
%require(graphics)
%
%setMethod("plot", "track",
% function(x, y, ...) plot(slot(x, "y"), y,  ...)
%)
%setMethod("plot", c("trackCurve", "missing"),
%function(x, y, ...) {
%  plot(as(x, "track"))
%  if(length(slot(x, "smooth") > 0))
%    lines(slot(x, "x"), slot(x, "smooth"))
%  }
%)
%
%promptClass("trackMultiCurve", stdout())
%
%promptClass("track", stdout())
%}
%\dontrun{> promptClass("track")
%A shell of class documentation has been written to the
%file "track-class.Rd".
%}
%\dontshow{removeMethods("plot")
%}}
%
%\keyword{programming}
%\keyword{classes}
%
%\encoding{UTF8}
%