% File src/library/methods/man/refClass.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2010-2014 R Core Team
% Distributed under GPL 2 or later

\name{ReferenceClasses}
\title{参照として扱われる欄を持つオブジェクト(OOP スタイル)}
%\title{Objects With Fields Treated by Reference (OOP-style)}
%@%\alias{参照として扱われる欄を持つオブジェクト}
\alias{ReferenceClasses}
\alias{setRefClass}
\alias{getRefClass}
\alias{initFieldArgs}
\alias{initRefFields}
\alias{activeBindingFunction-class}
\alias{defaultBindingFunction-class}
\alias{uninitializedField-class}
\alias{refClassRepresentation-class}
\alias{refObjectGenerator-class}
\alias{refGeneratorSlot-class}
\alias{refClass-class}
\alias{refObject-class}
\alias{refMethodDef-class}
\alias{refMethodDefWithTrace-class}
\alias{SuperClassMethod-class}
\alias{show,envRefClass-method}
\alias{show,refMethodDef-method}
\alias{show,externalRefMethod-method}
\alias{show,refClassRepresentation-method}
\alias{externalRefMethod}
\alias{externalRefMethod-class}
\description{
ここで説明されるソフトウェアは
Java と C++ のような \dQuote{OOP} 言語スタイルでの参照により
アクセスされる欄を持つオブジェクトの参照クラスをサポートする．

これらのオブジェクトを使った計算はそれらに対するメソッドを
起動しそれらの欄を取り出したり設定したりする．
欄とメソッド計算は可能性としてオブジェクトを修正する．
オブジェクトを参照する全ての計算は通常の
\R 中の関数プログラミングモデルとは異なり修正を見る．
参照クラスは \R 中や
OOP スタイルの言語へのインタフェイスとの連携で使うことが出来，
インタフェイスを拡張する \R で書かれたメソッドを許す．
}
\usage{
setRefClass(Class, fields = , contains = , methods =,
     where =, inheritPackage =, ...)

getRefClass(Class, where =)
}
\arguments{
  \item{Class}{
クラスに対する文字列名．

\code{getRefClass()} の呼び出し中ではこの引数は関連クラスからの
任意のオブジェクトでも良い；
\dQuote{参照メソッドを書く}節中に説明された対応する参照クラスメソッド
も注意せよ．
}
  \item{fields}{
欄名の文字列ベクトルか欄の名前付きリスト．
結果の欄は参照のセマンティックスを使いアクセスされる
(\dQuote{参照オブジェクト}についての節を見よ)．
もし引数がリストなら，リストの要素は
クラスの文字列名で良く，その場合欄はそのクラスかサブクラスからの
ものでなければならない．

リスト中の要素はまたは
\emph{アクセス関数}でもよく，この関数は引数一つの関数で引数無しで呼ばれると
欄を返し，さもなければ引数の値で欄を設定する．
アクセス関数は内部的とシステム間のインタフェイスアプリケーションに対して
使われる．
これらの定義はクラスに対するメソッドを書くための規則に従う；
これらは他の欄を参照でき，このクラスやそのスーパークラスに対する
他のメソッドを呼び出すことが出来る．
アクセス関数により使われる内部的機構に対しては
節\dQuote{実装}を見よ．

欄はもしあればオブジェクト中のスロットとは異なることを注意する．
スロットは通常のように
標準的な \R{} のオブジェクト管理で処理される．
同じクラス中にスロットと欄を混在させるのは一般に良いアイデアでは無い；
これは参照クラスと正規の S4 クラス間の挙動間の違いを混乱させる．
\dQuote{実装}節中のコメントを見よ．
}
  \item{contains}{
このクラスに対するスーパークラスのオプションのベクトル．
もしスーパークラスがまた参照クラスならば，
欄とクラスベースのメソッドが継承される．
}
  \item{methods}{
このクラスからのオブジェクトに適用できる関数定義の名前付きリスト．
これらは又返される生成器オブジェクトに \code{$methods} メソッドを
呼び出すことで作ることが出来る．
詳細は節\dQuote{参照メソッドを書く}を見よ．

二つのオプションのメソッド名
もし \code{initialize} メソッドが定義されると，
それはそのクラスからオブジェクトが生成されると適用される．
節\dQuote{参照オブジェクト生成器}中の
メソッド \code{$new(...)} の議論を見よ．%$

もし \code{finalize} メソッドが定義されると，関数は
オブジェクト中の環境がガベージコレクションで捨て去られる前に
呼び出されるように \link[=reg.finalizer]{registered} される；
終結化は \code{atexit=TRUE} で登録されるので，
\R{} セッションの最後にもまた実行される．
初期化と終結化メソッドの双方については行列ビューアの例を見よ．}

  \item{where}{
クラス定義をその中に保存
(または \code{getRefClass()} の場合はそれの探索を始める)する環境．
既定ではパッケージの名前空間か \R{} パッケージの部分であるコードに対する環境と，
セッションのトップレベルで直接読み込まれたコードに対する大局的環境．
}
  \item{inheritPackage}{
新しいクラスからのオブジェクトは含まれるスーパークラスのパッケージ
環境を継承すべきか?  既定値は \code{FALSE}．
節 \dQuote{パッケージ間のスーパークラスと外部メソッド}．
} 
  \item{\dots}{
\code{\link{setClass}} に渡される他の引数．
}
}

\value{
  \code{setRefClass()} はクラスからのオブジェクトの作成に適した
  生成関数を不可視で返す．この関数の呼び出しは任意の数の引数を取る．
  クラスやそのスーパークラスの一つにに対する \code{initialize} メソッドが
  適用されていなければ，既定のメソッドは
  欄の一つの名前を持つ名前付き引数と，もしあれば，このクラスのスーパークラス
  の一つからのオブジェクトである名前無しの引数を取る
  (しかしそれ自体が参照クラスであるスーパークラスだけが何らかの効果を持つ)．

  生成関数は \code{\link{setClass}} が返す S4 生成関数に類似するが，
  同時に参照クラス生成オブジェクトであり，
  様々なユーティリティに対する参照クラスメソッドを持つ．
  下の参照クラス生成オブジェクトに関する節を見よ．

もしクラスが \code{$initialize()} に対して定義されたメソッドを持てば，%$
このメソッドは参照オブジェクトが作られた時一度呼び出される．
ある種の特殊な初期化を行う必要があるクラスに対してそうした
メソッドを書くべきである．特に，参照クラスに対しては
欄の初期化の\emph{前}に参照オブジェクトに対するある種の特別な初期化が
必要になるため，
S4 総称的関数 \code{initialize()} に対するメソッドではなく参照メソッドが
推奨される．S4 クラスに於けるように，先の理由と又
\code{$new()} は生成オブジェクトに対して適用され
そのクラスに対するメソッドになるための双方から，%$
メソッドは \code{$new()} ではなく%$
\code{$initialize()} に対して書かれる．%$

\code{$initialize()} に対する既定メソッドは%$
メソッド \code{$initFields(...)} の適用と同値である．%$
名前付き引数は対応する欄の初期値を付値する．
名前無し引数はこのクラスかそのスーパークラスからのオブジェクト
でなければならない．
欄はそうしたオブジェクトの欄の内容に初期化されるが，
名前付き引数は対応する継承欄を上書きする．
欄は単純に付値されることを注意する．
もし欄がそれ自体参照オブジェクトならば，そのオブジェクトは
コピーされない．
新しいオブジェクトと以前のオブジェクトは参照を共有する．
又，名前無し引数から付値された欄はロックされた欄に対する付値であると
カウントされる．
ロックされた欄に対する継承値を上書きするには，
新しい値は初期化呼び出し中の名前付き引数の一つでなければならない．
欄の後からの付値はエラーになる．

初期化メソッドのデザインはある配慮を必要とする．
参照クラスに対する生成器は例えばオブジェクトをコピーする際
引数無しで呼び出される．
これらの呼び出しが失敗しないことを保証するには，
メソッドは全ての引数に対する既定値を持つか
\code{missing()} に対するチェックを必要とする．
メソッドは引数として \code{\dots} を含むべきであり，
これを \code{$callSuper()} 
(またはもし自分のスーパークラスが初期化メソッドを持たないことが
わかっていれば \code{$initFields()}) を使って渡すべきである．
これはこのクラスをサブクラスとする追加の欄を持つ将来のクラス定義を可能にする．

\code{getRefClass()} は又クラスに対する生成関数を返す．
必要ならクラスを見つけるためだけに使われる
\code{where} 引数とは無関係に，
値中のパッケージスロットはクラス定義からの
正しいパッケージであることを注意する．
}


\section{参照オブジェクト}{
\R 中の普通のオブジェクトは関数呼び出しに於いて関数プログラミングの
セマンティックスと一貫性を持って引数として渡される；
つまり，引数として渡されるオブジェクトに加えられた変更は
関数呼び出しに対して局所的である．
引数を提供したオブジェクトは変更されない．

関数モデル(\R ではこれは不正確ではあるがしばしば値渡しと呼ばれる)は
例えば統計モデル当てはめに対する基本
\R ソフトウェアのような，多くの統計計算に適している．
ある種の他の状況では，
任意の計算中で行われた変更がどこでも反映されるように，
あるオブジェクトを扱う全てのコードが
正確に同じ内容を見ることが好ましい．
これはユーザインタフェイス中のウィンドウのように
オブジェクトがある\dQuote{客観的}な実在性を
持つならばしばしば好ましい．

加えて，
Java, C++ そして多くの他を含むよく使われる
言語は参照セマンティックスを仮定するクラスとメソッドのバージョンを持つ．
対応するプログラミング機構は
オブジェクトに対してメソッドを適用する．
\R のシンタックス中では，この操作に対して \code{"$"}
を使う；%$
例えばオブジェクト \code{x} に対して
メソッド \code{m1} を表現式
\code{x$m1(...)} で適用する．%$

このパラダイムにおけるメソッドはメソッド，より正確に言えば
オブジェクトのクラスに関連しており，
基本的に関数に関連する
関数ベースのクラス/メソッドシステム中のメソッドと対比される
(\R では例えばある
\R セッション中の総称的関数はその現在知られているメソッドのテーブルを持つ)．
このドキュメントでは
\dQuote{関数に対するメソッド}に対する
\dQuote{クラスに対するメソッド}と区別される．

このパラダイムにおけるオブジェクトは普通
それに対してメソッドが操作される名前付き欄を持つ．
\R の実装では，欄はクラスが作成される時定義される．
欄自体はオプションで指定されたクラスを持つことが出来，
このクラスかそのサブクラスの一つからのオブジェクトだけが
欄に付値出来ることを意味する．
既定では，欄はクラス \code{"ANY"} を持つ．
欄は又欄を取り出したり設定したりするために呼び出される
アクセス関数を提供することで定義できる．
アクセス関数は参照クラスがシステム間インタフェイスの一部である時
に適当である．
インタフェイスは普通他の言語中の対応するクラスの定義に基づく
アクセス関数を自動的に提供する．

欄は参照によりアクセスされる．
特に，メソッドの適用は欄の内容を変更するかもしれない．

そうしたクラスに対するプログラミングは
特定のクラスに対する新しいメソッドを書くことを含む．
\R の実装に於いては，これらのメソッドは
\R 関数で，ゼロ個またはそれ以上の引数を持つ．
メソッドがそれに対して適用されるオブジェクトは
メソッドに対する明示的な引数ではない．
代わりに，クラスに対する欄とメソッドは
メソッド定義中の名前により参照することが出来る．
実装は名前で利用できる欄とメソッドを作るために
\R 環境を利用する．
追加の特殊な欄は完全なオブジェクトとクラスの定義への参照を
許す．
節\dQuote{参照メソッドを書く}を見よ．

ここで説明されたソフトウェアのゴールは，
\R 中で直接実装されるにせよ
OOP 言語のどれかへのインタフェイスであるにせよ，
参照クラスを扱うソフトウェアに対する
\R の一様なプログラミングスタイルを提供することである．
}


\section{参照メソッドを書く}{
参照メソッドは
\code{g$methods()} を生成オブジェクト%$}
\code{g} に対して適用する時かまたは
\code{setRefClass} の呼び出し中に
引数 \code{methods} として
名前付きリストとして提供される関数である．
それらは通常の \R 関数として書かれるがある種の特殊な特徴と制限を持つ．
関数の本体は任意の他の参照メソッドへの呼び出しを含むことが出来，
他の参照クラスから継承されたものを含みオブジェクト中の欄を名前で
参照するかもしれない．

または，メソッドは
その第一引数が \code{.self} である\emph{外部}メソッドかもしれない．

そうしたメソッドの本体は通常の関数として動作する．
メソッドは他のメソッドと同様に呼び出される
(内部的に提供され常にオブジェクト自体を参照する
\code{.self} 引数無しに)．
外部メソッドは参照クラスが他のパッケージ中の
スーパークラスのパッケージ環境を継承できるように存在する；
節\dQuote{パッケージ間スーパークラスと外部メソッド}を見よ．

欄はメソッド中で
下の例中の \code{$edit} と \code{$undo} に於けるように
非局所的な付値演算子 \code{<<-} で修正できる．
非局所的な付値が必要とされることを注意する：
\code{<-} 演算子を用いた局所的な付値は
任意の \R 関数中でそうあるべきであるように
関数呼び出し中で局所的なオブジェクトを作る．
メソッドがインストールされる時，欄名に対する局所的な付値に
対する発見法的なチェックが行われ，もしあれば警告が発せられる．

参照メソッドは単純であるべきである；
もしそれらがある特殊な
\R 計算を必要とするならば，計算は
参照メソッド中から呼び出される別個の
\R 関数を使うべきである．
具体的に言うと，メソッドの環境は欄と他のメソッドにアクセスするために使われるため，
メソッドは囲み環境機構の特殊な特性を使うことが出来ない．
特に，メソッドはパッケージの名前空間中の移出されない項目を
使うべきではない，なぜなら
メソッドは別のパッケージ中の参照クラスにより継承されているかもしれないからである．

\code{$initialize()} に対するメソッドは特殊な要求を持つ．%$
\dQuote{値}切中のコメントを見よ．

参照メソッドはそれら自体総称的関数にはなれない；
もし追加の関数ベースのメソッド選択適用が必要ならば，
別個の総称的関数を書きそれをメソッドから呼び出す．

オブジェクト全体は例の \code{save=} メソッド中で示されたように
メソッド中で予約語 \code{.self} で参照できる
特殊オブジェクト \code{.refClassDef} はオブジェクトのクラスの定義を含む．
これらの欄は一つの例外を除いて読み取り専用である
(これらの参照を修正することは意味が無い)．
原則として，\code{.self} 欄は
\code{$initialize} メソッド中で変更できる．%$
この段階ではオブジェクトは依然として構築中だからである．
ある種のこのクラスに対して定義されたオブジェクトの非参照特性を設定するのでなければ
これは明確に推奨できない．これ自体もしそれにスロットと欄が混在するならば
推奨できない．

次の節で議論されるように利用できるメソッドはスーパークラスから継承されるメソッドを含む．

実際に使われるメソッドだけが個別のオブジェクトに対応する
環境中に含められる．
あるメソッドが特定の他のメソッドを必要とすることを宣言するには，
最初のメソッドは
\code{$usingMethods()} に呼び出しを %$
他のメソッドの名前を引数として含むべきである．
メソッドをこのように宣言することは
もし他のメソッドが間接的に使われるときは本質的である
(例えば \code{\link{sapply}()} か \code{\link{do.call}()} 経由で)．
もしそれが直接呼び出されると，コード解析がそれを見つける．
メソッドの宣言はいかなる場合も無害であるが，
ソースコードの可読性を助けるかもしれない．

メソッドのドキュメント化は生成オブジェクトに対する
\code{$help} メソッドで得ることが出来る．%$}
クラスに対するメソッドは
\R 関数に対して使われる \code{Rd} 書式ではドキュメント化されない．
代わりに，\code{$help} メソッドはメソッドの呼び出し系列をプリントし，
メソッド定義からの Python 風の自己ドキュメントが後に続く．
もしメソッドの本体の最初の要素が文字通りの文字列
(可能性として複数行)ならば，文字列はドキュメントとして解釈される．
例中のメソッド定義を見よ．
}

\section{継承}{
参照クラスは標準の \R の継承を使うことで他の参照クラスを継承する；
つまり，新しいクラスを作る際に
\code{contains=} 引数にスーパークラスを含む．
参照スーパークラスの名前はクラス定義の
\code{refSuperClasses} スロット中にある．
参照クラスは通常の S4 継承できるが，
しかしこれはもしそれが参照欄と非参照スロットを併せ持てば
普通悪いアイデアである．
\dQuote{実装}に関する節中のコメントを見よ．

クラスの欄は継承される．クラス定義はスーパークラス中の同名の欄を
書き換えクラスが継承欄のクラスのサブクラスである時だけ
上書きする．これは欄中の適正なオブジェクトがスーパークラスに対しても
同様に適正であることを保証する．

継承メソッドは直接に指定されたメソッドと同じ仕方でインストールされる．
メソッド中のコードは直接に指定されたメソッドと同じ仕方で
継承メソッドを参照できる．

メソッドはスーパークラス中の同名のメソッドを上書きするかもしれない．
上書きするメソッドはスーパークラスメソッドを
下で解説されるように
\code{callSuper(...)} によって呼び出すことが出来る．

全ての参照クラスは以下のメソッドを提供する
クラス \code{"envRefClass"} を継承する．

\describe{
\item{\code{$callSuper(...)}}{ 
参照スーパークラスから継承されたメソッドを呼び出す．
呼び出しは別のメソッド内からだけ意味を持ち，
同名の継承メソッドの呼び出しになる．
\code{$callSuper} への引数はスーパークラスバージョンに渡される．
例中の行列ビューアクラスを見よ．

スーパークラスメソッドに対する意図する引数は明示的に
提供される必要があることを注意する；
関数メソッドに対する同様の機構とは対照的に，
引数を自動的に提供するための変換は無い．
}

\item{\code{$copy(shallow = FALSE)}}{ %$
オブジェクトのコピーを作る．
参照クラスに対しては，通常の \R オブジェクトとは異なり，
オブジェクトを異なった名前で付値することは独立なコピーを作らない．
もし \code{shallow} が \code{FALSE} ならば，それ自体参照オブジェクトである
任意の欄もコピーされ，
その欄に対しても同様に再帰的にコピーされる．
さもなければ，新しい参照オブジェクトへの欄の再付値は副作用を持たず，
そうした欄の修正はオブジェクトのコピーのどちらにも依然として反映される．
引数は欄中の非参照的なオブジェクトには何も効果を持たない．
ある欄に参照オブジェクトがあるがそれらが修正されるべきではないと
保証されているときは，
\code{shallow = TRUE} の使用が幾らかメモリーと時間を節約する．
}

\item{\code{$field(name, value)}}{ %$
引数が一つならば文字列 \code{name} を持つオブジェクトの欄を返す．
引数が二つならば，対応する欄に \code{value} を付値する．付値は
\code{name} が適正な欄を指定することをチェックするが，
引数が一つのバージョンはオブジェクトの環境からその名前を持つ
何かを得ようと試みる．

\code{$field()} メソッドは，
欄の名前が計算されなければならない時や幾つかの欄に渡るループに対して，
欄名の直接的な使用を置き換える．
}

\item{\code{$export(Class)}}{ %$
オブジェクトの \code{Class} への強制変換
(典型的にはオブジェクトのスーパークラスの一つ)の結果を返す．
メソッドの呼び出しはオブジェクト自体には何らの副作用を持たない．
}

\item{\code{$getRefClass()}; \code{$getClass()}}{
これらはそれぞれこのオブジェクトの参照クラスに対する
生成オブジェクトと形式的な定義を効率的に返す．
}

\item{\code{$import(value, Class = class(value))}}{ %$
現在のオブジェクト中の対応する欄を置き換え，
オブジェクト \code{value} を現在のオブジェクトに移入する．
オブジェクト \code{value} は現在のオブジェクトのクラスの
スーパークラスの一つに由来しなければならない．
もし引数 \code{Class} が提供されると，
\code{value} は先ずそのクラスに強制変換される．
}

\item{\code{$initFields(...)}}{ %$
オブジェクトの欄を提供された引数から初期化する．
このメソッドは普通
\code{$initialize()} メソッドを持つクラスだけから呼び出される．% $
参照クラスに対してはそれは既定の初期化に対応する．
もしスロットと非参照的スーパークラスがあれば，
これらも \dots 引数から提供できる．

典型的には，特殊化された \code{$initialize()} メソッドはそれ自体の
計算を行い，それから標準的な初期化を実行するために
下の例の \code{matrixViewer} クラス中で示されるように
\code{$initFields()} を適用する．% $
}

\item{\code{$show()}}{ %$
このメソッドは \code{\link{show}} 関数と同じように
オブジェクトが自動的にプリントされる時に呼び出される．
クラス \code{"envRefClass"} に対して一般的なメソッドが定義されている．
ユーザ定義の参照クラスはしばしばそれら自体のメソッドを定義する：
下の例を見よ．

例の中の二つの点に注意する．
任意の \code{show()} メソッドに於けるように，
サブクラスに対してメソッドを用いることを認めるため
クラスを明示的にプリントするのは良いアイデアである．
次に，メソッドから
\emph{関数} \code{show()} を呼び出すには，
\code{$show()} メソッド自体とは異なり，
\code{methods::show()} を明示的に参照する．
}

\item{\code{$trace(what, ...)}, \code{$untrace(what)} }{
\code{\link{trace}} 関数のトレースとデバッグ機能を
参照メソッド \code{what} に適用する．

意味のない \code{signature} 引数を除き，
\code{\link{trace}} 関数への全ての引数が提供できる．

参照メソッドはオブジェクトとしてもクラスに対する生成器としても
適用できる．詳細は下のデバッグの節を見よ．
}

\item{\code{$usingMethods(...)}}{ %$
このメソッドにより使われる参照メソッドは
引用符付きでも無しでも引数として名前を持つ．
現在のメソッドのインストールのコード分析フェーズ中では，
宣言されたメソッドが含められる．
非標準的な仕方で使われる任意のメソッドを宣言することが
不可欠である(例えば apply 関数を使い)．
直接呼ばれるメソッドは宣言される必要はないが，
そうすることは無害である．
\code{$usingMethods()} は実行時には何もしない．%$
}
} % end describe

オブジェクトはまた二つの予約欄を継承する：
\describe{
\item{\code{.self}}{
オブジェクト全体への参照；
}
\item{\code{.refClassDef}}{
クラス定義．
}
} % end \describe
定義された欄はこれらを上書きすべきではなく，
そして一般的に
実装が特殊な目的のためにそうした名前を使うかもしれないので，
名前が \code{"."} で始まる欄を定義することは賢明ではない．
}

\section{パッケージ間スーパークラスと外部メソッド}{
参照クラス中のメソッドの環境は環境としてのオブジェクト自体である．
これはオブジェクト全体と \code{"$"} 演算子無しに，
欄と他のメソッドを直接に参照することを許す．%$
その環境の親はその中に参照クラスが定義されているパッケージの
名前空間である．メソッド中の計算は，移出されているかどうかを問わず，
パッケージの名前空間中の全てのオブジェクトへのアクセスを持つ．

別のパッケージ中の参照スーパークラスを含むクラスを定義する時，
どのパッケージの名前空間がその役目を持つべきかについて曖昧さがある．
\code{setRefClass()} の引数 \code{inheritPackage} は
新しいオブジェクトの環境が別のパッケージ中の継承クラスを
継承すべきか，現在のパッケージの名前空間から継承することを
続けるべきかを制御する．

もしスーパークラスが僅かなメソッドを持ち\dQuote{傾いて}いるか，
主としてスーパークラスのファミリをサポートするために存在していいれば，
新しいパッケージの環境を使い続けるほうがよいかもしれない．
他方で，もしスーパークラスが本来単独使用のために
書かれていれば，この選択は既存のスーパークラスメソッドを
損なうかもしれない．
スーパークラスメソッドが動作し続けるためには，
それらはそれらのパッケージ中の移出関数だけを使わなければならず，
そして新しいパッケージはこれらを移入しなければならない．

どちらの方法でも，ある種のメソッドは
参照クラスメソッドに対する標準モデルを仮定\emph{しない}
がしかし本質的に通常の関数が参照クラスオブジェクトを
処理するように挙動するように書かれる必要があるかもしれない．

機構は \emph{外部メソッド}を認識する．
外部メソッドは名前付きの
\code{.self} が参照クラスオブジェクトを表す第一引数の
関数として書かれる．
この関数は参照クラスメソッドに対する定義として提供される．
メソッドは自動的に呼びだされ，最初の引数は現在のオブジェクトで，
もしあれば他の引数は実際の呼び出しに合わせて渡される．

外部メソッドはそのパッケージに対するソースコード中の
通常の関数であるので，
名前空間中の全てのオブジェクトにアクセスする．
参照クラス中の欄とメソッドは
\code{.self$name} という形式で参照されなければならない．%$

もしある理由で
\code{.self} を第一引数として使いたくなければ，
関数 \code{f()} は明示的に\cr
\code{externalRefMethod(f)} として変換可能で，
これはメソッドに対して提供することが出来る
クラス \code{"externalRefMethod"} のオブジェクトを
返す．最初の引数は依然としてオブジェクト全体に対応する．

外部メソッドは任意の参照クラスに対して提供できるが
それらが必要でない限り明白な利点はない．
それらは書くのが難しく，可読性が低く，そして
(少々)実行が遅い．

\emph{注意：} もしその参照クラスが恐らく別のパッケージ中のサブクラス
のパッケージの作者ならば，
自分のパッケージからの移出関数\emph{だけ}を使うメソッドを書くことで
これらの問題を完全に避けることが出来るので，
全てのメソッドが自分のそれらを移入する別のパッケージから
動作する．

}

\section{参照クラスの生成器}{
\code{setRefClass} の呼び出しは特殊なクラスを定義し，そして
そのクラスに対する\dQuote{生成関数}オブジェクトを返す．
このオブジェクトはクラス \code{"refObjectGenerator"} を持つ；
それは
\code{"function"} を \code{"classGeneratorFunction"} を通じて
継承し，そして参照クラスからの新しいオブジェクトを
生成するために呼び出すことが出来る．

返されたオブジェクトはまた参照クラスオブジェクトであるが，
標準的な構成ではない．
それは通常の仕方で参照メソッドを適用し欄にアクセスするために
使うことができるが，環境として直接実装される代わりに
標準的な参照オブジェクト(クラス
\code{"refGeneratorSlot"}) のスロットとしての補助的な
生成オブジェクトを持つ．
もしサブクラスを持つ参照クラス生成機能を拡張したければ，
これは \code{"refObjectGenerator"} ではなく
\code{"refGeneratorSlot"} をサブクラスとして行われるべきである．

欄はクラス定義である \code{def} とクラスの文字列名である
\code{className} である．
メソッドは，参照メソッドに関するヘルプにアクセスし，そして
クラスに対する新しい参照メソッドを定義する
クラスからのオブジェクトを生成する．
現在利用できるメソッドは：
\describe{
\item{\code{$new(...)}}{ %$
このメソッドは
\code{setRefClass} により返される生成関数の呼び出しと同値である．
}

\item{\code{$help(topic)}}{ %$
トピックに関するヘルプを簡潔にプリントする．
認識されるトピックスは参照メソッド名で，引用化
されていてもされていなくても良い．

プリントされる情報はメソッドの呼び出し系列で，もしあれば
自己ドキュメントがプラスされる．
参照メソッドはメソッドを定義する関数の本体中の
第一引数として初期文字列またはベクトルを持つことが出来る．
もしそうなら，この文字列はメソッドに対する自己ドキュメントとされる
(詳細は節\dQuote{参照メソッドを書く}を見よ)．

トピックが与えられないかトピックがメソッド名でないと，
クラスのメソッドがプリントされる．
}
\item{\code{$methods(...)}}{ %$
引数がないと，このクラスに対する参照メソッドの名前を返す．
一つの文字列名引数ではその名前のメソッドが返される．

名前付きの引数はメソッド定義で，
あたかも \code{setRefClass()} への \code{methods} 引数中で
提供されたかのようにクラス中にインストールされる．
\code{setRefClass()} への呼び出しの代わりに，
このようにメソッドを提供することはより明快なソースコード
のために推奨される．詳細は節\dQuote{参照メソッドを書く}を見よ．

クラスに対する全てのメソッドは，典型的にはパッケージの一部として，
クラスを定義するソースコード中に定義されるべきである．
特に，メソッドは名前空間を持つ付加されたパッケージ中で
再定義出来ない：
クラスメソッドはクラス定義のロックされた拘束をチェックする．

新しいメソッドは任意の現在定義されているメソッドを名前で
参照できる
\code{$methods()} へのこの呼び出し中で提供された他のメソッドを含む)．%$
しかしながら先に定義されたメソッドは再解析されないことは
それらが新しいメソッドを呼び出さないことを注意する
(それが同じ名前の既存のメソッドを再定義しない限り)．

メソッドを取り除くにはその新しい定義として \code{NULL} を与える．
}

\item{\code{$fields()}}{ %$}{
欄のリストを返す，各々は対応するクラスを持つ．
定義中にアクセス関数が低供されている欄
はクラス \code{"activeBindingFunction"} を持つ．
}

\item{\code{$lock(...)}}{ %$}{
引数中の欄名はロックされる；
具体的に言うとロックメソッドが呼びだされた後に
欄は一度設定出来るかもしれない．
それを更に設定しようとする試みはエラーを惹き起こす．

もし引数なしに呼び出されると，メソッドはロックされた欄の名前を返す．

明示的なアクセス関数により定義された欄はロックできない
(他方で，アクセス関数は引数無しで呼び出されるとエラーになるように
定義できる)．

欄をロックする全てのコードは通常クラスの定義の一部であるべきである；
つまり，欄の読み出し専用特性は
クラス定義の部分であり，後で加えられる動的な性質ではない．
特に，欄は名前空間を持つ付加パッケージ中のクラス中では
ロックできない：
クラスメソッドはクラス定義のロックされた拘束をチェックする．
ロックされた欄はその後でロック解除できない．
}

\item{\code{$trace(what, ..., classMethod = FALSE)}}{ %$}{
このクラスから生成されたオブジェクトに対する
メソッド \code{what} のトレース版を確立する．
生成オブジェクトのトレースは
クラスからのオブジェクトに対する \code{$trace()} メソッドと
同様に動作するが，二つの違いを持つ．%$
それはクラスオブジェクト中のメソッド定義自体を変更するため，
トレースは全てのオブジェクトに適用され，
トレースメソッドが適用されるものに対してだけではない．

次に，オプションの引数
\code{classMethod = TRUE} は生成オブジェクト自体のメソッドの
トレースを許す．既定では，
\code{what} はこのオブジェクトがそれに対する生成器であるクラス
中のメソッド名の名前として解釈される．
}

\item{\code{$accessors(...)}}{ %$}{
OOP プログラミングパラダイムを使う幾つかのシステムは
名前による直接のアクセスではなく，各欄に対応する
\emph{取得と設定メソッド}を推奨したり強要する．
もしこのスタイルが好みで
欄名 \code{abc} を
\code{x$getAbc()} で取り出しそれを
\code{x$setAbc(value)} で付値したければ，
the \code{$accessors} メソッドが
%$}
指定された欄に対する取得と設定メソッドを作り出す便利な関数である．
さもなければこの機構を使う理由はない．
特に，それは
\dQuote{参照オブジェクト}節で説明された欄を関数で定義する一般的な
能力とは何も関係がない．
}
} %% end of \describe
} %% end of \section

\section{実装}{
参照クラスは
タイプ \code{"environment"} のデータ部を持つ S4 クラスとして実装されている．
欄は環境中の名前付きオブジェクトに対応する．
関数に関連する欄は
\link[=bindenv]{active binding} として実装されている．
特に，指定されたクラスを持つ欄は
欄への適正な付値を強制するアクティブな拘束の特殊な形式で実装されている．
例えば \code{data} という欄は
関連クラスからの任意のオブジェクトに対して
形式 \code{x$data} の表現式で一般的にアクセスできる．%$}
このクラスへのメソッド中では欄は
\code{data} という名前でアクセスできる．
ロックされていない欄は
\code{x$data <- value} の形式の表現式で設定できる．%$
メソッドの内部では，欄は
形式 \code{x <<- value} の表現式で付値出来る．
演算子 \link[=assignOps]{非局所的付値} に注意しよう．
この演算子の標準的な \R の解釈はオブジェクトの環境中でそれを付値する．
もし欄が定義されたアクセス関数を持てば，取得と設定は
その関数を呼び出す．

メソッドがオブジェクトに対して適用されると，
メソッドを定義する関数は
オブジェクトの環境中にインストールされ，
関数の環境は同じ環境である．

実装のせいで，新しい参照クラスは
参照的なものと同じく非参照的な S4 クラスを継承できる．
もし非参照クラスからのスロットが欄の代替物と考えられるならば，
これは通常良いアイデアでは無い．
ある種の特殊な引数が好まれるのではなければ，同じオブジェクトに対する
関数と参照パラダイムの混在は概念的に不明瞭である．
加えて，クラスに対する初期化メソッドは
スロットからの欄をソートすべきで，
このクラスのサブクラスに対する変則的な挙動を作り出す可能性が十分ある．
S4 クラス中のスロットに類似した欄を定義し，それらをそのクラスからの S4 オブジェクト
から初期化するのが一般的に好ましい．
}

\section{システム間インタフェイス}{
幾つかの言語はクラスとクラスベースのメソッドを用いた
参照ベースのプログラミングモデルを使う．
用語と他の詳細の選択中の違いを別として，
これらの言語の多くはここで解説されたプログラミングスタイルと
互換性がある．
言語への \R インタフェイスが幾つかのパッケージ中に存在する．

ここでの参照クラス定義は
\R 中に現れる外部言語中のクラスに対するフックを提供する．
クラス中の欄 と/または メソッドへのアクセスは
インタフェイスを通じて利用可能にされるクラスに対応する
\R の参照クラスの定義により実装できる．
典型的には，システム間インタフェイスは
外部クラスの記述
(どのような欄とメソッドを持つか，欄に対するクラス，どれかが
読み取り専用か，等)
を与えて \R クラスの生成の詳細の面倒を見る．
特に，アクティブな拘束は取得と設定に対する欄のアクセスを
許し，実際のアクセスはシステム間インタフェイスによりなされる．

\R のメソッド と/または 欄は任意の参照クラスに関しては
クラス定義中に含めることが出来る．
メソッドは欄を使ったり設定でき，そして
欄やメソッドがインタフェイス由来か
\R 中で直接定義されたかによらず，他のメソッドを透過的に呼び出すことが出来る．

このアプローチを用いたシステム間インタフェイスについては，
パッケージ \code{Rcpp} のバージョン 0.8.7 またはそれ以降を見よ．
}
% \value{
% \code{setRefClass()} and \code{getRefClass()} both return a generator object for the class. This is
% itself a reference object, with methods to generate objects from the
% class and also for defining new methods and for help-style
% documentation. See the
% section on \dQuote{Reference Class Generator Objects} for details.
% Note that \code{Class} in the call to \code{getRefClass()} can be an
% object from the corresponding class, and that a similar reference
% class method \code{$getRefClass()} %$
% is available as well.

% \code{setRefClass} defines the class and stores its class definition.
% \code{getRefClass} requires that the class has been defined as a
% reference class.

% }
\section{デバッグ}{
標準の \R{} のデバッグとトレース機能は参照メソッドに適用出来る．
参照メソッドは
\code{\link{debug}} とオブジェクトからのその類似物に
そのオブジェクトに対する更なるメソッドの起動をデバッグするために
渡すことが出来る；例えば \code{debug(xx$edit)}．%$

幾らかより柔軟な使い方が
\code{\link{trace}} 関数の参照メソッドバージョンに対して利用できる．
対応する \code{$trace()} %$
参照メソッドがオブジェクトか参照クラス生成器に対して利用できる
(下の例の \code{xx$trace()} か \code{mEdit$trace()})．
\code{$trace()} をオブジェクトに対して使うと
そのオブジェクトに対する指定されたメソッドの将来の起動に対する
トレースバージョンを設定する．
\code{$trace()} をそのクラスに対する生成器に対して使うと
そのクラスからの全ての事後のオブジェクトに対するトレースバージョンを
設定する(そしてある時は，もしメソッドが宣言されていなかったり
前に起動されていなければ，そのクラスからの既存のオブジェクトに対しても)．

どちらの場合も，
参照クラスが S4 総称的ではないかもしれないので無意味な \code{signature=}
を除けば標準の \code{\link{trace}} 関数への全ての引数が利用できる．
これは対話的なデバッグに対する
典型的なスタイルの \code{trace(what, browser)} と
参照メソッドを対話的に編集する\cr
\code{trace(what, edit = TRUE)} を含む．

}
\author{
  John Chambers
}

\examples{
## 行列Bオブジェクトに対する簡単なエディタ．
## メソッド $edit() は値のある範囲を変更する：
## メソッド $undo() は最後の編集を下に戻す．
mEdit <- setRefClass("mEdit",
      fields = list( data = "matrix",
        edits = "list"),
      methods = list(
     edit = function(i, j, value) {
       ## 次の文字列はエディットメソッドをドキュメント化する
       'Replaces the range [i, j] of the
        object by value.
        '
         backup <-
             list(i, j, data[i,j])
         data[i,j] <<- value
         edits <<- c(edits, list(backup))
         invisible(value)
     },
     undo = function() {
       'Undoes the last edit() operation
        and update the edits field accordingly.
        '
         prev <- edits
         if(length(prev)) prev <- prev[[length(prev)]]
         else stop("No more edits to undo")
         edit(prev[[1]], prev[[2]], prev[[3]])
         ## trim the edits list
         length(edits) <<- length(edits) - 2
         invisible(prev)
     },
     show = function() {
       'Method for automatically printing matrix editors'
       cat("Reference matrix editor object of class",
          classLabel(class(.self)), "\n")
       cat("Data: \n")
       methods::show(data)
       cat("Undo list is of length", length(edits), "\n")
     }
     ))

xMat <- matrix(1:12,4,3)
xx <- mEdit(data = xMat)
xx$edit(2, 2, 0)
xx
xx$undo()
mEdit$help("undo")
stopifnot(all.equal(xx$data, xMat))

utils::str(xx) # 自明でないメソッドの欄と名前を示す

## 保存されたオブジェクトにメソッドを加える．
mEdit$methods(
     save = function(file) {
       'Save the current object on the file
        in R external object format.
       '
         base::save(.self, file = file)
     }
)

tf <- tempfile()
xx$save(tf)
\dontshow{
load(tf)
unlink(tf)
stopifnot(identical(xx$data, .self$data))
}

\dontrun{
## 参照クラスを継承する：行列のビューア
mv <- setRefClass("matrixViewer",
    fields = c("viewerDevice", "viewerFile"),
    contains = "mEdit",
    methods = list( view = function() {
        dd <- dev.cur(); dev.set(viewerDevice)
        devAskNewPage(FALSE)
        matplot(data, main = paste("After",length(edits),"edits"))
        dev.set(dd)},
        edit = # 先のメソッドを起動し，それから再プロット
          function(i, j, value) {
            callSuper(i, j, value)
            view()
          }))

## 初期化と終結化メソッド
mv$methods( initialize =
  function(file = "./matrixView.pdf", ...) {
    viewerFile <<- file
    pdf(viewerFile)
    viewerDevice <<- dev.cur()
    dev.set(dev.prev())
    callSuper(...)
  },
  finalize = function() {
    dev.off(viewerDevice)
  })

## オブジェクトのデバッグ：メソッド $edit() 中の browser() を呼び出す
xx$trace(edit, browser)

## メソッド $undo() 中のクラス mEdit からの全てのオブジェクトをデバッグ
mEdit$trace(undo, browser)
}
\dontshow{
removeClass("mEdit")
resetGeneric("$")
resetGeneric("initialize")
} %$
}
\keyword{ programming }
\keyword{ classes }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/refClass.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2010-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ReferenceClasses}
%\title{Objects With Fields Treated by Reference (OOP-style)}
%\alias{ReferenceClasses}
%\alias{setRefClass}
%\alias{getRefClass}
%\alias{initFieldArgs}
%\alias{initRefFields}
%\alias{activeBindingFunction-class}
%\alias{defaultBindingFunction-class}
%\alias{uninitializedField-class}
%\alias{refClassRepresentation-class}
%\alias{refObjectGenerator-class}
%\alias{refGeneratorSlot-class}
%\alias{refClass-class}
%\alias{refObject-class}
%\alias{refMethodDef-class}
%\alias{refMethodDefWithTrace-class}
%\alias{SuperClassMethod-class}
%\alias{show,envRefClass-method}
%\alias{show,refMethodDef-method}
%\alias{show,externalRefMethod-method}
%\alias{show,refClassRepresentation-method}
%\alias{externalRefMethod}
%\alias{externalRefMethod-class}
%\description{
%The software described here supports reference classes whose objects have
%fields
%accessed by reference in the style of \dQuote{OOP} languages such as Java and
%C++.
%Computations with these objects invoke methods on them and
%extract or set their fields.
%The field and method computations potentially modify the object.
%All computations referring to the objects see the modifications, in contrast to
%the usual functional programming model in \R.
%Reference classes can be used to program in \R directly or in combination
%with an interface to an OOP-style language, allowing \R-written methods to
%extend the interface.
%}
%\usage{
%setRefClass(Class, fields = , contains = , methods =,
%     where =, inheritPackage =, ...)
%
%getRefClass(Class, where =)
%}
%\arguments{
%  \item{Class}{
%character string name for the class.
%
%In the call to \code{getRefClass()} this argument can also be any
%object from the relevant class;  note also the corresponding reference
%class methods documented in the section on \dQuote{Writing Reference Methods}.
%}
%  \item{fields}{
%either a character vector of field names or
%a named list of the fields.  The resulting fields will be accessed with reference semantics (see
%the  section on \dQuote{Reference Objects}).  If the argument is a list, the
%elements of the list can be the character string name of a class, in
%which case the field must be from that class or a subclass.
%
% The element in the list can alternatively be an \emph{accessor
%   function}, a function of one argument that returns
%the field if called with no argument or sets it to the value of the
%argument otherwise.
%Accessor functions are used internally and for inter-system interface
%applications.
%Their definition follows the rules for writing methods for the class:
%they can refer to other fields and can call other methods for this
%class or its superclasses.
%See the section on \dQuote{Implementation} for the internal mechanism
%used by accessor functions.
%
%Note that fields are distinct from
%the slots, if any, in the object.  Slots are, as always, handled by
%standard \R{} object management.
%It is not generally a good idea to mix slots and fields in the same
%class; this confuses the distinction in behavior between reference
%classes and regular S4 classes.  See the comments in the
%\dQuote{Implementation} section.
%}
%  \item{contains}{
%optional vector of superclasses for this class.  If a superclass is
%also a reference class, the fields and class-based methods will be inherited.
%}
%  \item{methods}{
%a named list of function definitions that can be invoked on objects
%from this class.  These can also be created by invoking the
%\code{$methods} method on the generator object returned. %$
%See the section on \dQuote{Writing Reference Methods} for details.
%
%Two optional method names are interpreted specially, \code{initialize}
%and \code{finalize}. If an \code{initialize} method is defined, it
%will be invoked when an object is generated from the class.  See the
%discussion of method \code{$new(...)} %$
%in the section \dQuote{Reference Object Generators}.
%
%If a \code{finalize} method is defined, a function will be
%\link[=reg.finalizer]{registered} to invoke it before the environment in
%the object is discarded by the garbage collector; finalizers are
%registered with \code{atexit=TRUE}, and so are also run at the end of
%\R{} sessions. See the matrix viewer example for both initialize and
%finalize methods.}
%
%  \item{where}{
%the environment in which to store the class definition (or to begin the
%search for it, in
%the case of \code{getRefClass()}).  Defaults to
%the package namespace or environment for code that is part of an \R{}
%package, and to the global environment for code sourced directly at
%the session top level.
%}
%  \item{inheritPackage}{
%Should objects from the new class inherit the package environment of a
%contained superclass?  Default \code{FALSE}.  See the Section \dQuote{Inter-Package Superclasses
%  and External Methods}.
%} 
%  \item{\dots}{
%other arguments to be passed to \code{\link{setClass}}.
%}
%}
%
%\value{
%  \code{setRefClass()} returns a generator function suitable for
%  creating objects from the class, invisibly.  A call to this function
%  takes any number of arguments,
%  which will be passed on to the initialize method.  If no
%  \code{initialize} method is defined for the class or one of its
%  superclasses, the default method expects named arguments with the
%  name of one of the fields and unnamed arguments, if any, that are
%  objects from one of the superclasses of this class (but only
%  superclasses that are themselves reference classes have any effect).
%
%  The generator function is similar to the S4 generator function
%  returned by \code{\link{setClass}}. In addition to being a generator
%  function, however, it is also a reference class generator object,
%  with reference class methods for various utilities.  See the section
%  on reference class generator objects below.
%
%If the class has a method defined for \code{$initialize()}, %$
%this method will be called once the reference object has been
%created.  You should write such a method for a class that needs to do
%some special initialization.
%In particular, a reference method is recommended rather than a method
%for the S4 generic function \code{initialize()}, because some special initialization is
%required for reference objects \emph{before} the initialization of
%fields.
%As with S4 classes, methods are written for \code{$initialize()} %$
%and not for \code{$new()}, %$
%both for the previous reason and also because \code{$new()} %$
%is invoked on the generator object and would be a method for that class.
%
%The default method for \code{$initialize()} %$
%is equivalent to invoking the method \code{$initFields(...)}. %$
%Named arguments assign initial values to the corresponding fields.
%Unnamed arguments must be objects from this class or a reference
%superclass of this class.
%Fields will be initialized to the contents of the fields in such
%objects, but named arguments override the corresponding inherited
%fields.
%Note that fields are simply assigned.  If the field is itself a
%reference object, that object is not copied.
%The new and previous object will share the reference.
%Also, a field assigned from an unnamed argument counts as an
%assignment for locked fields.
%To override an inherited value for a locked field, the new value must
%be one of the named arguments in the initializing call.
%A later assignment of the field will result in an error.
%
%Initialization methods need some care in design.
%The generator
%for a reference class will be called with no arguments, for example
%when copying the object.
%To ensure that these calls do not fail, the method must have defaults
%for all arguments or check for \code{missing()}.
%The method
%should include \code{\dots} as an argument and
%pass this on via \code{$callSuper()} (or \code{$initFields()} if
%you know that your superclasses have no initialization methods).
%This allows future class definitions that subclass this class, with
%additional fields.
%
%\code{getRefClass()} also returns the generator function for the
%class.  Note that the package slot in the value is the correct package
%from the class definition, regardless of  the \code{where} argument,
%which is used only to
%find the class if necessary.
%}
%
%
%\section{Reference Objects}{
%Normal objects in \R are passed as arguments in function calls consistently with
%functional programming semantics; that is, changes made to an object
%passed as an argument are local to the function call.  The object that
%supplied the argument is unchanged.
%
%The functional model (sometimes called pass-by-value, although this is
%inaccurate for \R) is
%suitable for many statistical computations and is implicit, for
%example, in the basic \R software for fitting statistical models.
%In some other situations, one would like all the code dealing with an
%object to see the exact same content, so that changes made in any
%computation would be reflected everywhere.
%This is often suitable if the object has some \dQuote{objective}
%reality, such as a window in a user interface.
%
%In addition, commonly used languages, including Java, C++ and many
%others, support a version of classes and methods assuming reference
%semantics.
%The corresponding programming mechanism
%is to invoke a method on an object.
%In the \R syntax we use \code{"$"} %$
%for this operation; one invokes a method,
%\code{m1} say, on an object \code{x} by the expression
%\code{x$m1(...)}. %$
%
%Methods in this paradigm are associated with the object, or more
%precisely with the class of the object, as opposed to methods in a
%function-based class/method system, which are fundamentally associated
%with the function (in \R, for example, a generic function in an \R
%session has a table of all its currently known methods).
%In this document \dQuote{methods for a class} as opposed to
%\dQuote{methods for a function} will make the distinction.
%
%Objects in this paradigm usually have named fields on which
%the methods operate.
%In the \R implementation, the fields are defined when the class is
%created.
%The field itself can optionally have a specified class, meaning that only objects
%from this class or one of its subclasses can be assigned to the field.
%By default, fields have class \code{"ANY"}.
%Fields may also be defined by supplying an accessor function which
%will be called to get or set the field.
%Accessor functions are likely when reference classes are part of an
%inter-system interface.
%The interface will usually supply the accessor functions automatically
%based on the definition of the corresponding class in the other language.
%
%Fields are accessed by reference.
%In particular, invoking a method may modify the content of
%the fields.
%
%Programming for such classes involves writing new methods for a
%particular class.
%In the \R implementation, these methods are \R functions, with zero or
%more formal arguments.
%The object on which the methods are invoked is not an explicit
%argument to the method.
%Instead, fields and methods for the class can be referred to by name
%in the method definition.
%The implementation uses \R environments to make fields and methods
%available by name.
%Additional special fields allow reference to the complete object and
%to the definition of the class.  See the section on \dQuote{Writing
%  Reference Methods}.
%
%The goal of the software described here is to provide a uniform
%programming style in \R for software dealing with reference classes, whether
%implemented directly in \R or through an interface to one of the OOP
%languages.
%}
%
%
%\section{Writing Reference Methods}{
%Reference methods are functions supplied as elements of a named list,
%either
%when invoking \code{g$methods()} %$}
%on a generator object \code{g} or as
%the argument \code{methods} in a call to \code{setRefClass}.
%They are written as ordinary \R functions but have some special
%features and restrictions.
%The body of the function can contain calls to any other reference method,
%including those inherited from other reference classes and may refer
%to fields in the object by name.
%
%Alternatively, a method may be an \emph{external} method, a function
%whose first argument is \code{.self}.
%The body of such methods works like any ordinary function.
%The methods are called like other methods (without the \code{.self}
%argument, which is supplied internally and always refers to the object
%itself).
%External methods exist so that reference classes can inherit the
%package environment of superclasses
%in other packages; see the Section \dQuote{Inter-Package Superclasses
%  and External Methods}.
%
%Fields may be modified in a method by using the
%non-local assignment operator, \code{<<-}, as in the \code{$edit} and \code{$undo}
%methods in the example below.
%Note that non-local assignment is required:  a local assignment with
%the \code{<-} operator just creates a local object in the function
%call, as it would in any \R function.
%When methods are installed, a heuristic check is made for local
%assignments to field names and a warning issued if any are detected.
%
%Reference methods should be kept simple; if they need to do some
%specialized \R computation, that computation should use a separate \R
%function that is called from the reference method.
%Specifically, methods can not use special features of the
%enclosing environment mechanism, since the method's environment is
%used to access fields and other methods.
%In particular, methods should not use non-exported entries in the
%package's namespace, because the methods may be inherited by a
%reference class in another package.
%
%Methods for \code{$initialize()} %$
%have special requirements.  See the comments in the \dQuote{Value}
%section.
%
%Reference methods can not themselves be generic functions; if you want
%additional function-based method dispatch, write a separate generic
%function and call that from the method.
%
%The entire object can be referred to in a method by the reserved
%name \code{.self}, as shown in the \code{save=} method of the
%example.
%The special object \code{.refClassDef} contains the definition of the
%class of the object.
%These fields are read-only (it makes no sense to modify these
%references), with one exception.
%In principal, the \code{.self} field can be modified in the \code{$initialize} %$
%method, because the object is still being created at this stage.
%This is definitely not recommended, unless to set some
%non-reference properties of the object defined for this class, which
%is itself not recommended if it mixes slots and fields.
%
%
%The methods available include methods inherited from superclasses, as
%discussed in the next section.
%
%Only methods actually used will be included in the environment
%corresponding to an individual object.  To declare that a method requires a
%particular other method, the first method should include a call
%to \code{$usingMethods()} %$
%with the name of the other method as an argument.
%Declaring the methods this way is essential if the other method is used indirectly (e.g., via \code{\link{sapply}()}
%or \code{\link{do.call}()}).
%If it is called directly, code analysis will find it.
%Declaring the method is harmless in any case, however, and may aid
%readability of the source code.
%
%Documentation for the methods can be obtained by the \code{$help} %$}
%method for the generator object.
%Methods for classes are not documented in the \code{Rd} format used
%for \R functions.
%Instead, the \code{$help} %$}
%method prints the calling sequence of the method, followed by
%self-documentation from the method definition, in the style of Python.
%If the first element of the body of the method is a literal character
%string (possibly multi-line), that string is interpreted as documentation.
%See the method definitions in the example.
%}
%\section{Inheritance}{
%Reference classes inherit from other reference classes by using the
%standard \R inheritance; that is, by including the superclasses in the
%\code{contains=} argument when creating the new class.
%The names of the reference superclasses are in slot
%\code{refSuperClasses} of the class definition.
%Reference classes can inherit from ordinary S4 classes also, but this
%is usually a bad idea if it mixes reference fields and non-reference slots.
%See the comments in the section on \dQuote{Implementation}.
%
%Class fields are inherited.  A class definition can override a field
%of the same name in a superclass only if the overriding class is a
%subclass of the class of the inherited field.  This ensures that a
%valid object in the field remains valid for the superclass as well.
%
%Inherited methods are installed in the same way as directly
%specified methods.
%The code in a method can refer to  inherited methods in the same
%way as directly specified methods.
%
%A method may override a method of the same name in a superclass.
%The overriding method can call the superclass method by
%\code{callSuper(...)} as described below.
%
%All reference classes inherit from the class \code{"envRefClass"},
%which provides the following methods.
%
%\describe{
%\item{\code{$callSuper(...)}}{ %$
%Calls the method inherited from a reference superclass.
%The call is meaningful only from within another method, and will be
%resolved to call the inherited method of the same name.
%The arguments to \code{$callSuper} %$}
%are passed to the superclass version.
%See the matrix viewer class in the example.
%
%Note that the intended arguments for the superclass method must be
%supplied explicitly; there is no convention for supplying the
%arguments automatically, in contrast to the similar mechanism for
%functional methods.
%}
%
%\item{\code{$copy(shallow = FALSE)}}{ %$
%Creates a copy of the object.  With reference classes, unlike ordinary
%\R objects, merely assigning the object with a different name does not
%create an independent copy.  If \code{shallow} is \code{FALSE}, any
%field that is itself a reference object will also be copied, and
%similarly recursively for its fields.  Otherwise, while reassigning a
%field to a new reference object will have no side effect, modifying
%such a field will still be reflected in both copies of the object.
%The argument has no effect on non-reference objects in fields.  When
%there are reference objects in some fields but it is asserted that
%they will not be modified, using \code{shallow = TRUE} will save some
%memory and time.
%}
%
%\item{\code{$field(name, value)}}{ %$
%With one argument, returns the field of the object with character
%string \code{name}.  With two arguments, the corresponding field is
%assigned \code{value}.  Assignment checks that \code{name} specifies a
%valid field, but the single-argument version will attempt to get
%anything of that name from the object's environment.
%
%The \code{$field()} %$
%method replaces the direct use of a field name, when the name of the
%field must be calculated, or for looping over several fields.
%}
%
%\item{\code{$export(Class)}}{ %$
%Returns the result of coercing the object to \code{Class} (typically
%one of the superclasses of the object's class).  Calling the method
%has no side effect on the object itself.
%}
%
%\item{\code{$getRefClass()}; \code{$getClass()}}{
%These return respectively the generator object and the formal class
%definition for the reference class of this object, efficiently.
%}
%
%
%
%\item{\code{$import(value, Class = class(value))}}{ %$
%Import the object \code{value} into the current object, replacing the
%corresponding fields in the current object.
%Object \code{value} must come from one of the superclasses of the
%current object's class.
%If argument \code{Class} is supplied, \code{value} is first coerced to
%that class.
%}
%
%\item{\code{$initFields(...)}}{ %$
%Initialize the fields of the object from the supplied arguments.  This
%method is usually only called from a class with a \code{$initialize()}% $
%method.  It corresponds to the default initialization for reference
%classes.  If there are slots and non-reference superclasses, these may
%be supplied in the \dots argument as well.
%
%Typically, a specialized \code{$initialize()}% $
%method carries out its own computations, then invokes \code{$initFields()}% $
%to perform standard initialization, as shown in the
%\code{matrixViewer} class in the example below.
%}
%
%\item{\code{$show()}}{ %$
%This method is called when the object is printed automatically,
%analogously to the \code{\link{show}} function.  A general method is
%defined for class \code{"envRefClass"}.  User-defined reference
%classes will often define their own method: see the Example below.
%
%Note two points in the example.  As with any \code{show()} method, it
%is a good idea to print the class explicitly to allow for subclasses
%using the method.  Second, to call the \emph{function} \code{show()}
%from the method, as opposed to the \code{$show()} %$
%method itself, refer to \code{methods::show()} explicitly.
%}
%
%\item{\code{$trace(what, ...)}, \code{$untrace(what)} }{
%Apply the tracing and debugging facilities of the \code{\link{trace}}
%function to the reference method \code{what}.
%
%All the arguments of the \code{\link{trace}}
%function can be supplied, except for \code{signature}, which is not
%meaningful.
%
%The reference method can be invoked on either an object or the
%generator for the class.  See the section on Debugging below for details.
%}
%
%\item{\code{$usingMethods(...)}}{ %$
%Reference methods used by this method are named as the arguments
% either quoted or unquoted.  In the code analysis phase of installing the
% the present method, the declared methods will be included.  It is essential
% to declare any methods used in a nonstandard way (e.g., via an apply function).
% Methods called directly do not need to be declared, but it is harmless to do so.
% \code{$usingMethods()} does nothing at run time. %$
%}
%} % end describe
%
%Objects also inherit two reserved fields:
%\describe{
%\item{\code{.self}}{
%a reference to the entire object;
%}
%\item{\code{.refClassDef}}{
%the class definition.
%}
%} % end \describe
%The defined fields should not override these, and in general it is
%unwise to define a field whose name begins with \code{"."}, since the
%implementation may use such names for special purposes.
%
%}
%
%\section{Inter-Package Superclasses  and External Methods}{
%The environment of a method in a reference class is the object itself,
%as an environment.
%This allows the method to refer directly to fields and other methods,
%without using the whole object and the \code{"$"} %$
%operator.
%The parent of that environment is the namespace of the package in
%which the reference class is defined.
%Computations in the method have access to all the objects in the
%package's namespace, exported or not.
%
%When defining a class that contains a reference superclass in another
%package, there is an ambiguity about which package namespace should
%have that role.
%The argument \code{inheritPackage} to \code{setRefClass()} controls
%whether the environment of new objects should inherit from an
%inherited class in another package or continue to inherit from the
%current package's namespace.
%
%If the superclass is \dQuote{lean}, with few methods, or exists
%primarily to support a family of subclasses, then it may be better to
%continue to use the new package's environment.
%On the other hand, if the superclass was originally written as a
%standalone, this choice may invalidate existing superclass methods.
%For the superclass methods to continue to work, they must use only
%exported functions in their package and the new package must import
%these.
%
%Either way, some methods may need to be written that do \emph{not}
%assume the standard model for reference class methods, but behave
%essentially as ordinary functions would in dealing with reference
%class objects.
%
%The mechanism is to recognize \emph{external methods}.
%An external method  is
%written as a function in which the first argument, named \code{.self},
%stands for the reference class object.
%This function is supplied as the definition for a reference class method.
%The method will be called, automatically, with the first argument
%being the current object and the other arguments, if any, passed along
%from the actual call.
%
%Since an external method is an ordinary function in the source code
%for its package, it has access to all the objects in the namespace.
%Fields and methods in the reference class must be referred to in the
%form \code{.self$name}.%$
%
%If for some reason you do not want to use \code{.self} as the first
%argument, a function \code{f()} can be converted explicitly as
%\code{externalRefMethod(f)}, which returns an object of class
%\code{"externalRefMethod"} that can be supplied as a method for the
%class.
%The first argument will still correspond to the whole object.
%
%External methods can be supplied for any reference class, but there is no
%obvious advantage unless they are needed.
%They are more work to write, harder to read and (slightly) slower to
%execute.
%
%\emph{NOTE:} If you are the author of a package whose reference
%classes are likely to be subclassed in other packages, you can avoid
%these questions entirely by writing methods that \emph{only} use
%exported functions from your package, so that all the methods will
%work from another package that imports yours.
%
%}
%
%\section{Reference Class Generators}{
%The call to \code{setRefClass} defines the specified class and
%returns a \dQuote{generator function} object for that class.
%This object has class \code{"refObjectGenerator"}; it inherits
%from \code{"function"} via \code{"classGeneratorFunction"} and can be
%called to generate new objects from the reference class.
%
%The returned object is also a reference class object, although not of
%the standard construction.
%It can be used to invoke reference methods and access fields in the usual way, but
%instead of being implemented directly as an environment it has a
%subsidiary generator object as a slot, a
%standard reference object (of class
%\code{"refGeneratorSlot"}).
%Note that if one wanted to extend the reference class generator
%capability with a subclass, this should be done by subclassing
%\code{"refGeneratorSlot"}, not \code{"refObjectGenerator"}.
%
%The fields are \code{def}, the class definition, and \code{className},
%the character string name of the class.
%Methods generate objects
%from the class, to access help on reference methods, and to
%define new reference methods for the class.
%The currently available methods are:
%\describe{
%\item{\code{$new(...)}}{ %$
%This method is equivalent to calling the generator function returned
%by \code{setRefClass}.
%}
%
%\item{\code{$help(topic)}}{ %$
%Prints brief help on the topic.  The topics recognized
%are reference method names, quoted or not.
%
%The information printed is the calling sequence for the method, plus
%self-documentation if any.
%Reference methods can have an initial character string or vector as
%the first element in the body of the function defining the method.
%If so, this string is taken as self-documentation for the method (see
%the section on \dQuote{Writing Reference Methods} for details).
%
%If no topic is given or if the topic is not a method name, the
%definition of the class is printed.
%}
%\item{\code{$methods(...)}}{ %$
%With no arguments, returns the names of the reference methods for this
%class.
%With one character string argument, returns the method of that name.
%
%Named arguments
%are method definitions, which will be
%installed in the class, as if they had been supplied in the
%\code{methods} argument to \code{setRefClass()}.
%Supplying methods in this way, rather than in the call to
%\code{setRefClass()}, is recommended for the sake of clearer source
%code.
%See the section on \dQuote{Writing Reference Methods} for details.
%
%All methods for a class should be defined in the source code that
%defines the class, typically as part of a package.
%In particular, methods can not be redefined in a class in an attached
%package with a namespace: The class method checks for a locked
%binding of the class definition.
%
%
%The new methods can refer to any currently defined method by name
%(including other methods supplied in this call to
%\code{$methods()}. %$
%Note though that previously defined methods are not re-analyzed
%meaning that they will not call the new method (unless it redefines an
%existing method of the same name).
%
%To remove a method, supply \code{NULL} as its new definition.
%}
%
%\item{\code{$fields()}}{ %$}{
%Returns a list of the fields, each with its corresponding class.
%Fields for which an accessor function was supplied in the definition
%have class \code{"activeBindingFunction"}.
%}
%
%\item{\code{$lock(...)}}{ %$}{
%The fields named in the arguments are locked; specifically, after the
%lock method is called, the field may be set once.  Any further attempt
%to set it will generate an error.
%
%If called with no arguments, the method returns the names of the
%locked fields.
%
%Fields that are defined by an explicit accessor function can not be
%locked (on the other hand, the accessor function can be defined to
%generate an error if called with an argument).
%
%All code to lock fields should normally be part of the definition of a
%class; that is, the read-only nature of the fields is meant to be part
%of the class definition, not a dynamic property added later.
%In particular, fields can not be locked in a class in an attached
%package with a namespace:  The class method checks for a locked
%binding of the class definition.  Locked fields can not be
%subsequently unlocked.
%}
%
%\item{\code{$trace(what, ..., classMethod = FALSE)}}{ %$}{
%Establish a traced version of method \code{what} for objects generated
%from this class.  The generator object tracing works like the
%\code{$trace()}%$
%method for objects from the class, with two differences.
%Since it changes the method definition in the class object itself,
%tracing applies to all objects, not just the one on which the trace
%method is invoked.
%
%Second, the optional argument \code{classMethod = TRUE} allows tracing
%on the methods of the generator object itself.
%By default, \code{what} is interpreted as the name of a method in the
%class for which this object is the generator.
%}
%
%\item{\code{$accessors(...)}}{ %$}{
%A number of
%systems using the OOP programming paradigm recommend or enforce
%\emph{getter and setter methods}
%corresponding to each field, rather than direct access by name.
%If you like this style and want to  extract a field named \code{abc}
%by \code{x$getAbc()} and assign it by
%\code{x$setAbc(value)},
%the \code{$accessors} %$}
%method is a convenience function that creates such getter and setter methods for the
%specified fields.
%Otherwise there is no reason to use this mechanism.  In particular, it
%has nothing to do with the general ability to define fields by
%functions as described in the section on \dQuote{Reference Objects}.
%}
%} %% end of \describe
%} %% end of \section
%
%\section{Implementation}{
%Reference classes are implemented as S4 classes with a data part of
%type \code{"environment"}.
%Fields correspond to named objects in the environment.
%A field associated with a function is implemented as an
%\link[=bindenv]{active binding}.
%In particular, fields with a specified class are implemented as a
%special form of active binding to enforce valid assignment to the
%field.
%A field, say \code{data}, can be accessed generally by an expression
%of the form \code{x$data} %$}
%for any object from the relevant class.
%In a method for this class, the field can be accessed by the name
%\code{data}.
%A field that is not locked can be set by an expression of the form
%\code{x$data <- value}.%$
%Inside a method, a field can be assigned by an expression of the form
%\code{x <<- value}.
%Note the \link[=assignOps]{non-local assignment} operator.
%The standard \R interpretation of this operator works to assign it in
%the environment of the object.
%If the field has an accessor function defined, getting and setting
%will call that function.
%
%When a method is invoked on an object, the function defining the method is
%installed in the object's environment, with the same environment as the
%environment of the function.
%
%Because of the implementation, new reference classes can inherit from
%non-reference S4 classes as well as reference classes.
%This is usually a bad idea, if the slots from the non-reference
%class are thought of as alternatives to fields.
%Unless there is some special argument in favor, mixing the functional
%and reference paradigms for properties of the same object is
%conceptually unclear.
%In addition, the initialization method for the class will have to sort
%out fields from slots, with a good chance of creating anomalous
%behavior for subclasses of this class.
%Better in general to define fields analogous to the slots in the S4
%class, and to initialize those from an S4 object of that class.
%
%}
%
%\section{Inter-System Interfaces}{
%A number of
%languages use a similar reference-based programming model with classes
%and class-based methods.
%Aside from differences in choice of terminology and other details,
%many of these languages are compatible with the programming style
%described here.
%\R interfaces to the languages exist in a number of packages.
%
%The reference class definitions here provide a hook for
%classes in the foreign language to be exposed in \R.
%Access to fields and/or methods in the class can be
%implemented by defining an \R reference class corresponding to
%classes made available through the interface.
%Typically, the inter-system interface will take care of the details of
%creating the \R class, given a description of the foreign class (what fields
%and methods it has, the classes for the fields, whether any are
%read-only, etc.)
%The specifics for the fields and methods can be implemented via
%reference methods for the \R class.
%In particular, the use of active bindings allows field access for
%getting and setting, with
%actual access handled by the inter-system interface.
%
%\R methods and/or fields can be included in the class definition as for any
%reference class.
%The methods can use or set fields and can call other methods transparently
%whether the field or method comes from the interface or is defined
%directly in \R.
%
%For an inter-system interface using this approach, see the code for package \code{Rcpp}, version
%0.8.7 or later.
%}
%% \value{
%% \code{setRefClass()} and \code{getRefClass()} both return a generator object for the class. This is
%% itself a reference object, with methods to generate objects from the
%% class and also for defining new methods and for help-style
%% documentation. See the
%% section on \dQuote{Reference Class Generator Objects} for details.
%% Note that \code{Class} in the call to \code{getRefClass()} can be an
%% object from the corresponding class, and that a similar reference
%% class method \code{$getRefClass()} %$
%% is available as well.
%
%% \code{setRefClass} defines the class and stores its class definition.
%% \code{getRefClass} requires that the class has been defined as a
%% reference class.
%
%% }
%\section{Debugging}{
%The standard \R{} debugging and tracing facilities can be applied to
%reference methods.
%Reference methods can be passed to \code{\link{debug}} and its
%relatives from an object to debug further method invocations on that
%object; for example, \code{debug(xx$edit)}. %$
%
%Somewhat more flexible use is available for a reference method version
%of the \code{\link{trace}} function.
%A corresponding \code{$trace()} %$
%reference method is available for
%either an object or for the reference class generator
%(\code{xx$trace()} or \code{mEdit$trace()} in the example below).
%Using \code{$trace()} on an object sets up a tracing
%version for future invocations of the specified method for that
%object.
%Using \code{$trace()} on the generator for the class sets up a
%tracing version for all future objects from that class (and sometimes for
%existing objects from the class if the method is not declared or
%previously invoked).
%
%In either case, all the arguments to the standard  \code{\link{trace}}
%function are available, except for \code{signature=} which is
%meaningless since reference methods can not be S4 generic functions.
%This includes the typical style \code{trace(what, browser)} for
%interactive debugging and  \code{trace(what, edit = TRUE)} to edit the
%reference method interactively.
%
%}
%\author{
%  John Chambers
%}
%
%\examples{
%## a simple editor for matrix objects.  Method  $edit() changes some
%## range of values; method $undo() undoes the last edit.
%mEdit <- setRefClass("mEdit",
%      fields = list( data = "matrix",
%        edits = "list"),
%      methods = list(
%     edit = function(i, j, value) {
%       ## the following string documents the edit method
%       'Replaces the range [i, j] of the
%        object by value.
%        '
%         backup <-
%             list(i, j, data[i,j])
%         data[i,j] <<- value
%         edits <<- c(edits, list(backup))
%         invisible(value)
%     },
%     undo = function() {
%       'Undoes the last edit() operation
%        and update the edits field accordingly.
%        '
%         prev <- edits
%         if(length(prev)) prev <- prev[[length(prev)]]
%         else stop("No more edits to undo")
%         edit(prev[[1]], prev[[2]], prev[[3]])
%         ## trim the edits list
%         length(edits) <<- length(edits) - 2
%         invisible(prev)
%     },
%     show = function() {
%       'Method for automatically printing matrix editors'
%       cat("Reference matrix editor object of class",
%          classLabel(class(.self)), "\n")
%       cat("Data: \n")
%       methods::show(data)
%       cat("Undo list is of length", length(edits), "\n")
%     }
%     ))
%
%xMat <- matrix(1:12,4,3)
%xx <- mEdit(data = xMat)
%xx$edit(2, 2, 0)
%xx
%xx$undo()
%mEdit$help("undo")
%stopifnot(all.equal(xx$data, xMat))
%
%utils::str(xx) # show fields and names of non-trivial methods
%
%## add a method to save the object
%mEdit$methods(
%     save = function(file) {
%       'Save the current object on the file
%        in R external object format.
%       '
%         base::save(.self, file = file)
%     }
%)
%
%tf <- tempfile()
%xx$save(tf)
%\dontshow{
%load(tf)
%unlink(tf)
%stopifnot(identical(xx$data, .self$data))
%}
%
%\dontrun{
%## Inheriting a reference class:  a matrix viewer
%mv <- setRefClass("matrixViewer",
%    fields = c("viewerDevice", "viewerFile"),
%    contains = "mEdit",
%    methods = list( view = function() {
%        dd <- dev.cur(); dev.set(viewerDevice)
%        devAskNewPage(FALSE)
%        matplot(data, main = paste("After",length(edits),"edits"))
%        dev.set(dd)},
%        edit = # invoke previous method, then replot
%          function(i, j, value) {
%            callSuper(i, j, value)
%            view()
%          }))
%
%## initialize and finalize methods
%mv$methods( initialize =
%  function(file = "./matrixView.pdf", ...) {
%    viewerFile <<- file
%    pdf(viewerFile)
%    viewerDevice <<- dev.cur()
%    dev.set(dev.prev())
%    callSuper(...)
%  },
%  finalize = function() {
%    dev.off(viewerDevice)
%  })
%
%## debugging an object: call browser() in method $edit()
%xx$trace(edit, browser)
%
%## debugging all objects from class mEdit in method $undo()
%mEdit$trace(undo, browser)
%}
%\dontshow{
%removeClass("mEdit")
%resetGeneric("$")
%resetGeneric("initialize")
%} %$
%}
%\keyword{ programming }
%\keyword{ classes }
%
%\encoding{UTF8}
%