% File src/library/methods/man/selectSuperClass.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-12 R Core Team
% Distributed under GPL 2 or later

\name{selectSuperClasses}
%@%\alias{クラスの(特定の種類の)スーパークラス}
\alias{selectSuperClasses}
\alias{.selectSuperClasses}
\title{クラスの(特定の種類の)スーパークラス}
%\title{Super Classes (of Specific Kinds) of a Class}
\description{
  \code{ClassDef} のスーパークラスを返す．
  可能性として非仮想的だけであったり，または直接や単純な
  もの．

  これらの関数は速くなるようにデザインされており，
  従って対応するクラス定義の
  \code{contains} スロットにだけ動作する．
}
\usage{
selectSuperClasses(Class, dropVirtual = FALSE, namesOnly = TRUE,
                   directOnly = TRUE, simpleOnly = directOnly,
                   where = topenv(parent.frame()))

.selectSuperClasses(ext, dropVirtual = FALSE, namesOnly = TRUE,
                    directOnly = TRUE, simpleOnly = directOnly)
}
\arguments{
  \item{Class}{
    クラスの名前か(より効率的に)クラス定義
    (\code{\link{getClass}} を見よ)．}
  \item{dropVirtual}{
    非仮想的なスーパークラスだけが返されるべきかどうかを
    指示する論理値．}
  \item{namesOnly}{
    名前付きのクラス拡張のリストの代わりに
    ベクトル名だけを返すかどうかを指示する論理値．}
  \item{directOnly}{
    \emph{直接}のスーパークラスだけを返すべきかどうかを
    四s持する論理値．}
  \item{simpleOnly}{
    単純なクラス拡張だけを返すべきかどうかを指示する論理値．}
  \item{where}{
    (\code{Class} がクラス拡張で無い時だけ使われる)
    \code{Class} のクラス拡張が見つかる環境．}
  \item{ext}{
    \code{.selectSuperClasses()} に対してだけ，
    クラス拡張の \code{\link{list}} で，
    典型的には \code{\link{getClassDef}(..)@contains}．}
}
\note{典型的なユーザレベルの関数は
  \code{selectSuperClasses()} であり
  \code{.selectSuperClasses()} を呼び出す；つまり後者は
  経験のある \R ユーザが効率性のためだけに使われるべきである．
}
\value{
  \code{\link{character}} ベクトル
  (既定としてもし \code{namesOnly} が真なら)または
  クラス拡張のリスト
  (\code{\link{getClass}} の結果中の \code{contains} スロットとして)．
}
\seealso{
  \code{\link{is}}, \code{\link{getClass}}；
  更により技術的なクラス
  \code{\linkS4class{classRepresentation}} のドキュメント．
}
\examples{
setClass("Root")
setClass("Base", contains = "Root", representation(length = "integer"))
setClass("A", contains = "Base", representation(x = "numeric"))
setClass("B", contains = "Base", representation(y = "character"))
setClass("C", contains = c("A", "B"))

extends("C")   #-->  "C"  "A" "B"  "Base" "Root"
selectSuperClasses("C") # "A" "B"
selectSuperClasses("C", direct=FALSE) # "A" "B"  "Base"  "Root"
selectSuperClasses("C", dropVirt = TRUE, direct=FALSE)# 同上，"Root" 無し
}
\keyword{programming}
\keyword{classes}


\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/selectSuperClass.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-12 R Core Team
%% Distributed under GPL 2 or later
%
%\name{selectSuperClasses}
%\alias{selectSuperClasses}
%\alias{.selectSuperClasses}
%\title{Super Classes (of Specific Kinds) of a Class}
%\description{
%  Return superclasses of \code{ClassDef}, possibly only non-virtual or
%  direct or simple ones.
%
%  These functions are designed to be fast, and consequently only work
%  with the \code{contains} slot of the corresponding class definitions.
%}
%\usage{
%selectSuperClasses(Class, dropVirtual = FALSE, namesOnly = TRUE,
%                   directOnly = TRUE, simpleOnly = directOnly,
%                   where = topenv(parent.frame()))
%
%.selectSuperClasses(ext, dropVirtual = FALSE, namesOnly = TRUE,
%                    directOnly = TRUE, simpleOnly = directOnly)
%}
%\arguments{
%  \item{Class}{name of the class or (more efficiently) the class
%    definition object (see \code{\link{getClass}}).}
%  \item{dropVirtual}{logical indicating if only non-virtual superclasses
%    should be returned.}
%  \item{namesOnly}{logical indicating if only a vector names instead of
%    a named list class-extensions should be returned.}
%  \item{directOnly}{logical indicating if only a \emph{direct} super
%  classes should be returned.}
%  \item{simpleOnly}{logical indicating if only simple class extensions
%    should be returned.}
%  \item{where}{(only used when \code{Class} is not a class definition)
%    environment where the class definition of \code{Class} is found.}
%  \item{ext}{for \code{.selectSuperClasses()} only, a \code{\link{list}}
%    of class extensions, typically \code{\link{getClassDef}(..)@contains}.}
%}
%\note{The typical user level function is \code{selectSuperClasses()}
%  which calls \code{.selectSuperClasses()}; i.e., the latter should only
%  be used for efficiency reasons by experienced useRs.
%}
%\value{
%  a \code{\link{character}} vector (if \code{namesOnly} is true, as per
%  default) or a list of class extensions (as the \code{contains} slot in
%  the result of \code{\link{getClass}}).
%}
%\seealso{
%  \code{\link{is}}, \code{\link{getClass}}; further, the more technical
%  class \code{\linkS4class{classRepresentation}} documentation.
%}
%\examples{
%setClass("Root")
%setClass("Base", contains = "Root", representation(length = "integer"))
%setClass("A", contains = "Base", representation(x = "numeric"))
%setClass("B", contains = "Base", representation(y = "character"))
%setClass("C", contains = c("A", "B"))
%
%extends("C")   #-->  "C"  "A" "B"  "Base" "Root"
%selectSuperClasses("C") # "A" "B"
%selectSuperClasses("C", direct=FALSE) # "A" "B"  "Base"  "Root"
%selectSuperClasses("C", dropVirt = TRUE, direct=FALSE)# ditto w/o "Root"
%}
%\keyword{programming}
%\keyword{classes}
%
%
%\encoding{UTF8}
%