% File src/library/methods/man/setClass.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{setClass}
%@%\alias{クラス定義を作る}
\alias{setClass}
\alias{classGeneratorFunction-class}
\title{クラス定義を作る}
%\title{Create a Class Definition}
\description{
  表現(スロット) と/または これに含まれるクラス(スーパークラス)，
  プラス他のオプションの詳細を指定しクラス定義を作る．
  副作用として，クラス定義は指定された環境に保存される．
  生成関数は \code{setClass()} の値として返され，
  もし非仮想的ならばクラスからオブジェクトを作るのに
  適している．関数への多くの引数から
  \code{Class}, \code{slots=} そして \code{contains=} が
  普通必要とされる．
}
\usage{
setClass(Class, representation, prototype, contains=character(),
         validity, access, where, version, sealed, package,
         S3methods = FALSE, slots)
}
\arguments{
  \item{Class}{クラスに対する文字列名．}
  \item{slots}{
    名前付きリストか名前付き文字列．
    名前は新しいクラス中のスロット名で
    要素は対応するクラスの文字列名である．

    同じ名前の二つのクラスは異なったパッケージから移入されるので
    稀なケースではスロットのクラスに関する曖昧さがあり，
    対応する引数の要素は選択の曖昧さを無くすため
    \code{"package"} 属性を持たなければならない．

    極端なケースとして名前無しの文字列を与えることが許され，
    要素はスロット名として取られ，全てのスロットは
    無制約のクラス \code{"ANY"} を持つ．
  }
  \item{contains}{
    このクラスの\emph{スーパークラス}に対する
    名前(そしてオプションでパッケージスロット)．
    特別なスーパークラス \code{"VIRTUAL"} は
    新しいクラスが仮想的クラスとして生成されるようにする；
    \link{Classes} 中の仮想的クラスに対する節を見よ．}
  \item{prototype}{
    このクラス中のスロットに対する既定データを提供するオブジェクト．
    もし与えられれば，
    \code{\link{prototype}} への呼び出しの使用はある種のチェックを行う．}
  \item{where}{
    その中に定義を保存する環境．
    標準的な使用では与えるべきではない．
    パッケージに対するソースコード中に現れる \code{setClass()}
    への呼び出しに対しては既定値はパッケージの名前空間．
    タイプされるかセッションのトップレベルでソース読み込みされた
    呼び出しに対しては既定値は大局的環境．
  }
  \item{validity}{
    もし提供されると，このクラスからのオブジェクトに対する
    適正度チェックメソッド
    (もしその引数がこのクラスに対する適正なオブジェクトならば
    \code{TRUE} を返し，さもなければ失敗を説明する一つまたは
    それ以上の文字列)であるべきである．
    詳細は \code{\link{validObject}} を見よ．}
  \item{S3methods, representation, access, version }{
    これら全ての引数は \R のバージョン 3.0.0 から廃止予定とされ
    \emph{避ける}べきである．

    \code{S3methods} は旧式スタイルのメソッドがこのクラス
    を含んで書かれることを指示するフラグ．
    \R の新しいバージョンは形式的と旧式スタイルのメソッドに
    一貫性があるようにマッチすることを試みるので，
    この引数はあまり問題ではない．

    \code{representation} は
    \code{slots} と \code{contains} の双方に含まれる S から
    継承される引数であるが，後者の二つの引数の使用は
    より明快で推奨される．

    \code{access} と \code{version} は
    S-Plus との歴史的な互換性のために含まれているが無視される．
  }
  \item{sealed}{ もし \code{TRUE} ならばクラス定義は
    封印されるので，
    \code{setClass} への別の呼び出しはこのクラス名に対しては
    失敗する．
  }
  \item{package}{このクラスに対するオプションのパッケージ名．
    非常に稀にしか使われるべきではない．
    既定ではクラス定義がその中に付値されているパッケージの名前．
  }
}

\value{
  クラスからのオブジェクトに対して適当な生成関数を不可視で返す．
  この関数の呼び出しは
  クラスに対する \code{\link{new}} の呼び出しを生成する．
  呼び出しは任意個数の引数を取り，
  それらは初期化メソッドに渡される．
  もしクラスかそのスーパークラスの一つに対する
  \code{initialize} メソッドが与えられないと，
  既定メソッドはスロットの一つの名前を持つ名前付き引数を
  期待する．

  プログラミングの分かりやすさから，典型的には生成関数は
  クラスの名前を付けられる．
  これは要求では無く，そしてクラスからのオブジェクトはまた
  \code{\link{new}} から直接に生成することも出来る．
  生成関数の利点は少しより単純で明快な呼び出しであり，
  呼び出しがクラスのパッケージ名を含むことである
  (もし異なったパッケージからの二つのクラスが同じ名前を
  持てば曖昧さが無くせる)．

  もしクラスが仮想的ならば，生成器か
  \code{new()} のどちらかからのオブジェクトを生成しようとすると
  エラーになる．
}

\section{基本的な用法：スロットと継承}{
クラス名以外の二つの本質的な引数は
\code{slots} と \code{contains} で，明示的なスロットと
継承(スーパークラス)を定義する．
これらの引数は併せてこのクラスからの全ての情報を定義する；
つまり，それらの各々に対して必要とされる全てのスロットとクラスの名前である．

クラス名はどのメソッドがこのクラスからのオブジェクトに直接適用される
かを決定する．
継承情報はどのメソッドが継承により間接的に適用されるかを指定する．
\link{Methods} を見よ．

クラス定義中のスロットは
\code{slots} により直接指定される全てのスロットと全ての含まれるクラス
中のスロットの合併である．与えられた名前のスロットは一つしか許されない；
特に直接と継承されたスロット名はユニークでなければならない．
しかしながら，これは同じクラスが一つ以上のパスで継承されることを妨げない．

\code{contains=} 引数中の一種類の要素は特殊で，
一つの \R オブジェクトタイプかいくつかの他の特殊な
\R タイプ(\code{matrix} と \code{array})の一つを指定する．
下のオブジェクトタイプからの継承の節を見よ．


  スロット名 \code{"class"} と \code{"Class"} は許されない．
  特殊な意味を持つ他のスロット名がある；
  これらの名前は \code{"."} 文字で始まる．
  安全のために，自分自身の全てのスロットをあるアルファベット文字で始まる
  ように定義すべきである．
}

\section{オブジェクトタイプからの継承}{
他の S4 クラスを含む以外に，クラス定義は
S3 クラス(次の節を見よ)か組み込みの R の擬似クラス---
\R のオブジェクトタイプの一つか特殊な
\R の擬似クラス \code{"matrix"} と \code{"array"}---を含むことが出来る．
一つのクラスは他のタイプを最大一つ直接的または間接的に含むことが出来る．
もしそうであれば，その含まれたクラスはクラスの
\dQuote{データ部分}を決定する．

新しいクラスからのオブジェクトは含まれるタイプの
組み込みの挙動を継承使用と試みる．
ベクトル，関数そして表現式を含む正規の \R データタイプの場合，
実装は相対的に直接的である．
クラスからの任意のオブジェクトに対して，
\code{typeof(x)} は含まれる基本的タイプである；
そして特殊と擬似スロット，\code{.Data}，は対応する
クラスとして表示される．
下の例 \code{"numWithId"} を見よ．

クラスはまた
\code{"vector"}, \code{"matrix"} または \code{"array"} を継承できる．
これらのオブジェクトのデータ部分は任意のベクトルデータタイプ
であり得る．

これらのタイプやクラスを含ま
\emph{無い}任意のクラスからのオブジェクトに対しては，
\code{typeof(x)} は \code{"S4"} になる．

ある種の \R データタイプは，それらが非局所参照であるか
複製されない他のオブジェクトであるという意味で
普通の挙動をしない．
例はクラス \code{"environment"}, \code{"externalptr"} そして
\code{"name"} に対応するそれらを含む．
これらは，属性の設定があらゆる文脈でオブジェクトを
上書きするために，ユーザ定義のクラス
(S4 でも S3 でも)を持つオブジェクトに対するタイプにはなれない．
そうしたタイプを継承するクラスを定義することは
継承オブジェクトを予約スロットに補完する間接的な機構を通じて
可能である．下のクラス \code{"stampedEnv"} に対するクラスの例を見よ．
S3 メソッドの選択適用と関連する
\code{as.}\emph{type}\code{()} 関数は正しく動作すべきであるが，
オブジェクトのタイプを直接使うコードはしない．

又低水準の計算に渡されるオブジェクト
クラス中に定義された任意のスロット\emph{無し}の
基底にあるオブジェクトタイプであることを留意せよ．
完全な情報を返すためには，普通データパートを設定する
メソッドを書かねばならない．
}

\section{S3 クラスからの継承}{
旧式のスタイルの S3 クラスは形式的定義を持たない．
オブジェクトはそれらのクラス属性がクラスメイト考えられる
文字列を含む時そのクラス\dQuote{由来}とされる．

そうしたクラスを形式的クラスとメソッドと共に
使うことは，オブジェクトの中身や
継承メソッドの一貫性関する保証が無いため
危険な仕事になる．その上で，
S3 クラスを継承するクラスを定義することは，
クラスが旧式クラスとして登録されていれば
(\code{\link{setOldClass}} を見よ)依然可能である．

大まかに言えば，S3 と S4 メソッドの選択適用はどちらの
システム中の継承に関して意味があるように振る舞うように
務める．S4 オブジェクトをあたえた時，S3 メソッドの選択適用と
\code{\link{inherits}} 関数は
S4 継承情報を使うべきである．
S3 オブジェクトをあたえた時，S4 総称的関数は，
継承が \code{\link{setOldClass}} を使って宣言されている限り，
S3 継承を用いて S4 メソッドを選択適用する．
}

\section{クラスとパッケージ}{

クラス定義は普通パッケージに属する
(しかし同様に大局的環境中で
コマンドラインの表現式の評価やコマンドラインから
ソース読み込みされるファイル中で定義可能である)．
対応するパッケージ名はクラス定義の一部分である；
つまりその定義を保持する \code{classRepresentation}
オブジェクトの一部分である．
このように，同じ名前の二つのクラスが
異なったパッケージ中に存在できる．

クラス名が
\code{setClass} への呼び出し中のスロットやスーパークラスに
対して提供されると，曖昧さを避けるためにそうあるべきなように，
問題の呼び出しがパッケージに対するソース中に
直接現れることを仮定して，対応するクラス定義が
現在のパッケージの名前空間から探される．
クラス定義は現在の名前空間中，
その名前空間空間に対する移入物，またはメソッドパッケージで
定義された基本クラス中，で見つかるべきである．
(メソッドパッケージは
\code{"CMD check"} ユーティリティがこれらのクラスを見つけられるように
パッケージの \code{"DESCRIPTION"} ファイル中の
\code{Depends} ダイレクティブ中に含められるべきである．)

この規則がクラスをユニークに特定出来ない
(一つ以上の移入されたパッケージ中に現れるため)時は
文字列名の \code{\link{packageSlot}} が
その名前で提供される必要がある．
これは滅多に起きるべきではない．
}

\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\seealso{
  クラスの一般的な議論は \code{\link{Classes}}，
  メソッドの同様の議論は 
  \code{\link{makeClassRepresentation}}, \code{\link{Methods}}．
}
\examples{
\dontshow{
 if(isClass("trackMultiCurve")) removeClass("trackMultiCurve")
 if(isClass("trackCurve"))      removeClass("trackCurve")
 if(isClass("track"))           removeClass("track")
}
## 二つのスロットを持つ簡単な例
track <- setClass("track", slots = c(x="numeric", y="numeric"))
## クラスからのオブジェクト
t1 <- track(x = 1:10, y = 1:10 + rnorm(10))

## 先を拡張するクラス，スロットをもうひとつ加える
trackCurve <- setClass("trackCurve",
		slots = c(smooth = "numeric"),
		contains = "track")

## スーパークラスオブジェクトを含むオブジェクト
t1s <- trackCurve(t1, smooth = 1:10)

## "trackCurve" に類似のクラスだが，
## "y" に行列と "smooth" スロットを許す異なった構造を持つ
setClass("trackMultiCurve",
         slots = c(x="numeric", y="matrix", smooth="matrix"),
         prototype = list(x=numeric(), y=matrix(0,0,0),
                          smooth= matrix(0,0,0)))
## これらのクラスを使う更なる例に対しては ?setIs を見よ

## 組み込みのデータタイプ "numeric" を拡張するクラス

numWithId <- setClass("numWithId", slots = c(id = "character"),
         contains = "numeric")

numWithId(1:3, id = "An Example")

## タイプ "environment" の参照クラスを継承
stampedEnv <- setClass("stampedEnv", contains = "environment",
                       slots = c(update = "POSIXct"))
setMethod("[[<-", c("stampedEnv", "character", "missing"),
   function(x, i, j, ..., value) {
       ev <- as(x, "environment")
       ev[[i]] <- value  # 環境中のオブジェクトを更新
       x@update <- Sys.time() #そして更新日時
       x})


e1 <- stampedEnv(update = Sys.time())

e1[["noise"]] <- rnorm(10)

\dontshow{
tMC <- new("trackMultiCurve")
is.matrix(slot(tMC, "y"))
is.matrix(slot(tMC, "smooth"))
setClass("myMatrix", "matrix", prototype = matrix(0,0,0))
nrow(new("myMatrix")) # 0
nrow(new("matrix")) # 1
## プロトタイプデータの簡単なテスト
xxx <- stats::rnorm(3)
setClass("xNum", slots = c(x = "numeric"), prototype = list(x = xxx))
stopifnot(identical(new("xNum")@x, xxx))

removeClass("xNum")
removeClass("myMatrix")

## 以下は必要であるべきではない．しかし make check は
## クラス情報のリセットを引き起こさない素朴な仕方で
## 例のファイルファイル間で全てのファイルを取り除く．
## これらはこれを検出する方法は無いように見えるので，
## クラスを自分自身で取り除かなければならない．

removeClass("trackMultiCurve")
removeClass("trackCurve")
removeClass("track")
}%dont show
}
\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/setClass.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{setClass}
%\alias{setClass}
%\alias{classGeneratorFunction-class}
%\title{Create a Class Definition}
%\description{
%  Create  a class definition, specifying the representation (the
%  slots) and/or the classes contained in this one (the superclasses),
%  plus other optional details.  As a side effect, the class definition
%  is stored in the specified environment.  A generator function
%  is returned as the value of \code{setClass()}, suitable for creating
%  objects from the class if the class is not virtual.  Of the many
%  arguments to the function only \code{Class},
%  \code{slots=} and \code{contains=} are usually needed.
%}
%\usage{
%setClass(Class, representation, prototype, contains=character(),
%         validity, access, where, version, sealed, package,
%         S3methods = FALSE, slots)
%}
%\arguments{
%  \item{Class}{character string name for the class.}
%  \item{slots}{ a named list or named character vector.
%    The names are the names of the slots in the new class and
%    the elements are the character string names of  the
%    corresponding classes.
%
%    In rare cases where there is ambiguity about the class of a slot,
%    because two classes of the same name are imported from different
%    packages, the corresponding element of the argument must have a
%    \code{"package"} attribute to disambiguate the choice.
%
%    It is allowed to provide an unnamed character vector as a limiting
%    case, with the elements taken as slot names and all slots having
%    the unrestricted class \code{"ANY"}.
%  }
%  \item{contains}{ the names (and optionally package slots) for the
%    \emph{superclasses} of this class.  The special superclass
%    \code{"VIRTUAL"} causes the new class to be created as a
%    virtual class; see the section on virtual classes in \link{Classes}.}
%  \item{prototype}{ an object providing the default
%    data for the slots in this class.  By default, each will be the
%    prototype object for the superclass.  If provided, using a call to
%    \code{\link{prototype}} will carry out some checks. }
%  \item{where}{ the environment in which to store the definition.
%    Should not be supplied in standard use.  For calls to
%    \code{setClass()} appearing in the source code for a package, will
%    default to the namespace of the package.  For calls typed or sourced
%    at the top level in a session, will default to the global environment.
%  }
%  \item{validity}{ if supplied, should be a validity-checking method
%    for objects from this class (a function that returns \code{TRUE} if
%    its argument is a valid object of this class and one or more strings
%    describing the failures otherwise).  See \code{\link{validObject}}
%    for details.}
%  \item{S3methods, representation, access, version }{All these
%    arguments are deprecated from version 3.0.0 of \R and should be
%    \emph{avoided}.
%
%    \code{S3methods} is a flag indicating that old-style methods
%    will be written involving this class.  Modern versions of \R
%    attempt to match formal and old-style methods consistently, so
%    this argument is largely irrelevant.
%
%    \code{representation} is an argument inherited from S that
%    included both \code{slots} and \code{contains}, but the use of
%    the latter two arguments is clearer and recommended.
%
%    \code{access} and \code{version} are included for
%    historical compatibility with S-Plus, but ignored.
%  }
%  \item{sealed}{ if \code{TRUE}, the class definition will be sealed,
%    so that another call to \code{setClass} will fail on this class name.
%  }
%  \item{package}{ an optional package name for the class.  Should very
%      rarely be used. By default
%    the name of the package in which the class definition is assigned.
%  }
%}
%
%\value{
%  A generator function suitable for creating objects from the class is
%  returned, invisibly.  A call to this function generates a call to
%  \code{\link{new}} for the class.  The call takes any number of arguments,
%  which will be passed on to the initialize method.  If no
%  \code{initialize} method is defined for the class or one of its
%  superclasses, the default method expects named arguments with the
%  name of one of the slots.
%
%  Typically the generator function is assigned the name of the class,
%  for programming clarity.  This is not a requirement and objects
%  from the class can also be generated directly from
%  \code{\link{new}}.  The advantages of the generator function are a
%  slightly simpler and clearer call, and that the call will contain
%  the package name of the class (eliminating any ambiguity if two
%  classes from different packages have the same name).
%
%  If the class is virtual, an attempt to generate an object  from
%  either the generator or \code{new()}
%  will result in an error.
%}
%\section{Basic Use: Slots and Inheritance}{
%The two essential arguments other than the class name are
%\code{slots} and \code{contains}, defining the explicit slots
%and the inheritance (superclasses). Together, these arguments define
%all the information in an object from this class; that is, the names
%of all the slots and the classes required for each of them.
%
%The name of the class determines
%which methods apply directly to objects from this class.  The
%inheritance information specifies which methods apply indirectly,
%through inheritance.  See \link{Methods}.
%
%The slots in a class definition will be the union of all the slots
%specified directly by \code{slots} and all the slots in all
%the contained classes.
%There can only be one slot with a given name; specifically, the
%direct and inherited slot names must be unique.
%That does not, however, prevent the same class from being inherited
%via more than one path.
%
%One kind of element in the \code{contains=} argument is special, specifying one of the \R
%object types or one of a few other special \R types (\code{matrix} and
%\code{array}).
%See the section on inheriting from object types, below.
%
%
%  Slot names \code{"class"} and \code{"Class"} are not allowed.
%  There are other slot names with a special meaning; these names start with
%  the \code{"."} character.  To be safe, you should define all of
%  your own slots with names starting with an alphabetic character.
%}
%
%
%
%\section{Inheriting from Object Types}{
%In addition to containing other S4 classes, a class definition can
%contain either an S3 class (see the next section) or a built-in R pseudo-class---one
%of the \R
%object types or one of the special \R pseudo-classes \code{"matrix"} and
%\code{"array"}.
%A class can contain at most one of the object types, directly or indirectly.
%When it does, that contained class determines the \dQuote{data part}
%of the class.
%
%Objects from the new class try to inherit the built in
%behavior of the contained type.
%In the case of normal \R data types, including vectors, functions and
%expressions, the implementation is relatively straightforward.
%For any object \code{x} from the class,
%\code{typeof(x)} will be the contained basic type; and a special
%pseudo-slot, \code{.Data}, will be shown with the corresponding class.
%See the \code{"numWithId"} example below.
%
%Classes may also inherit from \code{"vector"}, \code{"matrix"} or
%\code{"array"}.
%The data part of these objects can be any vector data type.
%
%For an object from any class that does \emph{not} contain one of these
%types or classes,
%\code{typeof(x)} will be \code{"S4"}.
%
%Some \R data types do not behave normally, in the sense that they are
%non-local references or other objects that are not duplicated.
%Examples include those corresponding to classes \code{"environment"}, \code{"externalptr"}, and \code{"name"}.
%These can not be the types for objects with user-defined
%classes (either S4 or S3) because setting an attribute overwrites the
%object in all contexts.
%It is possible to define a class that inherits from such types,
%through an indirect mechanism that stores the inherited object in a
%reserved slot.
%See the
%example for class \code{"stampedEnv"} below.
%S3 method dispatch and the relevant \code{as.}\emph{type}\code{()}
%functions should behave correctly, but code that uses the type of the
%object directly will not.
%
%Also, keep in mind that the object passed to low-level computations
%will be the underlying object type, \emph{without} any of the slots
%defined in the class.
%To return the full information, you will usually have to define a
%method that sets the data part.
%
%}
%
%\section{Inheriting from S3 Classes}{
%Old-style S3 classes have no formal definition.  Objects are
%\dQuote{from} the class when their class attribute contains the
%character string considered to be the class name.
%
%Using such classes with formal classes and methods is necessarily a
%risky business, since there are no guarantees about the content of the
%objects or about consistency of inherited methods.
%Given that, it is still possible to define a class that inherits from
%an S3 class, providing that class has been registered as an old class
%(see \code{\link{setOldClass}}).
%
%Broadly speaking, both S3 and S4 method dispatch try to behave
%sensibly with respect to inheritance in either system.
%Given an S4 object, S3 method dispatch and the \code{\link{inherits}}
%function should use the S4 inheritance information.
%Given an S3 object, an S4 generic function will dispatch S4 methods
%using the S3 inheritance, provided that inheritance has been declared via
%\code{\link{setOldClass}}.
%
%}
%
%\section{Classes and Packages}{
%
%Class definitions normally belong to packages (but can be defined in
%the  global environment as well, by evaluating the expression on the
%command line or in a file sourced from the command line).
%The corresponding package name is part of the class definition; that
%is, part of the \code{classRepresentation} object holding that
%definition.  Thus, two classes with the same name can exist in
%different packages, for most purposes.
%
%When a class name is supplied for a slot or a superclass in a call to
%\code{setClass}, a
%corresponding class definition will be found, looking from the
%namespace of the current package, assuming the call in question appears directly in the source for the
%package, as it should to avoid ambiguity.
%The  class definition
%must be found in the namespace of the current package, in the imports for that
%namespace or in the basic classes defined by the methods package.
%(The methods package must be included in the \code{Depends} directive
%of the package's \code{"DESCRIPTION"} file in order for the
%\code{"CMD check"} utility to find these classes.)
%
%When this rule does not identify a class uniquely (because it appears
%in more than one imported package) then the \code{\link{packageSlot}}
%of the character string name needs to be supplied with the name.
%This should be a rare occurrence.
%}
%
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{
%  \code{\link{Classes}} for a general discussion of classes,
%  \code{\link{Methods}} for an analogous discussion of methods,
%  \code{\link{makeClassRepresentation}}
%}
%\examples{
%\dontshow{
% if(isClass("trackMultiCurve")) removeClass("trackMultiCurve")
% if(isClass("trackCurve"))      removeClass("trackCurve")
% if(isClass("track"))           removeClass("track")
%}
%## A simple class with two slots
%track <- setClass("track", slots = c(x="numeric", y="numeric"))
%## an object from the class
%t1 <- track(x = 1:10, y = 1:10 + rnorm(10))
%
%## A class extending the previous, adding one more slot
%trackCurve <- setClass("trackCurve",
%		slots = c(smooth = "numeric"),
%		contains = "track")
%
%## an object containing a superclass object
%t1s <- trackCurve(t1, smooth = 1:10)
%
%## A class similar to "trackCurve", but with different structure
%## allowing matrices for the "y" and "smooth" slots
%setClass("trackMultiCurve",
%         slots = c(x="numeric", y="matrix", smooth="matrix"),
%         prototype = list(x=numeric(), y=matrix(0,0,0),
%                          smooth= matrix(0,0,0)))
%## See ?setIs for further examples using these classes
%
%## A class that extends the built-in data type "numeric"
%
%numWithId <- setClass("numWithId", slots = c(id = "character"),
%         contains = "numeric")
%
%numWithId(1:3, id = "An Example")
%
%## inherit from reference object of type "environment"
%stampedEnv <- setClass("stampedEnv", contains = "environment",
%                       slots = c(update = "POSIXct"))
%setMethod("[[<-", c("stampedEnv", "character", "missing"),
%   function(x, i, j, ..., value) {
%       ev <- as(x, "environment")
%       ev[[i]] <- value  #update the object in the environment
%       x@update <- Sys.time() # and the update time
%       x})
%
%
%e1 <- stampedEnv(update = Sys.time())
%
%e1[["noise"]] <- rnorm(10)
%
%\dontshow{
%tMC <- new("trackMultiCurve")
%is.matrix(slot(tMC, "y"))
%is.matrix(slot(tMC, "smooth"))
%setClass("myMatrix", "matrix", prototype = matrix(0,0,0))
%nrow(new("myMatrix")) # 0
%nrow(new("matrix")) # 1
%## simple test of prototype data
%xxx <- stats::rnorm(3)
%setClass("xNum", slots = c(x = "numeric"), prototype = list(x = xxx))
%stopifnot(identical(new("xNum")@x, xxx))
%
%removeClass("xNum")
%removeClass("myMatrix")
%
%## The following should not be needed.  But make check removes all files
%## between example files, in a crude way that does not cause the class
%## information to be reset.  There seems no way to detect this, so we
%## have to remove classes ourselves
%
%removeClass("trackMultiCurve")
%removeClass("trackCurve")
%removeClass("track")
%}%dont show
%}
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%