% File src/library/methods/man/setClassUnion.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{setClassUnion}
%@%\alias{他のクラスの合併として定義されるクラス}
\alias{setClassUnion}
\alias{isClassUnion}
\alias{ClassUnionRepresentation-class}
\title{他のクラスの合併として定義されるクラス}
%\title{Classes Defined as the Union of Other Classes}
\description{
  クラスは他のクラスの
  \emph{合併}として定義出来る；
  つまり幾つかの他のクラスのスーパークラスとして
  定義された仮想クラスとして．
  クラス合併は，
  幾つかのクラスのどれかを提供することを許したいときは，
  メソッドのシグネチャ中や他のクラス中のスロット
  として有用である．
}
\usage{
setClassUnion(name, members, where)
isClassUnion(Class)
}
\arguments{
  \item{name}{新しい合併クラスの名前．}
  \item{members}{この合併のメンバーであるべきクラス．}
  \item{where}{
      クラス定義を保存する場所；
      既定では
      \code{setClassUnion} 呼び出しが登場するパッケージの環境，
      またはもしパッケージソース外から呼び出された場合は
      大局的環境．}
  \item{Class}{クラスの名前または定義．}
}
\details{
      \code{members} 中のクラスは合併を作る前に定義されて
      いなければならない．
      しかしながら，下の例のようにメンバーは既存の合併に
      後から付け加えることが出来る．
      クラス合併は他のクラス合併のメンバーになり得る．

      クラス合併の定義中のプロトタイプは
      もし \code{"NULL"} が合併のメンバーならば
      \code{NULL} であり，そして
      さもなければ最初のメンバーのクラスのプロトタイプ
      オブジェクトである
      (バージョン 2.15.0 の R に関しては；初期のバージョンは
      もしそれが不正であれば \code{NULL} プロトタイプを
      持っていた)．

      クラス合併はその定義が封印されているクラス
      (例えば基本データタイプまたは R の基本やメソッドパッケージ
      中で定義された他のクラス)
      により拡張されているクラスを作る唯一の方法である．
      \code{"other"} がクラス合併でない限り
      \code{setIs("function", "other")} と述べることは出来ない．
      一般に，この形式の呼び出し \code{setIs} は
      述べられた最初のクラスの定義を変更する
      (\code{"other"} を
      \code{"function"} の定義中に含まれるスーパークラスのりストに
      加える)．

  クラス合併はこれを最初のクラス定義を変更すること無く，
  代わりにクラス合併のサブクラススロット中の情報を
  保存することにより処理する，
  このテクニックが動作するためには，
  \code{\link{extends}(class1, class2)} のような表現式
  に対する内部計算は通常のクラスに対するのとは異なった
  動作をする；特にそれらは任意のクラスが
  \code{class1} のスーパークラスと
  \code{class2} のサブクラス間で共通であるかどうかをテストする．

  クラス合併に対するクラス定義オブジェクトはそれ自体
  \code{\linkS4class{classRepresentation}} の拡張である
  クラス \code{"ClassUnionRepresentation"} という
  特殊なクラスを持つため，クラス合併に対する異なった
  挙動が可能にされている．
  }

\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}

\examples{
## 数値か論理値データのどちらかに対するクラス
setClassUnion("maybeNumber", c("numeric", "logical"))

## 別のクラスのデータ部分として合併を使う
setClass("withId", representation("maybeNumber", id = "character"))

w1 <- new("withId", 1:10, id = "test 1")
w2 <- new("withId", sqrt(w1)\%\%1 < .01, id = "Perfect squares")

## 合併 "maybeNumber" にクラス "complex" を加える
setIs("complex", "maybeNumber")

w3 <- new("withId", complex(real = 1:10, imaginary = sqrt(1:10)))

## 既存の合併 "OptionalFunction" を含むクラス合併
setClassUnion("maybeCode",
    c("expression", "language", "OptionalFunction"))

is(quote(sqrt(1:10)), "maybeCode")  ## TRUE
\dontshow{
## 次のテストは見かけよりも自明ではない．
## それは is(ttt, "maybeNumber") を満足するために
## "numeric" への厳格な強制変換を実行しないデータ部分の付値に依存する．
.
stopifnot(identical(w1@.Data, 1:10))
removeClass("withId")
removeClass("maybeNumber")
}

}
\keyword{programming}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/setClassUnion.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{setClassUnion}
%\alias{setClassUnion}
%\alias{isClassUnion}
%\alias{ClassUnionRepresentation-class}
%\title{Classes Defined as the Union of Other Classes}
%\description{
%  A class may be defined as the \emph{union} of other classes; that
%  is, as a virtual class defined as a superclass of several other
%  classes. Class unions are useful in method signatures or as slots in
%  other classes, when we want to allow one of several classes to be supplied.
%}
%\usage{
%setClassUnion(name, members, where)
%isClassUnion(Class)
%}
%\arguments{
%  \item{name}{ the name for the new union class. }
%  \item{members}{ the classes that should be members of this union.}
%  \item{where}{ where to save the new class definition; by default,
%      the environment of the package in which the \code{setClassUnion}
%      call appears, or the global environment if called outside of the
%      source of a package.}
%
%
%  \item{Class}{ the name or definition of a class.
%    }
%}
%\details{
%  The classes in \code{members} must be defined before creating the
%      union.  However, members can be added later on to an existing
%      union, as shown in the example below. Class unions can be
%      members of other class unions.
%
%      The prototype object in the class union definition will be
%      \code{NULL} if class \code{"NULL"} is a member of the union and
%      the prototype object of the first member class otherwise (as of
%      version 2.15.0 of R; earlier versions had a \code{NULL} prototype even if
%      that was not valid).
%
%  Class unions are the only way to create a class that is extended by
%      a class whose definition is sealed (for example, the
%      basic datatypes or other classes defined in the base or methods
%      package in R are sealed).  You cannot say \code{setIs("function", "other")}
%      unless \code{"other"} is a class union.  In general, a
%      \code{setIs} call of this form changes the definition of the
%      first class mentioned (adding \code{"other"} to the list of
%      superclasses contained in the definition of \code{"function"}).
%
%      Class unions get around this by not modifying the first class
%  definition, relying instead on storing information in the subclasses
%  slot of the class union.  In order for this technique to work, the
%  internal computations for expressions such as
%  \code{\link{extends}(class1, class2)} work
%  differently for class unions than for regular classes; specifically,
%  they test whether any class is in common between the superclasses of
%  \code{class1} and the subclasses of \code{class2}.
%
%  The different behavior for class unions is made possible because the
%  class definition object for class unions has itself a special class,
%  \code{"ClassUnionRepresentation"}, an extension of class
%  \code{\linkS4class{classRepresentation}}.
%  }
%
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%
%\examples{
%## a class for either numeric or logical data
%setClassUnion("maybeNumber", c("numeric", "logical"))
%
%## use the union as the data part of another class
%setClass("withId", representation("maybeNumber", id = "character"))
%
%w1 <- new("withId", 1:10, id = "test 1")
%w2 <- new("withId", sqrt(w1)\%\%1 < .01, id = "Perfect squares")
%
%## add class "complex" to the union "maybeNumber"
%setIs("complex", "maybeNumber")
%
%w3 <- new("withId", complex(real = 1:10, imaginary = sqrt(1:10)))
%
%## a class union containing the existing class  union "OptionalFunction"
%setClassUnion("maybeCode",
%    c("expression", "language", "OptionalFunction"))
%
%is(quote(sqrt(1:10)), "maybeCode")  ## TRUE
%\dontshow{
%## The following test is less trivial than it looks.
%## It depends on the assignment of the data part NOT performing a
%## strict coerce to "numeric" on the way to satisfying
%## is(ttt, "maybeNumber").
%stopifnot(identical(w1@.Data, 1:10))
%removeClass("withId")
%removeClass("maybeNumber")
%}
%
%}
%\keyword{programming}
%\keyword{classes}
%
%\encoding{UTF8}
%