% File src/library/methods/man/setGeneric.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{setGeneric}
\alias{setGeneric}
%@%\alias{新しい総称的関数の定義}
\alias{setGroupGeneric}
\title{新しい総称的関数を定義する}
%\title{Define a New Generic Function}
\description{
  与えられた名前の新しい総称的関数を作る，つまり
  この関数に対して定義された形式的メソッドの間から
  引数のクラスに従ってメソッドを選択適用する関数．
}
\usage{
setGeneric(name, def= , group=list(), valueClass=character(),
           where= , package= , signature= , useAsDefault= ,
           genericFunction= , simpleInheritanceOnly = )

setGroupGeneric(name, def= , group=list(), valueClass=character(),
                knownMembers=list(), package= , where= )
}
\arguments{
  \item{name}{
    総称的関数の文字列名．
    最も簡単な(そして推奨される)呼び出し\cr
    \code{setGeneric(name)}
    はこの名前の関数を探し，そしてもし見つかった関数が総称的でなければ
    対応する総称的関数を作る，
    後者の場合，存在する関数は既定メソッドになる．
  }
  \item{def}{
    総称的関数関数を定義するオプションの関数オブジェクト．
    もし既存の非総称的関数を総称的にしたければこの引数を与えてはならない．
    この場合普通引数が一つの単純な呼び出しを使いたいであろう．

    もしこの名前の関数が無いか，ある理由からこの関数を
    総称的関数の定義に使いたくなければ \code{def} を与えない．
    この場合形式的引数と総称的関数に対する既定値は
    \code{def} から取られる．殆どの場合，
    \code{def} の本体はそうすると
    既存関数が引数一つの呼び出し中で行うように
    既定メソッドを定義する．

    もし既定メソッドを
    \emph{持たない}新しい総称的関数を作りたければ，
    \code{def} は \code{name} と同じ文字列を持つ
    \code{\link{standardGeneric}} の呼び出しだけであるべきである．
  }
  \item{group}{オプションで，この関数が属するグループ総称的関数の
    名前を与える文字列．
    メソッド選択中のグループ総称的関数の詳細については
    \link{Methods} を見よ．
  }
  \item{valueClass}{
    一つまたはそれ以上のクラス名のオプションのの文字列ベクトル．
    総称的関数が返す値はこのクラスを持つ(または拡張する)，
    またはクラスの一つ；さもなければエラーが起きる．
  }
  \item{package}{
    この関数が関連付けられているパッケージの名前．
    普通自動的に決定される
    (もしあればパッケージは非総称的バージョンを含むから，
    さもなければこの総称的関数が保存されるパッケージ)．
  }
  \item{where}{
    結果の初期メソッドと
    もしかすると総称的関数をどこに保存するか；
    既定ではトップレベルの環境中に保存する．
  }
  \item{signature}{
    オプションで，\code{\link{setMethod}} への呼び出し中で，
    この関数に対するメソッドのシグネチャ中に現れることが出来る
    関数への形式的引数中からの名前のベクトル．
    もし \code{\dots} が形式的引数の一つならば，それは特別に扱われる．
    バージョン 2.8.0 の \R 以来，\code{\dots} は総称的関数のシグネチャ
    でも良くなった．そうするとメソッドはもしそれらのシグネチャが
    全ての \code{\dots} 引数にマッチした時に選択される．
    詳細はトピック
    \link{dotsMethods} に対するドキュメントを見よ．
    現在のバージョンでは，
    \code{\dots} と他の引数をシグネチャ中で混ぜ合せることは
    不可能である
    (この制約は将来のバージョンでは外されるかもしれない)．

    既定では，シグネチャは非総称的関数に対応する
    暗黙の総称的関数から推測される．
    もし非総称的関数が定義されていないと，
    既定は \code{\dots} を除く全ての形式的引数で，関数定義に登場する
    順序である．\code{\dots} が唯一の形式的引数の場合，それは
    また既定のシグネチャである．
    \code{\dots} をある他の引数を持つ関数中のシグネチャ
    として使うためには，シグネチャ引数を明示的に
    与えなければならない．
    より詳細は下の\dQuote{暗黙の総称的関数}節を見よ．
  }
  \item{useAsDefault}{
    既定引数の選択を上書きする．
    引数 \code{useAsDefault} を既定として使われる関数か
    論理値として提供できる．
    この引数は今では滅多に必要でない．\sQuote{詳細}節を見よ．
  }
  \item{simpleInheritanceOnly}{
    選ばれたメソッドが
    単純な継承だけを通じて継承されることを要求するためには
    この引数を \code{TRUE} として与える；つまり，
    \code{\link{setClass}} への \code{contains=} 引数中で
    指定されたスーパークラスから，または
    クラス合併または他の仮想的クラスから．
    総称的関数は，もしそれが変換されたものでなく
    完全なオリジナルのオブジェクト
    を得ることが保証される必要があれば，
    総称的関数は単純な継承を要求すべきである．
    単純な継承を必要とする関数の例は
    \code{\link{initialize}} である，
    定義からそれはその引数と同じクラスからのオブジェクトを
    返さなければならないからである．

    そして \code{\link{show}} であり，
    それはその引数としてオブジェクトの完全な記述を
    与えることを要求するためである．
  }
  \item{genericFunction}{使わないこと；(可能性として)内部使用専用．}

  \item{knownMembers}{
    (\code{setGroupGeneric} に対してだけ．)
    このグループのメンバーに対して知られている関数の名前．
    この情報はグループ総称的関数に関する情報が変更された時
    メンバーの総称的関数のキャッシュされた定義をリセットするのに使われる．
  }
}
\section{基本的使用法}{
  \code{setGeneric} 関数は
  その関数に対してあるメソッド定義を用意するために
  総称的関数を初期化するために呼び出される．

  最も単純で最も普通の状況は
  \code{name} はすでに通常の非総称的で非プリミティブな関数で，
  この関数を総称的関数に変えたいというものである．
  この場合，最もしばしば
  \code{name} だけを提供する，例えば：

    \code{setGeneric("colSums")}

  この名前の既存の関数が
  ある付加されたパッケージ(この場合パッケージ \code{"base"})
  になければならない．
  この関数の総称的バージョンは現在のパッケージ中に
  作られる(またはもし
  \code{setGeneric()} への呼び出しが普通のソースファイルからか
  コマンドラインから入力されたならば大局的環境)．
  既存の関数は既定メソッドになり，
  そして新しい総称的関数のパッケージスロットは
  オリジナルの関数の位置に設定される
  (例では \code{"base"})．
  同じ総称的関数定義が毎回作られることは重要な特性である．
  例では \code{print} の定義とそれがどこで見つかるかにだけ依存する．
  総称的関数の \code{signature} は既定では，
  形式的引数のどれが指定されたメソッド中で使うことが出来るかを
  定義する \code{\dots} を除く形式的引数全てに設定される．

  この形式で \code{setGeneric()} を呼び出すことは厳密には
  同じ関数に対して \code{setMethod()} を呼び出す前には
  不要であることを注意する．もし総称的でなければ，
  \code{setMethod} は
  \code{setGeneric} 自体の呼び出しを実行する．
  関数を総称的にしたいと明示的に宣言することは
  より良いプログラミングスタイルと考えられる；
  しかしながら結果中の唯一の違いは
  もしそうしなければ総称的関数の生成を注意するメッセージを
  作り出す．

  ベースパッケージ中のプリミティブ関数の明示的な総称的バージョンを
  作ることは出来ない(し必要もない)．
  総称的関数として扱うことが出来るものは，
  効率性の配慮を満たすために，
  内部的なコードからメソッドが選択し適用され，そしてその他は
  総称的に出来ない．
  下のプリミティブ関数の節を見よ．

  また内部的に選択適用を行う非プリミティブ関数の
  明示的な総称的バージョンを作ることは不必要である．
  これらは \code{unlist} と \code{as.vector} を含む．

  上の解説は非総称的関数を持つパッケージが暗黙の総称的バージョン
  を創りだしていない時の効果である．
  さもなければ，使われるのはこの暗黙の総称的関数である．
  下の暗黙の総称的関数の節を見よ．
  どちらの場合も，本質的な結果は総称的関数の
  \emph{同じ}バージョンが毎回作られるということである．

  
  \code{setGeneric()} の二つ目の通常の用法は
  任意の既存の関数とは無関係に新しい総称的関数を作り，
  しばしば既定メソッドを持たない．
  この場合，関数に対する引数を定義するために関数定義の
  骨格を与える必要がある．
  総称的関数の本体は普通標準の形式
  \code{standardGeneric(name)} であり，ここで
  \code{name} は総称的関数の引用符付きの名前である．
  \code{setGeneric} をこの形式で呼び出す時は，
  普通 \code{def} 引数をこの形式の関数として提供する．
  下の二番目と三番目の例を見よ．

  引数 \code{useAsDefault} は新しい総称的関数の既定メソッドを
  制御する．もし別の指定がなければ，
  \code{setGeneric} は既定として使うために関数の
  非総称的バージョンを探す．
  従って，もし適当な既定メソッドがなければ，
  先ずこれを非総称的関数として設定し，それから
  この節の最初にある \code{setGeneric} を引数一つで呼び出す
  のがしばしばより簡単である．
  下の例の節の最初の例を見よ．

  もし既存の関数を既定としたく\emph{なければ}，
  \code{useAsDefault} 引数を提供する．この引数は
  既定メソッドにしたい関数で良く，
  既定無しにしたければ \code{FALSE} する
  (つまり関数の呼び出しに対して選択される直接か継承メソッドが
  もしなければエラーを起こす)．
}
\section{詳細}{
  \code{setGeneric()} の呼び出しの大多数は
  既存の関数がメソッドも持つことが出来ることを
  保証する一つの引数持つか，
  新しい総称的関数とオプションで既定メソッドを
  作るための引数 \code{name} と \code{def} を持つ．
  もしそれが希望のものでなければ先に読み進んで欲しい．

  もし既存の挙動を変更
  (典型的には別のパッケージ中のもの)したければ，
  対応して \code{setGeneric} に引数を提供する．
  どのような変更がされようと，新しい総称的関数は
  \emph{現在}のパッケージに設定されたパッケージスロット付きで
  付値される．このステップは，作成中のバージョンが
  最早他のパッケージ中の関数とは異なるので必要とされる．
  これが起きたことを知らせるメッセージがプリントされ，
  二つの関数間の違いの一つを注意する．
  二つのバージョンが今やメソッドに対して競合し，
  プログラミング中のミスの多くの可能性を持つため，
  これは悪いアイデアになりがちである．

  総称的関数の本体は普通
  \code{standardGeneric} の呼び出しによるメソッドの
  選択適用を除いて何も行わない．
  ある種の状況下では総称的関数自体中である追加の計算を
  行いたいかもしれない．自分の関数が結局
  \code{standardGeneric} を呼び出す限りこれは許される
  (しかしながら恐らく良いアイデアでは無い
  関数のより簡単には理解できない挙動を招くという意味で)．
  もし自分の総称的関数の明示的な定義が
  \code{standardGeneric} を呼びださ\emph{なければ}，
  この関数に対するどのメソッドも未だ選択適用されていないために
  問題が起きる

  既定では，総称的関数は如何なるオブジェクトも返すことが出来る．
  もし \code{valueClass} が提供されると，
  それはクラス名のベクトルであるべきである；
  メソッドが返す値はそうすると
  指定されたクラスの一つに対して \code{is(object, Class)}
  を満たすことが要求される．
  空(つまり長さがゼロ)のベクトルは何も許されないことを
  意味する．結果に対するより複雑な要求は
  非標準的な総称的関数を定義することで明示的に指定できる．

  \code{setGroupGeneric} 関数は
  それがグループ総称的関数を作ることを除いて
  \code{setGeneric} と似たような挙動をするが，
  2つの点で通常の総称的関数と異なる．
  先ずこの関数は直接呼び出すことは出来ず，作られた関数の
  本体はこの情報を持つ停止呼び出しを含む．
  次にグループ総称的関数は，
  検索リスト中の変更やメソッドの直接的な指定等で，
  グループ定義が変更された時にメンバーを更新し続けるために，
  グループの既知のメンバーに関する情報を含む．
}
\section{暗黙の総称的関数}{
  非総称的関数を\dQuote{総称的に変換する}ということは
  より正確には関数が
  対応する\emph{暗黙}の総称的関数に変換されることを意味する．
  もし特別なアクションが取られないと，
  任意の関数は暗黙のうちに同じ引数の総称的関数に
  対応し，\code{\dots} 以外の引数を使うことが出来る．
  この総称的関数のシグネチャは \code{\dots} を除いて
  順番に形式的引数のベクトルである．

  パッケージに対するソースコードは
  パッケージ中の任意の関数の暗黙の総称的関数バージョンを
  定義できる(機構については \link{implicitGeneric} を見よ)．
  一般に他人のパッケージ中に暗黙の総称的関数を
  出来ない．暗黙の総称的関数を定義する普通の理由は
  ある引数がシグネチャ中に登場することを妨げることにあり，
  もし引数が文字通りの意味で使いたいかまたは
  何らかの理由で遅延評価を強制したければそうしなければならない．
  暗黙の総称的関数はまた予め定義しておきたいあるメソッドを
  含むことが出来る；
  実際，総称的関数は任意の非総称的関数の総称的関数であり得る．
  暗黙の総称機構はまた総称バージョンを禁止することに
  使える(\code{\link{prohibitGeneric}} を見よ)．

  定義されたにせよ自動的に推測されたにせよ，
  暗黙の総称的関数は
  暗黙の総称的関数が別のパッケージ中にある時は
  \code{setGeneric} が作った総称的関数と比較される．
  もし二つの関数が同一であれば，作られた総称的関数の
  \code{package} スロットは暗黙の総称的関数を含む
  パッケージの名前を持つ．
  さもなければ，スロットは総称的関数が付値される
  パッケージの名前になる．

  この規則の目的は総称的関数とパッケージ名の
  特定の組み合わせに対して定義された全てのメソッドが
  単一で一貫性のある総称的関数のバージョンに対応することを
  保証することにある．
  \code{setGeneric} を引数として \code{name} だけと
  可能性として \code{package} とともに呼び出すことは
  もし存在すれば暗黙の総称的関数を得ることを保証する．

  他の引数のどれかを含むことは総称的関数の新しい局所的な
  バージョンを強制する．
  もし新しいバージョンを作りたくなければ，
  追加の引数を使わない．
}
\section{総称的関数とプリミティブな関数}{
  幾つかの基本的な
  \R 関数はプリミティブ関数として特殊な実装を持ち，
  \R の言語定義の評価ではなく，
  基底にある C コードで直接に評価される．
  殆どは暗黙の総称性を持ち
  (\code{\link{implicitGeneric}} を見よ)，そしてメソッドがそれらに対して
  定義される(グループメソッドを含む)や否や総称的関数になる．
  他は総称的関数に出来ない．

  そうした関数にメソッドが定義された時も，
  C バージョンが呼び出され続けるために
  総称的バージョンは検索リスト上で不可視である．
  メソッド選択は C コード中で初期化される．しかしながら，結果は
  メソッドをプリミティブ関数をシグネチャ中の
  クラスの少なくとも一つが形式的 S4 クラスであるシグネチャ
  に制限する．

  プリミティブ関数の総称的バージョンを見るには，
  \code{\link{getGeneric}(name)} を使う．関数
  \code{\link{isGeneric}} は現在のセッション中の関数に対して
  メソッドが定義されているかどうかを知らせる．

  S4 メソッドは
  \sQuote{\link{internal generic}} であるようなプリミティブ関数と，
  プラス \code{\%*\%} に対してだけ設定できることを注意する．
}
\value{
  \code{setGeneric} 関数はその副作用のために存在する：
  後で指定されるメソッドを許す総称的関数を保存する．
  \code{name} が返される．
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\examples{
\dontshow{
setClass("track", representation(x="numeric", y="numeric"))
}

## 新しい総称的関数を既定メソッドで作る
setGeneric("props", function(object) attributes(object))

## 既定メソッド無しの新しい総称的関数
setGeneric("increment",
  function(object, step, ...)
    standardGeneric("increment")
)


### 非標準的な総称的関数．メソッドが空でない文字列を返すことを要求する
### (setGeneric 呼び出し中の valueClass = "character" よりも強い要求)

setGeneric("authorNames",
    function(text) {
      value <- standardGeneric("authorNames")
      if(!(is(value, "character") && any(nchar(value)>0)))
        stop("authorNames methods must return non-empty strings")
      value
      })

\dontshow{
setMethod("authorNames", "character", function(text)text)

tryIt <- function(expr) tryCatch(expr, error = function(e) e)
stopifnot(identical(authorNames(c("me", "you")), c("me", "you")),
          is(tryIt(authorNames(character())), "error"), # empty value
          is(tryIt(authorNames(NULL)), "error"))        # no default method
}

## グループ総称的関数の例，クラス "track" を用いる；
## その定義については 'setClass' のドキュメントを見よ

## Arith グループに対するメソッドの定義

setMethod("Arith", c("track", "numeric"),
 function(e1, e2) {
  e1@y <- callGeneric(e1@y , e2)
  e1
})

setMethod("Arith", c("numeric", "track"),
 function(e1, e2) {
  e2@y <- callGeneric(e1, e2@y)
  e2
})

## 今や算術演算はメソッドを選択適用する：

t1 <- new("track", x=1:10, y=sort(stats::rnorm(10)))

t1 - 100
1/t1

\dontshow{
removeGeneric("authorNames")
removeClass("track")
removeMethods("Arith")
removeGeneric("props")
removeGeneric("increment")
}
}
\seealso{
  一般的議論は \code{\link{Methods}} とそこでのリンク，
  \code{\dots} に関して選択適用を行うメソッドに対しては
  \code{\link{dotsMethods}}，そしてメソッド定義については
  \code{\link{setMethod}}．
}
\keyword{ programming }
\keyword{ methods }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/setGeneric.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{setGeneric}
%\alias{setGeneric}
%\alias{setGroupGeneric}
%\title{Define a New Generic Function}
%\description{
%  Create a new generic function of the given name, that is, a function
%  that dispatches methods according to the classes of the arguments,
%  from among the formal methods defined for this function.
%}
%\usage{
%setGeneric(name, def= , group=list(), valueClass=character(),
%           where= , package= , signature= , useAsDefault= ,
%           genericFunction= , simpleInheritanceOnly = )
%
%setGroupGeneric(name, def= , group=list(), valueClass=character(),
%                knownMembers=list(), package= , where= )
%}
%\arguments{
%  \item{name}{ The character string name of the generic function.
%    The simplest (and recommended) call, \code{setGeneric(name)},
%    looks for a function with this name and creates a corresponding
%    generic function,  if the function found was not generic.  In the
%    latter case, the existing function becomes the default method.
%  }
%  \item{def}{An optional function object, defining the generic.
%    Don't supply this argument if you want to turn an existing non-generic
%    function into a generic. In this case, you usually want to use the
%    simple call with one argument.
%
%    Do supply \code{def} if there is no
%    current function of this name or for some reason you do not want
%    to use that function to define the generic. In that case, the
%    formal arguments and
%    default values for the generic are taken from \code{def}.  In most
%    cases, the body of \code{def} will then define the default method,
%    as the existing function did in the one-argument call.
%
%    If you want to create a new generic function with \emph{no}
%    default method, then \code{def} should be only a call to
%    \code{\link{standardGeneric}} with the same character string as
%    \code{name}.
%
%
%  }
%  \item{group}{ Optionally, a character string giving the name of the group
%    generic function to which this function belongs.  See
%    \link{Methods} for details of group generic functions in method selection.
%  }
%  \item{valueClass}{ An optional character vector of one or more class
%    names.  The value returned by the generic function must
%    have (or extend) this class, or one of the classes; otherwise,
%    an error is generated.
%  }
%  \item{package}{ The name of the package with which this function is
%    associated.  Usually determined automatically (as the package
%    containing the non-generic version if there is one, or else the
%    package where this generic is to be saved).
%  }
%  \item{where}{ Where to store the resulting initial methods definition,
%    and possibly the generic function; by
%    default, stored into the top-level environment.
%  }
%  \item{signature}{
%    Optionally, the vector of names, from among the formal arguments to
%    the function, that can appear in the signature of methods for this
%    function, in calls to \code{\link{setMethod}}.  If \code{\dots} is
%    one of the formal arguments, it is treated specially.  Starting with
%    version 2.8.0 of \R, \code{\dots} may be signature of the generic
%    function.  Methods will then be selected if their signature matches
%    all the \code{\dots} arguments.  See the documentation for topic
%    \link{dotsMethods} for details.  In the present version, it is not
%    possible to mix \code{\dots} and other arguments in the signature
%    (this restriction may be lifted in later versions).
%
%    By default, the signature is inferred from the implicit generic
%    function corresponding to a non-generic function.  If no implicit
%    generic function has been defined, the default is all the formal
%    arguments except \code{\dots}, in the order they appear in the
%    function definition. In the case that \code{\dots} is the only
%    formal argument, that is also the default signature.  To use
%    \code{\dots} as the signature in a function that has any other
%    arguments, you must supply the signature argument explicitly.  See
%    the \dQuote{Implicit Generic} section below for more details.
%  }
%  \item{useAsDefault}{
%    Override the usual choice of default argument.
%    Argument \code{useAsDefault} can be supplied, either as a function
%    to use for the default, or as a logical value.
%    This argument is now rarely needed.
%    See the section \sQuote{Details}.
%  }
%  \item{simpleInheritanceOnly}{
%    Supply this argument as \code{TRUE} to require that methods selected
%    be inherited through simple inheritance only; that is, from
%    superclasses specified in the \code{contains=} argument to
%    \code{\link{setClass}}, or by simple inheritance to a class union or
%    other virtual class.  Generic functions should require simple
%    inheritance if they need to be assured that they get the complete
%    original object, not one that has been transformed.  Examples of
%    functions requiring simple inheritance are \code{\link{initialize}},
%    because by definition it must return an object from the same class
%    as its argument, and \code{\link{show}}, because it claims to give a
%    full description of the object provided as its argument.
%  }
%  \item{genericFunction}{Don't use; for (possible) internal use only.}
%
%  \item{knownMembers}{
%    (For \code{setGroupGeneric} only.)  The names of functions that are
%    known to be members of this group.  This information is used to
%    reset cached definitions of the member generics when information
%    about the group generic is changed.
%  }
%}
%\section{Basic Use}{
%  The \code{setGeneric} function is called to initialize a generic
%  function as preparation for defining some methods for that function.
%
%  The simplest and most common situation is that \code{name} is already
%  an ordinary non-generic non-primitive function, and you now want to
%  turn this function into a generic.  In this case you will most often
%  supply only \code{name}, for example:
%
%    \code{setGeneric("colSums")}
%
%  There must be an existing function of this name, on some attached
%  package (in this case package \code{"base"}).  A generic version of
%  this function will be created in the current package (or in the global
%  environment if the call to \code{setGeneric()} is from an ordinary
%  source file or is entered on the command line).  The existing function
%  becomes the default method, and the package slot of the new generic
%  function is set to the location of the original function
%  (\code{"base"} in the example).  It's an important feature that the
%  same generic function definition is created each time, depending in
%  the example only on the definition of \code{print} and where it is
%  found.  The \code{signature} of the generic function, defining which
%  of the formal arguments can be used in specifying methods, is set by
%  default to all the formal arguments except \code{\dots}.
%
%  Note that calling \code{setGeneric()} in this form is not strictly
%  necessary before calling \code{setMethod()} for the same function.  If
%  the function specified in the call to \code{setMethod} is not generic,
%  \code{setMethod} will execute the call to \code{setGeneric} itself.
%  Declaring explicitly that you want the function to be generic can be
%  considered better programming style; the only difference in the
%  result, however, is that not doing so produces a message noting the
%  creation of the generic function.
%
%  You cannot (and never need to) create an explicit generic version of
%  the primitive functions in the base package.  Those which can be
%  treated as generic functions have methods selected and dispatched from
%  the internal C code, to satisfy concerns for efficiency, and the
%  others cannot be made generic.  See the section on Primitive Functions
%  below.
%
%  It is also unnecessary to create explicit generic versions of
%  non-primitive functions that dispatch internally. These include
%  \code{unlist} and \code{as.vector}.
%
%  The description above is the effect when the package that owns the
%  non-generic function has not created an implicit generic version.
%  Otherwise, it is this implicit generic function that is used. See the
%  section on Implicit Generic Functions below.  Either way, the
%  essential result is that the \emph{same} version of the generic
%  function will be created each time.
%
%  The second common use of \code{setGeneric()} is to create a new
%  generic function, unrelated to any existing function, and frequently
%  having no default method.  In this case, you need to supply a skeleton
%  of the function definition, to define the arguments for the function.
%  The body of a generic function is usually a standard form,
%  \code{standardGeneric(name)} where \code{name} is the quoted name of
%  the generic function.  When calling \code{setGeneric} in this form,
%  you would normally supply the \code{def} argument as a function of
%  this form.  See the second and third examples below.
%
%  The \code{useAsDefault} argument controls the default method for the
%  new generic.  If not told otherwise, \code{setGeneric} will try to
%  find a non-generic version of the function to use as a default.  So,
%  if you do have a suitable default method, it is often simpler to first
%  set this up as a non-generic function, and then use the one-argument
%  call to \code{setGeneric} at the beginning of this section.  See the
%  first example in the Examples section below.
%
%  If you \emph{don't} want the existing function to be taken as default,
%  supply the argument \code{useAsDefault}.  That argument can be the
%  function you want to be the default method, or \code{FALSE} to force
%  no default (i.e., to cause an error if there is no direct or inherited
%  method selected for a call to the function).
%}
%\section{Details}{
%  The great majority of calls to \code{setGeneric()} should either
%  have one argument to ensure that an existing function can have
%  methods, or arguments \code{name} and \code{def} to create a new
%  generic function and optionally a default method.  If that's not
%  what you plan to do, read on.
%
%  If you want to change the behavior of an existing function (typically,
%  one in another package) when you create a generic version, you must
%  supply arguments to \code{setGeneric} correspondingly.  Whatever
%  changes are made, the new generic function will be assigned with a
%  package slot set to the \emph{current} package, not the one in which
%  the non-generic version of the function is found.  This step is
%  required because the version you are creating is no longer the same as
%  that implied by the function in the other package.  A message will be
%  printed to indicate that this has taken place and noting one of the
%  differences between the two functions.  It tends to be a bad idea,
%  because the two versions are now competing for methods, with many
%  chances for mistakes in programming.
%
%  The body of a generic function usually does nothing except for
%  dispatching methods by a call to \code{standardGeneric}.  Under some
%  circumstances you might just want to do some additional computation in
%  the generic function itself.  As long as your function eventually
%  calls \code{standardGeneric} that is permissible (though perhaps not a
%  good idea, in that it may make the behavior of your function less easy
%  to understand).  If your explicit definition of the generic function
%  does \emph{not} call \code{standardGeneric} you are in trouble,
%  because none of the methods for the function will ever be dispatched.
%
%  By default, the generic function can return any object.  If
%  \code{valueClass} is supplied, it should be a vector of class names;
%  the value returned by a method is then required to satisfy
%  \code{is(object, Class)} for one of the specified classes.  An empty
%  (i.e., zero length) vector of classes means anything is allowed.  Note
%  that more complicated requirements on the result can be specified
%  explicitly, by defining a non-standard generic function.
%
%  The \code{setGroupGeneric} function behaves like \code{setGeneric}
%  except that it constructs a group generic function, differing in two
%  ways from an ordinary generic function.  First, this function cannot
%  be called directly, and the body of the function created will contain
%  a stop call with this information.  Second, the group generic function
%  contains information about the known members of the group, used to
%  keep the members up to date when the group definition changes, through
%  changes in the search list or direct specification of methods, etc.
%}
%\section{Implicit Generic Functions}{
%  Saying that a non-generic function \dQuote{is converted to a generic}
%  is more precisely state that the function is converted to the
%  corresponding \emph{implicit} generic function.  If no special action
%  has been taken, any function corresponds implicitly to a generic
%  function with the same arguments, in which all arguments other than
%  \code{\dots} can be used.  The signature of this generic function is the
%  vector of formal arguments, in order, except for \code{\dots}.
%
%  The source code for a package can define an implicit generic function
%  version of any function in that package (see \link{implicitGeneric}
%  for the mechanism).  You can not, generally, define an implicit
%  generic function in someone else's package. The usual reason for
%  defining an implicit generic is to prevent certain arguments from
%  appearing in the signature, which you must do if you want the
%  arguments to be used literally or if you want to enforce lazy
%  evaluation for any reason.  An implicit generic can also contain some
%  methods that you want to be predefined; in fact, the implicit generic
%  can be any generic version of the non-generic function.  The implicit
%  generic mechanism can also be used to prohibit a generic version (see
%  \code{\link{prohibitGeneric}}).
%
%  Whether defined or inferred automatically, the implicit generic will
%  be compared with the generic function that \code{setGeneric} creates,
%  when the implicit generic is in another package.  If the two functions
%  are identical, then the \code{package} slot of the created generic
%  will have the name of the package containing the implicit generic.
%  Otherwise, the slot will be the name of the package in which the
%  generic is assigned.
%
%  The purpose of this rule is to ensure that all methods defined for a
%  particular combination of generic function and package names
%  correspond to a single, consistent version of the generic function.
%  Calling \code{setGeneric} with only \code{name} and possibly
%  \code{package} as arguments guarantees getting the implicit generic
%  version, if one exists.
%
%  Including any of the other arguments can force a new, local version of
%  the generic function.  If you don't want to create a new version,
%  don't use the extra arguments.
%}
%\section{Generic Functions and Primitive Functions}{
%  A number of the basic \R functions are specially implemented as
%  primitive functions, to be evaluated directly in the underlying C code
%  rather than by evaluating an \R language definition.  Most have
%  implicit generics (see \code{\link{implicitGeneric}}), and become
%  generic as soon as methods (including group methods) are defined on
%  them.  Others cannot be made generic.
%
%  Even when methods are defined for such functions, the generic version
%  is not visible on the search list, in order that the C version
%  continues to be called.  Method selection will be initiated in the C
%  code.  Note, however, that the result is to restrict methods for
%  primitive functions to signatures in which at least one of the classes
%  in the signature is a formal S4 class.
%
%  To see the generic version of a primitive function, use
%  \code{\link{getGeneric}(name)}.  The function
%  \code{\link{isGeneric}} will tell you whether methods are defined
%  for the function in the current session.
%
%  Note that S4 methods can only be set on those primitives which are
%  \sQuote{\link{internal generic}}, plus \code{\%*\%}.
%}
%\value{
%  The \code{setGeneric} function exists for its side effect: saving the
%  generic function to allow methods to be specified later.  It returns
%  \code{name}.
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\examples{
%\dontshow{
%setClass("track", representation(x="numeric", y="numeric"))
%}
%
%## create a new generic function, with a default method
%setGeneric("props", function(object) attributes(object))
%
%## A new generic function with no default method
%setGeneric("increment",
%  function(object, step, ...)
%    standardGeneric("increment")
%)
%
%
%###   A non-standard generic function.  It insists that the methods
%###   return a non-empty character vector (a stronger requirement than
%###    valueClass = "character" in the call to setGeneric)
%
%setGeneric("authorNames",
%    function(text) {
%      value <- standardGeneric("authorNames")
%      if(!(is(value, "character") && any(nchar(value)>0)))
%        stop("authorNames methods must return non-empty strings")
%      value
%      })
%
%\dontshow{
%setMethod("authorNames", "character", function(text)text)
%
%tryIt <- function(expr) tryCatch(expr, error = function(e) e)
%stopifnot(identical(authorNames(c("me", "you")), c("me", "you")),
%          is(tryIt(authorNames(character())), "error"), # empty value
%          is(tryIt(authorNames(NULL)), "error"))        # no default method
%}
%
%## An example of group generic methods, using the class
%## "track"; see the documentation of 'setClass' for its definition
%
%## define a method for the Arith group
%
%setMethod("Arith", c("track", "numeric"),
% function(e1, e2) {
%  e1@y <- callGeneric(e1@y , e2)
%  e1
%})
%
%setMethod("Arith", c("numeric", "track"),
% function(e1, e2) {
%  e2@y <- callGeneric(e1, e2@y)
%  e2
%})
%
%## now arithmetic operators  will dispatch methods:
%
%t1 <- new("track", x=1:10, y=sort(stats::rnorm(10)))
%
%t1 - 100
%1/t1
%
%\dontshow{
%removeGeneric("authorNames")
%removeClass("track")
%removeMethods("Arith")
%removeGeneric("props")
%removeGeneric("increment")
%}
%}
%\seealso{
%  \code{\link{Methods}} and the links there for a general discussion,
%  \code{\link{dotsMethods}} for methods that dispatch on
%  \code{\dots}, and \code{\link{setMethod}} for method definitions.
%}
%\keyword{ programming }
%\keyword{ methods }
%
%\encoding{UTF8}
%