% File src/library/methods/man/setLoadActions.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2012-2014 R Core Team
% Distributed under GPL 2 or later

\name{setLoadActions}
%@%\alias{パッケージのロードに対するアクションを設定}
\alias{setLoadAction}
\alias{setLoadActions}
\alias{getLoadActions}
\alias{hasLoadAction}
\alias{evalOnLoad}
\alias{evalqOnLoad}
\title{パッケージのロードに対するアクションを設定する}
%\title{Set Actions For Package Loading}
\description{
  これらの関数はパッケージの名前空間のロード中になされるべき
  計算を指定するパッケージ対する機構を提供する．
  そうしたアクションはロード時だけに利用可能な情報
  (動的にリンクされるライブラリ中の位置のように)
  を提供する柔軟な方法である．

  \code{setLoadAction()} または \code{setLoadActions()} の呼び出しは
  対応する名前空間がロードされる時に呼び出される一つまたは
  それ以上の関数を指定し，
  \dots{} 引数名はアクションに対する名前を指定するために使われる．

  \code{getLoadActions} はパッケージの名前空間をその引数として
  与え，現在定義されているロードアクションを報告する．

  \code{hasLoadAction} はもし与えられた名前に対応する
  ロードアクションが
  \code{where} 名前空間に対して以前に設定されていれば
  \code{TRUE} を返す．

  \code{evalOnLoad()} と \code{evalqOnLoad()} はロード時に
  指定された特定の表現式のスケジュールを立てる．
}
\usage{
setLoadAction(action, aname=, where=)

setLoadActions(..., .where=)

getLoadActions(where=)

hasLoadAction(aname, where=)

evalOnLoad(expr, where=, aname=)

evalqOnLoad(expr, where=, aname=)
}
\arguments{

  \item{action, \dots}{
    一つまたはそれ以上の引数の関数で，パッケージがロードされる時
    呼び出される．関数は一つの引数
    (パッケージの名前空間)で呼び出されるので全ての引き続く
    引数は既定値を持たなければならない．

    もし \dots{} の要素が名前付きならば，これらの名前は
    対応するロードメタデータに対して使われる．
  }

  \item{where, .where}{
    ロードアクションのリストがそれに対して定義される
    パッケージの名前空間．
    この引数はもし呼び出しがパッケージ自体のソースコードに由来すれば
    普通省略されるが，
    パッケージが別のパッケージに対するロードアクションを
    提供すれば必要となる．
  }

  \item{aname}{アクションの名前．
    もしアクションが名前の提供なしに設定されると，
    既定では指定されたアクション系列中の位置が使われる
    (\code{".1"} 等)．
  }

  \item{expr}{
    環境 \code{where} 中のロードアクション中で評価される
    評価式．\code{evalqOnLoad()} の場合は
    評価式は文字通りに解釈される．
    \code{evalOnLoad()} 中のそれでは，
    典型的にはタイプ \code{"language"} のオブジェクト
    として予め計算される必要がある．
  }
}
\details{
  \code{evalOnLoad()} と \code{evalqOnLoad()} 関数は簡便性のために
  存在する．それらは表現式を評価し，そしてその関数への呼び出しを
  スケジュールするため
  \code{setLoadAction()} を呼び出す．

  \code{setLoadAction()} または \code{setLoadActions()}
  への引数として提供された関数の各々は名前空間中のメタデータ
  として保存され，典型的には
  \code{setLoadActions()} の呼び出しを含むパッケージの
  それになる．
  もしこのパッケージの名前空間がロードされると，これらの
  関数の各々が呼び出される．アクション関数は
  それらが \code{setLoadActions()} に提供された順序で
  呼び出される．
  付値されたオブジェクトは呼び出し中で提供された名前から
  構成されたメタデータ名を持つ；名前無しの引数はそれらの
  アクションのリスト中の位置から命名される
  (\code{".1"} 等)．
  
  \code{setLoadAction()} または \code{setLoadActions()} の
  複数の呼び出しをパッケージのコード中で使うことが出来る；
  アクションは
  \code{setLoadAction()} に与えられた名前が既存のアクションのそれ
  である場合を除き，任意の先に指定された後に
  スケジュールされる．典型的なアプリケーションでは，
  パッケージ自体のコードから幾つかのアクションを設定するために
  呼び出される時 \code{setLoadActions()} がより便利である．
  もしアクション名が構成されるならば \code{setLoadAction()}
  がより便利であり，
  これは一つのパッケージが別のパッケージに対する
  ロードアクションを構成するときにはより典型的である．

  アクションは実際にか構成された同じ名前で逐次的に
  付値することで改訂できる．
  置き換えは依然適正な関数でなければならないが，
  勿論もし意図することが指定されたアクションを除く
  ことにあれば何もしないことも可能である．

  関数は少なくとも一つ引数を持たなければならない．
  それらはパッケージの名前空間という一つの引数で
  呼び出される．
  関数は S4 メタデータの処理の最後，
  任意のコンパイル済みコードの動的リンク，
  もしあれば
  \code{.onLoad()} の呼び出し，そしてメソッドのキャッシュと
  クラス定義の後に呼び出されるが，名前空間が封印される前である．
  (ロードアクションはメソッド選択適用がオンの時だけ
  呼び出される．)

  関数は従って呼び出し中の引数として提供された名前空間
  中のオブジェクトに付値したり修正したり出来る．
  機構は，動的にリンクされたライブラリから得られる値のような，
  パッケージがロード時まで利用できない情報を
  保存することを可能にする．

  ロードアクションは
  \code{\link{setHook}()} により提供されるユーザのロードフックと
  比較されるべきである．ユーザフックは一般に
  パッケージの外部から提供され，そして名前空間が封印された後に
  実行される．ロードアクションは普通パッケージコードの一部であり，
  アクションのリストは普通パッケージがインストール
  される時に確立される．

  ロードアクションはパッケージに対するソースコード中で
  直接に提供することが出来る．
  一つのパッケージ中に別のパッケージ中のロードアクションを作る
  機能を提供することも可能で有用である．
  ソフトウェアはアクション関数を正しい環境，つまり目標パッケージの
  名前空間，に付値されるように注意しなければならない．
}

\value{  
  \code{setLoadAction()} と \code{setLoadActions()} は
  それらの副作用のために呼び出され，そして有用な
  値は何も返さない．

  \code{getLoadActions()} は提供された名前空間中の
  アクションの名前付きリストを返す．

  \code{hasLoadAction()} はもし指定された
  アクション名がこのパッケージに対するアクション中に
  あれば \code{TRUE} を返す．
}

\seealso{
  ベースパッケージ中のより安全
  (名前空間が封印された後に実行されるので)で
  より徹底的なバージョンに対しては
  \code{\link{setHook}}．
}

\examples{
\dontrun{
## あるパッケージに対するコード中で

## ... 何か他のもの
setLoadActions(function(ns)
   cat("Loaded package", sQuote(getNamespaceName(ns)),
       "at", format(Sys.time()), "\n"),
  setCount = function(ns) assign("myCount", 1, envir = ns),
  function(ns) assign("myPointer", getMyExternalPointer(), envir = ns))
  ... somewhere later
if(countShouldBe0)
  setLoadAction(function(ns) assign("myCount", 0, envir = ns), "setCount")
}
}
\keyword{ package }


\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/setLoadActions.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2012-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{setLoadActions}
%\alias{setLoadAction}
%\alias{setLoadActions}
%\alias{getLoadActions}
%\alias{hasLoadAction}
%\alias{evalOnLoad}
%\alias{evalqOnLoad}
%\title{
%Set Actions For Package Loading
%}
%\description{
%  These functions provide a mechanism for packages to specify
%  computations to be done during the loading of a package namespace.
%  Such actions are a flexible way to provide information only available at
%  load time (such as locations in a dynamically linked library).
%
%  A call to \code{setLoadAction()} or \code{setLoadActions()} specifies
%  one or more functions to be called when the corresponding namespace is
%  loaded, with the \dots{} argument names being used as identifying
%  names for the actions.
%
%  \code{getLoadActions} reports the currently defined load actions,
%  given a package's namespace as its argument.
%
%  \code{hasLoadAction} returns \code{TRUE} if a load action
%  corresponding to the given name has previously been set for the
%  \code{where} namespace.
%
%  \code{evalOnLoad()} and \code{evalqOnLoad()} schedule a specific
%  expression for evaluation at load time.
%}
%\usage{
%setLoadAction(action, aname=, where=)
%
%setLoadActions(..., .where=)
%
%getLoadActions(where=)
%
%hasLoadAction(aname, where=)
%
%evalOnLoad(expr, where=, aname=)
%
%evalqOnLoad(expr, where=, aname=)
%}
%\arguments{
%
%  \item{action, \dots}{
%    functions of one or more arguments, to be called when this package is
%    loaded. The functions will be called with one argument (the package
%    namespace) so all following arguments must have default values.
%
%    If the elements of \dots{} are named, these names will be used for the
%    corresponding load metadata.
%  }
%
%  \item{where, .where}{
%    the namespace of the package for which the list of load actions are
%    defined. This argument is normally omitted if the call comes from the
%    source code for the package itself, but will be needed if a package
%    supplies load actions for another package.
%  }
%
%  \item{aname}{the name for the action.  If an action is set without
%    supplying a name,  the default uses the position in the sequence of
%    actions specified (\code{".1"}, etc.).
%  }
%
%  \item{expr}{an expression to be evaluated in a load action in
%    environment \code{where}.  In the case of \code{evalqOnLoad()},
%    the expression is interpreted literally, in that of
%    \code{evalOnLoad()} it must be precomputed, typically as an object
%    of type \code{"language"}.
%  }
%}
%\details{
%  The \code{evalOnLoad()} and \code{evalqOnLoad()} functions are for
%  convenience.  They construct a function to evaluate the expression and
%  call \code{setLoadAction()} to schedule a call to that function.
%
%  Each of the functions supplied as an argument to \code{setLoadAction()}
%  or \code{setLoadActions()} is saved as metadata in the namespace,
%  typically that of the package containing the call to
%  \code{setLoadActions()}.  When this package's namespace is loaded, each
%  of these functions will be called.  Action functions are called in the
%  order they are supplied to \code{setLoadActions()}.  The objects
%  assigned have metadata names constructed from the names supplied in the
%  call; unnamed arguments are taken to be named by their position in the
%  list of actions (\code{".1"}, etc.).
%  
%  Multiple calls to \code{setLoadAction()} or \code{setLoadActions()}
%  can be used in a package's code; the actions will be scheduled after any
%  previously specified, except if the name given to \code{setLoadAction()}
%  is that of an existing action.  In typical applications,
%  \code{setLoadActions()} is more convenient when calling from the
%  package's own code to set several actions.  Calls to
%  \code{setLoadAction()} are more convenient if the action name is to be
%  constructed, which is more typical when one package constructs load
%  actions for another package.
%
%  Actions can be revised by assigning with the same name, actual or
%  constructed, in a subsequent call.  The replacement must still be a
%  valid function, but can of course do nothing if the intention was to
%  remove a previously specified action.
%
%  The functions must have at least one argument.  They will be called with
%  one argument, the namespace of the package.  The functions will be
%  called at the end of processing of S4 metadata, after dynamically
%  linking any compiled code, the call to \code{.onLoad()}, if any, and
%  caching method and class definitions, but before the namespace is
%  sealed.  (Load actions are only called if methods dispatch is on.)
%
%  Functions may therefore assign or modify objects in the namespace
%  supplied as the argument in the call.  The mechanism allows packages
%  to save information not available until load time, such as values
%  obtained from a dynamically linked library.
%
%  Load actions should be contrasted with user load hooks supplied by
%  \code{\link{setHook}()}.  User hooks are generally provided from
%  outside the package and are run after the namespace has been sealed.
%  Load actions are normally part of the package code, and the list of
%  actions is normally established when the package is installed.
%
%  Load actions can be supplied directly in the source code for a
%  package.  It is also possible and useful to provide facilities in one
%  package to create load actions in another package.  The software needs
%  to be careful to assign the action functions in the correct
%  environment, namely the namespace of the target package.
%}
%
%\value{  
%  \code{setLoadAction()} and \code{setLoadActions()} are called for
%  their side effect and return no useful value.
%
%  \code{getLoadActions()} returns a named list of the actions in the
%  supplied namespace.
%
%  \code{hasLoadAction()} returns \code{TRUE} if the specified action
%  name appears in the actions for this package.
%}
%
%\seealso{
%  \code{\link{setHook}} for safer (since they are run after the
%  namespace is sealed) and more comprehensive versions in the
%  base package.
%}
%
%\examples{
%\dontrun{
%## in the code for some package
%
%## ... somewhere else
%setLoadActions(function(ns)
%   cat("Loaded package", sQuote(getNamespaceName(ns)),
%       "at", format(Sys.time()), "\n"),
%  setCount = function(ns) assign("myCount", 1, envir = ns),
%  function(ns) assign("myPointer", getMyExternalPointer(), envir = ns))
%  ... somewhere later
%if(countShouldBe0)
%  setLoadAction(function(ns) assign("myCount", 0, envir = ns), "setCount")
%}
%}
%\keyword{ package }
%
%
%\encoding{UTF8}
%