% File src/library/methods/man/setMethod.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{setMethod}
%@%\alias{メソッドを作り保存}
\alias{setMethod}
\alias{removeMethod}
\title{メソッドを作り保存する}
%\title{ Create and Save a Method }
\description{
  与えられた関数とクラスリストに対する形式的メソッドを作り保存する．
}
\usage{
setMethod(f, signature=character(), definition,
          where = topenv(parent.frame()),
          valueClass = NULL, sealed = FALSE)

removeMethod(f, signature, where)
}
\arguments{
  \item{f}{
    総称的関数または関数の文字列名．
    内部的に選択適用を行う非プリミティブな基本関数は
    文字列で指定される必要がある．}
  \item{signature}{
    対応するクラスの文字列名を持つ
    \code{f} に対する形式的引数名のマッチ．
    下の詳細を見よ；もしシグネチャが自明でなければ， 
    \code{setMethod} への適正な呼び出しを生成するためには
    \code{\link{method.skeleton}} を使うべきである．}
  \item{definition}{
    関数定義で，\code{f} への呼び出し中で引数が
    \code{signature} 中のクラスに直接または継承でマッチした時に
    呼び出されるメソッドになる．}
  \item{where}{
    メソッドの定義を保管する環境．
    \code{setMethod} に対しては，この引数を省略しそして
    トップレベルで評価されるコードをソースコード中に含めることが
    推奨される；つまり，R セッション中で
    \code{\link{source}} に同値な何かか，パッケージに対する
    R ソースコードの一部として．

    \code{removeMethod} に対しては，既定値は
    このシグネチャに対するメソッドの(最初の)インスタンスの位置．}
  \item{valueClass}{
    旧式で使われないが，
    \code{\link{setGeneric}} に対する同じ引数を見よ．}
  \item{sealed}{
    もし \code{TRUE} ならば，そのように定義されたメソッドは
    \code{setMethod} への別の呼び出しで再定義されない
    (取り除いた後に再付値できるが)．}
}
\value{
  これらの関数は，
  指定された総称的関数に対するメソッドを定義するオブジェクト
  中のメソッドを設定したり取り除いたりする，それらの副作用のために存在する．

  \code{removeMethod} が返す値はもし取り除かれるメソッドが
  見つかれば \code{TRUE}．
}
\details{
\code{setMethod} の呼び出しは，典型的には大局的環境か
パッケージの名前空間である環境中のこの総称的関数に対する
メタデータテーブル中の提供されたメソッド定義を保管する．
パッケージの場合，テーブルオブジェクトは
パッケージの名前空間か環境の一部になる．
パッケージが後のセッション中にロードされる時，
メソッドは対応する総称的関数オブジェクト中の
メソッドのテーブル中に混ぜ合わされる．

総称的関数は関数名とパッケージ名の組み合わせにより参照される；
例えばパッケージ \code{"methods"} からの関数 \code{"show"}．
メソッドに対するメタデータは二つの文字列で特定される；
特に総称的関数オブジェクト自体はその名前とそのパッケージ名
を含むスロットを持つ．
総称的関数のパッケージ名はそれが元々そこから由来した
パッケージに従って設定される；特に，そしてしばしば，
関数の非総称バージョンがそこから由来するパッケージ．
例えば，パッケージ \pkg{base} 中の全ての関数に対する総称的関数は
パッケージ名として \code{"base"} を持つ．もっとも
そのパッケージについてはどれも
S4 総称的関数ではないが．これらは真の関数よりも，
プリミティブである基本関数の殆どを含む；
詳細については \code{\link{setGeneric}} に対するドキュメント中の
プリミティブ関数に関する節を見よ．

複数のパッケージが同じ総称的関数に対してメソッドを持つことが出来る；
つまり総称的関数名とパッケージ名の同じ組み合わせに対して．
メソッドは別個の環境の別個のテーブル中に保管されるものの，
対応するパッケージのロードはセッションの間中メソッドを
総称的関数自体に加える．

  シグネチャ中のクラス名は
  \code{"numeric"}, \code{"character"} そして
  \code{"matrix"} の様な基本的クラスを含む
  任意の形式的クラスであり得る．
  二つの追加の特殊なクラス名を使うことが出来る；
  この引数が任意のクラスを持つことが出来ることを
  意味する \code{"ANY"}；そして
  この引数がこのシグネチャにマッチするために呼び出し中に
  現れては\emph{ならない}ことを意味する \code{"missing"} である．
  この二つを混同してはならない：
  もしある引数がシグネチャ中に述べられていないと，
  それは暗黙のうちにクラス \code{"ANY"} に対応し，
  \code{"missing"} に対してではない．下の例を見よ．
  旧式(\sQuote{S3})のクラスもまたこれらとの互換性を
  必要とすれば使うことが出来るが，
  S3 スタイルの継承が動作するためには
  \code{\link{setOldClass}} を呼び出し明確にこれらの
  クラスを宣言しなければならない．

  メソッド定義は引数に対する既定表現式を持つことが出来るが，
  現在の限界は総称的関数は既定のメソッドが使われるためには同じ引数に対して
  \emph{ある}既定表現式を持たねばならないということである．
  もしそうならば，そしてもし対応する引数が
  総称的関数の呼び出し中で欠損しているならば，
  メソッド中の既定表現式が使われる．
  もしメソッド定義が引数に対して如何なる既定値を持たなければ，
  総称的関数自体の定義中で提供される表現式が使われるが，
  この表現式は，総称的関数のそれでは無く，メソッドの囲み環境を用いて
  評価されることを注意する．またシグネチャ中のクラス
  \code{"missing"} の指定は如何なる既定表現式も必要とせず，
  そしてメソッド選択は既定の表現式を評価しないことを注意する．
  総称的関数のシグネチャ中の全ての実際の(欠損していない)引数は

  メソッドが選択された時，\code{standardGeneric(f)} の呼び出しが起こった時，
  に評価されることを注意する．

  \code{setMethod} に提供されたメソッドに対する形式的引数と
  総称的関数のそれらの間にある違いがあることが可能である．
  簡単に言えば，もし総称的関数が \dots をその引数の一つとして
  持てば，メソッドは追加の引数を持つかもしれず，
  それは \code{f} への呼び出し中で \dots にマッチする
  引数からマッチされる．
  (実際に起こることは修正された形式的引数をもつ局所的な関数が
  メソッド内部で作られ，そしてその局所的関数を呼び出す
  メソッドが再定義される．)

  メソッドの選択適用は
  \code{f} に対して集められた利用可能なメソッドへの呼び出し中で
  実際の引数のクラスのマッチを試みる．
  もしこの呼び出し中に正確に同じクラスに対して定義されたメソッドが
  あれば，そのメソッドが使われる．
  さもなければ，実際のクラスか(\code{"ANY"} を含む)
  実際のクラスのスーパークラスに対応する全ての可能な
  シグネチャが考慮される．
  実際のクラスとの距離が最少のクラスが選択される；
  もし最少距離を持つクラスが複数あれば，
  (スーパークラスの言葉で辞書式順序で最初の)ものが
  選ばれるが警告が出る． 全ての選択された継承メソッドは
  別のテーブルに保存されるので，
  継承計算は実際のクラス系列毎でセッション毎になされるだけで良い．
  より詳細は \link{Methods} を見よ．

関数 \code{removeMethod} は指定されたメソッドを
対応する環境中のメタデータオブジェクトから取り除く．
普通何の定義も残さないよりはメソッドを再定義したいため，
これはそれほど使われる関数ではない．
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\examples{
\dontshow{  require(stats)
  setClass("track",
    representation(x="numeric", y = "numeric"))
  setClass("trackCurve", representation("track",
    smooth = "numeric"))
  setClass("trackMultiCurve", representation(x="numeric", y="matrix", smooth="matrix"),
          prototype = list(x=numeric(), y=matrix(0,0,0), smooth=
  matrix(0,0,0)))
}

require(graphics)
## track オブジェクトのプロットに対するメソッド(setClass に対する例を見よ)
##
## 先ず引数として唯一つのオブジェクト：
setMethod("plot", signature(x="track", y="missing"),
  function(x,  y, ...) plot(slot(x, "x"), slot(x, "y"), ...)
)
## 次にtrackからのデータを y 軸上に任意の x データに対してプロット
setMethod("plot", signature(y = "track"),
 function(x, y, ...) plot(x, slot(y, "y"), ...)
)
## そして track を x 軸上に同様に
## (シグネチャに対する指定の短縮形を用いて)
setMethod("plot", "track",
 function(x, y, ...) plot(slot(x, "y"), y,  ...)
)
t1 <- new("track", x=1:20, y=(1:20)^2)
tc1 <- new("trackCurve", t1)
slot(tc1, "smooth") <- smooth.spline(slot(tc1, "x"), slot(tc1, "y"))$y 
plot(t1)
plot(qnorm(ppoints(20)), t1)
## 継承メソッドと，それに準拠するメソッド引数
## (メソッド中の dotCurve 引数に注意，これは
## 総称的関数中の ... を取り出す)
setMethod("plot", c("trackCurve", "missing"),
function(x, y, dotCurve = FALSE, ...) {
  plot(as(x, "track"))
  if(length(slot(x, "smooth") > 0))
    lines(slot(x, "x"), slot(x, "smooth"),
         lty = if(dotCurve) 2 else 1)
  }
)
## tc1 だけのプロットは追加の曲線を持つ；tc1 の別の使用は
## それが "track" オブジェクトであるかのように扱われる．
plot(tc1, dotCurve = TRUE)
plot(qnorm(ppoints(20)), tc1)

## 特殊関数に対するメソッドの定義．
## "[" と "length" は普通の関数ではないが
## それらに対するメソッドを定義できる
setMethod("[", "track",
  function(x, i, j, ..., drop) {
    x@x <- x@x[i]; x@y <- x@y[i]
    x
  })
plot(t1[1:15])

setMethod("length", "track", function(x)length(x@y))
length(t1)

## メソッドは欠損引数に対しても同様に定義できる
setGeneric("summary") ## 関数を総称的関数にする

## summary() に対するメソッド
## メソッド定義は引数を含むことができるが，
## もしそれらが省略されると，クラス "missing" が仮定される．

setMethod("summary", "missing", function() "<No Object>")

\dontshow{

stopifnot(identical(summary(), "<No Object>"))

removeMethods("summary")

## プリミティブ関数に対して
## 継承メソッド

length(tc1)
tc1[-1]

## 旧式メソッドが依然として動作するようにする
t11 <- t1[1:15]
identical(t1@y[1:15], t11@y)

## nextMethod を持つ S3 メソッド
form <- y ~ x
form[1]

## S3 算術メソッド
ISOdate(1990, 12, 1)- ISOdate(1980, 12, 1)

## グループメソッド

setMethod("Arith", c("track", "numeric"), function(e1, e2){e1@y <-
  callGeneric(e1@y , e2); e1})


t1  - 100.

t1/2


## それが S3 メソッドを歪めてないかどうかをチェック
ISOdate(1990, 12, 1)- ISOdate(1980, 12, 1)

## .Generic 機構をテスト

setMethod("Compare", signature("track", "track"),
  function(e1,e2) {
  switch(.Generic,
   "==" = e1@y == e2@y,
  NA)
 })

#stopifnot(all(t1==t1))
#stopifnot(identical(t1<t1, NA))


## データフレームに適用された行列風引数を持つ
## "[" への入れ子の呼び出しのテスト(S3 メソッド)

setMethod("[", c("trackMultiCurve", "numeric", "numeric"), function(x, i, j, ..., drop) {
### FIXME: より良いバージョンはシグネチャ中に最初の引数だけを持ち
### そしてこれがプリミティブ関数に対して動作するには callNextMethod を使う．
    x@y <- x@y[i, j, drop=FALSE]
    x@x <- x@x[i]
    x
})


"testFunc" <-
function(cur) {
    sorted <- cur[order(cur[,1]),]
    sorted[ !is.na(sorted[,1]), ]
}

Nrow <- 1000 # 一回で，この大きさの値は
## gc/protect 中のバグを惹き起こす
## ここでのループはバグに対するトリガー
Niter <- 10
for(i in 1:Niter)  {
    yy <- matrix(stats::rnorm(10*Nrow), 10, Nrow)
    tDF <- as.data.frame(yy)
    testFunc(tDF)
}


tMC <- new("trackMultiCurve", x=seq_len(Nrow), y = yy)
## 十分多くの関数は testFunc を使うためにはこのクラスに
## 対するメソッドを持たない

stopifnot(identical(tMC[1:10, 1:10]@y, yy[1:10, 1:10]))


## メソッドと総称的関数を取り除けることを検証

removeMethods("-")
removeMethod("length", "track")
removeMethods("Arith")
removeMethods("Compare")

## プリミティブに関するテストをもう一回繰り返す

length(ISOdate(1990, 12, 1)- ISOdate(1980, 12, 1))

removeMethods("length")

## \%*\% に対するメソッド，これは他の演算子と同じ
## C コードではなされない

setClass("foo", representation(m="matrix"))
m1 <- matrix(1:12,3,4)
f1 = new("foo", m=m1)
f2 = new("foo", m=t(m1))

setMethod("\%*\%", c("foo", "foo"),
 function(x,y)callGeneric(x@m, y@m))

stopifnot(identical(f1\%*\%f2, m1\%*\% t(m1)))

removeMethods("\%*\%")

removeMethods("plot")

## removeMethods が改訂されるまで待機：
stopifnot(existsFunction("plot", FALSE) && !isGeneric("plot", 1))

## plotData に対するメソッド
plotData <- function(x, y, ...) plot(x, y, ...)

setGeneric("plotData")

setMethod("plotData", signature(x="track", y="missing"),
  function(x,  y, ...) plot(slot(x, "x"), slot(x, "y"), ...)
)
## そしてここで全ての総称的関数を取り除く
removeGeneric("plotData")

stopifnot(!exists("plotData", 1))

##  メソッド継承と多重選択適用のテスト
setClass("A0", representation(a0 = "numeric"))

setClass("A1", representation("A0", a1 = "character"))

setClass("B0" ,representation(b0 = "numeric"))

setClass("B1", "B0")

setClass("B2", representation("B1", b2 = "logical"))

setClass("AB0", representation("A1", "B2", ab0 = "matrix"))

f1 <- function(x,  y)"ANY"

setGeneric("f1")

setMethod("f1", c("A0", "B1"), function(x, y)"A0 B1")
setMethod("f1", c("B1", "A0"), function(x, y)"B1 A0")

a0 <- new("A0")
a1 <- new("A1")
b0 <- new("B0")
b1 <- new("B1")
b2 <- new("B2")

deparseText <- function(expr)
    paste(deparse(expr), collapse = "\\  ")

mustEqual <- function(e1, e2){
    if(!identical(e1, e2))
        stop(paste("!identical(", deparseText(substitute(e1)),
                   ", ", deparseText(substitute(e2)), ")", sep=""))
}

mustEqual(f1(a0, b0), "ANY")
mustEqual(f1(a1,b0), "ANY")
mustEqual(f1(a1,b1), "A0 B1")
mustEqual(f1(b1,a1), "B1 A0")
mustEqual(f1(b1,b1), "ANY")

## クラスを除く；より先のクラスを未定義にしないためには順序が重要
for(.cl in c("AB0", "A1", "A0", "B2", "B1", "B0"))
    removeClass(.cl)

removeGeneric("f1")

## 非標準的総称的関数の定義のテスト

setGeneric("doubleAnything", function(x) {
  methodValue <- standardGeneric("doubleAnything")
  c(methodValue, methodValue)
})

setMethod("doubleAnything", "ANY", function(x)x)

setMethod("doubleAnything", "character",
function(x)paste("<",x,">",sep=""))

mustEqual(doubleAnything(1:10), c(1:10, 1:10))
mustEqual(doubleAnything("junk"), rep("<junk>",2))

removeGeneric("doubleAnything")


}
}

\seealso{
\code{\link{method.skeleton}} は
\code{setMethod} の呼び出しの骨格を作る推奨される方法であり，
正しい形式的引数と他の詳細を備える．

一般的議論については \link{Methods} とそこでのリンク，
  \dQuote{\dots} の関して選択適用を行うメソッドについては
  \code{\link{dotsMethods}}，そして総称的関数については
  \code{\link{setGeneric}}．
}

\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/setMethod.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{setMethod}
%\alias{setMethod}
%\alias{removeMethod}
%\title{ Create and Save a Method }
%\description{
%  Create and save a formal method for a given function and list of classes.
%}
%\usage{
%setMethod(f, signature=character(), definition,
%          where = topenv(parent.frame()),
%          valueClass = NULL, sealed = FALSE)
%
%removeMethod(f, signature, where)
%}
%\arguments{
%  \item{f}{ A generic function or the character-string name of the
%  function. Non-primitive base functions that dispatch internally need
%  to be specified by character-string.}
%  \item{signature}{ A match of formal argument names for \code{f} with
%    the character-string names of corresponding classes.  See the
%    details below; however, if the signature is not trivial, you should use \code{\link{method.skeleton}} to generate a valid call to \code{setMethod}.}
%  \item{definition}{ A function definition, which will become the method
%    called when the arguments in a call to \code{f} match the
%    classes in \code{signature}, directly or through inheritance. }
%  \item{where}{the environment in which to store the definition of the
%    method.
%For \code{setMethod}, it is recommended to omit this argument and to include the call in source code that is evaluated at the top level; that is, either in an R session by something equivalent to a call to \code{\link{source}}, or as part of the R source code for a package.
%
%    For \code{removeMethod}, the default is the location of the (first)
%    instance of the method for this signature.}
%  \item{valueClass}{ Obsolete and unused, but see the same argument for \code{\link{setGeneric}}. }
%  \item{sealed}{ If \code{TRUE}, the method so defined cannot be
%      redefined by another call to \code{setMethod} (although it can
%      be removed and then re-assigned).}
%}
%\value{
%  These functions exist for their side-effect, in setting or removing a
%  method in the object defining methods for the specified generic.
%
%  The value returned by \code{removeMethod} is \code{TRUE} if a method
%  was found to be removed.
%}
%\details{
%The call to \code{setMethod} stores the supplied method definition  in
%the metadata table for this generic function in the environment,
%typically the global environment or the namespace of a package.
%In the case of a package, the table object becomes part of the namespace or environment of the
%package.
%When the package is loaded into a later session, the
%methods will be merged into the table of methods in the corresponding
%generic function object.
%
%Generic functions are referenced by the combination of the function name and
%the package name;
%for example, the function \code{"show"} from the package
%\code{"methods"}.
%Metadata for methods is identified by the two strings; in particular, the
%generic function object itself has slots containing its name and its
%package name.
%The package name of a generic is set according to the package
%from which it originally comes; in particular, and frequently, the
%package where a non-generic version of the function originated.
%For example, generic functions for all the functions in package \pkg{base} will
%have \code{"base"} as the package name, although none of them is an
%S4 generic on that package.
%These include most of the base functions that are primitives, rather than
%true functions; see the section on primitive functions in the
%documentation for \code{\link{setGeneric}} for details.
%
%Multiple packages can have methods for the same generic function; that
%is, for the same combination of generic function name and package
%name.
%Even though the methods are stored in separate tables in separate
%environments, loading the corresponding packages adds the methods to
%the table in the generic function itself, for the duration of the session.
%
% The class
%  names in the signature can be any formal class, including basic
%  classes such as \code{"numeric"}, \code{"character"}, and
%  \code{"matrix"}.  Two additional special class names can appear:
%  \code{"ANY"}, meaning that this argument can have any class at all;
%  and \code{"missing"}, meaning that this argument \emph{must not}
%  appear in the call in order to match this signature.  Don't confuse
%  these two:  if an argument isn't mentioned in a signature, it
%  corresponds implicitly to class \code{"ANY"}, not to
%  \code{"missing"}.  See the example below.  Old-style (\sQuote{S3})
%  classes can also be used, if you need compatibility with these, but
%  you should definitely declare these classes by calling
%  \code{\link{setOldClass}} if you want S3-style inheritance to work.
%
%
%  Method definitions can
%  have default expressions for arguments, but a current limitation is
%  that the generic function must have \emph{some} default expression for the
%  same argument in order for the method's defaults to be used.
%  If so, and if the corresponding argument is
%  missing in the call to the generic function, the default expression
%  in the method is used.  If the method definition has no default for
%  the argument, then the expression supplied in the definition of the
%  generic function itself is used, but note that this expression will
%  be evaluated using the enclosing environment of the method, not of
%  the generic function.
%  Note also that specifying class \code{"missing"} in the signature
%  does not require any default expressions, and method selection does
%  not evaluate default expressions.
%  All actual (non-missing) arguments in the signature of the
%  generic function will be evaluated when a method is selected---when
%  the call to \code{standardGeneric(f)} occurs.
%
%  It is possible to have some differences between the
%  formal arguments to a method supplied to \code{setMethod} and those
%  of the generic. Roughly, if the generic has \dots as one of its
%  arguments, then the method may have extra formal arguments, which
%  will be matched from the arguments matching \dots in the call to
%  \code{f}.  (What actually happens is that a local function is
%  created inside the method, with the modified formal arguments, and the method
%  is re-defined to call that local function.)
%
%  Method dispatch tries to match the class of the actual arguments in a
%  call to the available methods collected for \code{f}.  If there is a
%  method defined for the exact same classes as in this call, that
%  method is used.  Otherwise, all possible signatures are considered
%  corresponding to the actual classes or to superclasses of the actual
%  classes (including \code{"ANY"}).
%  The method having the least distance from the actual classes is
%  chosen; if more than one method has minimal distance, one is chosen
%  (the lexicographically first in terms of superclasses) but a warning
%  is issued.
%  All inherited methods chosen are stored in another table, so that
%  the inheritance calculations only need to be done once per session
%  per sequence of actual classes.
%  See
%  \link{Methods} for more details.
%
%The function \code{removeMethod} removes the specified method from the
%metadata table in the corresponding environment.
%It's not a function that is used much, since one normally wants to
%redefine a method rather than leave no definition.
%
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\examples{
%\dontshow{  require(stats)
%  setClass("track",
%    representation(x="numeric", y = "numeric"))
%  setClass("trackCurve", representation("track",
%    smooth = "numeric"))
%  setClass("trackMultiCurve", representation(x="numeric", y="matrix", smooth="matrix"),
%          prototype = list(x=numeric(), y=matrix(0,0,0), smooth=
%  matrix(0,0,0)))
%}
%
%require(graphics)
%## methods for plotting track objects (see the example for \link{setClass})
%##
%## First, with only one object as argument:
%setMethod("plot", signature(x="track", y="missing"),
%  function(x,  y, ...) plot(slot(x, "x"), slot(x, "y"), ...)
%)
%## Second, plot the data from the track on the y-axis against anything
%## as the x data.
%setMethod("plot", signature(y = "track"),
% function(x, y, ...) plot(x, slot(y, "y"), ...)
%)
%## and similarly with the track on the x-axis (using the short form of
%## specification for signatures)
%setMethod("plot", "track",
% function(x, y, ...) plot(slot(x, "y"), y,  ...)
%)
%t1 <- new("track", x=1:20, y=(1:20)^2)
%tc1 <- new("trackCurve", t1)
%slot(tc1, "smooth") <- smooth.spline(slot(tc1, "x"), slot(tc1, "y"))$y #$
%plot(t1)
%plot(qnorm(ppoints(20)), t1)
%## An example of inherited methods, and of conforming method arguments
%## (note the dotCurve argument in the method, which will be pulled out
%## of ... in the generic.
%setMethod("plot", c("trackCurve", "missing"),
%function(x, y, dotCurve = FALSE, ...) {
%  plot(as(x, "track"))
%  if(length(slot(x, "smooth") > 0))
%    lines(slot(x, "x"), slot(x, "smooth"),
%         lty = if(dotCurve) 2 else 1)
%  }
%)
%## the plot of tc1 alone has an added curve; other uses of tc1
%## are treated as if it were a "track" object.
%plot(tc1, dotCurve = TRUE)
%plot(qnorm(ppoints(20)), tc1)
%
%## defining methods for a special function.
%## Although "[" and "length" are not ordinary functions
%## methods can be defined for them.
%setMethod("[", "track",
%  function(x, i, j, ..., drop) {
%    x@x <- x@x[i]; x@y <- x@y[i]
%    x
%  })
%plot(t1[1:15])
%
%setMethod("length", "track", function(x)length(x@y))
%length(t1)
%
%## methods can be defined for missing arguments as well
%setGeneric("summary") ## make the function into a generic
%
%## A method for summary()
%## The method definition can include the arguments, but
%## if they're omitted, class "missing" is assumed.
%
%setMethod("summary", "missing", function() "<No Object>")
%
%\dontshow{
%
%stopifnot(identical(summary(), "<No Object>"))
%
%removeMethods("summary")
%
%## for the primitives
%## inherited methods
%
%length(tc1)
%tc1[-1]
%
%## make sure old-style methods still work.
%t11 <- t1[1:15]
%identical(t1@y[1:15], t11@y)
%
%## S3 methods, with nextMethod
%form <- y ~ x
%form[1]
%
%## S3 arithmetic methods
%ISOdate(1990, 12, 1)- ISOdate(1980, 12, 1)
%
%## group methods
%
%setMethod("Arith", c("track", "numeric"), function(e1, e2){e1@y <-
%  callGeneric(e1@y , e2); e1})
%
%
%t1  - 100.
%
%t1/2
%
%
%## check it hasn't screwed up S3 methods
%ISOdate(1990, 12, 1)- ISOdate(1980, 12, 1)
%
%## test the .Generic mechanism
%
%setMethod("Compare", signature("track", "track"),
%  function(e1,e2) {
%  switch(.Generic,
%   "==" = e1@y == e2@y,
%  NA)
% })
%
%#stopifnot(all(t1==t1))
%#stopifnot(identical(t1<t1, NA))
%
%
%## A test of nested calls to "[" with matrix-style arguments
%## applied to data.frames (S3 methods)
%
%setMethod("[", c("trackMultiCurve", "numeric", "numeric"), function(x, i, j, ..., drop) {
%### FIXME:  a better version has only 1st arg in signature
%### and uses callNextMethod, when this works with primitives.
%    x@y <- x@y[i, j, drop=FALSE]
%    x@x <- x@x[i]
%    x
%})
%
%
%"testFunc" <-
%function(cur) {
%    sorted <- cur[order(cur[,1]),]
%    sorted[ !is.na(sorted[,1]), ]
%}
%
%Nrow <- 1000 # at one time, values this large triggered a bug in gc/protect
%## the loop here was a trigger for the bug
%Niter <- 10
%for(i in 1:Niter)  {
%    yy <- matrix(stats::rnorm(10*Nrow), 10, Nrow)
%    tDF <- as.data.frame(yy)
%    testFunc(tDF)
%}
%
%
%tMC <- new("trackMultiCurve", x=seq_len(Nrow), y = yy)
%## not enough functions have methods for this class to use testFunc
%
%stopifnot(identical(tMC[1:10, 1:10]@y, yy[1:10, 1:10]))
%
%
%## verify we can remove methods and generic
%
%removeMethods("-")
%removeMethod("length", "track")
%removeMethods("Arith")
%removeMethods("Compare")
%
%## repeat the test one more time on the primitives
%
%length(ISOdate(1990, 12, 1)- ISOdate(1980, 12, 1))
%
%removeMethods("length")
%
%## methods for \%*\%, which isn't done by the same C code as other ops
%
%setClass("foo", representation(m="matrix"))
%m1 <- matrix(1:12,3,4)
%f1 = new("foo", m=m1)
%f2 = new("foo", m=t(m1))
%
%setMethod("\%*\%", c("foo", "foo"),
% function(x,y)callGeneric(x@m, y@m))
%
%stopifnot(identical(f1\%*\%f2, m1\%*\% t(m1)))
%
%removeMethods("\%*\%")
%
%removeMethods("plot")
%
%## Hold until removeMethods revised: stopifnot(existsFunction("plot", FALSE) && !isGeneric("plot", 1))
%
%## methods for plotData
%plotData <- function(x, y, ...) plot(x, y, ...)
%
%setGeneric("plotData")
%
%setMethod("plotData", signature(x="track", y="missing"),
%  function(x,  y, ...) plot(slot(x, "x"), slot(x, "y"), ...)
%)
%## and now remove the whole generic
%removeGeneric("plotData")
%
%stopifnot(!exists("plotData", 1))
%
%##  Tests of method inheritance & multiple dispatch
%setClass("A0", representation(a0 = "numeric"))
%
%setClass("A1", representation("A0", a1 = "character"))
%
%setClass("B0" ,representation(b0 = "numeric"))
%
%setClass("B1", "B0")
%
%setClass("B2", representation("B1", b2 = "logical"))
%
%setClass("AB0", representation("A1", "B2", ab0 = "matrix"))
%
%f1 <- function(x,  y)"ANY"
%
%setGeneric("f1")
%
%setMethod("f1", c("A0", "B1"), function(x, y)"A0 B1")
%setMethod("f1", c("B1", "A0"), function(x, y)"B1 A0")
%
%a0 <- new("A0")
%a1 <- new("A1")
%b0 <- new("B0")
%b1 <- new("B1")
%b2 <- new("B2")
%
%deparseText <- function(expr)
%    paste(deparse(expr), collapse = "\\  ")
%
%mustEqual <- function(e1, e2){
%    if(!identical(e1, e2))
%        stop(paste("!identical(", deparseText(substitute(e1)),
%                   ", ", deparseText(substitute(e2)), ")", sep=""))
%}
%
%mustEqual(f1(a0, b0), "ANY")
%mustEqual(f1(a1,b0), "ANY")
%mustEqual(f1(a1,b1), "A0 B1")
%mustEqual(f1(b1,a1), "B1 A0")
%mustEqual(f1(b1,b1), "ANY")
%
%## remove classes:  order matters so as not to undefine earlier classes
%for(.cl in c("AB0", "A1", "A0", "B2", "B1", "B0"))
%    removeClass(.cl)
%
%removeGeneric("f1")
%
%## test of nonstandard generic definition
%
%setGeneric("doubleAnything", function(x) {
%  methodValue <- standardGeneric("doubleAnything")
%  c(methodValue, methodValue)
%})
%
%setMethod("doubleAnything", "ANY", function(x)x)
%
%setMethod("doubleAnything", "character",
%function(x)paste("<",x,">",sep=""))
%
%mustEqual(doubleAnything(1:10), c(1:10, 1:10))
%mustEqual(doubleAnything("junk"), rep("<junk>",2))
%
%removeGeneric("doubleAnything")
%
%
%}
%}
%
%\seealso{
%
%\code{\link{method.skeleton}}, which is the recommended way to generate a skeleton of the call to \code{setMethod}, with the correct formal arguments and other details.
%
%\link{Methods} and the links there for a general discussion, \code{\link{dotsMethods}} for methods that dispatch on
%  \dQuote{\dots}, and \code{\link{setGeneric}} for generic functions.
%}
%
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%