% File src/library/methods/man/setOldClass.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{setOldClass}
%@%\alias{旧式スタイル(S3)のクラスと継承}
\alias{setOldClass}
\alias{.setOldIs}
\alias{POSIXct-class}
\alias{POSIXlt-class}
\alias{POSIXt-class}
\alias{aov-class}
\alias{maov-class}
\alias{anova-class}
\alias{anova.glm-class}
\alias{anova.glm.null-class}
\alias{Date-class}
\alias{data.frame-class}
\alias{data.frameRowLabels-class}
\alias{density-class}
\alias{dump.frames-class}
\alias{factor-class}
\alias{formula-class}
\alias{glm-class}
\alias{glm.null-class}
\alias{hsearch-class}
\alias{integrate-class}
\alias{libraryIQR-class}
\alias{lm-class}
\alias{logLik-class}
\alias{mlm-class}
\alias{mtable-class}
\alias{mts-class}
\alias{ordered-class}
\alias{packageIQR-class}
\alias{packageInfo-class}
\alias{recordedplot-class}
\alias{rle-class}
\alias{socket-class}
\alias{summaryDefault-class}
\alias{summary.table-class}
\alias{oldClass-class}
\alias{.OldClassesList}
\alias{table-class}
\alias{initialize,data.frame-method}
\alias{initialize,factor-method}
\alias{initialize,ordered-method}
\alias{initialize,table-method}
\alias{initialize,summary.table-method}
\title{旧式スタイル(S3)のクラスと継承}
%\title{Register Old-Style (S3) Classes and Inheritance}
\description{
  旧式(\sQuote{S3} としても知られる)のクラスを形式的に
  定義されたクラスとして登録する．
  \code{Classes} 引数は
  \code{class} 属性として使われる文字列ベクトル；
  特に，もし複数の文字列があれば，
  旧式のクラス継承が模倣される．
  \code{setOldClass} 経由の登録はメソッドシグネチャ中に
  S4 クラスのスロットか S4 クラスのスーパークラスとして
  S3 クラスが現れるのを可能にする．
}
\usage{
setOldClass(Classes, prototype, where, test = FALSE, S4Class)
}
\arguments{
  \item{Classes}{
    S3 クラスの名前を与える文字列ベクトルで，
    S3 計算中の
    \code{class} 属性の付値の右辺に登場するようなもの．

    もし S3 クラスがそのデータがその形式であることが必要とされることが
    知られていれば，
    S3 クラスに加えてオブジェクトタイプまたは
    他の適正なデータ部分を指定できる．
  }
\item{prototype}{
    プロトタイプとして使うオプションのオブジェクト．
    これはクラスに対する既定の S3 オブジェクトとして
    与えられるべきである．
    もし省略されると，S3 クラスを登録するために作られる
    S4 クラスは
    \code{VIRTUAL} である．詳細を見よ．
  }
  \item{where}{
    どこにクラス定義を保管するか，既定では大局的または
    トップレベルの環境．
    (パッケージに対するソース中のどれかの関数が
    呼び出される時，クラス定義は既定でパッケージの
    環境中に含まれる．)
  }
  \item{test}{フラグで，もし \code{TRUE} なら各オブジェクト
    に対する継承の明示的なテストを手配する，
    もし S3 クラスが同じ最初の文字列を持つ
    異なったクラス文字を持てるためには必要とされる．
    これは実装中の異なった機構で
    オプションの継承をもつクラスの各々の対に対して個別に
    指定されなければならない．
  }
  \item{S4Class}{
    オプションの S4 クラスクラス定義かクラス名．
    新しいクラスはこのクラスの全てのスロットと他の
    性質，プラス \code{Classses} 引数で定義されるような
    その S3 継承を持つ．
    引数 \code{prototype} と \code{test} はこの場合
    提供されてはならない．
    以下の\dQuote{既知の属性を持つ S3 クラス}節を見よ．
  }
}
\details{
  各々の名前は S4 クラスとして定義され，
  \code{Classes} 中の残りのクラス
  と全ての旧式のクラスの \sQuote{ルート}を拡張する．
  S3 クラスは形式的定義を持たず，
  従って形式的に定義されたスロットは無い．
  もし \code{setOldClass()} の呼び出し中に
  \code{prototype} 引数が与えられると，
  クラスからのオブジェクトが \code{\link{new}} の呼び出しにより
  生成できる；しかしながらこれは普通サブクラスからオブジェクトを
  生成する程は妥当ではない
  (下の S3 クラスの拡張に関する節を見よ)．
  もしプロトタイプが提供されないと，
  クラスは仮想的 S4 クラスとして作られる．
  主要な欠点はこのクラスをスロットとして使う S4 クラス中の
  プロトタイプオブジェクトは
  そのスロット中に \code{NULL} オブジェクトを持ち，
  これはある場合に混乱に導く可能性がある．

  バージョン 2.8.0 の \R から
  (登録された) S3 クラスを新しい S4 クラスの
  スーパークラスに使うためのサポートが提供された．
  下の S3 クラスの節と例を見よ．

  メソッドの選択適用と継承の詳細は \link{Methods} を見よ．

  ある種の S3 クラスは S4 クラスとスーパークラスの通常の
  組み合わせとして表現できない，なぜなら
  S3 クラスからのオブジェクトはクラス中の文字列の可変なセットを
  持つことができるからである．
  そうしたクラスを S4 クラスとして登録することは依然として
  可能であるが，しかし継承は今や各オブジェクトに対して
  検証されなければならず，
  各スーパークラスに対して一度 \code{setOldClass}
  を引数 \code{test=TRUE} で呼び出さなければならない．

  例えば，順序付き因子は
  \emph{常に} S3 クラス \code{c("ordered", "factor")}
  を持つ．これは適正な挙動であり，
  \code{"factor"} を \code{"ordered"} に拡張して
  単純に S4 クラスにマップする．

  しかしそのクラス属性が \code{"POSIXt"} を最初の文字列としてもつ
  オブジェクトは二番目の文字列として
  \code{"POSIXct"} または \code{"POSIXlt"} (またはどちらも)
  を持つかもしれない．この挙動は S4 クラス中にマップできるが，
  例えば \code{is(x, "POSIXlt")} を評価するために
  各オブジェクトに関して S3 クラス属性のチェックを
  必要とする．クラス定義中に明示的なテストが含められる．
  このテストを持つことは決してまずくはないが，
  しかしそれは継承クラスに対して定義されたメソッドに対して
  相当のオーバーヘッドを加えるので，
  もしオブジェクト固有のテストが必要であることが知られている
  時だけこの引数を与えるべきである．

  リスト \code{.OldClassesList} は methods パッケージにより
  定義された旧式のクラスを含む．
  このリストの各要素は文字列ベクトルで，
  もし継承が含まれれば複数の文字列を持つ．
  リストの各要素は
  \pkg{methods} パッケージを作る時 \code{setOldClass} に
  渡された；従って，これらのクラスは
  呼び出し \code{\link{setMethod}} 中で使うことが出来，
  リストが含意する継承を持つ．
}

\section{S3 クラスの拡張}{
  \code{setOldClass} の呼び出しは
  S3 クラスに対応する形式的クラスを作り，
  他のクラスのスロットとしてや
  \code{\link{setMethod}} 中のシグネチャ中に許され，
  S3 継承を模倣する．

  \R 中の S4 クラスの最初の実装に対するドキュメントでは
  ユーザは S3 クラスを含む S4 クラスの定義に対しては，
  これらが登録されていたとしても，警告された．
  警告は主に2つの点に基づいていた．
  1: オブジェクトの S3 挙動は S3 クラスが可視でないため
  失敗する，例えば S3 メソッドが選択適用された時．
  2: S3 クラスは形式的定義を持たないので，そうしたクラスからの
  オブジェクトの S3 部分については一般に
  何も保証されない．
  (警告は下の最初の参照まで繰り返される．)

  しかしながr，S3 クラスを含みそしてその挙動を拡張する
  S4 クラスを定義するのは多くの応用で魅力的である．
  形式的クラスとメソッド定義の柔軟さとセキュリティ無しに
  S3 プログラミングに忠実であることである．

  バージョン 2.8.0 から，\R は
  登録された S3 クラスの拡張に対するサポートを
  提供する；つまり，
  \code{contains=} 引数がその中に S3 クラスを含む
  \code{\link{setClass}} の呼び出しにより定義された
  新しいクラスに対して．サポートは第一に
  クラス \linkS4class{oldClass} を拡張する全てのクラス
  に対する S3 クラス情報を提供することを第一に
  目指している，特にそうしたクラスからの全てのオブジェクトが
  S3 クラスを特別なスロットに含むことを保証することで．

  既存の S3 クラスへの拡張を指示する三つの異なった方法がある：
  \code{setOldClass()}, \code{setClass()} そして
  \code{setIs()} である．殆どの場合，
  \code{setOldClass} の呼び出しが最良のアプローチであるが，
  下で説明されたような特別な状況では別の方法が好まれる
  かもしれない．

  \code{"A"} が
  \code{"oldClass"} を拡張する任意のクラスと仮定する．

  \code{setOldClass(c("B", "A"))}

  はその S3 クラスが \code{"B"} と \code{S3Class("A")} を連結する
  新しいクラス \code{"B"} を作る．
  新しいクラスは仮想的クラスである．
  もし \code{"A"} が既知の
  属性/スロットを使って定義されていないと，
  \code{"B"} はこれらのスロットも持つ；
  従って
  クラス \code{"B"} からの対応する S3 オブジェクトが
  実際に要求される属性を真に持つことを
  確信しなければならない．
  追加の属性を指定するために新しいクラスに S4
  定義を与えることが出来ることを注意する
  (次の節で解説されるように．)
  最初の別の呼び出しは非仮想的なクラスを呼び出す．

  \code{setClass("B", contains = "A")}

  これは
  クラス \code{"A"} と同じスロットとスーパークラスを持つ
  非仮想的なクラスを作る．しかしながら，クラス \code{"B"} は
  プロトタイプ中に明示的にそれを与えない限り，
  新しいクラスの S3 クラススロットには含まれない．

  \code{setClass("B"); setIs("B", "A", .....)}

  これは \code{"A"} を拡張する仮想的なクラスを作るが，
  \code{"A"} のスロットを含まない．
  \code{\link{setIs}} への追加の引数は強制変換と置き換えメソッドを
  提供すべきである．  新しいクラスが S3 メソッドを継承するためには，
  強制変換メソッドは
  作られたクラス \code{"A"} のオブジェクトが適当な
  S3 クラスを持つことを保証しなければならない．
  この三番目のアプローチを好む唯一のありそうな理由は
  \code{"B"} が
  クラス \code{"A"} 中の既知の属性と一貫性がないことである．

  バージョン 2.9.0 の \R 以来，
  S3 クラスを拡張するクラスからのオブジェクトは
  そのクラスに対して定義された S3 メソッドに渡される時
  対応する S3 クラスに変換される
  (つまり S3 クラス属性中の文字列の一つに対して)．
  これは通常の S3 オブジェクトに対して動作するならば，
  可能な限りそうしたメソッドが動作することを保証することを
  意図している．詳細は \code{\link{Classes}} を見よ．
}

\section{既知の属性を持つ S3 クラス}{
  S3 クラスの更なる特定を
  \emph{もし}クラスが既知のクラスのある属性を持つことが
  保証されれば行うことが出来る
  (スロットに関しては，
  \dQuote{既知}とは属性が指定されたクラスか，そのクラスのサブクラス
  であることを意味する)．

  この場合
  \code{setOldClass()} の呼び出しは既知の構造を表現する
  S4 クラス定義を提供できる．
  S4 スロットは属性として実装されている
  (主として単にこの理由のため)ため，既知の属性は
  S4 クラスの表現中に指定できる．
  通常のテクニックは希望の構造を持つ
  S4 クラスを作ることであり，
  それからクラス名か定義を \code{setOldClass()} への
  \code{S4Class} 引数として与えることである．

  下の例のクラス \code{"ts"} の定義を見よ．
  S4 クラスを作る
  \code{\link{setClass}} の呼び出しは，そこでのように，
  クラス定義が封印されていない限り，同じクラス名を
  使うことが出来る．
  この例では，\code{"ts"} は
  \code{"tsp"} に対する数値スロットを持つベクトル構造として定義した．
  この定義の妥当性は
  このクラスに対する全ての S3 コードが定義と一貫性があることに
  依存している；
  特に，全ての \code{"ts"} オブジェクトが
  ベクトル構造として挙動し数値
  \code{"tsp"} 属性を持つことである．
  我々は \R 中の全ての基本コードに対してこれが正しいと信じているが，
  S3 クラスに対しては常にそうであるように保証は出来ない．

  S4 クラス定義は
  S3 クラスがこれらと一貫性のある振る舞いをする
  ことが保証されれば(例では，時系列オブジェクトは
  \linkS4class{structure} クラスと一貫性があることが保証される)
  仮想的なスーパークラス(\code{"ts"} のケース中のように)
  を持つことが出来る．
  
  別の例では
  \code{"data.frame"} に対する S4 定義を探す．

  S3 クラスがその保証された行動とそぐわぬ失敗は
  普通訂正されない．
  S3 クラスは本来定義を持たず，結果の不正な S4 オブジェクトは
  あらゆる面倒を引き起こしかねないからである．
  属性の存在やクラスのいずれかが保証されないため，
  (例えば配列中の \code{dimnames}，これらは
  S3 クラスでさえ無いが)，またはクラスは属性よりも
  リストの名前付き成分を使うため
  (例えば \code{"lm"})，  多くの S3 クラスは既知のスロットの候補ではない．
  時として欠損する属性は，
  仮にそれがクラス \code{"NULL"} として存在するふりをしても，
  スロットとして表現できない．
  スロットでないような属性は値 \code{NULL} を持てないからである．.

  しかしながら，普通見逃される一つの例外は
  オプションで他の属性を存在が保証されている他の属性に
  付け加えることである
  (例えば \code{\link{model.frame}} が返す \code{"data.frame"}
  オブジェクト中の \code{"terms"})．
  バージョン 2.8.0 のように，
  \code{\link{validObject}} による正当性チェックは追加の属性を
  無視する；
  仮にこのチェックが将来厳格化されても，
  追加の属性は極めて普通なため，S3 クラスを拡張するクラスは
  恐らく免除されるであろう．
}

\seealso{
  \code{\link{setClass}}, \code{\link{setMethod}}
}

\references{
  Chambers, John M. (2008)
  \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して：メソッド選択については節
  10.6，そして総称的関数については節 13.4 を見よ)．

  Chambers, John M. (1998)
  \emph{Programming with Data}
  Springer (オリジナルの S4 バージョン．)
}

\examples{
require(stats)
setOldClass(c("mlm", "lm"))
setGeneric("dfResidual", function(model)standardGeneric("dfResidual"))
setMethod("dfResidual", "lm", function(model)model$df.residual)

## dfResidual は lm オブジェクトと同様に mlm オブジェクトにも使える
myData <- data.frame(time = 1:10, y = (1:10)^.5)
myLm <- lm(cbind(y, y^3)  ~ time, myData)

showClass("data.frame")# 予め定義された S4 "oldClass" を見る

## S3 クラス "lm" を拡張する二つの例．
## クラス "xlm" は直接に，そして "ylm" は間接的に
setClass("xlm", representation(eps = "numeric"), contains = "lm")
setClass("ylm", representation(header = "character"), contains = "xlm")
ym1 = new("ylm", myLm, header = "Example", eps = 0.)
## より多くの例は ?\link{S3Class} を見よ．

utils::str(.OldClassesList)

\dontshow{
stopifnot(identical(dfResidual(myLm), myLm$df.residual))
removeClass("ylm"); removeClass("xlm")
rm(myData, myLm)
removeGeneric("dfResidual")}

## ベクトルを持つ S3 クラスが保証された属性 "stamped" と
## "date" 属性を持つ S3 クラスの例．
## 以下は生成関数と S3 プリントメソッド
## 注意：生成関数が属性クラスをチェックするのが本質的である
stamped <- function(x, date = Sys.time()) {
    if(!inherits(date, "POSIXt"))
      stop("bad date argument")
    if(!is.vector(x))
      stop("x must be a vector")
    attr(x, "date") <- date
    class(x) <- "stamped"
    x
}

print.stamped <- function(x, ...) {
    print(as.vector(x))
    cat("Date: ",  format(attr(x,"date")), "\n")
}

## そして同じ属性を持つ S4 クラス：
setClass("stamped4", contains = "vector", representation(date = "POSIXt"))

## "stamped" を登録するために S4 クラスをその属性付きで使うことが出来る：
setOldClass("stamped", S4Class = "stamped4")
selectMethod("show", "stamped")
## そしてそれから "stamped4" を取り除く
removeClass("stamped4")
\dontshow{
set.seed(113)}
someLetters <- stamped(sample(letters, 10),
                       ISOdatetime(2008, 10, 15, 12, 0, 0))

st <- new("stamped", someLetters)
st
# show() メソッドはオブジェクトのクラスをプリントし，
# それから S3 プリントメソッドを呼び出す．

stopifnot(identical(S3Part(st, TRUE), someLetters))

# S4 オブジェクトをそのデータ部分とスロットから直接に作る
new("stamped", 1:10, date = ISOdatetime(1976, 5, 5, 15, 10, 0))

\dontrun{
## "ts" を S4 クラスとして定義する R 中のコード
setClass("ts", contains = "structure",
      representation(tsp = "numeric"),
      prototype(NA, tsp = rep(1,3)))
# プロトタイプは正規の S3 時系列
## そしてそれを S# クラスとして登録する
    setOldClass("ts", S4Class = "ts", where = envir)
}

\dontshow{
  removeClass("stamped")
  rm(someLetters, st)
}

}
\keyword{ programming }
\keyword{ methods }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/setOldClass.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{setOldClass}
%\alias{setOldClass}
%\alias{.setOldIs}
%\alias{POSIXct-class}
%\alias{POSIXlt-class}
%\alias{POSIXt-class}
%\alias{aov-class}
%\alias{maov-class}
%\alias{anova-class}
%\alias{anova.glm-class}
%\alias{anova.glm.null-class}
%\alias{Date-class}
%\alias{data.frame-class}
%\alias{data.frameRowLabels-class}
%\alias{density-class}
%\alias{dump.frames-class}
%\alias{factor-class}
%\alias{formula-class}
%\alias{glm-class}
%\alias{glm.null-class}
%\alias{hsearch-class}
%\alias{integrate-class}
%\alias{libraryIQR-class}
%\alias{lm-class}
%\alias{logLik-class}
%\alias{mlm-class}
%\alias{mtable-class}
%\alias{mts-class}
%\alias{ordered-class}
%\alias{packageIQR-class}
%\alias{packageInfo-class}
%\alias{recordedplot-class}
%\alias{rle-class}
%\alias{socket-class}
%\alias{summaryDefault-class}
%\alias{summary.table-class}
%\alias{oldClass-class}
%\alias{.OldClassesList}
%\alias{table-class}
%\alias{initialize,data.frame-method}
%\alias{initialize,factor-method}
%\alias{initialize,ordered-method}
%\alias{initialize,table-method}
%\alias{initialize,summary.table-method}
%\title{Register Old-Style (S3) Classes and Inheritance}
%\description{
%  Register an old-style (a.k.a. \sQuote{S3}) class as a formally defined
%  class. The \code{Classes} argument is the character vector used as the
%  \code{class} attribute; in particular, if there is more than one
%  string, old-style class inheritance is mimicked.  Registering via
%  \code{setOldClass} allows S3 classes to appear in method signatures,
%  as a slot in an S4 class, or as a superclass of an S4 class.
%}
%\usage{
%setOldClass(Classes, prototype, where, test = FALSE, S4Class)
%}
%\arguments{
%  \item{Classes}{
%    A character vector, giving the names for S3
%    classes, as they would appear on the right side of an assignment of
%    the \code{class} attribute in S3 computations.
%
%    In addition to S3 classes, an object type or other valid data part
%    can be specified, if the S3 class is known to require its data to
%    be of that form.
%  }
%\item{prototype}{
%    An optional object to use as the prototype.  This should be provided
%    as the default S3 object for the class.  If omitted, the S4 class
%    created to register the S3 class is \code{VIRTUAL}.  See the
%    details.
%  }
%  \item{where}{
%    Where to store the class definitions, the global or top-level
%    environment by default.  (When either function is called in the
%    source for a package, the class definitions will be included in the
%    package's environment by default.)
%  }
%  \item{test}{flag, if \code{TRUE}, arrange to test inheritance
%    explicitly for each object, needed if the S3 class can have a
%    different set of class strings, with the same first string.
%    This is a different mechanism in implementation and should be
%    specified separately for each pair of classes that have an
%    optional inheritance.  See the \sQuote{Details}.
%  }
%  \item{S4Class}{ optionally, the class definition or the class name
%    of an S4 class.  The new class will have all the slots and other
%    properties of this class, plus its S3 inheritance as defined by
%    the \code{Classses} argument.  Arguments \code{prototype} and
%    \code{test} must not be supplied in this case.  See the section
%    on \dQuote{S3 classes with known attributes} below.
%  }
%}
%\details{
%  Each of the names will be defined as an S4 class, extending the
%  remaining classes in \code{Classes}, and the class \code{oldClass},
%  which is the \sQuote{root} of all old-style classes. S3 classes have
%  no formal definition, and therefore no formally defined slots. If a
%  \code{prototype} argument is supplied in the call to
%  \code{setOldClass()}, objects from the class can be generated, by a
%  call to \code{\link{new}}; however, this usually not as relevant as
%  generating objects from subclasses (see the section on extending S3
%  classes below).   If  a prototype is not provided,
%   the class will be created as a virtual S4 class.
%  The main disadvantage is that the prototype object in an S4 class that
%  uses this class as a slot will have a \code{NULL} object in that slot,
%  which can sometimes lead to confusion.
%
%  Beginning with version 2.8.0 of \R, support is provided for using a
%  (registered) S3 class as a superclass of a new S4 class.  See the
%  section on extending S3 classes below, and the examples.
%
%  See \link{Methods} for the details of method dispatch and
%  inheritance.
%
%  Some S3 classes cannot be represented as an ordinary combination of S4
%  classes and superclasses, because objects from the S3 class can have a
%  variable set of strings in the class. It is still possible to register
%  such classes as S4 classes, but now the inheritance has to be verified
%  for each object, and you must call \code{setOldClass} with argument
%  \code{test=TRUE} once for each superclass.
%
%  For example, ordered factors \emph{always} have the S3
%  class \code{c("ordered", "factor")}.  This is proper behavior, and
%  maps simply into two S4 classes, with \code{"ordered"} extending
%  \code{"factor"}.
%
%  But objects whose class attribute has \code{"POSIXt"} as the first
%  string may have either (or neither) of \code{"POSIXct"} or
%  \code{"POSIXlt"} as the second string.  This behavior can be mapped
%  into S4 classes but now to evaluate \code{is(x, "POSIXlt")}, for
%  example, requires checking the S3 class attribute on each object.
%  Supplying the \code{test=TRUE} argument to \code{setOldClass} causes
%  an explicit test to be included in the class definitions.  It's
%  never wrong to have this test, but since it adds significant
%  overhead to methods defined for the inherited classes, you should
%  only supply this argument if it's known that object-specific tests
%  are needed.
%
%  The list \code{.OldClassesList} contains the old-style classes that
%  are defined by the methods package.  Each element of the list is a
%  character vector, with multiple strings if inheritance is included.
%  Each element of the list was passed to \code{setOldClass} when
%  creating the \pkg{methods} package; therefore, these classes can be used
%  in \code{\link{setMethod}} calls, with the inheritance as implied by
%  the list.
%}
%
%\section{Extending S3 classes}{
%  A call to \code{setOldClass} creates formal classes corresponding
%  to S3 classes, allows these to be used as slots in other classes or in
%  a signature in \code{\link{setMethod}}, and mimics the S3
%  inheritance.
%
%  In documentation for the initial implementation of S4 classes in \R,
%  users were warned against defining S4 classes that contained S3
%  classes, even if those had been registered.  The warning was based
%  mainly on two points.  1: The S3 behavior of the objects would fail
%  because the S3 class would not be visible, for example, when S3
%  methods are dispatched.  2: Because S3 classes have no formal
%  definition, nothing can be asserted in general about the S3 part of
%  an object from such a class.  (The warning was repeated as recently
%  as the first reference below.)
%
%  Nevertheless, defining S4 classes to contain an S3 class and extend
%  its behavior is attractive in many applications.  The alternative is
%  to be stuck with S3 programming, without the flexibility and security of
%  formal class and method definitions.
%
%  Beginning with version 2.8.0, \R provides support for extending
%  registered S3 classes; that is, for new classes defined by a call to
%  \code{\link{setClass}} in which the \code{contains=} argument
%  includes an S3 class.  See the examples below.  The support is aimed
%  primarily at providing the S3 class information for all classes that
%  extend class \linkS4class{oldClass}, in particular by ensuring that
%  all objects from such classes contain the S3 class in a special
%  slot.
%
%  There are three different ways to indicate an extension to an existing
%  S3 class:  \code{setOldClass()},  \code{setClass()} and
%  \code{setIs()}.  In most cases, calling \code{setOldClass} is the
%  best approach,  but the alternatives may be preferred in the special
%  circumstances described below.
%
%  Suppose \code{"A"} is any class extending \code{"oldClass"}. then
%
%  \code{setOldClass(c("B", "A"))}
%
%  creates a new class \code{"B"} whose S3 class
%  concatenates \code{"B"}  with \code{S3Class("A")}.  The new class is a
%  virtual class.  If \code{"A"} was defined with known attribute/slots,
%  then \code{"B"} has these slots also; therefore, you must believe that
%  the corresponding S3 objects from class \code{"B"} do indeed have the
%  claimed attributes.  Notice that you can supply an S4 definition for the
%  new class to specify additional attributes (as described in the next
%  section.)
%  The first alternative call produces a non-virtual class.
%
%  \code{setClass("B", contains = "A")}
%
%  This creates a non-virtual class with the same slots and superclasses
%  as class \code{"A"}.  However, class \code{"B"} is not included in
%  the S3 class slot of the new class, unless you provide it explicitly
%  in the prototype.
%
%  \code{setClass("B"); setIs("B", "A", .....)}
%
%  This creates a virtual class that extends \code{"A"}, but does not
%  contain the slots of \code{"A"}.  The additional arguments to
%  \code{\link{setIs}} should provide a coerce and replacement method.
%  In order for the new class to inherit S3 methods, the coerce method must
%  ensure that the class \code{"A"} object produced has a suitable S3
%  class.  The only likely reason to prefer this third approach is that
%  class \code{"B"} is not consistent with known attributes in class
%  \code{"A"}.
%
%  Beginning with version 2.9.0 of \R, objects from a class extending an
%  S3 class will be converted to the corresponding S3 class when being
%  passed to an S3 method defined for that class (that is, for one of the
%  strings in the S3 class attribute).  This is intended to ensure, as
%  far as possible, that such methods will work if they work for ordinary
%  S3 objects.  See \code{\link{Classes}} for details.
%}
%
%\section{S3 Classes with known attributes}{
%  A further specification of an S3 class can be made \emph{if} the
%  class is guaranteed to have some attributes of known class (where as
%  with slots, \dQuote{known} means that the attribute is an object of
%  a specified class, or a subclass of that class).
%
%  In this case, the call to \code{setOldClass()} can supply an S4 class
%  definition representing the known structure.  Since S4 slots are
%  implemented as attributes (largely for just this reason), the know
%  attributes can be specified in the representation of the S4 class.
%  The usual technique will be to create an S4 class with the desired
%  structure, and then supply the class name or definition as the
%  argument \code{S4Class} to \code{setOldClass()}.
%
%  See the definition of class \code{"ts"} in the examples below.  The
%  call to \code{\link{setClass}} to create the S4 class can use the same
%  class name, as here, so long as the class definition is not sealed.
%  In the example, we define \code{"ts"} as a vector structure with a
%  numeric slot for \code{"tsp"}.  The validity of this definition relies
%  on an assertion that all the S3 code for this class is consistent with
%  that definition; specifically, that all \code{"ts"} objects will
%  behave as vector structures and will have a numeric \code{"tsp"}
%  attribute. We believe this to be true of all the base code in \R, but
%  as always with S3 classes, no guarantee is possible.
%
%  The S4 class definition can  have virtual superclasses (as in
%  the \code{"ts"} case) if the S3 class is asserted to behave
%  consistently with these (in the example, time-series objects are
%  asserted to be consistent with the \linkS4class{structure} class).
%
%  For another example, look at the S4 class definition for \code{"data.frame"}.
%
%  Be warned that failures of the S3 class to live up to its asserted
%  behavior will usually go uncorrected, since S3 classes inherently
%  have no definition, and the resulting invalid S4 objects can cause
%  all sorts of grief.  Many S3 classes are not candidates for known
%  slots, either because the presence or class of the attributes are
%  not guaranteed  (e.g., \code{dimnames} in arrays, although these are
%  not even S3 classes), or because the class uses named components of
%  a list rather than attributes (e.g., \code{"lm"}).  An attribute
%  that is sometimes missing cannot be represented as a slot, not even
%  by pretending that it is present with class \code{"NULL"}, because
%  attributes unlike slots can not have value \code{NULL}.
%
%  One irregularity that is usually tolerated, however, is to optionally
%  add other attributes to those guaranteed to exist (for example,
%  \code{"terms"} in \code{"data.frame"} objects returned by
%  \code{\link{model.frame}}).  As of version 2.8.0, validity checks by
%  \code{\link{validObject}} ignore extra attributes; even if this check
%  is tightened in the future, classes extending S3 classes would likely
%  be exempted because extra attributes are so common.
%}
%
%\seealso{
%  \code{\link{setClass}}, \code{\link{setMethod}}
%}
%
%\references{
%  Chambers, John M. (2008)
%  \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version: see section 10.6 for method
%  selection and section 13.4 for generic functions).
%
%  Chambers, John M. (1998)
%  \emph{Programming with Data}
%  Springer (For the original S4 version.)
%}
%
%\examples{
%require(stats)
%setOldClass(c("mlm", "lm"))
%setGeneric("dfResidual", function(model)standardGeneric("dfResidual"))
%setMethod("dfResidual", "lm", function(model)model$df.residual)
%
%## dfResidual will work on mlm objects as well as lm objects
%myData <- data.frame(time = 1:10, y = (1:10)^.5)
%myLm <- lm(cbind(y, y^3)  ~ time, myData)
%
%showClass("data.frame")# to see the predefined S4 "oldClass"
%
%## two examples extending S3 class "lm", class "xlm" directly
%## and "ylm" indirectly
%setClass("xlm", representation(eps = "numeric"), contains = "lm")
%setClass("ylm", representation(header = "character"), contains = "xlm")
%ym1 = new("ylm", myLm, header = "Example", eps = 0.)
%## for more examples, see ?\link{S3Class}.
%
%utils::str(.OldClassesList)
%
%\dontshow{
%stopifnot(identical(dfResidual(myLm), myLm$df.residual))
%removeClass("ylm"); removeClass("xlm")
%rm(myData, myLm)
%removeGeneric("dfResidual")}
%
%## Examples of S3 classes with guaranteed attributes
%## an S3 class "stamped" with a vector and  a "date" attribute
%## Here is a generator function and an S3 print method.
%## NOTE:  it's essential that the generator checks the attribute classes
%stamped <- function(x, date = Sys.time()) {
%    if(!inherits(date, "POSIXt"))
%      stop("bad date argument")
%    if(!is.vector(x))
%      stop("x must be a vector")
%    attr(x, "date") <- date
%    class(x) <- "stamped"
%    x
%}
%
%print.stamped <- function(x, ...) {
%    print(as.vector(x))
%    cat("Date: ",  format(attr(x,"date")), "\n")
%}
%
%## Now, an S4 class with the same structure:
%setClass("stamped4", contains = "vector", representation(date = "POSIXt"))
%
%## We can use the S4 class to register "stamped", with its attributes:
%setOldClass("stamped", S4Class = "stamped4")
%selectMethod("show", "stamped")
%## and then remove "stamped4" to clean up
%removeClass("stamped4")
%\dontshow{
%set.seed(113)}
%someLetters <- stamped(sample(letters, 10),
%                       ISOdatetime(2008, 10, 15, 12, 0, 0))
%
%st <- new("stamped", someLetters)
%st
%# show() method prints the object's class, then calls the S3 print method.
%
%stopifnot(identical(S3Part(st, TRUE), someLetters))
%
%# creating the S4 object directly from its data part and slots
%new("stamped", 1:10, date = ISOdatetime(1976, 5, 5, 15, 10, 0))
%
%\dontrun{
%## The code in R that defines "ts" as an S4 class
%setClass("ts", contains = "structure",
%      representation(tsp = "numeric"),
%      prototype(NA, tsp = rep(1,3)))
%# prototype to be a legal S3 time-series
%## and now registers it as an S3 class
%    setOldClass("ts", S4Class = "ts", where = envir)
%}
%
%\dontshow{
%  removeClass("stamped")
%  rm(someLetters, st)
%}
%
%}
%\keyword{ programming }
%\keyword{ methods }
%
%\encoding{UTF8}
%