% File src/library/methods/man/show.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{show}
%@%\alias{オブジェクトの表示}
\alias{show}
\alias{show-methods}
\alias{show,ANY-method}
\alias{show,traceable-method}
\alias{show,ObjectsWithPackage-method}
\alias{show,MethodDefinition-method}
\alias{show,MethodWithNext-method}
\alias{show,genericFunction-method}
\alias{show,classRepresentation-method}
\title{オブジェクトを示すt}
%\title{Show an Object}
\description{
  オブジェクトをプリント，プロットまたはそのクラスに適合する
  何ででも表示する．
  この関数はメソッドにより特定化されるために存在する．
  既定メソッドは \code{\link{showDefault}} を呼び出す．

  \code{show} に対する形式的メソッドは普通
  自動プリント(詳細を見よ)のために起動される．
}
\usage{
show(object)
}
\arguments{
  \item{object}{任意の R オブジェクト}
}
\value{
  \code{show} は不可視の \code{NULL} を返す．
}
\details{
  S4 クラス(\code{\link{setClass}} の呼び出しで定義されたクラス)
  のオブジェクトは \code{show} の呼び出しで自動的に表示される．
  S3 オブジェクトの属性として生じた S4 オブジェクトも
  この形式で表示される；逆に，
  S4 オブジェクト中のスロットとして見つかった S3 オブジェクトは
  \code{\link{print}} の呼び出しによるかのように便宜的にプリントされる．

\code{show} に対して定義されたメソッドは単純な継承によってのみ
継承される，さもなければメソッドは完全なオリジナルのオブジェクトを
  受け取り，誤解を招く結果を生じるからである．
  一般的な概念については \code{\link{setGeneric}} への
  \code{simpleInheritanceOnly}
  引数と \code{\link{setIs}} 中の議論を見よ．

}
\seealso{
  \code{\link{showMethods}} は一つまたはそれ以上の関数に対する
  全てのメソッドをプリントする．
}
\examples{
## setMethod のドキュメント中で紹介された例に続く ...
setClass("track",
         representation(x="numeric", y="numeric"))
setClass("trackCurve",
         representation("track", smooth = "numeric"))

t1 <- new("track", x=1:20, y=(1:20)^2)

tc1 <- new("trackCurve", t1)

setMethod("show", "track",
  function(object)print(rbind(x = object@x, y=object@y))
)
## メソッドは今や t1 の自動プリントに使われる

t1

\dontrun{  [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12]
x    1    2    3    4    5    6    7    8    9    10    11    12
y    1    4    9   16   25   36   49   64   81   100   121   144
  [,13] [,14] [,15] [,16] [,17] [,18] [,19] [,20]
x    13    14    15    16    17    18    19    20
y   169   196   225   256   289   324   361   400
}
## そして "track" を拡張するクラスのオブジェクトである tc1 に対しても
tc1

\dontrun{  [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12]
x    1    2    3    4    5    6    7    8    9    10    11    12
y    1    4    9   16   25   36   49   64   81   100   121   144
  [,13] [,14] [,15] [,16] [,17] [,18] [,19] [,20]
x    13    14    15    16    17    18    19    20
y   169   196   225   256   289   324   361   400
}
}
\keyword{programming}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/show.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{show}
%\alias{show}
%\alias{show-methods}
%\alias{show,ANY-method}
%\alias{show,traceable-method}
%\alias{show,ObjectsWithPackage-method}
%\alias{show,MethodDefinition-method}
%\alias{show,MethodWithNext-method}
%\alias{show,genericFunction-method}
%\alias{show,classRepresentation-method}
%\title{Show an Object}
%\description{
%  Display the object, by printing, plotting or whatever suits its
%  class.  This function exists to be specialized by methods.  The
%  default method calls \code{\link{showDefault}}.
%
%  Formal methods for \code{show} will
%  usually be invoked for automatic printing (see the details).
%}
%\usage{
%show(object)
%}
%\arguments{
%  \item{object}{Any R object}
%}
%\value{
%  \code{show} returns an invisible \code{NULL}.
%}
%\details{
%  Objects from an S4 class (a class defined by a call to
%  \code{\link{setClass}}) will be displayed automatically is if by a
%  call to \code{show}.  S4 objects that occur as attributes of S3
%objects will also be displayed in this form; conversely, S3 objects
%encountered as slots in S4 objects will be printed using the S3
%convention, as if by a call to \code{\link{print}}.
%
%Methods defined for \code{show} will only be inherited  by simple
%inheritance, since otherwise the method would not receive the
%complete, original object, with misleading results.  See the
%\code{simpleInheritanceOnly} argument to \code{\link{setGeneric}} and
%the discussion in \code{\link{setIs}} for the general concept.
%
%}
%\seealso{
%  \code{\link{showMethods}} prints all the methods for one or more
%  functions.
%}
%\examples{
%## following the example shown in the setMethod documentation ...
%setClass("track",
%         representation(x="numeric", y="numeric"))
%setClass("trackCurve",
%         representation("track", smooth = "numeric"))
%
%t1 <- new("track", x=1:20, y=(1:20)^2)
%
%tc1 <- new("trackCurve", t1)
%
%setMethod("show", "track",
%  function(object)print(rbind(x = object@x, y=object@y))
%)
%## The method will now be used for automatic printing of t1
%
%t1
%
%\dontrun{  [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12]
%x    1    2    3    4    5    6    7    8    9    10    11    12
%y    1    4    9   16   25   36   49   64   81   100   121   144
%  [,13] [,14] [,15] [,16] [,17] [,18] [,19] [,20]
%x    13    14    15    16    17    18    19    20
%y   169   196   225   256   289   324   361   400
%}
%## and also for tc1, an object of a class that extends "track"
%tc1
%
%\dontrun{  [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12]
%x    1    2    3    4    5    6    7    8    9    10    11    12
%y    1    4    9   16   25   36   49   64   81   100   121   144
%  [,13] [,14] [,15] [,16] [,17] [,18] [,19] [,20]
%x    13    14    15    16    17    18    19    20
%y   169   196   225   256   289   324   361   400
%}
%}
%\keyword{programming}
%
%\encoding{UTF8}
%