% File src/library/methods/man/showMethods.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{showMethods}
%@%\alias{関数またはクラス中に対する全てのメソッド}
\alias{showMethods}
\alias{.S4methods}
\title{指定された関数またはクラス中に対する全てのメソッドを示す}
%\title{Show all the methods for the specified function(s) or class}
\description{
  一つまたはそれ以上の総称的関数に対する要約を表示する，
  可能性として指定されたクラスを含むものに限られる．
}
\usage{
showMethods(f = character(), where = topenv(parent.frame()),
            classes = NULL, includeDefs = FALSE,
            inherited = !includeDefs,
            showEmpty, printTo = stdout(), fdef)
.S4methods(generic.function, class)
}
\arguments{
  \item{f}{
    一つまたは複数の関数名．もし省略されると，
    他の引数にマッチする全ての関数が示される．

    引数は単一の総称的関数に評価される表現式であり得，
    この場合引数 \code{fdef} は無視される．
    関数に対する表現式の提供は
    隠匿されていたり匿名の関数の吟味を許す；
    \code{isDiagonal()} に対する例を見よ．}
  \item{where}{
    もし引数として与えられないと，どこで総称的関数を探すか．
    \code{f} が欠損しているか長さが 0 なら，
    これは又どの総称的関数を調べるかを決定する．
    もし \code{where} が与えられると，
    \code{getGenerics(where)} により返される総称的関数だけが
    プリントに好ましい．
    もし \code{where} も欠損していれば，
    全てのキャッシュされた総称的関数が考慮される．}
  \item{classes}{
    もし引数 \code{classes} が提供されると，これは
    表示結果をそのシグネチャが一つまたは複数のこれらのクラス
    を含むようなメソッドに限定するクラス名のベクトル．}
  \item{includeDefs}{
    もし \code{includeDefs} が \code{TRUE} ならば，
    プリントアウト中に個々のメソッドの定義を含める．}
  \item{inherited}{
    このセッション中に関する限り，継承により見つかっていれば
    メソッドを含め継承されているとマークされるかを指示する論理値．
    継承メソッドは普通それがこのセッション中で
    使われるまでは登場しない．
    どのメソッドが特定の引数のクラスに対して
    選択適用されるかを知りたければ \code{\link{selectMethod}}
    を見よ．}
  \item{showEmpty}{
    他の基準にマッチするメソッドが無いメソッドもともかく
    表示するかどうかを指示する論理値．
    既定では引数 \code{f} が欠損していない時そしてその時だけ
    \code{TRUE}．}
  \item{printTo}{それに対して情報が示されるコネクション；
    既定では標準出力に出力される．}
  \item{fdef}{オプションで，使用する総称的関数の定義；
    もし欠損していれば，指定されていれば
    \code{where} の中を探す．
    \sQuote{詳細}節中のコメントも見よ．}
  \item{generic.function, class}{\code{methods} を見よ．}
}
\details{
  \code{.S4methods} の記述に対しては \code{methods} を見よ．

  総称的関数の名前とパッケージは，
  様々な引数により決定される基準に従って，
  メソッドがそれに対して現在定義されている
  シグネチャのりストが続く．
  パッケージは総称的関数のソースを参照することを注意する．
  総称的関数に対する個々のメソッドは同様に他のパッケージに
  由来できる．

  指定されるか \code{f} が欠損しているため，複数の総称的関数が
  含まれるときは，関数が探され，引数 \code{fdef} としての総称的関数を含み，
  \code{showMethods} が各々に対して再呼び出しされる．
  複雑な状況では，これはある種の変則的な結果を
  避けることが出来る．
}
\value{
  もし \code{printTo} が \code{FALSE} ならば，プリントされるべき
  文字列が返される；さもなければ値は
  \code{\link{invisible}} を使ったコネクションかファイル名．
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\seealso{
  \code{\link{setMethod}}，メソッドを含む他のツールに対しては
  \code{\link{GenericFunctions}}；
  \code{\link{selectMethod}} は特定の関数と引数に対する
  クラスのシグネチャに対して選択適用されるメソッドを示す．

  \code{\link{methods}} は軽量の対話的使用に対するメソッド
  発見ツールを提供する．
}
\examples{
require(graphics)
\dontshow{
 setClass("track",
          representation(x="numeric", y="numeric"))
 ## 先ず引数として唯一つのオブジェクトを持つ：
 setMethod("plot", signature(x="track", y="missing"),
           function(x,  y, ...) plot(slot(x, "x"), slot(x, "y"), ...))
 ## 次に track からのデータを y 軸上に
 ## 任意の x データに対してプロット．
 setMethod("plot", signature(y = "track"),
           function(x, y, ...) plot(x, slot(y, "y"), ...))
 setMethod("plot", "track",
           function(x, y, ...) plot(slot(x, "y"), y,  ...))
}
## help(setMethod) の例の中でのように plot に対するメソッドを仮定する，
## クラス "track" を含むメソッドを(定義無し)プリント：
showMethods("plot", classes = "track")
\dontrun{
# 関数 "plot":
# x = ANY, y = track
# x = track, y = missing
# x = track, y = ANY

require("Matrix")
showMethods("\%*\%")# many!
    methods(class = "Matrix")# 何もない
showMethods(class = "Matrix")# 全て
showMethods(Matrix:::isDiagonal) # 移出されていない総称的関数
}%end{dontrun}

%% ロードされているが付加されていない名前空間からのメソッドを示す例
%% but not attached namespace.
if(no4 <- is.na(match("stats4", loadedNamespaces())))
   loadNamespace("stats4")
showMethods(classes = "mle") # -> show() に対するメソッド
if(no4) unloadNamespace("stats4")
}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/showMethods.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{showMethods}
%\alias{showMethods}
%\alias{.S4methods}
%\title{Show all the methods for the specified function(s) or class}
%\description{
%  Show a summary of the methods for one or more generic functions,
%  possibly restricted to those involving specified classes.
%}
%\usage{
%showMethods(f = character(), where = topenv(parent.frame()),
%            classes = NULL, includeDefs = FALSE,
%            inherited = !includeDefs,
%            showEmpty, printTo = stdout(), fdef)
%.S4methods(generic.function, class)
%}
%\arguments{
%  \item{f}{one or more function names.  If omitted, all functions
%    will be shown that match the other arguments.
%
%    The argument can also be an expression that evaluates to a single
%    generic function, in which
%    case argument \code{fdef} is ignored.  Providing an expression for
%    the function allows examination of hidden or anonymous functions;
%    see the example for \code{isDiagonal()}.}
%  \item{where}{Where to find the generic function, if not supplied as an
%    argument. When \code{f} is missing, or length 0, this also
%    determines which generic functions to examine.  If \code{where} is
%    supplied, only the generic functions returned by
%    \code{getGenerics(where)} are eligible for printing.  If
%    \code{where} is also missing, all the cached generic functions are
%    considered.}
%  \item{classes}{If argument \code{classes} is supplied, it is a vector
%    of class names that restricts the displayed results to those methods
%    whose signatures include one or more of those classes.}
%  \item{includeDefs}{If \code{includeDefs} is \code{TRUE}, include the
%    definitions of the individual methods in the printout.}
%  \item{inherited}{logical indicating if methods that have been found by
%    inheritance, so far in the session, will be included and marked as
%    inherited.  Note that an inherited method will not usually appear
%    until it has been used in this session.  See
%    \code{\link{selectMethod}} if you want to know what method would be
%    dispatched for particular classes of arguments.}
%  \item{showEmpty}{logical indicating whether methods with no defined
%    methods matching the other criteria should be shown at all.  By
%    default, \code{TRUE} if and only if argument \code{f} is not
%    missing.}
%  \item{printTo}{The connection on which the information will be
%    shown; by default, on standard output.}
%  \item{fdef}{Optionally, the generic function definition to use; if
%    missing, one is found, looking in \code{where} if that is specified.
%    See also comment in \sQuote{Details}.}
%  \item{generic.function, class}{See \code{methods}.}
%}
%\details{
%  See \code{methods} for a description of \code{.S4methods}.
%
%  The name and package of the generic are followed by the list of
%  signatures for which methods are currently defined, according to the
%  criteria determined by the various arguments.  Note that the package
%  refers to the source of the generic function.  Individual methods
%  for that generic can come from other packages as well.
%
%  When more than one generic function is involved, either as specified or
%  because \code{f} was missing, the functions are found and
%  \code{showMethods} is recalled for each, including the generic as the
%  argument \code{fdef}.  In complicated situations, this can avoid some
%  anomalous results.
%}
%\value{
%  If \code{printTo} is \code{FALSE}, the character vector that would
%  have been printed is returned; otherwise the value is the connection
%  or filename, via \code{\link{invisible}}.
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{
%  \code{\link{setMethod}}, and \code{\link{GenericFunctions}}
%  for other tools involving methods;
%  \code{\link{selectMethod}} will show you the method dispatched for a
%  particular function and signature of classes for the arguments.
%
%  \code{\link{methods}} provides method discovery tools for light-weight
%  interactive use.
%}
%\examples{
%require(graphics)
%\dontshow{
% setClass("track",
%          representation(x="numeric", y="numeric"))
% ## First, with only one object as argument:
% setMethod("plot", signature(x="track", y="missing"),
%           function(x,  y, ...) plot(slot(x, "x"), slot(x, "y"), ...))
% ## Second, plot the data from the track on the y-axis against anything
% ## as the x data.
% setMethod("plot", signature(y = "track"),
%           function(x, y, ...) plot(x, slot(y, "y"), ...))
% setMethod("plot", "track",
%           function(x, y, ...) plot(slot(x, "y"), y,  ...))
%}
%## Assuming the methods for plot
%## are set up as in the example of help(setMethod),
%## print (without definitions) the methods that involve class "track":
%showMethods("plot", classes = "track")
%\dontrun{
%# Function "plot":
%# x = ANY, y = track
%# x = track, y = missing
%# x = track, y = ANY
%
%require("Matrix")
%showMethods("\%*\%")# many!
%    methods(class = "Matrix")# nothing
%showMethods(class = "Matrix")# everything
%showMethods(Matrix:::isDiagonal) # a non-exported generic
%}%end{dontrun}
%
%%% An example of showing methods from a loaded,
%%% but not attached namespace.
%if(no4 <- is.na(match("stats4", loadedNamespaces())))
%   loadNamespace("stats4")
%showMethods(classes = "mle") # -> a method for show()
%if(no4) unloadNamespace("stats4")
%}
%\keyword{methods}
%
%\encoding{UTF8}
%