% File src/library/methods/man/slot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Copyright 2005-2010 The R Foundation
% Distributed under GPL 2 or later

\name{slot}
%@%\alias{slot}
\alias{slot}
\alias{.hasSlot}
\alias{slot<-}
\alias{slotNames}
\alias{.slotNames}
\alias{getSlots}
\title{形式的クラスからのオブジェクト中のスロット}
%\title{The Slots in an Object from a Formal Class}
\description{
  これらの関数はオブジェクト中の個別のスロットに関する
  情報を返すか設定する．
}
\usage{
\special{object@name}% @ really is in base.
\special{object@name <- value}% @<- really is in base.

slot(object, name)
slot(object, name, check = TRUE) <- value
.hasSlot(object, name)% not saying more; prefer is(), extends(), etc!

slotNames(x)
getSlots(x)
}
%% .slotNames(x)
%%
%% NOTA BENE: We shouldn't advertize .slotNames() --
%% - - - - -  rather  slotNames() should be changed {and getSlots() too}
%%   such that it doesn't special-case class representations!
%%
\arguments{
  \item{object}{形式的に定義されたクラスからのオブジェクト．}
  \item{name}{スロット名．演算子は固定された名前を取り，
    それは言語中の構文的な名前ならば引用化されていなくて良い．
    スロット名は任意の空でない文字列で良いが，
    もし名前が文字，数，そして
    \code{.} から成り立っていなければ，引用化
    (バックチックまたは一重・二重引用符で)される必要がある．

    \code{slot} 関数の場合，\code{name} はクラス定義中の任意の
    適正なスロットを評価する表現式で良い．一般的に，
    単純な演算子ではなくこの関数を使う唯一の理由は
    スロット名を計算しなければならない
    \emph{から}である．
  }
  \item{value}{名前付きスロットに対する新しい値．
    値はこのオブジェクトのクラスに対して適正でなければならない．}
  \item{check}{\code{slot} の置き換えバージョンではフラグ．
    もし \code{TRUE} なら，このスロットの値としての付値される
    値の適正さをチェックする．
    結果のオブジェクトが不正になり得るため，
    ユーザのコードはこれを
    \code{FALSE} に設定すべきではない．
  }
  \item{x}{クラスの名前
    (文字列として)かクラス定義．
    もし文字列でもなくクラス定義でもない引数が与えられると，
    \code{slotNames} (だけ)は代わりに \code{class(x)} を使う．}
}
\value{
  \code{"@"} 演算子と \code{slot} 関数はオブジェクトに対する
  形式的に定義されたスロットから取り出したり，
  置き換えたりする．

  関数 \code{slotNames} と \code{getSlots} はそれぞれ
  指定されたクラス定義中のスロットの名前と
  スロットに関連したクラスを返す．
  その \code{x} (上)の拡張された解釈を除けば，
  \code{slotNames(x)} は正に \code{names(getSlots(x))} である．
}
\details{
  クラス定義はそのクラスに対して定義されたスロットを
  直接的または間接的に指定する．
  各スロットは名前と関連するクラスを持つ．
  スロットの取り出しはそのクラスからのオブジェクトを返す．
  スロットの設定は先ず
  値を指定されたスロットに強制変換しそれからそれを保存する．

  一般的な属性とは異なり，スロットは特にマッチされず，
  スロットにそのクラスに対しては不正な名前を要求(または設定を試みると)
  するとエラーになる．

  \code{\link{@}} 抽出演算子と
  \code{slot} 関数自体はクラス定義に対してチェックをせず，
  単にオブジェクト自体中の名前をマッチする．
  置き換え形式はチェックを行う
  (\code{check=FALSE} の場合の \code{slot} を除く)．
  スロットがインチキ無しに設定されている限り，取り出された
  スロットは適正である．

  インチキをする二つの方法があることを注意する．
  しかしどちらも避けるべきであり保証はされない．
  自明な方法はスロットを
  \code{check=FALSE} で付値する．
  又 \R 中のスロットは，ある種の後方互換性のために，
  属性として実装されている．現在の実装は属性を
  \code{\link{attr<-}} を使って付値されることを妨げず，
  そうした付値はスロット名の適正さをチェックされない．

  取り出しと置き換えに対する \code{"@"} 演算子は
  プリミティブで実際は \pkg{base} パッケージ中に収まっている．

  \code{"@"} と \code{slot()} の置き換えバージョンは
  付値の右辺側をスロットの宣言されたクラスへの変換の
  計算で異なる．
  どちらも提供された値が宣言されたスロットクラスのサブクラス
  からのものかどうかを検証する．
  \code{slot()} バージョンはもしあれば強制変換メソッドの
  呼び出しに移り，実際には計算
  \code{as(value, slotClass, strict = FALSE)} を行う．
  \code{"@"} バージョンは関係を検証し，
  任意の強制変換の実行を後に残す
  (例えば，関連するメソッドが選択適用される時)．

  殆どの使用で結果は同値であり，
  \code{"@"} バージョンは追加の関数呼びしを保存するが，
  経験的な証拠が変換が必要なことを示すと，
  置き換え前に \code{as()} を呼び出すか
  \code{slot()} の置き換えバージョンを使う．
}
\references{
 Chambers, John M. (2008)
 \emph{Software for Data Analysis: Programming with R}
  Springer.  (R バージョンに対して．)

 Chambers, John M. (1998)
 \emph{Programming with Data}
 Springer (オリジナルの S4 バージョンに対して．)
}
\seealso{
  \code{\link{@}},
  \code{\link{Classes}},
  \code{\link{Methods}},
  \code{\link{getClass}},
  \code{\link{names}}.
}
\examples{
\dontshow{if(isClass("track")) removeClass("track")}

setClass("track", representation(x="numeric", y="numeric"))
myTrack <- new("track", x = -4:4, y = exp(-4:4))
slot(myTrack, "x")
slot(myTrack, "y") <- log(slot(myTrack, "y"))
utils::str(myTrack)

getSlots("track") # または
getSlots(getClass("track"))
slotNames(class(myTrack)) # 次と同じ
slotNames(myTrack)

\dontshow{removeClass("track")##  必要であるべきではない... setClass.Rd を見よ}
}
\keyword{programming}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/slot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Copyright 2005-2010 The R Foundation
%% Distributed under GPL 2 or later
%
%\name{slot}
%\alias{slot}
%\alias{.hasSlot}
%\alias{slot<-}
%\alias{slotNames}
%\alias{.slotNames}
%\alias{getSlots}
%\title{The Slots in an Object from a Formal Class}
%\description{
%  These functions return or set information about the individual slots
%  in an object.
%}
%\usage{
%\special{object@name}% @ really is in base.
%\special{object@name <- value}% @<- really is in base.
%
%slot(object, name)
%slot(object, name, check = TRUE) <- value
%.hasSlot(object, name)% not saying more; prefer is(), extends(), etc!
%
%slotNames(x)
%getSlots(x)
%}
%%% .slotNames(x)
%%%
%%% NOTA BENE: We shouldn't advertize .slotNames() --
%%% - - - - -  rather  slotNames() should be changed {and getSlots() too}
%%%   such that it doesn't special-case class representations!
%%%
%\arguments{
%  \item{object}{An object from a formally defined class.}
%  \item{name}{The name of the slot. The operator
%    takes a fixed name, which can be unquoted if it is syntactically a
%    name in the language.  A slot name can be any non-empty string, but
%    if the name is not made up of letters, numbers, and \code{.}, it
%    needs to be quoted (by backticks or single or double quotes).
%
%    In the case of the \code{slot} function, \code{name} can be any
%    expression that evaluates to a valid slot in the class definition.
%    Generally, the only reason to use the functional form rather than
%    the simpler operator is \emph{because} the slot name has to be computed.
%  }
%  \item{value}{A new value for the named slot.  The value must be
%    valid for this slot in this object's class.}
%  \item{check}{In the replacement version of \code{slot}, a flag.  If
%    \code{TRUE}, check the assigned value for validity
%    as the value of this slot.  User's coded should not set this to
%    \code{FALSE} in normal use, since the resulting object can be invalid.
%  }
%  \item{x}{either the name of a class (as character string), or a class
%    definition.  If given an argument that is neither a character string
%    nor a class definition, \code{slotNames} (only) uses \code{class(x)}
%    instead.}
%}
%\value{
%  The \code{"@"} operator and the \code{slot} function extract or
%  replace the formally defined slots for the object.
%
%  Functions \code{slotNames} and \code{getSlots} return respectively the
%  names of the slots and the classes associated with the slots in the
%  specified class definition.  Except for its extended interpretation of
%  \code{x} (above), \code{slotNames(x)} is just \code{names(getSlots(x))}.
%}
%\details{
%  The definition of the class specifies all slots directly and
%  indirectly defined for that class.  Each slot has a name and an
%  associated class.  Extracting a slot returns an object from that
%  class.  Setting a slot first coerces the value to the specified slot
%  and then stores it.
%
%  Unlike general attributes, slots are not partially matched, and asking
%  for (or trying to set) a slot with an invalid name for that class
%  generates an error.
%
%  The \code{\link{@}} extraction operator and \code{slot}
%  function themselves do no checking against the class definition,
%  simply matching the name in the object itself.
%  The replacement forms do check (except for \code{slot} in the case
%  \code{check=FALSE}).  So long as slots are set without cheating, the
%  extracted slots will be valid.
%
%  Be aware that there are two ways to cheat, both to be avoided but
%  with no guarantees.  The obvious way is to assign a slot with
%  \code{check=FALSE}.  Also, slots in \R are implemented as
%  attributes, for the sake of some back compatibility.  The current
%  implementation does not prevent attributes being assigned, via
%  \code{\link{attr<-}}, and such assignments are not checked for
%  legitimate slot names.
%
%  Note that the \code{"@"} operators for extraction and replacement are
%  primitive and actually reside in the \pkg{base} package.
%
%  The replacement versions of  \code{"@"} and \code{slot()} differ in
%  the computations done to coerce the right side of the assignment to
%  the declared class of the slot.  Both verify that the value provided
%  is from a subclass of the declared slot class.  The  \code{slot()}
%  version will go on to call the coerce method if there is one, in
%  effect doing the computation \code{as(value, slotClass, strict =
%    FALSE)}. The  \code{"@"} version just verifies the relation,
%  leaving any coerce to be done later (e.g., when a relevant method is
%  dispatched).
%
%  In most uses the result is equivalent, and the  \code{"@"} version
%  saves an extra function call, but if empirical evidence shows that a
%  conversion is needed, either call \code{as()} before the replacement
%  or use the replacement version of \code{slot()}.
%}
%\references{
% Chambers, John M. (2008)
% \emph{Software for Data Analysis: Programming with R}
%  Springer.  (For the R version.)
%
% Chambers, John M. (1998)
% \emph{Programming with Data}
% Springer (For the original S4 version.)
%}
%\seealso{
%  \code{\link{@}},
%  \code{\link{Classes}},
%  \code{\link{Methods}},
%  \code{\link{getClass}},
%  \code{\link{names}}.
%}
%\examples{
%\dontshow{if(isClass("track")) removeClass("track")}
%
%setClass("track", representation(x="numeric", y="numeric"))
%myTrack <- new("track", x = -4:4, y = exp(-4:4))
%slot(myTrack, "x")
%slot(myTrack, "y") <- log(slot(myTrack, "y"))
%utils::str(myTrack)
%
%getSlots("track") # or
%getSlots(getClass("track"))
%slotNames(class(myTrack)) # is the same as
%slotNames(myTrack)
%
%\dontshow{removeClass("track")##  should not be needed... see ./setClass.Rd}
%}
%\keyword{programming}
%\keyword{classes}
%
%\encoding{UTF8}
%