% File src/library/methods/man/stdRefClass.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2010-2014 R Core Team
% Distributed under GPL 2 or later

\name{envRefClass-class}
\Rdversion{1.1}
\docType{class}
%@%\alias{クラス "envRefClass"}
\alias{envRefClass-class}
\alias{$,envRefClass-method}
\alias{$<-,envRefClass-method}
\alias{initialize,envRefClass-method}

\title{クラス \code{"envRefClass"}}
%\title{Class \code{"envRefClass"}}
\description{
参照セマンティクスを用いて R オブジェクトを実装するクラスをサポートする
}
\section{注意：}{
ここで解説されるソフトウェアは初期バージョンである．
最終ゴールは \R 自体か内部システムインタフェイスを使い
参照スタイルのクラスをサポートすることである．
現在の実装
(\R バージョン 2.12.0)は予備的であり変更の可能性があり，
現在 \R だけの実装のみを含む．
開発者はこのソフトウェアを使って実験することを推奨されるが，
ここでの記述は普通以上に変更の可能性がある．
}
\section{クラスの目的}{
このクラスは
\R{} オブジェクトに対する基本的参照スタイルを実装する．
オブジェクトは通常直接的にはこのクラスには由来せず，
\code{\link{setRefClass}} の呼び出しにより定義されるサブクラスに
由来する．下のドキュメントは実装を解説する技術的背景であるが，
アプリケーションは
\code{\link{setRefClass}} の下で解説されたインタフェイス
，特にここで解説された \code{$} 演算子と欄へのアクセス関数，
を使うべきである．
}

\section{基本的な参照クラス}{
\R{} に対する参照クラスのデザインはこれらのクラスを
参照，欄，そしてクラスメソッドの実装に対する機構に
従って分割する．この機構の各バージョンは
\emph{基本参照クラス}により定義されており，
これはメソッドのセットと
\code{\link{setRefClass}} により使われるある更なる情報
を提供しなければならない．

必要とされるメソッドは
オブジェクト中の欄を取得し設定する演算子 \code{$} と \code{$<-}，
そしてオブジェクトを初期化する
\code{\link{initialize}} に対するものである．

これらのメソッドをサポートするために，
基本的な参照クラスはデータをオブジェクト中の欄に保管し回収する
ある実装機構を持つ必要がある．
この機構は参照のセマンティクスと一貫性がある必要がある；
つまり，あるオブジェクトの中身に行われた変更は大局的で，
変更が行われた関数呼び出しに対して局所的ではなく，
そのオブジェクトにアクセスする全てのコードから見えなければならない．
下で説明されるように，クラス \code{envRefClass} は
\linkS4class{environment} オブジェクトの特殊な使用を用いて
参照セマンティクスを実装する．
他の基本的な参照クラスはクラスに対する参照セマンティクスを用いて
Java や C++ の様な言語へのインタフェイスを使うかもしれない．

普通 \R ユーザは
\code{$} 演算子を使いクラスにクラスメソッドを起動できる．
\code{$} に対する基本的な参照クラスはこれが可能になるようにする
必要がある．本質的に，演算子はオブジェクトとクラスメソッド名に
対応する \R 関数を返さなければならない．

クラスメソッドは
欄が \dQuote{get} と \dQuote{set} メソッドでアクセスできるという
意味でデータ抽象化の実装を含むかもしれない．
基本的な参照クラスはこの機能を 引数一つの関数に対する
その定義中のスロット \code{"fieldAccessorGenerator"} を
設定することで提供する．
この関数は欄名のベクトルを引数とすることで
\code{\link{setRefClass}} により呼び出される．
生成関数は定義されたアクセス関数のリストを返さなければならない．
取得演算に対応する要素は引数無しで起動され
対応する欄を取り出すべきである；
設定演算は欄に付値される値である引数一つで起動される．
実装はそれがメソッド起動の引数ではないためオブジェクトを
提供する必要がある．
現在 \code{envRefClass} が使う機構は下で解説される．
}
\section{サポートクラス}{
二つの仮想的クラスが参照クラスのテストのために提供される：
\code{is(x, "refClass")} は
\code{x} がここで解説された参照クラス機構を使い定義された
クラスに由来するかどうかをテストする；
\code{is(x, "refObject")} はオブジェクトが，
先のクラスとまた \code{"environment"} の様な参照セマンティクス
を持つ \R タイプを継承するクラスを含み，
一般的参照セマンティクスを持つかどうかをテストする．

インストールされるクラスメソッドは
\code{"classMethodDefinition"} オブジェクトで，
クラスメソッドとしての関数名と
このメソッドから呼び出される他のクラスメソッドを特定する．
後者の情報は
クラスが \code{codetools} 推奨パッケージを使うことで
定義された時にヒューリスティックに決定される．
このパッケージは参照クラスが定義される時にインストール
されるべきであるが，
既存の参照クラスを使うためには不要である．
}

\author{
John Chambers
}
\keyword{classes}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/stdRefClass.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2010-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{envRefClass-class}
%\Rdversion{1.1}
%\docType{class}
%\alias{envRefClass-class}
%\alias{$,envRefClass-method}
%\alias{$<-,envRefClass-method}
%\alias{initialize,envRefClass-method}
%
%\title{Class \code{"envRefClass"}}
%\description{
%Support Class to Implement R Objects using Reference Semantics
%}
%\section{NOTE:}{
%The software described here is an initial version.  The eventual goal
%is to support reference-style classes with software in \R itself
%or using inter-system interfaces.  The current implementation (\R
%version 2.12.0) is preliminary and subject to change, and currently
%includes only the \R-only implementation.  Developers are encouraged
%to experiment with the software, but the description here is more than
%usually subject to change.
%}
%\section{Purpose of the Class}{
%This class implements basic reference-style semantics for \R{}
%objects.  Objects normally do not come directly from this class, but
%from subclasses defined by a call to \code{\link{setRefClass}}.
%The documentation below is technical background describing the implementation, but applications
%should use the interface documented under \code{\link{setRefClass}},
%in particular the \code{$} operator and field accessor functions as
%described there.
%}
%
%\section{A Basic Reference Class}{
%The design of reference classes for \R{} divides those classes up
%according to the mechanism used for implementing references, fields,
%and class methods.
%Each version of this mechanism is defined by a \emph{basic reference
%  class}, which must implement a set of methods and provide some
%further information used by \code{\link{setRefClass}}.
%
%The required methods are for operators \code{$} and \code{$<-} to
%get and set a field in an object, and for \code{\link{initialize}} to
%initialize objects.
%
%To support these methods, the basic reference class needs to have some
%implementation mechanism to store and retrieve data from fields in the
%object.
%The mechanism needs to be consistent with reference semantics; that
%is, changes made to the contents of an object are global, seen by any
%code accessing that object, rather than only local to the function
%call where the change takes place.
%As described below, class \code{envRefClass} implements reference
%semantics through specialized use of \linkS4class{environment}
%objects.
%Other basic reference classes may use an interface to a language such
%as Java or C++ using reference semantics for classes.
%
%Usually, the \R  user will be able to invoke class methods on the
%class, using the \code{$} operator.  The basic reference class
%method for \code{$} needs to make this possible.  Essentially, the
%operator must return an \R function corresponding to the object and
%the class method name.
%
%Class methods may include an implementation of data abstraction, in
%the sense that fields are accessed by \dQuote{get} and \dQuote{set}
%methods.  The basic reference class provides this facility by setting
%the \code{"fieldAccessorGenerator"} slot in its definition to a
%function of one variable.
%This function will be called by \code{\link{setRefClass}} with the
%vector of field names as arguments.
%The generator function must return a list of defined accessor
%functions.
%An element corresponding to a get operation is invoked with no
%arguments and should extract the corresponding field; an element for a
%set operation will be invoked with a single argument, the value to be
%assigned to the field.
%The implementation needs to supply the object, since that is not an
%argument in the method invocation.
%The mechanism used currently by \code{envRefClass} is described below.
%}
%\section{Support Classes}{
%Two virtual classes are supplied to test for reference objects:
%\code{is(x, "refClass")} tests whether \code{x} comes from a class
%defined using the reference class mechanism described here;
%\code{is(x, "refObject")} tests whether the object has reference
%semantics generally, including the previous classes and also classes
%inheriting from the \R types with reference semantics, such as
%\code{"environment"}.
%
%Installed class methods are \code{"classMethodDefinition"} objects,
%with slots that identify the name of the function as a class method
%and the other class methods called from this method.
%The latter information is determined heuristically when the class is
%defined by using the \code{codetools} recommended package.  This
%package must be installed when reference classes are defined, but is
%not needed in order to use existing reference classes.
%}
%
%\author{
%John Chambers
%}
%\keyword{classes}
%
%\encoding{UTF8}
%