% File src/library/methods/man/testInheritedMethods.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-2015 R Core Team
% Distributed under GPL 2 or later

\name{testInheritedMethods}
%@%\alias{継承メソッドの選択をテスト，報告}
\alias{testInheritedMethods}
\alias{MethodSelectionReport-class}
\alias{.Other-class}
\title{継承メソッドの選択をテスト，報告する}
%\title{Test for and Report about  Selection of Inherited Methods}
\description{
  異なった継承シグネチャのセットが
  指定された総称的関数の全てのメソッドに対する継承を
  テストするために生成される．
  もしメソッド選択がこれらのどれかに対して曖昧ならば，
  返されるオブジェクトに曖昧さの要約が付け加えられる．
  このテストはパッケージをリリースする\emph{前に}パッケージ作者により
  実行されるべきである．
}
\usage{
testInheritedMethods(f, signatures, test = TRUE, virtual = FALSE,
                     groupMethods = TRUE, where = .GlobalEnv)
}
\arguments{
  \item{f}{
    総称的関数またはそれの文字列名．
    既定ではこの総称的関数に対する全てのメソッドシグネチャの
    現在定義されている全てのサブクラスが調べられる．
    他の引数は主にどのような継承パターンが調べられるかを修正する
    オプションである．
  }
  \item{signatures}{
    \code{testInheritedMethods} により計算される関連サブクラスの代わりに使う
    サブクラスシグネチャのオプションのセット．
    これがどのようになされるかについては詳細を見よ．
    この引数は選択をバッチでテストするために
    \code{test = FALSE} を使った呼び出しの後に提供されるかもしれない．
  }
  \item{test}{
    メソッド選択を実際にテストするかどうかを
    制御するオプションのフラグ．
    もし \code{FALSE} ならば
    各シグネチャに対して \code{\link{selectMethod}} を呼び出すこと無しに
    サブクラスに対する関連シグネチャのりストを単に返す．
    もし非常に沢山のシグネチャがあれば，
    完全なリストを集めそれからバッチでそれらをテストしたくなるかもしれない．
  }
  \item{virtual}{
    関連サブクラスの中に仮想的クラスを含めるべきか．
    実際の引数のクラスだけが
    総称的関数の呼び出し中で継承の計算を惹き起こすので，
    普通はしない．
    仮想的クラスを含めることは，
    もしクラスが現在非仮想的なサブクラスを持たないが
    ユーザが将来そうしたクラスを定義するかもしれないと
    予想するのならば，有用かもしれない．
}
  \item{groupMethods}{
    グループ総称的関数に対するメソッドも含めるべきか?
  }
  \item{where}{
    クラス定義をその中で探す環境．
    ほとんど常に，
    関連するメソッド と/または クラス定義をもつ全ての
    パッケージを付加した後に既定の大局的環境を使おう．
  }
}
\details{
  以下の解説は普通のケースであるオプション引数が省略された場合に
  適用される．先ず全てのメソッドに対するシグネチャの定義は
  \code{\link{findMethodSignatures}} の呼び出しで計算される．
  これらから全ての既知の非仮想的サブクラスが
  あるメソッドのシグネチャ中に現れる各クラスに対して見つけられる．
  これらのサブクラスはそれらがどのクラスを継承するかに
  従ってグループに分割され，
  そして各グループからただ一つのサブクラスが保持される
  (総称的関数のシグネチャ中の各引数にたいして)．
  従ってもしメソッドが
  ある引数に対するクラス \code{"vector"} を用いて定義されていると，
  一つの実際のベクトルクラスが任意に選択される．
  \code{"ANY"} のケースは全てのクラスがそれを拡張するため
  特別に扱われる．非仮想的クラスであるダミーの \code{".Other"} は
  テストされるもののうちスーパークラスを
  持たない全てのクラスに対応する．

  総称的関数のシグネチャ中の引数に対して保持されたサブクラスの
  全ての組み合わせがそれから計算される．
  結果の行列の各行は
  \code{\link{selectMethod}} の呼び出しによりテストされる
  シグネチャである．曖昧な選択に関する情報を収集するため，
  \code{testInheritedMethods} は
  特別なシグナル \code{"ambiguousMethodSelection"} に対する呼び出し
  ハンドラーを，対応するオプションを設定することで，確立する．
}
\value{
  クラス \code{"methodSelectionReport"} のオブジェクト．
  このクラスの詳細は現在変更の可能性がある．
  これはスロット \code{"target"}, \code{"selected"}, \code{"candidates"}
  そして \code{"note"} を持ち，全ては曖昧なケースを参照する
  (そしてもし何もなければ長さは 0 である)．
  これらのスロットはプログラマにより検出と
  できれば曖昧なメソッド選択をフィックスすることが
  意図されている．
  オブジェクトは更に総称的関数名であるスロットと，
  そしてテストされる全てに対するラベルのベクトルを与える
  \code{"allSelections"} を含む．
}
\references{
  Chambers, John M. (2008)
  \emph{Software for Data Analysis: Programming with R}
  Springer.  (メソッド選択の基本については節10.6．)

  Chambers, John M. (2009)
  \emph{Class Inheritance in R}
  \url{https://statweb.stanford.edu/~jmc4/classInheritance.pdf}.
}
\examples{
## もし他の付加されたパッケージが
## `+` またはそのグループ総称的関数に対するメソッドを持たなければ，
## これは選択パターンの 16 x 2 行列を返す(R 2.9.0 では)
testInheritedMethods("+")
}

\keyword{programming}
\keyword{classes}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/methods/man/testInheritedMethods.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{testInheritedMethods}
%\alias{testInheritedMethods}
%\alias{MethodSelectionReport-class}
%\alias{.Other-class}
%\title{
%Test for and Report about  Selection of Inherited Methods
%}
%\description{
%  A set of distinct inherited signatures is generated to test
%  inheritance for all the methods of a specified generic function.  If
%  method selection is ambiguous for some of these, a summary of the
%  ambiguities is attached to the returned object.  This test should be
%  performed by package authors \emph{before} releasing a package.
%}
%\usage{
%testInheritedMethods(f, signatures, test = TRUE, virtual = FALSE,
%                     groupMethods = TRUE, where = .GlobalEnv)
%}
%\arguments{
%  \item{f}{a generic function or the character string name of one.  By default,
%    all currently defined subclasses of all the method signatures for this
%    generic will be examined.  The other arguments are mainly options to
%    modify which inheritance patterns will be examined.
%  }
%  \item{signatures}{
%    An optional set of subclass signatures to use instead of the relevant
%    subclasses computed by \code{testInheritedMethods}.  See the Details
%    for how this is done.  This argument might be supplied after a call
%    with \code{test = FALSE}, to test selection in batches.
%  }
%  \item{test}{
%    optional flag to control whether method selection is actually tested.
%    If \code{FALSE}, returns just the list of relevant signatures for
%    subclasses, without calling \code{\link{selectMethod}} for each signature.
%    If there are a very large number of signatures, you may want to collect the full list  and then test them in batches.
%  }
%  \item{virtual}{
%    should virtual classes be included in the relevant subclasses.
%    Normally not, since only the classes of actual arguments will trigger
%    the inheritance calculation in a call to the generic function.
%    Including virtual classes may be useful if the class has no current
%    non-virtual subclasses but you anticipate your users may define such
%    classes in the future.
%}
%  \item{groupMethods}{
%    should methods for the group generic function be included?
%  }
%  \item{where}{
%    the environment in which to look for class definitions.  Nearly
%    always, use the default global environment after attaching all the
%    packages with relevant methods and/or class definitions.
%  }
%}
%\details{
%  The following description applies when the optional arguments are
%  omitted, the usual case.
%  First, the defining signatures for all methods are computed by calls
%  to \code{\link{findMethodSignatures}}.
%  From these all the known non-virtual subclasses are found for each
%  class that appears in the signature of some method.
%  These subclasses are split into groups according to which class they
%  inherit from, and only one subclass from each group is retained (for
%  each argument in the generic signature).
%  So if a method was defined with class \code{"vector"} for some
%  argument, one actual vector class is chosen arbitrarily.
%  The case of \code{"ANY"} is dealt with specially, since all classes
%  extend it.  A dummy, nonvirtual class, \code{".Other"}, is used to
%  correspond to all classes that have no superclasses among those being
%  tested.
%
%  All combinations of retained subclasses for the
%  arguments in the generic signature are then computed.
%  Each row of the resulting matrix is a signature to be tested by a call
%  to \code{\link{selectMethod}}.
%  To collect information on ambiguous selections,
%  \code{testInheritedMethods} establishes a calling handler for the
%  special signal \code{"ambiguousMethodSelection"}, by setting the
%  corresponding option.
%}
%\value{
%  An object of class \code{"methodSelectionReport"}.  The details of
%  this class are currently subject to change.  It has slots
%  \code{"target"}, \code{"selected"}, \code{"candidates"}, and
%  \code{"note"}, all referring to the ambiguous cases (and so of length
%  0 if there were none).  These slots are intended to be examined by the
%  programmer to detect and preferably fix ambiguous method selections.
%  The object contains in addition slots \code{"generic"}, the name of
%  the generic function, and
%  \code{"allSelections"},  giving the vector of labels for all
%  the signatures tested.
%}
%\references{
%  Chambers, John M. (2008)
%  \emph{Software for Data Analysis: Programming with R}
%  Springer.  (Section 10.6 for basics of method selection.)
%
%  Chambers, John M. (2009)
%  \emph{Class Inheritance in R}
%  \url{https://statweb.stanford.edu/~jmc4/classInheritance.pdf}.
%}
%\examples{
%## if no other attached packages have methods for `+` or its group
%## generic functions, this returns a 16 by 2 matrix of selection
%## patterns (in R 2.9.0)
%testInheritedMethods("+")
%}
%
%\keyword{programming}
%\keyword{classes}
%\keyword{methods}
%
%\encoding{UTF8}
%