% File src/library/parallel/man/RngStream.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2011-2014 R Core Team
% Distributed under GPL 2 or later

\name{RNGstreams}
\alias{nextRNGStream}
\alias{nextRNGSubStream}
\alias{clusterSetRNGStream}
\alias{mc.reset.stream}

\title{Implementation of Pierre L'Ecuyer's RngStreams}
\description{
  これは Pierre L'Ecuyer の \sQuote{RngStreams} の
  擬似乱数の多重ストリームの \R への再実装である．
}
\usage{
nextRNGStream(seed)
nextRNGSubStream(seed)

clusterSetRNGStream(cl = NULL, iseed)
mc.reset.stream()
}
\arguments{
  \item{seed}{
    \samp{"L'Ecuyer-CMRG"} RNG が使われているときは
    \code{.Random.seed} が与えるような長さ 7 の整数ベクトル．
    個々の値については \code{\link{RNG}} を見よ．}
  \item{cl}{
    このパッケージかパッケージ \CRANpkg{snow} からの
    クラスター，又は(もし \code{NULL} なら)登録されたクラスター．}
  \item{iseed}{
    \code{\link{set.seed}} へ提供される整数，もしくは
    再現可能な乱数種を設定しないのなら \code{NULL}．}
}
\details{
  \sQuote{RngStream} インタフェイスは(可能性として)擬似乱数の
  多重ストリームで動作する：各作業が別個の RNG ストリームを
  付値できるのでこれは並列計算の作業では特に有用である．
  
  これは基礎の生成器として
  L'Ecuyer (1999) の \code{RNGkind("L'Ecuyer-CMRG")} を使う．
  これは6個の(符号付き)整数のベクトルを乱数種として持ち，
  周期は約 \eqn{2^{191}}{2^191} である．
  各\sQuote{ストリーム}は長さ \eqn{2^{127}}{2^127} の周期で，
  それを長さ \eqn{2^{76}}{2^76} の周期を持つ 
  \sQuote{サブストリーム}に分割する．

  L'Ecuyer \emph{et al} (2002) のアイデアは並列計算の各々に対して
  別個のストリームを使い
  (乱数発生器は決して同期しないことが保証される)，
  必要なら並列計算自体がサブストリームを使うというものである．
  オリジナルのインタフェイスは最初のストリームのオリジナルな
  乱数種，現在のストリームのオリジナルな乱数種，そして
  現在の乱数種を保存する：
  これを \R に移植することは可能であるが，
  関連する \code{.Random.seed} の値を保存して作業するほうが簡単である：
  例を見よ．

  \code{clusterSetRNGStream} は \code{"L'Ecuyer-CMRG"} RNG を
  選択し，それからクラスターのメンバーにストリームを配分する．
  オプションでストリームの乱数種を \code{set.seed(iseed)}
  を使い設定する
  (さもなければ L'Ecuyer 生成器を選択した後に，
  それらはマスタープロセスの現在の乱数種から設定される．)
#ifdef unix

  L'Ecuyer の乱数発生器と乱数種を設定した後の
  \code{mc.reset.stream()} の呼び出しは
  \code{\link{mcparallel}(mc.set.seed = TRUE)} からの
  実行を再生可能にする．
  これは \code{\link{mclapply}} と \code{\link{pvec}}
  により内部的になされる．
  (それはマスタープロセスの乱数種を設定しないので，
  これらの関数のシリアル復帰バージョンに影響しないことを注意する．)
#endif
}
\value{
  \code{nextRNGStream} と \code{nextRNGSubStream} に対しては
  \code{.Random.seed} に付値可能な値．
}
\references{
  L'Ecuyer, P. (1999) Good parameters and implementations for combined
  multiple recursive random number generators.  \emph{Operations
  Research} \bold{47}, 159--164.

  L'Ecuyer, P., Simard, R.,  Chen, E. J. and Kelton, W. D. (2002)
  An object-oriented random-number package with many long streams
  and substreams.  \emph{Operations Research} \bold{50} 1073--5.
}
\author{
  Brian Ripley
}
\seealso{
  \R の組み込み乱数生成器のより完全な詳細は \code{\link{RNG}}．

  パッケージ \pkg{parallel} のビニエット．
}
\note{
  L'Ecuyer の C コードへのインタフェイスは CRAN パッケージ
  \CRANpkg{rlecuyer} と \CRANpkg{rstream} にある．
}

\examples{
RNGkind("L'Ecuyer-CMRG")
set.seed(123)
(s <- .Random.seed)
## 乱数を含むある作業．
nextRNGStream(s)
nextRNGSubStream(s)
}
\keyword{distribution}
\keyword{sysdata}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/parallel/man/RngStream.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2011-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{RNGstreams}
%\alias{nextRNGStream}
%\alias{nextRNGSubStream}
%\alias{clusterSetRNGStream}
%\alias{mc.reset.stream}
%
%\title{Implementation of Pierre L'Ecuyer's RngStreams}
%\description{
%  This is an \R re-implementation of Pierre L'Ecuyer's \sQuote{RngStreams}
%  multiple streams of pseudo-random numbers.
%}
%\usage{
%nextRNGStream(seed)
%nextRNGSubStream(seed)
%
%clusterSetRNGStream(cl = NULL, iseed)
%mc.reset.stream()
%}
%\arguments{
%  \item{seed}{An integer vector of length 7 as given by
%    \code{.Random.seed} when the \samp{"L'Ecuyer-CMRG"} RNG is in use.
%    See \code{\link{RNG}} for the valid values.}
%  \item{cl}{A cluster from this package or package \CRANpkg{snow}, or (if
%    \code{NULL}) the registered cluster.}
%  \item{iseed}{An integer to be supplied to \code{\link{set.seed}}, or
%    \code{NULL} not to set reproducible seeds.}
%}
%\details{
%  The \sQuote{RngStream} interface works with (potentially) multiple
%  streams of pseudo-random numbers: this is particularly suitable for
%  working with parallel computations since each task can be assigned a
%  separate RNG stream.
%
%  This uses as its underlying generator \code{RNGkind("L'Ecuyer-CMRG")},
%  of L'Ecuyer (1999), which has a seed vector of 6 (signed) integers and a
%  period of around \eqn{2^{191}}{2^191}.  Each \sQuote{stream} is a
%  subsequence of the period of length \eqn{2^{127}}{2^127} which is in
%  turn divided into \sQuote{substreams} of length \eqn{2^{76}}{2^76}.
%
%  The idea of L'Ecuyer \emph{et al} (2002) is to use a separate stream
%  for each of the parallel computations (which ensures that the random
%  numbers generated never get into to sync) and the parallel
%  computations can themselves use substreams if required.  The original
%  interface stores the original seed of the first stream, the original
%  seed of the current stream and the current seed: this could be
%  implemented in \R, but it is as easy to work by saving the relevant
%  values of \code{.Random.seed}: see the examples.
%
%  \code{clusterSetRNGStream} selects the \code{"L'Ecuyer-CMRG"} RNG and
%  then distributes streams to the members of a cluster, optionally
%  setting the seed of the streams by \code{set.seed(iseed)} (otherwise
%  they are set from the current seed of the master process: after
%  selecting the L'Ecuyer generator).
%#ifdef unix
%
%  Calling \code{mc.reset.stream()} after setting the L'Ecuyer random
%  number generator and seed makes runs from
%  \code{\link{mcparallel}(mc.set.seed = TRUE)} reproducible.  This is
%  done internally in \code{\link{mclapply}} and \code{\link{pvec}}.
%  (Note that it does not set the seed in the master process, so does not
%  affect the fallback-to-serial versions of these functions.)
%#endif
%}
%\value{
%  For \code{nextRNGStream} and \code{nextRNGSubStream},
%  a value which can be assigned to \code{.Random.seed}.
%}
%\references{
%  L'Ecuyer, P. (1999) Good parameters and implementations for combined
%  multiple recursive random number generators.  \emph{Operations
%  Research} \bold{47}, 159--164.
%
%  L'Ecuyer, P., Simard, R.,  Chen, E. J. and Kelton, W. D. (2002)
%  An object-oriented random-number package with many long streams
%  and substreams.  \emph{Operations Research} \bold{50} 1073--5.
%}
%\author{
%  Brian Ripley
%}
%\seealso{
%  \code{\link{RNG}} for fuller details of \R's built-in random number
%  generators.
%
%  The vignette for package \pkg{parallel}.
%}
%\note{
%  Interfaces to L'Ecuyer's C code are available in CRAN
%  packages \CRANpkg{rlecuyer} and \CRANpkg{rstream}.
%}
%
%\examples{
%RNGkind("L'Ecuyer-CMRG")
%set.seed(123)
%(s <- .Random.seed)
%## do some work involving random numbers.
%nextRNGStream(s)
%nextRNGSubStream(s)
%}
%\keyword{distribution}
%\keyword{sysdata}
%
%\encoding{UTF8}
%