% File src/library/splines/man/bs.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{bs}
%@%\alias{B スプラインのベース}
\alias{bs}
\title{多項式スプラインに対する B スプラインのベース}
%\title{B-Spline Basis for Polynomial Splines}
\description{
  多項式スプラインに対する B スプラインベース行列を生成する．
}
\usage{
bs(x, df = NULL, knots = NULL, degree = 3, intercept = FALSE,
   Boundary.knots = range(x))
}
\arguments{
  \item{x}{予測変数．欠損値が許される．}
  \item{df}{自由度：\code{knots} ではなく \code{df} を指定できる；
    \code{bs()} はそうすると \code{df-degree} 個のノット
    (切片があればマイナス 1)を \code{x} の適当なクォンタイル位置に
    設定する(欠損値は無視される)．
    既定の \code{NULL} は内部ノット
    \emph{無し}に対応する，つまり \code{degree - intercept}．}
  \item{knots}{
    スプラインを定義する\emph{内部的}な分点．
    既定値は \code{NULL} で，通常の多項式回帰に対するベースに帰着する．
    典型的な値は一つのノットに対しては平均かメディアンで，
    より多くのノットに対してはクォンタイルである．
    \code{Boundary.knots} も見よ．}
  \item{degree}{区分的な多項式の次数---既定ではキュービックスプラインに対しては \code{3}．}
  \item{intercept}{
    もし \code{TRUE} なら切片項がベースに含められる；
    既定では \code{FALSE}．}
  \item{Boundary.knots}{
    B スプラインのベースを支える境界点
    (既定では \code{\link{NA}} でないデータの範囲)．
    もし \code{knots} と \code{Boundary.knots} の両方が与えられると，
    ベースのパラメータは \code{x} に依存する．データは
    \code{Boundary.knots} を超えて伸びても良い．}
}
\details{
  \code{bs} は関数 \code{\link{spline.des}} に依存している．
  これは指定された内部ノットと次数を持ち，\code{x} の値で
  評価された区分的な多項式族の表現のためのベースの行列を生成する．
  主要な使用目的はモデル中の区分的な多項式を直接に指定する公式の
  モデリングにある．

  \code{Boundary.knots} が
  \code{range(x)} の\emph{内部}に設定された時は，
  \code{bs()} は今や微分係数に対して重要な
  それぞれの境界ノット内部で\sQuote{ピボット}を使う．
  \R のバージョン \eqn{\le}{<=} 3.2.2 では，境界ノット自体が
  ピボットとして使われてきたが，これは
  少々良くない補外に繋がる．
}
\value{
  次元 \code{c(length(x), df)} の行列で，ここで \code{df} が
  提供されるか，またはもし
  \code{knots} が提供されるともし切片があれば
  \code{df = length(knots) + degree} プラス 1．
  \code{bs} への引数に対応する属性が返され，
  そして \code{predict.bs()} で使うために
  \code{knots}, \code{Boundary.knots} 等を明示的に与える．
}
\seealso{
  \code{\link{ns}}, \code{\link{poly}}, \code{\link{smooth.spline}},
  \code{\link{predict.bs}}, \code{\link{SafePrediction}}
}
\author{Douglas Bates と Bill Venables．R Core により微修正され，
  \code{Boundary.knots} の\dQuote{外側}への補外への修正パッチは
  Trevor Hastie による}
\references{
  Hastie, T. J. (1992)
  Generalized additive models.
  Chapter 7 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\examples{
require(stats); require(graphics)
bs(women$height, df = 5)
summary(fm1 <- lm(weight ~ bs(height, df = 5), data = women))
## 安全な予測の例
plot(women, xlab = "Height (in)", ylab = "Weight (lb)")
ht <- seq(57, 73, length.out = 200)
lines(ht, predict(fm1, data.frame(height = ht)))
\dontshow{
## 一貫性：
x <- c(1:3, 5:6)
stopifnot(identical(bs(x), bs(x, df = 3)),
          identical(bs(x, df = 4), bs(x, df = 4, knots = NULL)), # not true till 2.15.2
          !is.null(kk <- attr(bs(x), "knots")), # not true till 1.5.1
          length(kk) == 0)
}}
\keyword{smooth}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/splines/man/bs.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{bs}
%\alias{bs}
%\title{B-Spline Basis for Polynomial Splines}
%\description{
%  Generate the B-spline basis matrix for a polynomial spline.
%}
%\usage{
%bs(x, df = NULL, knots = NULL, degree = 3, intercept = FALSE,
%   Boundary.knots = range(x))
%}
%\arguments{
%  \item{x}{the predictor variable.  Missing values are allowed.}
%  \item{df}{degrees of freedom; one can specify \code{df} rather than
%    \code{knots}; \code{bs()} then chooses \code{df-degree} (minus one
%    if there is an intercept) knots at suitable quantiles of \code{x}
%    (which will ignore missing values).  The default, \code{NULL},
%    corresponds to \emph{no} inner knots, i.e., \code{degree - intercept}.}
%  \item{knots}{the \emph{internal} breakpoints that define the
%    spline.  The default is \code{NULL}, which results in a basis for
%    ordinary polynomial regression.  Typical values are the mean or
%    median for one knot, quantiles for more knots.  See also
%    \code{Boundary.knots}.}
%  \item{degree}{degree of the piecewise polynomial---default is \code{3} for
%    cubic splines.}
%  \item{intercept}{if \code{TRUE}, an intercept is included in the
%    basis; default is \code{FALSE}.}
%  \item{Boundary.knots}{boundary points at which to anchor the B-spline
%    basis (default the range of the non-\code{\link{NA}} data).  If both
%    \code{knots} and \code{Boundary.knots} are supplied, the basis
%    parameters do not depend on \code{x}.  Data can extend beyond
%    \code{Boundary.knots}.}
%}
%\details{
%  \code{bs} is based on the function \code{\link{spline.des}}.
%  It generates a basis matrix for
%  representing the family of piecewise polynomials with the specified
%  interior knots and degree, evaluated at the values of \code{x}.  A
%  primary use is in modeling formulas to directly specify a piecewise
%  polynomial term in a model.
%
%  When \code{Boundary.knots} are set \emph{inside} \code{range(x)},
%  \code{bs()} now uses a \sQuote{pivot} inside the respective boundary
%  knot which is important for derivative evaluation.  In \R versions
%  \eqn{\le}{<=} 3.2.2, the boundary knot itself had been used as
%  pivot, which lead to somewhat wrong extrapolations.
%}
%\value{
%  A matrix of dimension \code{c(length(x), df)}, where either \code{df}
%  was supplied or if \code{knots} were supplied, \code{df =
%  length(knots) + degree} plus one if there is an intercept.  Attributes
%  are returned that correspond to the arguments to \code{bs}, and
%  explicitly give the \code{knots}, \code{Boundary.knots} etc for use by
%  \code{predict.bs()}.
%}
%\seealso{
%  \code{\link{ns}}, \code{\link{poly}}, \code{\link{smooth.spline}},
%  \code{\link{predict.bs}}, \code{\link{SafePrediction}}
%}
%\author{Douglas Bates and Bill Venables.  Tweaks by R Core, and a patch
%  fixing extrapolation \dQuote{outside} \code{Boundary.knots} by Trevor
%  Hastie.
%}
%\references{
%  Hastie, T. J. (1992)
%  Generalized additive models.
%  Chapter 7 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\examples{
%require(stats); require(graphics)
%bs(women$height, df = 5)
%summary(fm1 <- lm(weight ~ bs(height, df = 5), data = women))
%
%## example of safe prediction
%plot(women, xlab = "Height (in)", ylab = "Weight (lb)")
%ht <- seq(57, 73, length.out = 200)
%lines(ht, predict(fm1, data.frame(height = ht)))
%\dontshow{
%## Consistency:
%x <- c(1:3, 5:6)
%stopifnot(identical(bs(x), bs(x, df = 3)),
%          identical(bs(x, df = 4), bs(x, df = 4, knots = NULL)), # not true till 2.15.2
%          !is.null(kk <- attr(bs(x), "knots")), # not true till 1.5.1
%          length(kk) == 0)
%}}
%\keyword{smooth}
%
%\encoding{UTF8}
%