% File src/library/stats/man/Lognormal.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Lognormal}
\alias{Lognormal}
\alias{dlnorm}
\alias{plnorm}
\alias{qlnorm}
\alias{rlnorm}
\title{The Log Normal Distribution}
\description{
  対数正規分布に対する密度，分布関数，クォンタイル関数と乱数生成．
  その対数は平均 \code{meanlog} で標準偏差が \code{sdlog}．
}
\usage{
dlnorm(x, meanlog = 0, sdlog = 1, log = FALSE)
plnorm(q, meanlog = 0, sdlog = 1, lower.tail = TRUE, log.p = FALSE)
qlnorm(p, meanlog = 0, sdlog = 1, lower.tail = TRUE, log.p = FALSE)
rlnorm(n, meanlog = 0, sdlog = 1)
}
\arguments{
  \item{x, q}{クォンタイルのベクトル．}
  \item{p}{確率のベクトル．}
  \item{n}{観測値数．もし \code{length(n) > 1} なら長さが
    必要な個数とされる．}
  \item{meanlog, sdlog}{対数スケールでの平均と標準偏差，
    既定値はそれぞれ \code{0} と \code{1}．}
  \item{log, log.p}{論理値；もし TRUE なら確率 p は log(p) とされる．}
  \item{lower.tail}{論理値；もし TRUE (既定値)なら
    確率は \eqn{P[X \le x]} で，さもなければ \eqn{P[X > x]}．}
}
\value{
  \code{dlnorm} は密度，\code{plnorm} は分布関数，
  \code{qlnorm} はクォンタイル関数，そして
  \code{rlnorm} は乱数を生成する．

  不正な引数は値 \code{NaN} を返し，警告が出る．

  \code{rbeta} に対しては結果の長さは \code{n} で決まり，
  そして他の関数に対しては数値引数の最大長である．

  \code{n} 以外の数値引数は結果の長さまでリサイクルされる．
  論理値引数は最初の要素だけが使われる．
}
\source{
  \code{dlnorm} はその定義(\sQuote{詳細})
  から計算される．
  \code{[pqr]lnorm} は正規分布との関係に基づく．

  結果として境界ケース \code{sdlog = 0} に対しては
  それらは \code{exp(meanlog)} における一点分布になる．
}
\details{
  対数正規分布は密度
  \deqn{
    f(x) = \frac{1}{\sqrt{2\pi}\sigma x} e^{-(\log(x) - \mu)^2/2 \sigma^2}%
  }{f(x) = 1/(\sqrt(2 \pi) \sigma x) e^-((log x - \mu)^2 / (2 \sigma^2))}
  を持つ，ここで \eqn{\mu} と \eqn{\sigma} は対数の平均と標準偏差
  である．
  平均は \eqn{E(X) = exp(\mu + 1/2 \sigma^2)} で，
  中央値は \eqn{med(X) = exp(\mu)}，そして分散は
  \eqn{Var(X) = exp(2\mu + \sigma^2)(exp(\sigma^2) - 1)}{Var(X) = exp(2*\mu + \sigma^2)*(exp(\sigma^2) - 1)}
  となる．従って変動係数は
  \eqn{\sqrt{exp(\sigma^2) - 1}}{sqrt(exp(\sigma^2) - 1)} であり，
  これはそれが小さい(例えば \eqn{\sigma < 1/2}) なら
  近似的に \eqn{\sigma} に等しい．
}
%% Mode = exp(max(0, mu - sigma^2))
\note{
  累積ハザード関数 \eqn{H(t) = - \log(1 - F(t))}{H(t) = - log(1 - F(t))}
  は \code{-plnorm(t, r, lower = FALSE, log = TRUE)}．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Johnson, N. L., Kotz, S. and Balakrishnan, N. (1995)
  \emph{Continuous Univariate Distributions}, volume 1, chapter 14.
  Wiley, New York.
}
\seealso{
  正規分布 \code{\link{dnorm}} を含む他の標準分布については
  \link{Distributions}．

}
\examples{
dlnorm(1) == dnorm(0)
}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/Lognormal.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Lognormal}
%\alias{Lognormal}
%\alias{dlnorm}
%\alias{plnorm}
%\alias{qlnorm}
%\alias{rlnorm}
%\title{The Log Normal Distribution}
%\description{
%  Density, distribution function, quantile function and random
%  generation for the log normal distribution whose logarithm has mean
%  equal to \code{meanlog} and standard deviation equal to \code{sdlog}.
%}
%\usage{
%dlnorm(x, meanlog = 0, sdlog = 1, log = FALSE)
%plnorm(q, meanlog = 0, sdlog = 1, lower.tail = TRUE, log.p = FALSE)
%qlnorm(p, meanlog = 0, sdlog = 1, lower.tail = TRUE, log.p = FALSE)
%rlnorm(n, meanlog = 0, sdlog = 1)
%}
%\arguments{
%  \item{x, q}{vector of quantiles.}
%  \item{p}{vector of probabilities.}
%  \item{n}{number of observations. If \code{length(n) > 1}, the length
%    is taken to be the number required.}
%  \item{meanlog, sdlog}{mean and standard deviation of the distribution
%    on the log scale with default values of \code{0} and \code{1} respectively.}
%  \item{log, log.p}{logical; if TRUE, probabilities p are given as log(p).}
%  \item{lower.tail}{logical; if TRUE (default), probabilities are
%    \eqn{P[X \le x]}, otherwise, \eqn{P[X > x]}.}
%}
%\value{
%  \code{dlnorm} gives the density,
%  \code{plnorm} gives the distribution function,
%  \code{qlnorm} gives the quantile function, and
%  \code{rlnorm} generates random deviates.
%
%  The length of the result is determined by \code{n} for
%  \code{rlnorm}, and is the maximum of the lengths of the
%  numerical arguments for the other functions.
%
%  The numerical arguments other than \code{n} are recycled to the
%  length of the result.  Only the first elements of the logical
%  arguments are used.
%}
%\source{
%  \code{dlnorm} is calculated from the definition (in \sQuote{Details}).
%  \code{[pqr]lnorm} are based on the relationship to the normal.
%
%  Consequently, they model a single point mass at \code{exp(meanlog)}
%  for the boundary case \code{sdlog = 0}.
%}
%\details{
%  The log normal distribution has density
%  \deqn{
%    f(x) = \frac{1}{\sqrt{2\pi}\sigma x} e^{-(\log(x) - \mu)^2/2 \sigma^2}%
%  }{f(x) = 1/(\sqrt(2 \pi) \sigma x) e^-((log x - \mu)^2 / (2 \sigma^2))}
%  where \eqn{\mu} and \eqn{\sigma} are the mean and standard
%  deviation of the logarithm.
%  The mean is \eqn{E(X) = exp(\mu + 1/2 \sigma^2)},
%  the median is \eqn{med(X) = exp(\mu)}, and the variance
%  \eqn{Var(X) = exp(2\mu + \sigma^2)(exp(\sigma^2) - 1)}{Var(X) = exp(2*\mu + \sigma^2)*(exp(\sigma^2) - 1)}
%  and hence the coefficient of variation is
%  \eqn{\sqrt{exp(\sigma^2) - 1}}{sqrt(exp(\sigma^2) - 1)} which is
%  approximately \eqn{\sigma} when that is small (e.g., \eqn{\sigma < 1/2}).
%}
%%% Mode = exp(max(0, mu - sigma^2))
%\note{
%  The cumulative hazard \eqn{H(t) = - \log(1 - F(t))}{H(t) = - log(1 - F(t))}
%  is \code{-plnorm(t, r, lower = FALSE, log = TRUE)}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Johnson, N. L., Kotz, S. and Balakrishnan, N. (1995)
%  \emph{Continuous Univariate Distributions}, volume 1, chapter 14.
%  Wiley, New York.
%}
%\seealso{
%  \link{Distributions} for other standard distributions, including
%  \code{\link{dnorm}} for the normal distribution.
%}
%\examples{
%dlnorm(1) == dnorm(0)
%}
%\keyword{distribution}
%
%\encoding{UTF-8}
%