% File src/library/stats/man/ar.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{ar}
\alias{ar}
\alias{ar.burg}
\alias{ar.burg.default}
\alias{ar.burg.mts}
\alias{ar.yw}
\alias{ar.yw.default}
\alias{ar.yw.mts}
\alias{ar.mle}
\alias{print.ar}
\alias{predict.ar}
\concept{autoregression}
%%\title{Fit Autoregressive Models to Time Series}
\title{時系列への AR モデルの当てはめ}
\usage{
ar(x, aic = TRUE, order.max = NULL,
   method = c("yule-walker", "burg", "ols", "mle", "yw"),
   na.action, series, \dots)

ar.burg(x, \dots)
\method{ar.burg}{default}(x, aic = TRUE, order.max = NULL,
        na.action = na.fail, demean = TRUE, series,
        var.method = 1, \dots)
\method{ar.burg}{mts}(x, aic = TRUE, order.max = NULL,
        na.action = na.fail, demean = TRUE, series,
        var.method = 1, \dots)

ar.yw(x, \dots)
\method{ar.yw}{default}(x, aic = TRUE, order.max = NULL,
      na.action = na.fail, demean = TRUE, series, \dots)
\method{ar.yw}{mts}(x, aic = TRUE, order.max = NULL,
      na.action = na.fail, demean = TRUE, series,
      var.method = 1, \dots)

ar.mle(x, aic = TRUE, order.max = NULL, na.action = na.fail,
       demean = TRUE, series, \dots)

\method{predict}{ar}(object, newdata, n.ahead = 1, se.fit = TRUE, \dots)
}
\arguments{
  \item{x}{一変量か多変量時系列．}
  \item{aic}{論理フラグ．もし \code{TRUE} なら赤池の情報量規準が
    自己回帰モデルの次数を決めるために使われる．
    もし \code{FALSE} なら次数 \code{order.max} のモデルが当てはめられる．}
  \item{order.max}{当てはめられるモデルの最大次数(又は次数)．
    既定では \eqn{N-1} と \eqn{10\log_{10}(N)}{10*log10(N)} の小さい方で，
    ここで \eqn{N} は観測値数．
    例外は \code{method = "mle"} の時でこの数と 12 の小さいほうが使われる．}
  \item{method}{モデルを当てはめるのに使われるメソッドを与える文字列．
    既定の引数中の文字列のどれかでなければならない
    (最初の数文字が十分)．既定では \code{"yule-walker"}．}
  \item{na.action}{欠損値を処理するために呼び出される関数．}
  \item{demean}{当てはめの間に平均を推定すべきか?}
  \item{series}{系列に対する名前．既定では
    \code{deparse(substitute(x))}．}
  \item{var.method}{イノベーション分散を推定するメソッド
    (\sQuote{詳細}を見よ)．}
  \item{\dots}{特定のメソッドに対する追加引数．}
  \item{object}{\code{ar} からの当てはめ．}
  \item{newdata}{予測を適用するデータ．}
  \item{n.ahead}{予測する将来のステップ数．}
  \item{se.fit}{論理値：予測誤差の推定標準エラーを返すか?}
}
\description{
  データに自己回帰時系列を当てはめる．
  既定では AIC で複雑さを選択する．
}
\details{
  明確さのために
  AR 係数は次のような符号を持つことを注意する

  \deqn{x_t - \mu = a_1(x_{t-1} - \mu) + \cdots +  a_p(x_{t-p} - \mu) + e_t}{x[t] - m = a[1]*(x[t-1] - m) + \dots +  a[p]*(x[t-p] - m) + e[t]}

  \code{ar} は単に関数
  \code{ar.yw},
  \code{ar.burg}, \code{\link{ar.ols}} そして \code{ar.mle} のラッパである．

  次数の選択はもし
  \code{aic} が真なら AIC でなされる．
  メソッドの内 \code{ar.mle} だけが真の最尤推定を行うため，
  これは問題があるかもしれない．
  AIC はあたかも分散推定値が MLE であるかのように計算され，
  尤度から行列式部分を除外する．
  これは推定パラメータ値で評価されたガウシアン尤度とは
  同じでないことを注意する．
  \code{ar.yw} ではイノベーションの分散行列は
  当てはめ係数と
  \code{x} の自己共分散から計算される．

  \code{ar.burg} はイノベーション分散を推定する二つの方法を
  許し，従って AIC も二種類考えられる．
  方法 1 は
  Levinson-Durbin 再帰式 (Brockwell and Davis, 1991, page 242 の (8.2.6))
  で与えられる更新式を使い S-PLUS に倣う．
  方法 2 は前進と後退予測エラーの二乗平均である
  (Brockwell and Davis, 1996, page 145 のように).
  Percival and Walden (1998) は両者を議論している．
  多変量ケースでは推定係数は
  分散の推定方法に(少し)依存する．

  \code{ar} は AR モデルを当てはめる前に
  \code{x} の全体的な平均を取り去るか，
  又は(\code{ar.mle})引き去る定数を推定することにより，
  既定でモデル中に定数を含む．
}
\value{
  クラス \code{"ar"} のりストで次の成分を持つ：
  \item{order}{当てはめモデルの次数．これはもし
    \code{aic = TRUE} ならば AIC を最小化して選ばれる，
    さもなければそれは \code{order.max} である．}
  \item{ar}{当てはめモデルに対する推定自己回帰係数．}
  \item{var.pred}{予測分散：自己回帰モデルで説明できない
    時系列の分散の部分の推定値．}
  \item{x.mean}{当てはめと予測中で用いられる推定平均．}
  \item{x.intercept}{(\code{ar.ols} のみ．)
    \code{x - x.mean} に対するモデル中の切片．}
  \item{aic}{各モデルと最良の当てはめモデル間の AIC の差．
    後者は \code{-Inf} の AIC を持ち得ることを注意する．}
  \item{n.used}{時系列中の観測値数．}
  \item{order.max}{\code{order.max} 引数の値．}
  \item{partialacf}{ラグ \code{order.max} までの部分自己相関関数．}
  \item{resid}{最初の \code{order} 観測値で条件付けられた
    当てはめモデルからの残差．
    最初の \code{order} 個の残差は
    \code{NA} とされる．もし \code{x} が時系列ならば
    \code{resid} もそうである．}
  \item{method}{\code{method} 引数の値．}
  \item{series}{時系列の名前．}
  \item{frequency}{時系列の周波数．}
  \item{call}{マッチした呼び出し．}
  \item{asy.var.coef}{(一変量ケース，\code{order > 0}．)
    係数推定値の漸近理論による分散行列．}

  \code{predict.ar} に対しては予測値の時系列，又は
  もし \code{se.fit = TRUE} なら予測値
  \code{pred} と推定標準エラー \code{se} を成分に持つリスト．
  どちらの成分も時系列である．
}
\author{
  \code{ar.yw} の一変量ケースと \code{ar.mle} は Martyn Plummer，
  \code{ar.burg} の一変量ケースに対する C コードは B. D. Ripley．
}
\note{
  \code{ar.mle} の一変量ケースだけが移植されている．

  長い系列に対する \code{method="mle"} の当てはめは非常に遅い．
}
\seealso{
  ARMA モデルに対しては \code{\link{ar.ols}}, \code{\link{arima}}；
  ACF からの AR の構成は \code{\link{acf2AR}}， 

  AR プロセスのシミュレーションは \code{\link{arima.sim}}．
}
\references{
  Brockwell, P. J. and Davis, R. A. (1991) \emph{Time
    Series and Forecasting Methods.}  Second edition. Springer, New
  York. Section 11.4.

  Brockwell, P. J. and Davis, R. A. (1996) \emph{Introduction to Time
    Series and Forecasting.} Springer, New York. Sections 5.1 and 7.6.

  Percival, D. P. and Walden, A. T. (1998) \emph{Spectral Analysis
    for Physical Applications.} Cambridge University Press.

  Whittle, P. (1963) On the fitting of multivariate autoregressions
  and the approximate canonical factorization of a spectral density
  matrix. \emph{Biometrika} \bold{40}, 129--134.
}
\examples{
ar(lh)
ar(lh, method = "burg")
ar(lh, method = "ols")
ar(lh, FALSE, 4) # ar(4) の当てはめ

(sunspot.ar <- ar(sunspot.year))
predict(sunspot.ar, n.ahead = 25)
## 他のメソッドも試みる

ar(ts.union(BJsales, BJsales.lead))
## OLS (ar.ols を見よ)と同様に Burg はここでは全く異なる
ar(ts.union(BJsales, BJsales.lead), method = "burg")
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/ar.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ar}
%\alias{ar}
%\alias{ar.burg}
%\alias{ar.burg.default}
%\alias{ar.burg.mts}
%\alias{ar.yw}
%\alias{ar.yw.default}
%\alias{ar.yw.mts}
%\alias{ar.mle}
%\alias{print.ar}
%\alias{predict.ar}
%\concept{autoregression}
%\title{Fit Autoregressive Models to Time Series}
%\usage{
%ar(x, aic = TRUE, order.max = NULL,
%   method = c("yule-walker", "burg", "ols", "mle", "yw"),
%   na.action, series, \dots)
%
%ar.burg(x, \dots)
%\method{ar.burg}{default}(x, aic = TRUE, order.max = NULL,
%        na.action = na.fail, demean = TRUE, series,
%        var.method = 1, \dots)
%\method{ar.burg}{mts}(x, aic = TRUE, order.max = NULL,
%        na.action = na.fail, demean = TRUE, series,
%        var.method = 1, \dots)
%
%ar.yw(x, \dots)
%\method{ar.yw}{default}(x, aic = TRUE, order.max = NULL,
%      na.action = na.fail, demean = TRUE, series, \dots)
%\method{ar.yw}{mts}(x, aic = TRUE, order.max = NULL,
%      na.action = na.fail, demean = TRUE, series,
%      var.method = 1, \dots)
%
%ar.mle(x, aic = TRUE, order.max = NULL, na.action = na.fail,
%       demean = TRUE, series, \dots)
%
%\method{predict}{ar}(object, newdata, n.ahead = 1, se.fit = TRUE, \dots)
%}
%\arguments{
%  \item{x}{A univariate or multivariate time series.}
%
%  \item{aic}{Logical flag.  If \code{TRUE} then the Akaike Information
%    Criterion is used to choose the order of the autoregressive
%    model. If \code{FALSE}, the model of order \code{order.max} is
%    fitted.}
%
%  \item{order.max}{Maximum order (or order) of model to fit. Defaults
%    to the smaller of \eqn{N-1} and \eqn{10\log_{10}(N)}{10*log10(N)}
%    where \eqn{N} is the number of observations
%    except for \code{method = "mle"} where it is the minimum of this
%    quantity and 12.}
%
%  \item{method}{Character string giving the method used to fit the
%    model.  Must be one of the strings in the default argument
%    (the first few characters are sufficient).  Defaults to
%    \code{"yule-walker"}.}
%
%  \item{na.action}{function to be called to handle missing values.}
%
%  \item{demean}{should a mean be estimated during fitting?}
%
%  \item{series}{names for the series.  Defaults to
%    \code{deparse(substitute(x))}.}
%
%  \item{var.method}{the method to estimate the innovations variance
%    (see \sQuote{Details}).}
%
%  \item{\dots}{additional arguments for specific methods.}
%
%  \item{object}{a fit from \code{ar}.}
%
%  \item{newdata}{data to which to apply the prediction.}
%
%  \item{n.ahead}{number of steps ahead at which to predict.}
%
%  \item{se.fit}{logical: return estimated standard errors of the
%    prediction error?}
%}
%\description{
%  Fit an autoregressive time series model to the data, by default
%  selecting the complexity by AIC.
%}
%\details{
%  For definiteness, note that the AR coefficients have the sign in
%
%  \deqn{x_t - \mu = a_1(x_{t-1} - \mu) + \cdots +  a_p(x_{t-p} - \mu) + e_t}{x[t] - m = a[1]*(x[t-1] - m) + \dots +  a[p]*(x[t-p] - m) + e[t]}
%
%  \code{ar} is just a wrapper for the functions \code{ar.yw},
%  \code{ar.burg}, \code{\link{ar.ols}} and \code{ar.mle}.
%
%  Order selection is done by AIC if \code{aic} is true. This is
%  problematic, as of the methods here only \code{ar.mle} performs
%  true maximum likelihood estimation. The AIC is computed as if the variance
%  estimate were the MLE, omitting the determinant term from the
%  likelihood. Note that this is not the same as the Gaussian likelihood
%  evaluated at the estimated parameter values. In \code{ar.yw} the
%  variance matrix of the innovations is computed from the fitted
%  coefficients and the autocovariance of \code{x}.
%
%  \code{ar.burg} allows two methods to estimate the innovations
%  variance and hence AIC. Method 1 is to use the update given by
%  the Levinson-Durbin recursion (Brockwell and Davis, 1991, (8.2.6)
%  on page 242), and follows S-PLUS. Method 2 is the mean of the sum
%  of squares of the forward and backward prediction errors
%  (as in Brockwell and Davis, 1996, page 145). Percival and Walden
%  (1998) discuss both. In the multivariate case the estimated
%  coefficients will depend (slightly) on the variance estimation method.
%
%  Remember that \code{ar} includes by default a constant in the model, by
%  removing the overall mean of \code{x} before fitting the AR model,
%  or (\code{ar.mle}) estimating a constant to subtract.
%}
%\value{
%  For \code{ar} and its methods a list of class \code{"ar"} with
%  the following elements:
%  \item{order}{The order of the fitted model.  This is chosen by
%    minimizing the AIC if \code{aic = TRUE}, otherwise it is \code{order.max}.}
%  \item{ar}{Estimated autoregression coefficients for the fitted model.}
%  \item{var.pred}{The prediction variance: an estimate of the portion of the
%    variance of the time series that is not explained by the
%    autoregressive model.}
%  \item{x.mean}{The estimated mean of the series used in fitting and for
%    use in prediction.}
%  \item{x.intercept}{(\code{ar.ols} only.) The intercept in the model for
%    \code{x - x.mean}.}
%  \item{aic}{The differences in AIC between each model and the
%    best-fitting model.  Note that the latter can have an AIC of \code{-Inf}.}
%  \item{n.used}{The number of observations in the time series.}
%  \item{order.max}{The value of the \code{order.max} argument.}
%  \item{partialacf}{The estimate of the partial autocorrelation function
%    up to lag \code{order.max}.}
%  \item{resid}{residuals from the fitted model, conditioning on the
%    first \code{order} observations. The first \code{order} residuals
%    are set to \code{NA}. If \code{x} is a time series, so is \code{resid}.}
%  \item{method}{The value of the \code{method} argument.}
%  \item{series}{The name(s) of the time series.}
%  \item{frequency}{The frequency of the time series.}
%  \item{call}{The matched call.}
%  \item{asy.var.coef}{(univariate case, \code{order > 0}.)
%    The asymptotic-theory variance matrix of the coefficient estimates.}
%
%  For \code{predict.ar}, a time series of predictions, or if
%  \code{se.fit = TRUE}, a list with components \code{pred}, the
%  predictions, and \code{se}, the estimated standard errors. Both
%  components are time series.
%}
%\author{
%  Martyn Plummer. Univariate case of \code{ar.yw}, \code{ar.mle}
%  and C code for univariate case of \code{ar.burg} by B. D. Ripley.
%}
%
%\note{
%  Only the univariate case of \code{ar.mle} is implemented.
%
%  Fitting by \code{method="mle"} to long series can be very slow.
%}
%
%\seealso{
%  \code{\link{ar.ols}}, \code{\link{arima}} for ARMA models;
%  \code{\link{acf2AR}}, for AR construction from the ACF.
%
%  \code{\link{arima.sim}} for simulation of AR processes.
%}
%
%\references{
%  Brockwell, P. J. and Davis, R. A. (1991) \emph{Time
%    Series and Forecasting Methods.}  Second edition. Springer, New
%  York. Section 11.4.
%
%  Brockwell, P. J. and Davis, R. A. (1996) \emph{Introduction to Time
%    Series and Forecasting.} Springer, New York. Sections 5.1 and 7.6.
%
%  Percival, D. P. and Walden, A. T. (1998) \emph{Spectral Analysis
%    for Physical Applications.} Cambridge University Press.
%
%  Whittle, P. (1963) On the fitting of multivariate autoregressions
%  and the approximate canonical factorization of a spectral density
%  matrix. \emph{Biometrika} \bold{40}, 129--134.
%}
%
%\examples{
%ar(lh)
%ar(lh, method = "burg")
%ar(lh, method = "ols")
%ar(lh, FALSE, 4) # fit ar(4)
%
%(sunspot.ar <- ar(sunspot.year))
%predict(sunspot.ar, n.ahead = 25)
%## try the other methods too
%
%ar(ts.union(BJsales, BJsales.lead))
%## Burg is quite different here, as is OLS (see ar.ols)
%ar(ts.union(BJsales, BJsales.lead), method = "burg")
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
