% File src/library/stats/man/birthday.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{birthday}
\alias{qbirthday}
\alias{pbirthday}
%%\title{Probability of coincidences}
\title{誕生日パラドックス}
\description{
  一般化\emph{誕生日のパラドックス}問題への回答．
  \code{pbirthday} は一致確率を計算し，
  \code{qbirthday} は少なくとも指定した一致確率を持つ最少の
  観測値数を計算する．
}
\usage{
qbirthday(prob = 0.5, classes = 365, coincident = 2)
pbirthday(n, classes = 365, coincident = 2)
}
\arguments{
  \item{classes}{人々がどれだけ異なったカテゴリーに分けられるか．}
  \item{prob}{期待される一致確率．}
  \item{n}{人数．}
  \item{coincident}{同じカテゴリーに入る人数．}
}
\value{
  \item{qbirthday}{
    \code{classes} 個の等確率のラベルから
    \code{k} 又はそれ以上が同じものを持つ確率が
    少なくとも \code{prob} になるのに必要な最少人数．
  }
  \item{pbirthday}{指定された一致の確率．}
}
\details{
 誕生日のパラドックスとは，
 二人以上が同じ誕生日を持つ確率が 0.5 以上になるためには
 非常に少ない人数，23，で十分というものである．
 この関数は 0.5 以外の確率，2 以外の出来事の一致数，そして
 365 以外のクラスに計算を一般化している．

 \code{coincident > 2} に対する計算は近似である．
 近似は適度な \code{prob} の値に対してはかなり良いが，
 小さな確率に対しては精度が落ちる．
}
\references{
  Diaconis, P. and Mosteller F. (1989)
  Methods for studying coincidences.
  \emph{J. American Statistical Association}, \bold{84}, 853--861.
}
\examples{
require(graphics)

## 標準バージョン
qbirthday() # 23
## ３人以上が同じ誕生日を持つ確率
pbirthday(23, coincident = 3)

## Diaconis & Mosteller p. 858 からの例
## '一致'とは夫．妻．娘が皆 16 日に生まれること
qbirthday(classes = 30, coincident = 3) # 約 18
qbirthday(coincident = 4)  # 正確な値 187
qbirthday(coincident = 10) # 正確な値 1181

## 同じ 4 桁の PIN 番号
qbirthday(classes = 10^4)

## 三人以上の一致誕生日確率が 0.9
qbirthday(coincident = 3, prob = 0.9)

## 150 人中 4 人以上の誕生日が一致
pbirthday(150, coincident = 4)

## 1000 人中 100 人以上の誕生日が一致：非常に稀
pbirthday(1000, coincident = 100)
}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/birthday.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{birthday}
%\alias{qbirthday}
%\alias{pbirthday}
%\title{Probability of coincidences}
%\description{
%  Computes answers to a generalised \emph{birthday paradox} problem.
%  \code{pbirthday} computes the probability of a coincidence and
%  \code{qbirthday} computes the smallest number of observations needed
%  to have at least a specified probability of coincidence.
%}
%\usage{
%qbirthday(prob = 0.5, classes = 365, coincident = 2)
%pbirthday(n, classes = 365, coincident = 2)
%}
%\arguments{
%  \item{classes}{How many distinct categories the people could fall into}
%  \item{prob}{The desired probability of coincidence}
%  \item{n}{The number of people}
%  \item{coincident}{The number of people to fall in the same category}
%}
%\value{
%  \item{qbirthday}{
%    Minimum number of people needed for a probability of at least
%    \code{prob} that \code{k} or more of them have the same one out of
%    \code{classes} equiprobable labels.
%  }
%
%  \item{pbirthday}{Probability of the specified coincidence.}
%}
%\details{
% The birthday paradox is that a very small number of people, 23,
% suffices to have a 50--50 chance that two or more of them have the same
% birthday.  This function generalises the calculation to probabilities
% other than 0.5, numbers of coincident events other than 2, and numbers
% of classes other than 365.
%
% The formula used is approximate for \code{coincident > 2}.  The
% approximation is very good for moderate values of \code{prob} but less
% good for very small probabilities.
%}
%\references{
%  Diaconis, P. and Mosteller F. (1989)
%  Methods for studying coincidences.
%  \emph{J. American Statistical Association}, \bold{84}, 853--861.
%}
%\examples{
%require(graphics)
%
%## the standard version
%qbirthday() # 23
%## probability of > 2 people with the same birthday
%pbirthday(23, coincident = 3)
%
%## examples from Diaconis & Mosteller p. 858.
%## 'coincidence' is that husband, wife, daughter all born on the 16th
%qbirthday(classes = 30, coincident = 3) # approximately 18
%qbirthday(coincident = 4)  # exact value 187
%qbirthday(coincident = 10) # exact value 1181
%
%## same 4-digit PIN number
%qbirthday(classes = 10^4)
%
%## 0.9 probability of three or more coincident birthdays
%qbirthday(coincident = 3, prob = 0.9)
%
%## Chance of 4 or more coincident birthdays in 150 people
%pbirthday(150, coincident = 4)
%
%## 100 or more coincident birthdays in 1000 people: very rare
%pbirthday(1000, coincident = 100)
%}
%\keyword{distribution}
%
%\encoding{UTF-8}
%
