% File src/library/stats/man/complete.cases.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{complete.cases}
\alias{complete.cases}
%%\title{Find Complete Cases}
\title{欠損値の有無の検査}
\description{
  どのケースが完全，つまり欠損値を含まない，かを指示する
  論理値ベクトルを返す．
}
\usage{
complete.cases(\dots)
}
\arguments{
  \item{\dots}{ベクトル，行列そしてデータフレームの系列．}
}
\value{
  全ての系列に渡りその観測値/行が欠損値を含まないかを指示する論理値ベクトル．
}
\note{
  現在のこの関数の限界はそれが
  長さと欠損値の有無を決定する低水準関数を使い
  クラスを無視することである．これはある列が
  \code{\link{length}} 又は \code{\link{is.na}} メソッドを持つ
  クラスを持つ時偽りのエラーを導く，例えば
  \PR{16648} で述べられたような \code{"\link{POSIXlt}"}．
}
\seealso{
  \code{\link{is.na}},
  \code{\link{na.omit}},
  \code{\link{na.fail}}.
}
\examples{
x <- airquality[, -1] # x は回帰デザイン行列
y <- airquality[,  1] # y は対応する応答

stopifnot(complete.cases(y) != is.na(y))
ok <- complete.cases(x, y)
sum(!ok) # "ok" でないものはどれだけあるか?
x <- x[ok,]
y <- y[ok]
}
\keyword{NA}
\keyword{logic}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/complete.cases.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{complete.cases}
%\alias{complete.cases}
%\title{Find Complete Cases}
%\description{
%  Return a logical vector indicating which cases are complete, i.e.,
%  have no missing values.
%}
%\usage{
%complete.cases(\dots)
%}
%\arguments{
%  \item{\dots}{a sequence of vectors, matrices and data frames.}
%}
%\value{
%  A logical vector specifying which observations/rows have no missing
%  values across the entire sequence.
%}
%\note{
%  A current limitation of this function is that it uses low level
%  functions to determine lengths and missingness, ignoring the 
%  class.  This will lead to spurious errors when some columns
%  have classes with \code{\link{length}} or \code{\link{is.na}}
%  methods, for example \code{"\link{POSIXlt}"}, as described
%  in \PR{16648}.
%}
%\seealso{
%  \code{\link{is.na}},
%  \code{\link{na.omit}},
%  \code{\link{na.fail}}.
%}
%\examples{
%x <- airquality[, -1] # x is a regression design matrix
%y <- airquality[,  1] # y is the corresponding response
%
%stopifnot(complete.cases(y) != is.na(y))
%ok <- complete.cases(x, y)
%sum(!ok) # how many are not "ok" ?
%x <- x[ok,]
%y <- y[ok]
%}
%\keyword{NA}
%\keyword{logic}
%
%\encoding{UTF-8}
%
