% File src/library/stats/man/confint.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{confint}
%%\title{Confidence Intervals for Model Parameters}
\title{当てはめモデルのパラメータの信頼区間}
\alias{confint}
\alias{confint.default}
\alias{confint.lm}
\description{
  当てはめモデル中の一つ又はそれ以上のパラメータに対する
  信頼区間を計算する．
  クラス \code{"\link{lm}"} を継承するクラスのオブジェクトに対する既定と
  メソッドがある．
}
\usage{
confint(object, parm, level = 0.95, \dots)
}
\arguments{
  \item{object}{当てはめモデルオブジェクト．}
  \item{parm}{どのパラメータに対して信頼区間を与えるかの指示，
    番号のベクトルか名前のベクトル．もし無ければ全てのパラメータが
    考慮される．}
  \item{level}{必要な信頼水準．}
  \item{\dots}{メソッドに対する追加引数．}
}
\value{
  各パラメータに対する上下の信頼限界を与える列を持つ
  行列(又はベクトル)．
  これらは \% 単位で (1-level)/2 と 1 - (1-level)/2 という
  ラベルが付く(既定では 2.5\% と 97.5\%)．
}
\details{
  \code{confint} は総称的関数である．
  既定のメソッドは漸近的正規性を仮定し，
  適当な \code{\link{coef}} と 
  \code{\link{vcov}} メソッドが利用できる必要がある．
  既定メソッドは他のメソッドとの比較のため直接呼び出すことが出来る．

  クラス \code{"lm"} のオブジェクトに対しては
  \eqn{t} 値に基づく直接的公式が使われる．

  これらはパッケージ \CRANpkg{MASS} (もしインストールされていれば)
  中のそれらを呼び出す
  クラス \code{"glm"} と \code{"nls"} のための
  パッケージ \pkg{stats} 中の切り株メソッドである：
  もし \CRANpkg{MASS} の名前空間がロードされていればそのメソッドが
  直接呼び出される．
  (これらのメソッドはプロファイル尤度に基づく．)
}
\seealso{
  パッケージ \CRANpkg{MASS} 中の \code{\link[MASS:confint]{confint.glm}} と
  \code{\link[MASS:confint]{confint.nls}}．
}
\examples{
fit <- lm(100/mpg ~ disp + hp + wt + am, data = mtcars)
confint(fit)
confint(fit, "wt")

\donttest{## example(glm) から
counts <- c(18,17,15,20,10,20,25,13,12)
outcome <- gl(3, 1, 9); treatment <- gl(3, 3)
glm.D93 <- glm(counts ~ outcome + treatment, family = poisson())
confint(glm.D93) # MASS がインストールされている必要
confint.default(glm.D93)  # 漸近正規性に基づく
}
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/confint.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{confint}
%\title{Confidence Intervals for Model Parameters}
%\alias{confint}
%\alias{confint.default}
%\alias{confint.lm}
%\description{
%  Computes confidence intervals for one or more parameters in a fitted
%  model.  There is a default and a method for objects inheriting from class
%  \code{"\link{lm}"}.
%}
%\usage{
%confint(object, parm, level = 0.95, \dots)
%}
%\arguments{
%  \item{object}{a fitted model object.}
%  \item{parm}{a specification of which parameters are to be given
%    confidence intervals, either a vector of numbers or a vector of
%    names.  If missing, all parameters are considered.}
%  \item{level}{the confidence level required.}
%  \item{\dots}{additional argument(s) for methods.}
%}
%\value{
%  A matrix (or vector) with columns giving lower and upper confidence
%  limits for each parameter. These will be labelled as (1-level)/2 and
%  1 - (1-level)/2 in \% (by default 2.5\% and 97.5\%).
%}
%\details{
%  \code{confint} is a generic function.  The default method assumes
%  asymptotic normality, and needs suitable \code{\link{coef}} and
%  \code{\link{vcov}} methods to be available.  The default method can be
%  called directly for comparison with other methods.
%
%  For objects of class \code{"lm"} the direct formulae based on \eqn{t}
%  values are used.
%
%  There are stub methods in package \pkg{stats} for classes \code{"glm"}
%  and \code{"nls"} which call those in package \CRANpkg{MASS} (if
%  installed): if the \CRANpkg{MASS} namespace has been loaded, its
%  methods will be used directly.  (Those methods are based on profile
%  likelihood.)
%}
%\seealso{
%  \code{\link[MASS:confint]{confint.glm}} and
%  \code{\link[MASS:confint]{confint.nls}} in package \CRANpkg{MASS}.
%}
%\examples{
%fit <- lm(100/mpg ~ disp + hp + wt + am, data = mtcars)
%confint(fit)
%confint(fit, "wt")
%
%\donttest{## from example(glm)
%counts <- c(18,17,15,20,10,20,25,13,12)
%outcome <- gl(3, 1, 9); treatment <- gl(3, 3)
%glm.D93 <- glm(counts ~ outcome + treatment, family = poisson())
%confint(glm.D93) # needs MASS to be installed
%confint.default(glm.D93)  # based on asymptotic normality}
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
