% File src/library/stats/man/contrast.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{contrast}
\alias{contr.helmert}
\alias{contr.poly}
\alias{contr.sum}
\alias{contr.treatment}
\alias{contr.SAS}
%%\title{(Possibly Sparse) Contrast Matrices}
\title{対比行列}
\description{
  対比の行列を返す．
}
\usage{
contr.helmert(n, contrasts = TRUE, sparse = FALSE)
contr.poly(n, scores = 1:n, contrasts = TRUE, sparse = FALSE)
contr.sum(n, contrasts = TRUE, sparse = FALSE)
contr.treatment(n, base = 1, contrasts = TRUE, sparse = FALSE)
contr.SAS(n, contrasts = TRUE, sparse = FALSE)
}
\arguments{
  \item{n}{因子に対する水準のベクトル，又は水準数．}
  \item{contrasts}{対比を計算すべきかどうかを指示する論理値．}
  \item{sparse}{結果が祖であるべきかどうかを指示する論理値
    (クラス \code{\link[Matrix:dgCMatrix-class]{dgCMatrix}})で，
    パッケージ \CRANpkg{Matrix} を使う．}
  \item{scores}{それに対して直交多項式が計算される値の集合．}
  \item{base}{どのグループが基礎のグループであるかを指示する整数．
    \code{contrasts} が \code{FALSE} なら無視される．}
}
\details{
  これらの関数は分散分析や回帰モデルの当てはめで使う対比の行列を作るのに
  使われる．結果の行列は
  \code{n} 水準の因子のコーディングのために使うことが出来る対比を
  含む．もし引数 \code{contrasts} が \code{FALSE} ならば
  \code{contr.poly} 用
  (これは \code{contrasts = FALSE} の時は 0 次，つまり定数の
  多項式を使う)を\bold{除いて}
  正方インディケータ行列(ダミーのコーディング)を返す．

  \code{contr.helmert} は Helmert 対比を返す，これは
  二番目の水準を最初に対して対比し，三番目を最初の二つに対して対比する，
  云々．\code{contr.poly} は多項式に基づく対比を返す．
  \code{contr.sum} は\sQuote{総和がゼロ}の対比を返す．

  \code{contr.treatment} は各水準を
  基礎水準(\code{base} で指示される)に関して対比する：
  これは切片に対して直交ではないため
  線形モデルに対する標準理論で定義される\sQuote{対比}を生成しないことを注意する．

  \code{contr.SAS} は
  \code{contr.treatment} に対するラッパで，
  基本水準が因子の最後の水準になるように設定する．
  これらの対比を使った時に作られる係数は
  多くの(しかし全てではない) SAS の手続きで作られるものに
  同値であるべきである．

  一貫性のため \code{sparse} はこれら全ての対比関数に対する引数であるが，
  \code{contr.poly} に対する \code{sparse = TRUE} は典型的には
  無意味で \code{contr.helmert} に対しては滅多に使われない．
}
\value{
  \code{n} 行と \code{k} 列の行列で，
  もし \code{contrasts} が \code{TRUE} なら \code{k=n-1} で，
  またもし \code{contrasts} が \code{FALSE} なら \code{k=n}．
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical models.}
  Chapter 2 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{contrasts}},
  \code{\link{C}},% ./zC.Rd
  そして
  \code{\link{aov}},
  \code{\link{glm}},
  \code{\link{lm}}.
}
\examples{
(cH <- contr.helmert(4))
apply(cH, 2, sum) # 列和は 0
crossprod(cH) # 対角行列 -- 列は直交
contr.helmert(4, contrasts = FALSE) # 丁度 4 x 4 単位行列

(cT <- contr.treatment(5))
all(crossprod(cT) == diag(4)) # TRUE: それどころか直交

(cT. <- contr.SAS(5))
all(crossprod(cT.) == diag(4)) # TRUE

zapsmall(cP <- contr.poly(3)) # 線形と二次
zapsmall(crossprod(cP), digits = 15) # 誤差を除いて直交
}
\keyword{design}
\keyword{regression}
\keyword{array}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/contrast.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{contrast}
%\alias{contr.helmert}
%\alias{contr.poly}
%\alias{contr.sum}
%\alias{contr.treatment}
%\alias{contr.SAS}
%\title{(Possibly Sparse) Contrast Matrices}
%\description{
%  Return a matrix of contrasts.
%}
%\usage{
%contr.helmert(n, contrasts = TRUE, sparse = FALSE)
%contr.poly(n, scores = 1:n, contrasts = TRUE, sparse = FALSE)
%contr.sum(n, contrasts = TRUE, sparse = FALSE)
%contr.treatment(n, base = 1, contrasts = TRUE, sparse = FALSE)
%contr.SAS(n, contrasts = TRUE, sparse = FALSE)
%}
%\arguments{
%  \item{n}{a vector of levels for a factor, or the number of levels.}
%  \item{contrasts}{a logical indicating whether contrasts should be
%    computed.}
%  \item{sparse}{logical indicating if the result should be sparse
%    (of class \code{\link[Matrix:dgCMatrix-class]{dgCMatrix}}), using
%    package \CRANpkg{Matrix}.}
%  \item{scores}{the set of values over which orthogonal polynomials are
%    to be computed.}
%  \item{base}{an integer specifying which group is considered the
%    baseline group. Ignored if \code{contrasts} is \code{FALSE}.}
%}
%\details{
%  These functions are used for creating contrast matrices for use in
%  fitting analysis of variance and regression models.  The columns of
%  the resulting matrices contain contrasts which can be used for coding
%  a factor with \code{n} levels.  The returned value contains the
%  computed contrasts.  If the argument \code{contrasts} is \code{FALSE}
%  a square indicator matrix (the dummy coding) is returned \bold{except}
%  for \code{contr.poly} (which includes the 0-degree, i.e.\sspace{}constant,
%  polynomial when \code{contrasts = FALSE}).
%
%  \code{contr.helmert} returns Helmert contrasts, which contrast the
%  second level with the first, the third with the average of the first
%  two, and so on.  \code{contr.poly} returns contrasts based on
%  orthogonal polynomials. \code{contr.sum} uses \sQuote{sum to zero
%  contrasts}.
%
%  \code{contr.treatment} contrasts each level with the baseline level
%  (specified by \code{base}): the baseline level is omitted.  Note that
%  this does not produce \sQuote{contrasts} as defined in the standard
%  theory for linear models as they are not orthogonal to the intercept.
%
%  \code{contr.SAS} is a wrapper for \code{contr.treatment} that sets
%  the base level to be the last level of the factor.  The coefficients
%  produced when using these contrasts should be equivalent to those
%  produced by many (but not all) SAS procedures.
%
%  For consistency, \code{sparse} is an argument to all these contrast
%  functions, however \code{sparse = TRUE} for \code{contr.poly}
%  is typically pointless and is rarely useful for
%  \code{contr.helmert}.
%}
%\value{
%  A matrix with \code{n} rows and \code{k} columns, with \code{k=n-1} if
%  \code{contrasts} is \code{TRUE} and \code{k=n} if \code{contrasts} is
%  \code{FALSE}.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical models.}
%  Chapter 2 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{contrasts}},
%  \code{\link{C}},% ./zC.Rd
%  and
%  \code{\link{aov}},
%  \code{\link{glm}},
%  \code{\link{lm}}.
%}
%\examples{
%(cH <- contr.helmert(4))
%apply(cH, 2, sum) # column sums are 0
%crossprod(cH) # diagonal -- columns are orthogonal
%contr.helmert(4, contrasts = FALSE) # just the 4 x 4 identity matrix
%
%(cT <- contr.treatment(5))
%all(crossprod(cT) == diag(4)) # TRUE: even orthonormal
%
%(cT. <- contr.SAS(5))
%all(crossprod(cT.) == diag(4)) # TRUE
%
%zapsmall(cP <- contr.poly(3)) # Linear and Quadratic
%zapsmall(crossprod(cP), digits = 15) # orthonormal up to fuzz
%}
%\keyword{design}
%\keyword{regression}
%\keyword{array}
%
%\encoding{UTF-8}
%
