% File src/library/stats/man/effects.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{effects}
\title{Effects from Fitted Model}
\usage{
effects(object, \dots)

\method{effects}{lm}(object, set.sign = FALSE, \dots)
}
\alias{effects}%@%\alias{当てはめモデルからの効果}
\alias{effects.lm}
\alias{effects.glm}
\arguments{
 \item{object}{\R オブジェクト；典型的には
   \code{\link{lm}} のようなモデル当てはめ関数の結果．}
 \item{set.sign}{論理値．もし \code{TRUE} ならモデル中の
   係数に対応する効果の符号は
   対応する係数の符号と一致するように設定される，
   さもなければ符号は任意である．}
 \item{\dots}{他のメソッドに・から渡される引数．}
}
\description{
  普通線形でモルである当てはめモデルから(直交の)効果を返す．
  これは総称的関数であるが，
  現在は
  クラス \code{"lm"} と \code{"glm"} のクラスを継承するオブジェクト
  に対してだけメソッドを持つ．
}
\details{
  \code{\link{lm}} や \code{\link{aov}} で当てはめられた
  線形モデルに対しては，効果は
  当てはめ過程の途中で QR 分解で生成された引き続く直交
  部分空間にデータを射影することで得られる無相関の
  単一自由度である．
  最初の \eqn{r} (モデルのランク)は係数に関連しており，
  残りは残差の空間を張る
  (しかし特定の残差に関連してはいない)．

  空のモデルは効果を持たない．
}
\value{
  \code{\link{residuals}} と同じ長さの
  (名前付き) 数値ベクトル，又は
  当てはめモデルに複数の応答があれば行列，
  どちらのケースも
  クラス \code{"coef"} である．

  最初の \eqn{r} 行は対応する係数でラベルがつき，
  残りの行は付かない．
  ランク落ちのモデルではもしピボットが
  起きれば対応する係数は異なった順序になる．
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S.}
  Wadsworth & Brooks/Cole.
}
\seealso{\code{\link{coef}}}
\examples{
y <- c(1:3, 7, 5)
x <- c(1:3, 6:7)
( ee <- effects(lm(y ~ x)) )
c( round(ee - effects(lm(y+10 ~ I(x-3.8))), 3) )
# 最初だけが異なる
}
\keyword{models}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/effects.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{effects}
%\title{Effects from Fitted Model}
%\usage{
%effects(object, \dots)
%
%\method{effects}{lm}(object, set.sign = FALSE, \dots)
%}
%\alias{effects}
%\alias{effects.lm}
%\alias{effects.glm}
%\arguments{
% \item{object}{an \R object; typically, the result of a model fitting function
%   such as \code{\link{lm}}.}
% \item{set.sign}{logical. If \code{TRUE}, the sign of the effects
%   corresponding to coefficients in the model will be set to agree with the
%   signs of the corresponding coefficients, otherwise the sign is
%   arbitrary.}
% \item{\dots}{arguments passed to or from other methods.}
%}
%\description{
%  Returns (orthogonal) effects from a fitted model, usually a linear
%  model. This is a generic function, but currently only has a methods for
%  objects inheriting from classes \code{"lm"} and \code{"glm"}.
%}
%\details{
%  For a linear model fitted by \code{\link{lm}} or \code{\link{aov}},
%  the effects are the uncorrelated single-degree-of-freedom values
%  obtained by projecting the data onto the successive orthogonal
%  subspaces generated by the QR decomposition during the fitting
%  process. The first \eqn{r} (the rank of the model) are associated with
%  coefficients and the remainder span the space of residuals (but are
%  not associated with particular residuals).
%
%  Empty models do not have effects.
%}
%\value{
%  A (named) numeric vector of the same length as
%  \code{\link{residuals}}, or a matrix if there were multiple responses
%  in the fitted model, in either case of class \code{"coef"}.
%
%  The first \eqn{r} rows are labelled by the corresponding coefficients,
%  and the remaining rows are unlabelled.  Note that in rank-deficient
%  models the corresponding coefficients will be in a different
%  order if pivoting occurred.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S.}
%  Wadsworth & Brooks/Cole.
%}
%\seealso{\code{\link{coef}}}
%\examples{
%y <- c(1:3, 7, 5)
%x <- c(1:3, 6:7)
%( ee <- effects(lm(y ~ x)) )
%c( round(ee - effects(lm(y+10 ~ I(x-3.8))), 3) )
%# just the first is different
%}
%\keyword{models}
%\keyword{regression}
%
%\encoding{UTF-8}
%
