% File src/library/stats/man/expand.model.frame.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{expand.model.frame}
\alias{expand.model.frame}%@%\alias{モデルフレームに変数を加える}
\title{Add new variables to a model frame}
\description{
  新しい変数をそれがあたかも指定されたモデルの公式の一部であったかのように
  評価する．これは同じ \code{na.action} と
  \code{subset} 引数が適用され，そして，例えば，
  \code{x} が \code{sin(x)} を予測子に用いる
  モデルに対して回復されることを許す．
}
\usage{
expand.model.frame(model, extras,
                   envir = environment(formula(model)),
                   na.expand = FALSE)
}
\arguments{
  \item{model}{当てはめモデル．}
  \item{extras}{追加される新しい変数を記述する
  片側公式又は文字列ベクトル．}
  \item{envir}{その中で評価をする環境．}
  \item{na.expand}{論理値；下を見よ．}
}
\details{
  もし \code{na.expand = FALSE} ならば
  追加変数中の \code{NA} 値は
  \code{model} 中で使われる \code{na.action} 関数へ渡される．
  これは短いデータフレーム
  (\code{\link{na.omit}} の時)やエラー(\code{\link{na.fail}} の時)
  になるかもしれない．
  もし \code{na.expand = TRUE} ならば返されるデータフレームは
  正確に \code{model.frame(model)} と同じ行を持つが，
  追加変数に対応する列は \code{NA} を含むかもしれない．
}
\value{
  データフレーム．
}
\seealso{\code{\link{model.frame}}, \code{\link{predict}}}

\examples{
model <- lm(log(Volume) ~ log(Girth) + log(Height), data = trees)
expand.model.frame(model, ~ Girth) # データフレーム風にプリント

dd <- data.frame(x = 1:5, y = rnorm(5), z = c(1,2,NA,4,5))
model <- glm(y ~ x, data = dd, subset = 1:4, na.action = na.omit)
expand.model.frame(model, "z", na.expand = FALSE) # = 既定
expand.model.frame(model, "z", na.expand = TRUE)
}
\keyword{manip}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/expand.model.frame.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{expand.model.frame}
%\alias{expand.model.frame}
%\title{Add new variables to a model frame}
%\description{
%  Evaluates new variables as if they had been part of the formula of the
%  specified model.  This ensures that the same \code{na.action} and
%  \code{subset} arguments are applied and allows, for example, \code{x}
%  to be recovered for a model using \code{sin(x)} as a predictor.
%}
%\usage{
%expand.model.frame(model, extras,
%                   envir = environment(formula(model)),
%                   na.expand = FALSE)
%}
%\arguments{
%  \item{model}{a fitted model}
%  \item{extras}{one-sided formula or vector of character strings
%    describing new variables to be added}
%  \item{envir}{an environment to evaluate things in}
%  \item{na.expand}{logical; see below}
%}
%\details{
%  If \code{na.expand = FALSE} then \code{NA} values in the extra variables
%  will be passed to the \code{na.action} function used in
%  \code{model}.  This may result in a shorter data frame (with
%  \code{\link{na.omit}}) or an error (with \code{\link{na.fail}}).  If
%  \code{na.expand = TRUE} the returned data frame will have precisely the
%  same rows as \code{model.frame(model)}, but the columns corresponding to
%  the extra variables may contain \code{NA}.
%}
%\value{
%  A data frame.
%}
%\seealso{\code{\link{model.frame}}, \code{\link{predict}}}
%
%\examples{
%model <- lm(log(Volume) ~ log(Girth) + log(Height), data = trees)
%expand.model.frame(model, ~ Girth) # prints data.frame like
%
%dd <- data.frame(x = 1:5, y = rnorm(5), z = c(1,2,NA,4,5))
%model <- glm(y ~ x, data = dd, subset = 1:4, na.action = na.omit)
%expand.model.frame(model, "z", na.expand = FALSE) # = default
%expand.model.frame(model, "z", na.expand = TRUE)
%}
%\keyword{manip}
%\keyword{regression}
%
%\encoding{UTF-8}
%
