% File src/library/stats/man/factor.scope.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{factor.scope}
\title{Compute Allowed Changes in Adding to or Dropping from a Formula}
\usage{
add.scope(terms1, terms2)

drop.scope(terms1, terms2)

factor.scope(factor, scope)
}
\alias{add.scope}%@%\alias{公式に付加・除去できる項を求める}
\alias{drop.scope}
\alias{factor.scope}
\arguments{
 \item{terms1}{基礎モデルに対する公式の項．}
 \item{terms2}{上向き(\code{add.scope})又は下向き(\code{drop.scope})スコープ
   に対する公式の項．
   \code{drop.scope} に対して欠損していればこれは空の公式
   とされ，従って全ての項(切片を除く)が除去の候補になる．}
 \item{factor}{基礎モデルの項の \code{"factor"} 属性．}
 \item{scope}{成分 \code{drop} と \code{add} の一つ又は双方を含むリストで，
   それぞれ下向きと上向きのスコープに対する \code{"factor"} 属性を
   与える．}
}
\description{
 \code{add.scope} と \code{drop.scope} は項の階層を尊重しながら
 個別に加えたり除いたり出来る項を計算する．
}
\details{
 \code{factor.scope} はユーザが直接呼び出すことを意図していない．
}
\value{
  \code{add.scope} と \code{drop.scope} に対しては
  高ラベルの文字列ベクトル．
  \code{factor.scope} に対しては成分
  \code{drop} と \code{add} のりストで，項ラベルの文字列ベクトル．
}

\seealso{\code{\link{add1}}, \code{\link{drop1}},
  \code{\link{aov}}, \code{\link{lm}}}

\examples{
add.scope( ~ a + b + c + a:b,  ~ (a + b + c)^3)
# [1] "a:c" "b:c"
drop.scope( ~ a + b + c + a:b)
# [1] "c"   "a:b"
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/factor.scope.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{factor.scope}
%\title{Compute Allowed Changes in Adding to or Dropping from a Formula}
%\usage{
%add.scope(terms1, terms2)
%
%drop.scope(terms1, terms2)
%
%factor.scope(factor, scope)
%}
%\alias{add.scope}
%\alias{drop.scope}
%\alias{factor.scope}
%\arguments{
% \item{terms1}{the terms or formula for the base model.}
% \item{terms2}{the terms or formula for the upper (\code{add.scope}) or
%   lower (\code{drop.scope}) scope. If missing for \code{drop.scope} it is
%   taken to be the null formula, so all terms (except any intercept) are
%   candidates to be dropped.}
% \item{factor}{the \code{"factor"} attribute of the terms of the base object.}
% \item{scope}{a list with one or both components \code{drop} and
%   \code{add} giving the \code{"factor"} attribute of the lower and
%   upper scopes respectively.}
%}
%\description{
% \code{add.scope} and \code{drop.scope} compute those terms that can be
% individually added to or dropped from a model while respecting the
% hierarchy of terms.
%}
%\details{
% \code{factor.scope} is not intended to be called directly by users.
%}
%\value{
%  For \code{add.scope} and \code{drop.scope} a character vector of
%  terms labels.  For \code{factor.scope}, a list with components
%  \code{drop} and \code{add}, character vectors of terms labels.
%}
%
%\seealso{\code{\link{add1}}, \code{\link{drop1}},
%  \code{\link{aov}}, \code{\link{lm}}}
%
%\examples{
%add.scope( ~ a + b + c + a:b,  ~ (a + b + c)^3)
%# [1] "a:c" "b:c"
%drop.scope( ~ a + b + c + a:b)
%# [1] "c"   "a:b"
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
