% File src/library/stats/man/glm.control.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{glm.control}
\alias{glm.control}%@%\alias{GLM 当てはめの制御用補助関数}
\title{Auxiliary for Controlling GLM Fitting}
\description{
  \code{\link{glm}} 当てはめに対する補助関数．
  典型的には \code{\link{glm.fit}} により内部的にのみ使われるが，
  どちらの関数に対する
  \code{control} 引数を作るのにも使うことが出来る．
}
\usage{
glm.control(epsilon = 1e-8, maxit = 25, trace = FALSE)
}
\arguments{
  \item{epsilon}{正の収束許容度 \eqn{\epsilon}；
    繰り返しは
    \eqn{|dev - dev_{old}|/(|dev| + 0.1) < \epsilon} の時
    収束する．}
  \item{maxit}{IWLS 繰り返しの最大数を与える整数．}
  \item{trace}{各繰り返し毎に出力を作るかどうかを指示する論理値．}
}
\details{
  \code{\link{glm}} への \code{control} 引数は既定では
  \code{\link{glm.fit}} の \code{control} 引数に渡される，
  これはその要素を
  \code{glm.control} への引数として使う：後者は
  既定値と健全さのチェックを提供する．

  もし \code{epsilon} が小さければ(\eqn{10^{-10}}{1e-10} 未満)，
  それは又最少二乗解中の共線性の検出に対する許容度として使われる．

  \code{trace} が真の時，
  \code{\link{cat}} への呼び出しが
  各 IWLS 繰り返しに対する出力を作る．
  従って精度を高めるために \code{\link{options}(digits = *)}
  を使うことが出来る，例を見よ．
}
\value{
  引数で名前が付いた成分のリスト．
}
\references{
  Hastie, T. J. and Pregibon, D. (1992)
  \emph{Generalized linear models.}
  Chapter 6 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{glm}} により使われる当てはめ手順 \code{\link{glm.fit}}．
}
\examples{\donttest{
### example(glm) のバリエーション：

## Annette Dobson の例 ...
counts <- c(18,17,15,20,10,20,25,13,12)
outcome <- gl(3,1,9)
treatment <- gl(3,3)
oo <- options(digits = 12) # トレース時により多くを見る：
glm.D93X <- glm(counts ~ outcome + treatment, family = poisson(),
                trace = TRUE, epsilon = 1e-14)
options(oo)
coef(glm.D93X) # 最後の二つは ?glm の glm.D93 よりもゼロに近い
}}
\keyword{optimize}
\keyword{models}


\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/glm.control.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{glm.control}
%\alias{glm.control}
%\title{Auxiliary for Controlling GLM Fitting}
%\description{
%  Auxiliary function for \code{\link{glm}} fitting.
%  Typically only used internally by \code{\link{glm.fit}}, but may be
%  used to construct a \code{control} argument to either function.
%}
%\usage{
%glm.control(epsilon = 1e-8, maxit = 25, trace = FALSE)
%}
%\arguments{
%  \item{epsilon}{positive convergence tolerance \eqn{\epsilon};
%    the iterations converge when
%    \eqn{|dev - dev_{old}|/(|dev| + 0.1) < \epsilon}.}
%  \item{maxit}{integer giving the maximal number of IWLS iterations.}
%  \item{trace}{logical indicating if output should be produced for each
%    iteration.}
%}
%\details{
%  The \code{control} argument of \code{\link{glm}} is by default passed
%  to the \code{control} argument of \code{\link{glm.fit}}, which uses
%  its elements as arguments to \code{glm.control}: the latter provides
%  defaults and sanity checking.
%
%  If \code{epsilon} is small (less than \eqn{10^{-10}}{1e-10}) it is
%  also used as the tolerance for the detection of collinearity in the
%  least squares solution.
%
%  When \code{trace} is true, calls to \code{\link{cat}} produce the
%  output for each IWLS iteration.  Hence, \code{\link{options}(digits = *)}
%  can be used to increase the precision, see the example.
%}
%\value{
%  A list with components named as the arguments.
%}
%\references{
%  Hastie, T. J. and Pregibon, D. (1992)
%  \emph{Generalized linear models.}
%  Chapter 6 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{glm.fit}}, the fitting procedure used by \code{\link{glm}}.
%}
%\examples{\donttest{
%### A variation on  example(glm) :
%
%## Annette Dobson's example ...
%counts <- c(18,17,15,20,10,20,25,13,12)
%outcome <- gl(3,1,9)
%treatment <- gl(3,3)
%oo <- options(digits = 12) # to see more when tracing :
%glm.D93X <- glm(counts ~ outcome + treatment, family = poisson(),
%                trace = TRUE, epsilon = 1e-14)
%options(oo)
%coef(glm.D93X) # the last two are closer to 0 than in ?glm's  glm.D93
%}}
%\keyword{optimize}
%\keyword{models}
%
%
%\encoding{UTF-8}
%
