% File src/library/stats/man/lm.influence.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{lm.influence}
\title{Regression Diagnostics}
\usage{
influence(model, \dots)
\method{influence}{lm}(model, do.coef = TRUE, \dots)
\method{influence}{glm}(model, do.coef = TRUE, \dots)

lm.influence(model, do.coef = TRUE)
}
\alias{lm.influence}%@%\alias{回帰診断}
\alias{influence}
\alias{influence.lm}
\alias{influence.glm}
\arguments{
  \item{model}{
    \code{\link{lm}} や \code{\link{glm}} が返すようなオブジェクト．}
  \item{do.coef}{
    変更された \code{coefficients} 
    (下を見よ)が必要かどうかを指示する論理値．
    これは \eqn{O(n^2 p)} 倍の計算時間が必要になる．}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
}
\description{
  この関数は回帰当てはめの品位をチェックするための
  様々な種類の診断を作るのに使われる基本量を提供する．
}
\details{
  \bold{関連}節で挙げられた \code{\link{influence.measures}()} と
  他の関数は多種類の回帰診断を計算するユーザー試行の方法を提供する．
  それら全ては \code{lm.influence} の上に作られている．
  (恒等リンクのガウシアンファミリを除く) GLM に対してはこれらは
  一ステップの近似に基づいており，
  高度の影響をもつケースに対しては不十分かもしれない．

  確率 1 をもつ計算されたハット値は 1 として扱われることを
  保証するように工夫がされており，
  \code{sigma} と d \code{coefficients} の対応する行は \code{NaN} である．
  (そうしたケースを除くと普通変数が除かれる結果になり，
  従って単純な一つを除く診断が不可能になる．)

  \code{\link{naresid}} が結果に適用され，従って
  もし当てはめが \code{na.action = na.exclude} を持てば
  それを \code{NA} で埋める．
}
\value{
  次の同じ長さか，ゼロでない重みの数である行数 \eqn{n} である
  成分を含むリスト．当てはめで除外されたケースは
  (\code{\link{na.exclude}} のように)それらを回復する
  \code{\link{na.action}} メソッドが使われたのでなければ
  除外される

  \item{hat}{\sQuote{ハット}行列の対角部分を含むベクトル．}
  \item{coefficients}{(\code{do.coef} が偽でない限り)その
    i 番目の行が i 番目のケースを回帰から除いた時の推定係数の
    変化を含む行列．
    別名化された係数は行列に含まれないことを注意する．}
  \item{sigma}{
    i 番目の要素が i 番目のケースを回帰から除いた時の残差標準偏差の
    推定値を含むベクトル．
    行列．(GLM に対して必要な近似は
    \code{NaN} という結果になり得る)．}
  \item{wt.res}{
    \emph{重み付き}(またはクラス \code{glm} に対してはむしろ
    \emph{逸脱度})残差のベクトル．}
}
\note{
  \R バージョンの \code{lm.influence} が返す
  \code{coefficients} は S が計算するものとは異なる．
  各ケースを除いた結果の係数を返す代わりに
  係数の変化を返す．
  これは診断の目安としてより直接に役立つ．\cr
  これは \eqn{O(n^2 p)} 倍の計算時間を必要とするため，
  \code{do.coef = FALSE} で除くことが出来る．

  \code{weights == 0} のケースは\emph{捨てられる}
  (S 中の状況とは異なり)ことを注意する．

  もしモデルが
  \code{na.action = na.exclude} で当てはめられると
  (\code{\link{na.exclude}} を見よ)，当てはめで除外されたケースがここでは
  考慮\emph{される}．
}
\references{
  \code{\link{influence.measures}} に対するドキュメント中のリストを見よ．

  Chambers, J. M. (1992)
  \emph{Linear models.}
  Chapter 4 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\seealso{
\code{\link{summary}} と関連するメソッドには \code{\link{summary.lm}}．\cr 
\code{\link{influence.measures}},\cr
ハット行列の対角成分に対しては \code{\link{hat}}，\cr
\code{\link{dfbetas}},
\code{\link{dffits}},
\code{\link{covratio}},
\code{\link{cooks.distance}},
\code{\link{lm}}．
}
\examples{
## Belsley, Kuh and Welsch 中の生涯貯蓄データの解析
summary(lm.SR <- lm(sr ~ pop15 + pop75 + dpi + ddpi,
                    data = LifeCycleSavings),
        corr = TRUE)
utils::str(lmI <- lm.influence(lm.SR))

## より多くの"ユーザーレベル"の例は example(influence.measures) を使う
}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/lm.influence.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{lm.influence}
%\title{Regression Diagnostics}
%\usage{
%influence(model, \dots)
%\method{influence}{lm}(model, do.coef = TRUE, \dots)
%\method{influence}{glm}(model, do.coef = TRUE, \dots)
%
%lm.influence(model, do.coef = TRUE)
%}
%\alias{lm.influence}
%\alias{influence}
%\alias{influence.lm}
%\alias{influence.glm}
%\arguments{
%  \item{model}{an object as returned by \code{\link{lm}} or \code{\link{glm}}.}
%  \item{do.coef}{logical indicating if the changed \code{coefficients}
%    (see below) are desired.  These need \eqn{O(n^2 p)} computing time.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\description{
%  This function provides the basic quantities which are
%  used in forming a wide variety of diagnostics for
%  checking the quality of regression fits.
%}
%\details{
%  The \code{\link{influence.measures}()} and other functions listed in
%  \bold{See Also} provide a more user oriented way of computing a
%  variety of regression diagnostics.  These all build on
%  \code{lm.influence}.  Note that for GLMs (other than the Gaussian
%  family with identity link) these are based on one-step approximations
%  which may be inadequate if a case has high influence.
%
%  An attempt is made to ensure that computed hat values that are
%  probably one are treated as one, and the corresponding rows in
%  \code{sigma} and \code{coefficients} are \code{NaN}.  (Dropping such a
%  case would normally result in a variable being dropped, so it is not
%  possible to give simple drop-one diagnostics.)
%
%  \code{\link{naresid}} is applied to the results and so will fill in
%  with \code{NA}s it the fit had \code{na.action = na.exclude}.
%}
%\value{
%  A list containing the following components of the same length or
%  number of rows \eqn{n}, which is the number of non-zero weights.
%  Cases omitted in the fit are omitted unless a \code{\link{na.action}}
%  method was used (such as \code{\link{na.exclude}}) which restores them.
%
%  \item{hat}{a vector containing the diagonal of the \sQuote{hat} matrix.}
%  \item{coefficients}{(unless \code{do.coef} is false) a matrix whose
%    i-th row contains the change in the estimated coefficients which
%    results when the i-th case is dropped from the regression.  Note
%    that aliased coefficients are not included in the matrix.}
%  \item{sigma}{a vector whose i-th element contains the estimate
%    of the residual standard deviation obtained when the i-th
%    case is dropped from the regression.  (The approximations needed for
%    GLMs can result in this being \code{NaN}.)}
%  \item{wt.res}{a vector of \emph{weighted} (or for class \code{glm}
%    rather \emph{deviance}) residuals.}
%}
%\note{
%  The \code{coefficients} returned by the \R version
%  of \code{lm.influence} differ from those computed by S.
%  Rather than returning the coefficients which result
%  from dropping each case, we return the changes in the coefficients.
%  This is more directly useful in many diagnostic measures.\cr
%  Since these need \eqn{O(n^2 p)} computing time, they can be omitted by
%  \code{do.coef = FALSE}.
%
%  Note that cases with \code{weights == 0} are \emph{dropped} (contrary
%  to the situation in S).
%
%  If a model has been fitted with \code{na.action = na.exclude} (see
%  \code{\link{na.exclude}}), cases excluded in the fit \emph{are}
%  considered here.
%}
%\references{
%  See the list in the documentation for \code{\link{influence.measures}}.
%
%  Chambers, J. M. (1992)
%  \emph{Linear models.}
%  Chapter 4 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\seealso{
%\code{\link{summary.lm}} for \code{\link{summary}} and related methods;\cr
%\code{\link{influence.measures}},\cr
%\code{\link{hat}} for the hat matrix diagonals,\cr
%\code{\link{dfbetas}},
%\code{\link{dffits}},
%\code{\link{covratio}},
%\code{\link{cooks.distance}},
%\code{\link{lm}}.
%}
%\examples{
%## Analysis of the life-cycle savings data
%## given in Belsley, Kuh and Welsch.
%summary(lm.SR <- lm(sr ~ pop15 + pop75 + dpi + ddpi,
%                    data = LifeCycleSavings),
%        corr = TRUE)
%utils::str(lmI <- lm.influence(lm.SR))
%
%## For more "user level" examples, use example(influence.measures)
%}
%\keyword{regression}
%
%\encoding{UTF-8}
%
