% File src/library/stats/man/median.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2016 R Core Team
% Distributed under GPL 2 or later

\name{median}
\title{Median Value}
\alias{median}%@%\alias{標本メディアンを計算}
\alias{median.default}
\usage{
median(x, na.rm = FALSE)
}
\arguments{
  \item{x}{メソッドが定義されているオブジェクト，または
    そのメディアンを計算すべき値を含む数値ベクトル．}
  \item{na.rm}{計算が行われる前に
    \code{NA} を除くかどうかを指示する論理値．}
}
\description{
  標本メディアンを計算する．
}
\details{
  これは総称的な関数で，それに対するメソッドを書くことが出来る．
  しかしながら，既定のメソッドは
  パッケージ \pkg{base} からの
  全てが総称的な \code{is.na}, \code{sort} そして \code{mean} を
  使うので，既定メソッドはメディアンが合理的に考えられる
  殆どのクラス(例えば，\code{"\link{Date}"})に対して動作する．
}
\value{
  既定のメソッドは
  \code{x} と同じタイプの長さ 1 のオブジェクトを返す．
  例外は \code{x} が論理値か偶数の長さの整数の時で
  結果は実数になる．

  値が無いか，またはもし \code{na.rm = FALSE} で \code{NA} 値が
  あれば結果は \code{x} と同じタイプの \code{NA} である
  (又はより一般に \code{x[FALSE][NA]} の結果)．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{一般的なクォンタイルについては \code{\link{quantile}}．}
\examples{
median(1:4)                # = 2.5 [偶数]
median(c(1:3, 100, 1000))  # = 3 [奇数，頑健]
}
\keyword{univar}
\keyword{robust}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/median.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{median}
%\title{Median Value}
%\alias{median}
%\alias{median.default}
%\usage{
%median(x, na.rm = FALSE)
%}
%\arguments{
%  \item{x}{an object for which a method has been defined, or a
%    numeric vector containing the values whose median is to be computed.}
%  \item{na.rm}{a logical value indicating whether \code{NA}
%    values should be stripped before the computation proceeds.}
%}
%\description{
%  Compute the sample median.
%}
%\details{
%  This is a generic function for which methods can be written.  However,
%  the default method makes use of \code{is.na}, \code{sort} and
%  \code{mean} from package \pkg{base} all of which are generic, and so
%  the default method will work for most classes
%  (e.g., \code{"\link{Date}"}) for which a median is a reasonable
%  concept.
%}
%\value{
%  The default method returns a length-one object of the same type as
%  \code{x}, except when \code{x} is logical or integer of even length,
%  when the result will be double.
%
%  If there are no values or if \code{na.rm = FALSE} and there are \code{NA}
%  values the result is \code{NA} of the same type as \code{x} (or more
%  generally the result of \code{x[FALSE][NA]}).
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{\code{\link{quantile}} for general quantiles.}
%\examples{
%median(1:4)                # = 2.5 [even number]
%median(c(1:3, 100, 1000))  # = 3 [odd, robust]
%}
%\keyword{univar}
%\keyword{robust}
%
%\encoding{UTF-8}
%
