% File src/library/stats/man/plot.lm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{plot.lm}
\alias{plot.lm}%@%\alias{lm オブジェクトに対する診断図を描く}
% \alias{plot.mlm} %which is .NotYetImplemented()
\title{Plot Diagnostics for an lm Object}
\usage{
\method{plot}{lm}(x, which = c(1:3, 5), %% was which = 1:4
     caption = list("Residuals vs Fitted", "Normal Q-Q",
       "Scale-Location", "Cook's distance",
       "Residuals vs Leverage",
       expression("Cook's dist vs Leverage  " * h[ii] / (1 - h[ii]))),
     panel = if(add.smooth) panel.smooth else points,
     sub.caption = NULL, main = "",
     ask = prod(par("mfcol")) < length(which) && dev.interactive(),
     \dots,
     id.n = 3, labels.id = names(residuals(x)), cex.id = 0.75,
     qqline = TRUE, cook.levels = c(0.5, 1.0),
     add.smooth = getOption("add.smooth"), label.pos = c(4,2),
     cex.caption = 1, cex.oma.main = 1.25)
}
\arguments{
  \item{x}{\code{lm} オブジェクト，典型的には
    \code{\link{lm}} や \code{\link{glm}} の結果．}
  \item{which}{もしプロットの一部が必要なら，番号
    \code{1:6} の一部分を指定する．}
  \item{caption}{プロットの上に現れるキャプション；
    文字列ベクトル又は適正なグラフィックス注釈のリスト，
    \code{\link{as.graphicsAnnot}} を見よ．
    長さは 6 で j 番目の項目は
    \code{which[j]} に対応する．全てのキャプションを抑制するには
    \code{""} か \code{NA} を設定できる．
  }
  \item{panel}{パネル関数．\code{\link{points}} に対する有用な代替物，
    \code{\link{panel.smooth}} は\cr
    \code{add.smooth = TRUE} で選択できる．}
  \item{sub.caption}{共通タイトル---もし複数あれば図の上部；
    さもなければ \code{sub} (\code{\link{title}} を見よ)．
    もし既定である \code{NULL} ならば
    可能な \code{deparse(x$call)} の省略バージョンが使われる．}
  \item{main}{各プロットへのタイトル---\code{caption} に加えて．}
  \item{ask}{論理値；もし \code{TRUE} ならば，
     各プロットの前に確認がある，
    \code{\link{par}(ask=.)} を見よ．}
  \item{\dots}{プロット関数に渡される他のパラメータ．}
  \item{id.n}{各プロット中でラベルが付く点の数，
    最も極端なものから始まる．}
  \item{labels.id}{ラベルのベクトルで，
    そこから極端な点に対するラベルが選ばれる．
    \code{NULL} は観測番号を使う．}
  \item{cex.id}{点ラベルの拡大率．}
  \item{qqline}{
    \code{\link{qqline}()} を
    正規 Q-Q プロットに加えるべきかどうかを指示する論理値．}
  \item{cook.levels}{等高線が描かれる Cook 距離の水準．}
  \item{add.smooth}{
    殆どのプロットに平滑化を加えるべきかどうかを指示する論理値；
    上の \code{panel} も見よ．}
  \item{label.pos}{プロット 1-3 に対して，ラベルの位置決め，
    それぞれグラフの左半分と右半分．}
  \item{cex.caption}{
    \code{caption} のサイズを制御する．}
  \item{cex.oma.main}{
    複数のプロットがありそれが図の\emph{上}にある時だけ，
    \code{sub.caption} のサイズを制御する．}
}
\description{
  6種類のプロットが現在利用できる(\code{which} で選択可能)：
  当てはめ値に対する残差のプロット，
  当てはめ値に対する \eqn{\sqrt{| residuals |}}{sqrt(| residuals |)} の
  スケール-ロケーションプロット，
  正規 Q-Q プロット，
  生のラベルに対する Cook 距離のプロット，
  梃子値に対する残差のプロット，そして
  leverage/(1-leverage) に対する
  Coo 距離のプロットである．既定では
  最初の三つと五番目が提供される．
}
\details{
  \code{sub.caption}---既定では関数呼び出し---は
  プロットが別の頁にあるときは各プロット上に
  副タイトルとして(x 軸タイトルの下に)示される．
  さもなければ，ページ毎に複数のプロットがある時には
  外部余白(もしあれば)中の副タイトルとして示される．

  \sQuote{スケール-ロケーション}プロットはまた
  \sQuote{Spread-Location} や \sQuote{S-L} プロットとも呼ばれ，
  歪みを減らすために絶対残差の平方根を取る
  (\eqn{\sqrt{| E |}}{sqrt(|E|)} は平均 0 のガウシアン \eqn{E}
  に対して \eqn{| E |} よりもはるかに歪みが少ない)．

  \sQuote{S-L}, Q-Q そして残差-梃子値プロットは
  (仮定の下では)同じ分散を持つ
  \emph{標準化}残差を使う．
  これらは \eqn{R_i / (s \times \sqrt{1 - h_{ii}})}{R[i] / (s * sqrt(1 - h.ii))}
  として与えられ，ここで
  \eqn{h_{ii}}{h.ii} は
  ハット行列
  \code{\link{influence}()$hat} (\code{\link{hat}} も見よ)
  の対角成分で，そして,
  残差-梃子値プロットは \eqn{R[i]} として標準化ペアソン残差
  (\code{\link{residuals.glm}(type = "pearson")})を使う． 

  残差-梃子値プロットは
  値 \code{cook.levels} (既定では 0.5 と 1)に対する
  等しい Cook 距離の等高線を示し，
  梃子値が 1 のケースは警告と共に除外する．
  もし梃子値が定数のケースでは
  (釣り合い型 AOV の状況では典型的にそうなる)
  プロットは x 軸に対して梃子値の代わりに因子水準の組み合わせを使う．

  Cook 距離対 leverage/(1-leverage) のプロットでは，
  同じ大きさの標準化残差等高線は原点を通る．
  等高線は大きさでラベルが付けられる．
}
\references{
  Belsley, D. A., Kuh, E. and Welsch, R. E. (1980)
  \emph{Regression Diagnostics.}  New York: Wiley.

  Cook, R. D. and Weisberg, S. (1982)
  \emph{Residuals and Influence in Regression.}
  London: Chapman and Hall.

  Firth, D. (1991) Generalized Linear Models.  In Hinkley, D. V. and
  Reid, N. and Snell, E. J., eds: Pp.\sspace{}55-82 in Statistical Theory and
  Modelling. In Honour of Sir David Cox, FRS.  London: Chapman and Hall.

  Hinkley, D. V. (1975) On power transformations to
  symmetry. \emph{Biometrika} \bold{62}, 101--111.

  McCullagh, P. and Nelder, J. A. (1989)
  \emph{Generalized Linear Models.}
  London: Chapman and Hall.
}
\author{
  John Maindonald と Martin Maechler．
}
\seealso{\code{\link{termplot}}, \code{\link{lm.influence}},
  \code{\link{cooks.distance}}, \code{\link{hatvalues}}.
}
\examples{
require(graphics)

## Belsley, Kuh and Welsch で与えられた生涯貯蓄データの解析
lm.SR <- lm(sr ~ pop15 + pop75 + dpi + ddpi, data = LifeCycleSavings)
plot(lm.SR)

## 一頁に 4 つのプロット；
## モデル公式を外部余白にプリントする隙間を許す
par(mfrow = c(2, 2), oma = c(0, 0, 2, 0))
plot(lm.SR)
plot(lm.SR, id.n = NULL)                 # id 無し
plot(lm.SR, id.n = 5, labels.id = NULL)  # 5 つの id 番号

## R <= 2.1.x では既定であった：
## 残差梃子値プロットの代わりに Cook 距離
plot(lm.SR, which = 1:4)

## 可能ならば滑らかなカーブを当てはめ：
plot(lm.SR, panel = panel.smooth)
## 滑らかなカーブを与える
plot(lm.SR, panel = function(x, y) panel.smooth(x, y, span = 1))

par(mfrow = c(2,1))  # 上と同じ oma
plot(lm.SR, which = 1:2, sub.caption = "Saving Rates, n=50, p=5")

\dontshow{
##短縮化が必要な*長い*公式の例：
for(i in 1:5) assign(paste("long.var.name", i, sep = "."), runif(10))
plot(lm(long.var.name.1 ~
        long.var.name.2 + long.var.name.3 + long.var.name.4 + long.var.name.5))
}
}
\keyword{hplot}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/plot.lm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{plot.lm}
%\alias{plot.lm}
%% \alias{plot.mlm} %which is .NotYetImplemented()
%\title{Plot Diagnostics for an lm Object}
%\usage{
%\method{plot}{lm}(x, which = c(1:3, 5), %% was which = 1:4
%     caption = list("Residuals vs Fitted", "Normal Q-Q",
%       "Scale-Location", "Cook's distance",
%       "Residuals vs Leverage",
%       expression("Cook's dist vs Leverage  " * h[ii] / (1 - h[ii]))),
%     panel = if(add.smooth) panel.smooth else points,
%     sub.caption = NULL, main = "",
%     ask = prod(par("mfcol")) < length(which) && dev.interactive(),
%     \dots,
%     id.n = 3, labels.id = names(residuals(x)), cex.id = 0.75,
%     qqline = TRUE, cook.levels = c(0.5, 1.0),
%     add.smooth = getOption("add.smooth"), label.pos = c(4,2),
%     cex.caption = 1, cex.oma.main = 1.25)
%}
%\arguments{
%  \item{x}{\code{lm} object, typically result of \code{\link{lm}} or
%    \code{\link{glm}}.}
%  \item{which}{if a subset of the plots is required, specify a subset of
%    the numbers \code{1:6}.}
%  \item{caption}{captions to appear above the plots;
%    \code{\link{character}} vector or \code{\link{list}} of valid
%    graphics annotations, see \code{\link{as.graphicsAnnot}}, of length
%    6, the j-th entry corresponding to \code{which[j]}.  Can be set to
%    \code{""} or \code{NA} to suppress all captions.
%  }
%  \item{panel}{panel function.  The useful alternative to
%    \code{\link{points}}, \code{\link{panel.smooth}} can be chosen
%    by \code{add.smooth = TRUE}.}
%  \item{sub.caption}{common title---above the figures if there are more
%    than one; used as \code{sub} (s.\code{\link{title}}) otherwise.  If
%    \code{NULL}, as by default, a possible abbreviated version of
%    \code{deparse(x$call)} is used.}
%  \item{main}{title to each plot---in addition to \code{caption}.}
%  \item{ask}{logical; if \code{TRUE}, the user is \emph{ask}ed before
%    each plot, see \code{\link{par}(ask=.)}.}
%  \item{\dots}{other parameters to be passed through to plotting
%    functions.}
%  \item{id.n}{number of points to be labelled in each plot, starting
%    with the most extreme.}
%  \item{labels.id}{vector of labels, from which the labels for extreme
%    points will be chosen.  \code{NULL} uses observation numbers.}
%  \item{cex.id}{magnification of point labels.}
%  \item{qqline}{logical indicating if a \code{\link{qqline}()} should be
%    added to the normal Q-Q plot.}
%  \item{cook.levels}{levels of Cook's distance at which to draw contours.}
%  \item{add.smooth}{logical indicating if a smoother should be added to
%    most plots; see also \code{panel} above.}
%  \item{label.pos}{positioning of labels, for the left half and right
%    half of the graph respectively, for plots 1-3.}
%  \item{cex.caption}{controls the size of \code{caption}.}
%  \item{cex.oma.main}{controls the size of the \code{sub.caption} only if
%    that is \emph{above} the figures when there is more than one.}
%}
%\description{
%  Six plots (selectable by \code{which}) are currently available: a plot
%  of residuals against fitted values, a Scale-Location plot of
%  \eqn{\sqrt{| residuals |}}{sqrt(| residuals |)}
%  against fitted values, a Normal Q-Q plot, a
%  plot of Cook's distances versus row labels, a plot of residuals
%  against leverages, and a plot of Cook's distances against
%  leverage/(1-leverage).  By default, the first three and \code{5} are
%  provided.
%}
%\details{
%  \code{sub.caption}---by default the function call---is shown as
%  a subtitle (under the x-axis title) on each plot when plots are on
%  separate pages, or as a subtitle in the outer margin (if any) when
%  there are multiple plots per page.
%
%  The \sQuote{Scale-Location} plot, also called \sQuote{Spread-Location} or
%  \sQuote{S-L} plot, takes the square root of the absolute residuals in
%  order to diminish skewness (\eqn{\sqrt{| E |}}{sqrt(|E|)}) is much less skewed
%  than \eqn{| E |} for Gaussian zero-mean \eqn{E}).
%
%  The \sQuote{S-L}, the Q-Q, and the Residual-Leverage plot, use
%  \emph{standardized} residuals which have identical variance (under the
%  hypothesis).  They are given as
%  \eqn{R_i / (s \times \sqrt{1 - h_{ii}})}{R[i] / (s * sqrt(1 - h.ii))}
%  where \eqn{h_{ii}}{h.ii} are the diagonal entries of the hat matrix,
%  \code{\link{influence}()$hat} (see also \code{\link{hat}}), and
%  where the Residual-Leverage plot uses standardized Pearson residuals
%  (\code{\link{residuals.glm}(type = "pearson")}) for \eqn{R[i]}.
%
%  The Residual-Leverage plot shows contours of equal Cook's distance,
%  for values of \code{cook.levels} (by default 0.5 and 1) and omits
%  cases with leverage one with a warning.  If the leverages are constant
%  (as is typically the case in a balanced \code{\link{aov}} situation)
%  the plot uses factor level combinations instead of the leverages for
%  the x-axis.  (The factor levels are ordered by mean fitted value.)
%
%  In the Cook's distance vs leverage/(1-leverage) plot, contours of
%  standardized residuals that are equal in magnitude are lines through
%  the origin.  The contour lines are labelled with the magnitudes.
%}
%\references{
%  Belsley, D. A., Kuh, E. and Welsch, R. E. (1980)
%  \emph{Regression Diagnostics.}  New York: Wiley.
%
%  Cook, R. D. and Weisberg, S. (1982)
%  \emph{Residuals and Influence in Regression.}
%  London: Chapman and Hall.
%
%  Firth, D. (1991) Generalized Linear Models.  In Hinkley, D. V. and
%  Reid, N. and Snell, E. J., eds: Pp.\sspace{}55-82 in Statistical Theory and
%  Modelling. In Honour of Sir David Cox, FRS.  London: Chapman and Hall.
%
%  Hinkley, D. V. (1975) On power transformations to
%  symmetry. \emph{Biometrika} \bold{62}, 101--111.
%
%  McCullagh, P. and Nelder, J. A. (1989)
%  \emph{Generalized Linear Models.}
%  London: Chapman and Hall.
%}
%\author{
%  John Maindonald and Martin Maechler.
%}
%\seealso{\code{\link{termplot}}, \code{\link{lm.influence}},
%  \code{\link{cooks.distance}}, \code{\link{hatvalues}}.
%}
%\examples{
%require(graphics)
%
%## Analysis of the life-cycle savings data
%## given in Belsley, Kuh and Welsch.
%lm.SR <- lm(sr ~ pop15 + pop75 + dpi + ddpi, data = LifeCycleSavings)
%plot(lm.SR)
%
%## 4 plots on 1 page;
%## allow room for printing model formula in outer margin:
%par(mfrow = c(2, 2), oma = c(0, 0, 2, 0))
%plot(lm.SR)
%plot(lm.SR, id.n = NULL)                 # no id's
%plot(lm.SR, id.n = 5, labels.id = NULL)  # 5 id numbers
%
%## Was default in R <= 2.1.x:
%## Cook's distances instead of Residual-Leverage plot
%plot(lm.SR, which = 1:4)
%
%## Fit a smooth curve, where applicable:
%plot(lm.SR, panel = panel.smooth)
%## Gives a smoother curve
%plot(lm.SR, panel = function(x, y) panel.smooth(x, y, span = 1))
%
%par(mfrow = c(2,1))  # same oma as above
%plot(lm.SR, which = 1:2, sub.caption = "Saving Rates, n=50, p=5")
%
%\dontshow{
%## An example with *long* formula that needs abbreviation:
%for(i in 1:5) assign(paste("long.var.name", i, sep = "."), runif(10))
%plot(lm(long.var.name.1 ~
%        long.var.name.2 + long.var.name.3 + long.var.name.4 + long.var.name.5))
%}
%}
%\keyword{hplot}
%\keyword{regression}
%
%\encoding{UTF-8}
%
