% File src/library/stats/man/poisson.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{poisson.test}
\alias{poisson.test}%@%\alias{ポアソン分布に対する正確検定}
\title{Exact Poisson tests}
\description{
     ポアッソン分布の割合パラメータ，
     又は二つの割合パラメータ間の比率に関する単純帰無仮説の正確検定
     を実行する．
}
\usage{
poisson.test(x, T = 1, r = 1,
    alternative = c("two.sided", "less", "greater"),
    conf.level = 0.95)
}
\arguments{
  \item{x}{イベント数．長さ 1 か 2 のベクトル．}
  \item{T}{イベントのカウントに対する時間基数．イベント数．長さ 1 か 2 のベクトル．}
  \item{r}{仮説の割合又は割合比率．}
  \item{alternative}{対立仮説を指示し，
    \code{"two.sided"}, \code{"greater"} そして \code{"less"} の
    どれかでなければならない．頭文字を指定するだけで良い．}
  \item{conf.level}{返される信頼区間に対する信頼水準．}
}
\details{
  信頼区間は
  一標本ケースでは \code{\link{binom.test}} のそれと同じように計算され，
  二標本ケースでは \code{\link{binom.test}} を使う．
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{イベント数(もし二標本なら最初の標本の)．}
  \item{parameter}{対応する期待カウント．}
  \item{p.value}{検定の p 値．}
  \item{conf.int}{割合もしくは割合比率に対する信頼区間．}
  \item{estimate}{割合もしくは割合比率の推定値．}
  \item{null.value}{帰無仮説の下での割合もしくは割合比率，\code{r}．}
  \item{alternative}{対立仮説を記述する文字列．}
  \item{method}{文字列 \code{"Exact Poisson test"} か
    \sspace{}\code{"Comparison of Poisson rates"}．}
  \item{data.name}{データの名前を与える文字列．}
}
\note{
  ポアッソン分布の割合パラメータはしばしば
  \dQuote{検査時間} や同様の量(人-年，人口サイズ，
  又は死亡表からの期待ケース数)に基づいている．これが
  \code{T} 引数の役割である．

  一標本ケースは実効的には非常に大きな
  \code{n} の二項検定である．に標本ケースは
  総継起数で条件つけた二項検定に変換され，
  割合比率は二項分布のオッズに直接関連する．
}
\seealso{
  \code{\link{binom.test}}
}
\examples{
### これらは ISwR パッケージ中のデータセットの意訳である

## 標準化死亡比，ウェールズのニッケル労働者
poisson.test(137, 24.19893)

## eba1977, Fredericia を他の三つの都市と年齢 55-59 で比較
poisson.test(c(11, 6+8+7), c(800, 1083+1050+878))
}
\keyword{htest}


\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/poisson.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{poisson.test}
%\alias{poisson.test}
%\title{Exact Poisson tests}
%\description{
%     Performs an exact test of a simple null hypothesis about the
%     rate parameter in Poisson distribution, or for the
%     ratio between two rate parameters.
%}
%\usage{
%poisson.test(x, T = 1, r = 1,
%    alternative = c("two.sided", "less", "greater"),
%    conf.level = 0.95)
%}
%\arguments{
%  \item{x}{number of events. A vector of length one or two.}
%  \item{T}{time base for event count. A vector of length one or two. }
%  \item{r}{hypothesized rate or rate ratio}
%  \item{alternative}{indicates the alternative hypothesis and must be
%    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.
%    You can specify just the initial letter.}
%  \item{conf.level}{confidence level for the returned confidence
%    interval.}
%}
%\details{
%  Confidence intervals are computed similarly to those of
%  \code{\link{binom.test}} in the one-sample case, and using
%  \code{\link{binom.test}} in the two sample case.
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the number of events (in the first sample if there
%    are two.)}
%  \item{parameter}{the corresponding expected count}
%  \item{p.value}{the p-value of the test.}
%  \item{conf.int}{a confidence interval for the rate or rate ratio.}
%  \item{estimate}{the estimated rate or rate ratio.}
%  \item{null.value}{the rate or rate ratio under the null,
%    \code{r}.}
%  \item{alternative}{a character string describing the alternative
%    hypothesis.}
%  \item{method}{the character string \code{"Exact Poisson test"} or
%    \code{"Comparison of Poisson rates"} as appropriate.}
%  \item{data.name}{a character string giving the names of the data.}
%}
%\note{
%  The rate parameter in Poisson data is often given based on a
%  \dQuote{time on test} or similar quantity (person-years, population
%  size, or expected number of cases from mortality tables). This is the
%  role of the \code{T} argument.
%
%  The one-sample case is effectively the binomial test with a very large
%  \code{n}. The two sample case is converted to a binomial test by
%  conditioning on the total event count, and the rate ratio is directly
%  related to the odds in that binomial distribution.
%}
%\seealso{
%  \code{\link{binom.test}}
%}
%\examples{
%### These are paraphrased from data sets in the ISwR package
%
%## SMR, Welsh Nickel workers
%poisson.test(137, 24.19893)
%
%## eba1977, compare Fredericia to other three cities for ages 55-59
%poisson.test(c(11, 6+8+7), c(800, 1083+1050+878))
%}
%\keyword{htest}
%
%
%\encoding{UTF-8}
%
