% File src/library/stats/man/predict.glm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{predict.glm}
\alias{predict.glm}%@%\alias{一般化線形モデル当てはめに対する予測}
\concept{regression}
\title{Predict Method for GLM Fits}
\usage{
\method{predict}{glm}(object, newdata = NULL,
            type = c("link", "response", "terms"),
            se.fit = FALSE, dispersion = NULL, terms = NULL,
            na.action = na.pass, \dots)
}
\arguments{
  \item{object}{
    \code{"glm"} からのクラスを継承するオブジェクト．}
  \item{newdata}{オプションで，
    それに対して予測を行う変数を探すデータフレーム．
    もし省略されると当てはめられた線形予測量が使われる．}
  \item{type}{要求される予測のタイプ．
    既定では線形予測量のスケールに基づく；
    今一つの
    \code{"response"} は応答変数のスケールに基づく．
    従って既定の二項モデルでは，既定の予測量は
    対数オッズ(対数スケールでの確率)で
    \code{type = "response"} は予測された確率を与える．
    \code{"terms"} オプションは線形予測量のスケールでのモデル公式中の
    各項の予測値を与える行列を返す．

    この引数の値は短縮化出来る．
  }
  \item{se.fit}{標準誤差が必要かどうかを指示する論理値．}
  \item{dispersion}{
    標準誤差の計算中で仮定される GLM 当てはめの散布度．
    もし省略されるとオブジェクトに適用された \code{summary} が返すものが使われる．}
  \item{terms}{
    \code{type = "terms"} では既定で全ての項が返される．
    どの項を返すべきかを指示する文字列．}
  \item{na.action}{
    \code{newdata} 中の欠損値をどのように処理するかを決める関数．
    既定では \code{NA} を予測する．}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
}
\description{
  当てはめ一般化線形モデルオブジェクトからの
  予測と，オプションで推定標準誤差を得る．
}
\details{
  もし \code{newdata} が省略されると予測は当てはめに使われた
  データに基づく．
  その場合オリジナルの当てはめ中の欠損値を持つケースの処理は
  当てはめの \code{na.action} 引数により決定される．
  もし \code{na.action = na.omit} ならば省略されたケースは
  残差には現れず，一方で
  もし \code{na.action = na.exclude} ならばそれらは
  (予測と標準誤差中に)残差 \code{NA} で現れる．
  \code{\link{napredict}} も見よ．
}
\value{
  もし \code{se.fit = FALSE} ならば予測値のベクトルもしくは行列．
  \code{type = "terms"} に対してはこれは項毎に列を持つ行列で，
  属性 \code{"constant"} を持つかもしれない．
  
  もし \code{se.fit = TRUE} ならば，次の成分を持つリスト
  \item{fit}{予測値，\code{se.fit = FALSE} に対するような．}
  \item{se.fit}{推定標準誤差．}
  \item{residual.scale}{
    標準誤差の計算で使われた散布度の平方根を与えるスカラ．}
}
\note{
  変数は最初
  \code{newdata} 中で探され，それから通常の仕方で
  探される(これは当てはめで使われた公式の環境を含む)．
  見つかった変数が
  もし提供された \code{newdata} 中のそれらと同じ長さでなければ
  警告が出る．
}
\seealso{
  \code{\link{glm}}, \code{\link{SafePrediction}}
}

\examples{
require(graphics)

## Venables and Ripley (2002, pp. 190-2.) からの例．
ldose <- rep(0:5, 2)
numdead <- c(1, 4, 9, 13, 18, 20, 0, 2, 6, 10, 12, 16)
sex <- factor(rep(c("M", "F"), c(6, 6)))
SF <- cbind(numdead, numalive = 20-numdead)
budworm.lg <- glm(SF ~ sex*ldose, family = binomial)
summary(budworm.lg)

plot(c(1,32), c(0,1), type = "n", xlab = "dose",
     ylab = "prob", log = "x")
text(2^ldose, numdead/20, as.character(sex))
ld <- seq(0, 5, 0.1)
lines(2^ld, predict(budworm.lg, data.frame(ldose = ld,
   sex = factor(rep("M", length(ld)), levels = levels(sex))),
   type = "response"))
lines(2^ld, predict(budworm.lg, data.frame(ldose = ld,
   sex = factor(rep("F", length(ld)), levels = levels(sex))),
   type = "response"))
}
\keyword{models}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/predict.glm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{predict.glm}
%\alias{predict.glm}
%\concept{regression}
%\title{Predict Method for GLM Fits}
%\usage{
%\method{predict}{glm}(object, newdata = NULL,
%            type = c("link", "response", "terms"),
%            se.fit = FALSE, dispersion = NULL, terms = NULL,
%            na.action = na.pass, \dots)
%}
%\arguments{
%  \item{object}{a fitted object of class inheriting from \code{"glm"}.}
%  \item{newdata}{optionally, a data frame in which to look for variables with
%    which to predict.  If omitted, the fitted linear predictors are used.}
%  \item{type}{the type of prediction required.  The default is on the
%    scale of the linear predictors; the alternative \code{"response"}
%    is on the scale of the response variable.  Thus for a default
%    binomial model the default predictions are of log-odds (probabilities
%    on logit scale) and \code{type = "response"} gives the predicted
%    probabilities.  The \code{"terms"} option returns a matrix giving the
%    fitted values of each term in the model formula on the linear predictor
%    scale.
%
%    The value of this argument can be abbreviated.
%  }
%  \item{se.fit}{logical switch indicating if standard errors are required.}
%  \item{dispersion}{the dispersion of the GLM fit to be assumed in
%    computing the standard errors.  If omitted, that returned by
%    \code{summary} applied to the object is used.}
%  \item{terms}{with \code{type = "terms"} by default all terms are returned.
%    A character vector specifies which terms are to be returned}
%  \item{na.action}{function determining what should be done with missing
%    values in \code{newdata}.  The default is to predict \code{NA}.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\description{
%  Obtains predictions and optionally estimates standard errors of those
%  predictions from a fitted generalized linear model object.
%}
%\details{
%  If \code{newdata} is omitted the predictions are based on the data
%  used for the fit.  In that case how cases with missing values in the
%  original fit is determined by the \code{na.action} argument of that
%  fit.  If \code{na.action = na.omit} omitted cases will not appear in
%  the residuals, whereas if \code{na.action = na.exclude} they will
%  appear (in predictions and standard errors), with residual value
%  \code{NA}.  See also \code{\link{napredict}}.
%}
%\value{
%  If \code{se.fit = FALSE}, a vector or matrix of predictions.
%  For \code{type = "terms"} this is a matrix with a column per term, and
%  may have an attribute \code{"constant"}.
%  
%  If \code{se.fit = TRUE}, a list with components
%  \item{fit}{Predictions, as for \code{se.fit = FALSE}.}
%  \item{se.fit}{Estimated standard errors.}
%  \item{residual.scale}{A scalar giving the square root of the
%    dispersion used in computing the standard errors.}
%}
%\note{
%  Variables are first looked for in \code{newdata} and then searched for
%  in the usual way (which will include the environment of the formula
%  used in the fit).  A warning will be given if the
%  variables found are not of the same length as those in \code{newdata}
%  if it was supplied.
%}
%\seealso{
%  \code{\link{glm}}, \code{\link{SafePrediction}}
%}
%
%\examples{
%require(graphics)
%
%## example from Venables and Ripley (2002, pp. 190-2.)
%ldose <- rep(0:5, 2)
%numdead <- c(1, 4, 9, 13, 18, 20, 0, 2, 6, 10, 12, 16)
%sex <- factor(rep(c("M", "F"), c(6, 6)))
%SF <- cbind(numdead, numalive = 20-numdead)
%budworm.lg <- glm(SF ~ sex*ldose, family = binomial)
%summary(budworm.lg)
%
%plot(c(1,32), c(0,1), type = "n", xlab = "dose",
%     ylab = "prob", log = "x")
%text(2^ldose, numdead/20, as.character(sex))
%ld <- seq(0, 5, 0.1)
%lines(2^ld, predict(budworm.lg, data.frame(ldose = ld,
%   sex = factor(rep("M", length(ld)), levels = levels(sex))),
%   type = "response"))
%lines(2^ld, predict(budworm.lg, data.frame(ldose = ld,
%   sex = factor(rep("F", length(ld)), levels = levels(sex))),
%   type = "response"))
%}
%\keyword{models}
%\keyword{regression}
%
%\encoding{UTF-8}
%
