% File src/library/stats/man/sd.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{sd}
\alias{sd}%@%\alias{標準偏差}
\title{Standard Deviation}
\description{
  この関数は
  \code{x} 中の値の標準偏差を計算する．
  もし \code{na.rm} が \code{TRUE} ならば欠損値は計算が進行する前に取り除かれる．
}
\usage{
sd(x, na.rm = FALSE)
}
\arguments{
  \item{x}{数値ベクトル又はそうしたものに
    \code{as.double(x)} で強制変換出来る \R オブジェクト．}
  \item{na.rm}{論理値．欠損値は取り除かれるべきか?}
}
\details{
  \code{\link{var}} と同じようにこれは分母 \eqn{n - 1} を用いる．

  長さゼロのベクトル
  (もし \code{na.rm = TRUE} ならば \code{NA} を除いた後の)は定義されずエラーを
  与える．
  長さ 1 のベクトルの標準偏差は \code{NA} である．
}
\seealso{
  その二乗に対しては \code{\link{var}} ，そして最も頑健な代替物である \code{\link{mad}}．
}
\examples{
sd(1:2) ^ 2
}
\keyword{univar}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/sd.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{sd}
%\alias{sd}
%\title{Standard Deviation}
%\description{
%  This function computes the standard deviation of the values in
%  \code{x}.
%  If \code{na.rm} is \code{TRUE} then missing values are removed before
%  computation proceeds.
%}
%\usage{
%sd(x, na.rm = FALSE)
%}
%\arguments{
%  \item{x}{a numeric vector or an \R object which is coercible to one
%    by \code{as.double(x)}.}
%  \item{na.rm}{logical.  Should missing values be removed?}
%}
%\details{
%  Like \code{\link{var}} this uses denominator \eqn{n - 1}.
%
%  The standard deviation of a zero-length vector (after removal of
%  \code{NA}s if \code{na.rm = TRUE}) is not defined and gives an error.
%  The standard deviation of a length-one vector is \code{NA}.
%}
%\seealso{
%  \code{\link{var}} for its square, and \code{\link{mad}}, the most
%  robust alternative.
%}
%\examples{
%sd(1:2) ^ 2
%}
%\keyword{univar}
%
%\encoding{UTF-8}
%
