% File src/library/stats/man/summary.glm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{summary.glm}
\alias{summary.glm}%@%\alias{一般化線形モデルの要約}
\alias{print.summary.glm}
\title{Summarizing Generalized Linear Model Fits}
\usage{
\method{summary}{glm}(object, dispersion = NULL, correlation = FALSE,
        symbolic.cor = FALSE, \dots)

\method{print}{summary.glm}(x, digits = max(3, getOption("digits") - 3),
      symbolic.cor = x$symbolic.cor,
      signif.stars = getOption("show.signif.stars"), \dots)
}
\arguments{
  \item{object}{
    クラス \code{"glm"} のオブジェクト，普通
    \code{\link{glm}} 呼び出しの結果．}
  \item{x}{
    an object of class
    クラス \code{"summary.glm"} のオブジェクト，
    \code{summary.glm} 呼び出しの結果．}
  \item{dispersion}{
    使用されるファミリに対する散布度パラメータ．
    単一の数値か，\code{object} から推測される場合は
    \code{NULL} (既定)．(\sQuote{詳細}節を見よ)．}
  \item{correlation}{論理値；
    もし \code{TRUE} なら推定パラメータの相関行列が返され
    プリントされる．}
  \item{digits}{プリントに使われる有効桁数．}
  \item{symbolic.cor}{論理値．もし \code{TRUE} なら，
    相関を数値ではなくシンボリックな形式
    (\code{\link{symnum}} を見よ)でプリントする．}
  \item{signif.stars}{論理値．もし \code{TRUE} なら，
    \sQuote{信頼星印}が各係数に対してプリントされる．}
  \item{\dots}{他の引数に・から渡される引数．}
}
\description{
  これらの関数は全て
  クラス \code{glm} か \code{summary.glm} のオブジェクトに対する
  メソッドである．
}
\details{
  \code{print.summary.glm} は
  係数，標準エラー等の整形をスマートにすべく試み，
  追加で
  もし \code{signif.stars} が \code{TRUE} なら\sQuote{信頼星印}
  を与える．
  結果の \code{coefficients} 成分は推定係数とそれらの推定標準エラーを
  それらの比と共に与える．
  この三番目の列はもし逸脱度が推定されるとラベル \code{t ratio} ，
  散布度が既知(又はファミリみより固定され)ならば \code{z ratio} が付く．
  四番目の列は Student t か正規参照分布に基づく
  t 又は z 比対応する両側 p 値を与える．
  (散布度が未知でそれからそれを推定すべき残差自由度が無いことが起き得る．
  その場合推定値は \code{NaN} である．)

  別名化された係数は返り値オブジェクトからは除かれるが
  \code{print} メソッドにより保存される．

  相関は二桁(又はシンボリックに)でプリントされる：
  実際の相関を見るには\cr
  \code{summary(object)$correlation} を直接プリントする．

  GLM の散布度は当てはめ過程では使われないが，
  標準エラーを見つけるためには必要である．
  もし \code{dispersion} が提供されないかまたは \code{NULL} ならば，
  \code{binomial} と \code{Poisson} ファミリに対しては散布度は \code{1}
  とされ，さもなければ残差カイ二乗統計量
  (ゼロでない重みのケースから計算される)
  を残差自由度で割って推定される．

  \code{summary} は
  \code{\link{summary.lm}} によっては扱えない
  既知のエラー分散を持つ線形回帰のケースを扱うガウシアン
  \code{glm} 当てはめに対して使うことが出来る．
}
\value{
  \code{summary.glm} は次の成分を持つクラス \code{"summary.glm"}
  のりストを返す

  \item{call}{\code{object} からの成分．}
  \item{family}{ \code{object}  からの成分．}
  \item{deviance}{ \code{object} からの成分．}
  \item{contrasts}{ \code{object} からの成分．}
  \item{df.residual}{ \code{object} からの成分．}
  \item{null.deviance}{ \code{object} からの成分．}
  \item{df.null}{ \code{object} からの成分．}
  \item{deviance.resid}{逸脱度残差：
    \code{\link{residuals.glm}} を見よ．}
  \item{coefficients}{
    係数，標準エラー，z 値そして p 値の行列．
    別名化された係数は除かれる．}
  \item{aliased}{
    オリジナルの係数が別名化されているどうかを示す名前付き論理値．}
  \item{dispersion}{
    提供された引数か，
    もし後者が \code{NULL} なら推定された逸脱度．}
  \item{df}{
    モデルのランクと残差自由度，加えて係数の個数
    (別名化されたものを含む)の長さ 3 のベクトル．}
  \item{cov.unscaled}{
    推定係数のスケール化されていない(\code{dispersion = 1})
    推定共分散行列．}
  \item{cov.scaled}{同上，\code{dispersion} でスケール化されている．}
  \item{correlation}{
    (\code{correlation} が真の時だけ．)
    推定係数の推定相関行列．}
  \item{symbolic.cor}{
    (\code{correlation} が真の時だけ．)
    引数 \code{symbolic.cor} の値．}
}
\seealso{
  \code{\link{glm}}, \code{\link{summary}}.
}
\examples{
## 例は example(glm) を見よ．
}
\keyword{models}
\keyword{regression}


\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/summary.glm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{summary.glm}
%\alias{summary.glm}
%\alias{print.summary.glm}
%\title{Summarizing Generalized Linear Model Fits}
%\usage{
%\method{summary}{glm}(object, dispersion = NULL, correlation = FALSE,
%        symbolic.cor = FALSE, \dots)
%
%\method{print}{summary.glm}(x, digits = max(3, getOption("digits") - 3),
%      symbolic.cor = x$symbolic.cor,
%      signif.stars = getOption("show.signif.stars"), \dots)
%}
%\arguments{
%  \item{object}{an object of class \code{"glm"}, usually, a result of a
%    call to \code{\link{glm}}.}
%  \item{x}{an object of class \code{"summary.glm"}, usually, a result of a
%    call to \code{summary.glm}.}
%  \item{dispersion}{the dispersion parameter for the family used.
%    Either a single numerical value or \code{NULL} (the default), when
%    it is inferred from \code{object} (see \sQuote{Details}).}
%  \item{correlation}{logical; if \code{TRUE}, the correlation matrix of
%    the estimated parameters is returned and printed.}
%  \item{digits}{the number of significant digits to use when printing.}
%  \item{symbolic.cor}{logical. If \code{TRUE}, print the correlations in
%    a symbolic form (see \code{\link{symnum}}) rather than as numbers.}
%  \item{signif.stars}{logical. If \code{TRUE}, \sQuote{significance stars}
%    are printed for each coefficient.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\description{
%  These functions are all \code{\link{methods}} for class \code{glm} or
%  \code{summary.glm} objects.
%}
%\details{
%  \code{print.summary.glm} tries to be smart about formatting the
%  coefficients, standard errors, etc. and additionally gives
%  \sQuote{significance stars} if \code{signif.stars} is \code{TRUE}.
%  The \code{coefficients} component of the result gives the estimated
%  coefficients and their estimated standard errors, together with their
%  ratio.  This third column is labelled \code{t ratio} if the
%  dispersion is estimated, and \code{z ratio} if the dispersion is known
%  (or fixed by the family).  A fourth column gives the two-tailed
%  p-value corresponding to the t or z ratio based on a Student t or
%  Normal reference distribution.  (It is possible that the dispersion is
%  not known and there are no residual degrees of freedom from which to
%  estimate it.  In that case the estimate is \code{NaN}.)
%
%  Aliased coefficients are omitted in the returned object but restored
%  by the \code{print} method.
%
%  Correlations are printed to two decimal places (or symbolically): to
%  see the actual correlations print \code{summary(object)$correlation}
%  directly.
%
%  The dispersion of a GLM is not used in the fitting process, but it is
%  needed to find standard errors.
%  If \code{dispersion} is not supplied or \code{NULL},
%  the dispersion is taken as \code{1} for the \code{binomial} and
%  \code{Poisson} families, and otherwise estimated by the residual
%  Chisquared statistic (calculated from cases with non-zero weights)
%  divided by the residual degrees of freedom.
%
%  \code{summary} can be used with Gaussian \code{glm} fits to handle the
%  case of a linear regression with known error variance, something not
%  handled by \code{\link{summary.lm}}.
%}
%\value{
%  \code{summary.glm} returns an object of class \code{"summary.glm"}, a
%  list with components
%
%  \item{call}{the component from \code{object}.}
%  \item{family}{the component from \code{object}.}
%  \item{deviance}{the component from \code{object}.}
%  \item{contrasts}{the component from \code{object}.}
%  \item{df.residual}{the component from \code{object}.}
%  \item{null.deviance}{the component from \code{object}.}
%  \item{df.null}{the component from \code{object}.}
%  \item{deviance.resid}{the deviance residuals:
%    see \code{\link{residuals.glm}}.}
%  \item{coefficients}{the matrix of coefficients, standard errors,
%    z-values and p-values.  Aliased coefficients are omitted.}
%  \item{aliased}{named logical vector showing if the original
%    coefficients are aliased.}
%  \item{dispersion}{either the supplied argument or the inferred/estimated
%    dispersion if the latter is \code{NULL}.}
%  \item{df}{a 3-vector of the rank of the model and the number of
%    residual degrees of freedom, plus number of coefficients (including
%    aliased ones).}
%  \item{cov.unscaled}{the unscaled (\code{dispersion = 1}) estimated covariance
%    matrix of the estimated coefficients.}
%  \item{cov.scaled}{ditto, scaled by \code{dispersion}.}
%  \item{correlation}{(only if \code{correlation} is true.)  The estimated
%    correlations of the estimated coefficients.}
%  \item{symbolic.cor}{(only if \code{correlation} is true.)  The value
%    of the argument \code{symbolic.cor}.}
%}
%\seealso{
%  \code{\link{glm}}, \code{\link{summary}}.
%}
%\examples{
%## For examples see example(glm)
%}
%\keyword{models}
%\keyword{regression}
%
%
%\encoding{UTF-8}
%
