% File src/library/stats/man/uniroot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{uniroot}
\title{One Dimensional Root (Zero) Finding}
\alias{uniroot}%@%\alias{一次元方程式の根}
\usage{
uniroot(f, interval, \dots,
        lower = min(interval), upper = max(interval),
        f.lower = f(lower, \dots), f.upper = f(upper, \dots),
        extendInt = c("no", "yes", "downX", "upX"), check.conv = FALSE,
        tol = .Machine$double.eps^0.25, maxiter = 1000, trace = 0)
}
\arguments{
  \item{f}{根を求めたい関数．}
  \item{interval}{根を探す区間の端点を含むベクトル．}
  \item{\dots}{
    \code{f} に渡される追加の名前付き又は名前無しの引数．}
  \item{lower, upper}{探索される区間の下と上の端点．}
  \item{f.lower, f.upper}{
    それぞれ \code{f(upper)} と \code{f(lower)} と同じ．
    これらのしばしば既知の値を呼び出し側に渡すことは
    \code{f()} がトリビアルでない計算を含むのならより経済的である．}
  \item{extendInt}{
    \code{f()} が端点で異なった符号を持たなければ区間
    \code{c(lower,upper)} を拡大すべきかすぐにエラーを
    与えるかを指示する文字列．
    既定の \code{"no"} は探索区間を保ち従ってエラーを与える．
    短縮可能．}
  \item{check.conv}{
    基礎にある \code{\link{uniroot}} の収束警告が
    エラーとされるべきか，そして
    \code{maxiter} 回の繰り返しで非収束なら警告の代わりに
    エラーを与えるかを指示する論理値．}
  \item{tol}{希望する精度(収束許容度)．}
  \item{maxiter}{最大繰り返し数．}
  \item{trace}{整数値；もし正ならば，トレース情報が産み出される．
    produced.  より大きな値はより詳細を与える．}
}
\description{
  関数 \code{uniroot} は
  \code{lower} から \code{upper} への区間を
  関数 \code{f} の最初の引数に対する
  根(つまりゼロ点)を探す．

  \code{extendInt} を \code{"no"} でない文字列に設定することは，
  もし \code{sign(f(x))} が区間の端点で要請を満たさなければ
  正しい \code{interval = c(lower,upper)} を探すことを意味する；
  \sQuote{詳細}節を見よ．
}
\details{
  \code{\dots} の後の引数は正確にマッチされなければならないことを
  注意する．

  \code{interval} か，\code{lower} と \code{upper} の両者が
  指定されなければならない：
  上端は下端よりも狭義に大きくなければならない．
  既定の \code{extendInt="no"} に対しては，
  端点での関数値は反対の符号(又はゼロ)でなければならない．
  さもなければ，もし \code{extendInt="yes"} ならば，区間は
  符号が変化するように両端で拡大される，つまり
  探索区間 \eqn{[l,u]} は
  \eqn{f(l) \cdot f(u) \le 0}{f(l) * f(u) <= 0} を満たす．

  もし \eqn{f} が根 \eqn{x_0}{x0} でどのように符号を変えるか，
  つまり関数がそこで増加か減少か，が\emph{既知}ならば，
  \code{extendInt} をそれぞれ
  \code{"upX"} (\dQuote{上向きに横切る場合})と，
  又は \code{"downX"} と指定できる(そして典型的にはすべき)．
  同値であるが，\eqn{S := \pm 1}{S:= +/- 1} を定義すると，
  解で
  \eqn{S = \mathrm{sign}(f(x_0 + \epsilon))}{S = sign(f(x0 + eps))}
  を要求する．この場合，探索区間 \eqn{[l,u]} は可能性として
  \eqn{S\cdot f(l)\le 0}{S * f(l) <= 0} と
  \eqn{S \cdot f(u) \ge 0}{S * f(u) >= 0} となるように
  拡大される．

  \code{uniroot()} は下の参考文献で与えられている
  アルゴリズムに基づく Fortran サブルーティン \file{"zeroin"} (Netlib から)
  を使っている．これらは連続関数を仮定する
  (そうするとそれは区間中に少なくとも一つの根を持つことが
  分かる)．

  収束はもし \code{f(x) == 0} か
  アルゴリズムの一回のステップで \code{x} fの変化が
  \code{tol} (プラス \code{x} 中の表現誤差に対する許容度)
  以下になれば宣言される．

  もしアルゴリズムが
  \code{maxiter} 回のステップで収束しなければ，
  警告がプリントされ現在の近似が返される．

  \code{f} は数値 \var{x} に対して \code{f(\var{x}, ...)} として
  呼び出される．

  \code{f} に渡される引数は特別なセマンティックスを持ち
  呼び出し間で共有される．
  関数はそれをコピーすべきではない．
}

\value{
  少なくとも四つの成分を持つリスト：\code{root} と \code{f.root}
  は根の位置とその点で評価された関数の値である．
  \code{iter} と \code{estim.prec} は繰り返し回数と \code{root}
  に対する近似的な推定精度である．
  (もし根が端点にあれば，推定精度は
  で起きれば \code{NA} である．)

  追加の成分が将来付け加えられるかもしれない：
  成分 \code{init.it} は \R 3.1.0 で加えられた．  
}
%\author{of \code{extendInt} and \code{check.conv}: Martin Maechler.}% originally as
% safeUroot() in CRAN packages nor1mix and copula
\source{
  \url{http://www.netlib.org/c/brent.shar} の \file{zeroin.c} に基づく． 
}
\references{
  Brent, R. (1973)
  \emph{Algorithms for Minimization without Derivatives.}
  Englewood Cliffs, NJ: Prentice-Hall.
}
\seealso{
  多項式の全ての複素根に対しては \code{\link{polyroot}}；
  \code{\link{optimize}}, \code{\link{nlm}}.
}
\examples{\donttest{
require(utils) # str のため

## ある種のプラットフォームでは最初のステップでゼロをヒットする：
## もしそうなら推定精度は 2/3．
f <- function (x, a) x - a
str(xmin <- uniroot(f, c(0, 1), tol = 0.0001, a = 1/3))

## 電卓計算の例：cos(.) の不動点．
uniroot(function(x) cos(x) - x, lower = -pi, upper = pi, tol = 1e-9)$root

str(uniroot(function(x) x*(x^2-1) + .5, lower = -2, upper = 2,
            tol = 0.0001))
str(uniroot(function(x) x*(x^2-1) + .5, lower = -2, upper = 2,
            tol = 1e-10))

## exp(x) > 0 となる最少の x を(数値的に)見つける：
r <- uniroot(function(x) 1e80*exp(x) - 1e-300, c(-1000, 0), tol = 1e-15)
str(r, digits.d = 15) # 約 -745，プラットフォーム依存

exp(r$root)     # = 0，しかし r$root * 0.999... では異なる
minexp <- r$root * (1 - 10*.Machine$double.eps)
exp(minexp)     # 典型的に非正規化される
}% donttest because printed output is so much platform dependent

##--- 新しい区間拡大とチェック機能を持つ uniroot()： --------------

f1 <- function(x) (121 - x^2)/(x^2+1)
f2 <- function(x) exp(-x)*(x - 12)

try(uniroot(f1, c(0,10)))
try(uniroot(f2, c(0, 2)))
##--> エラー：f() .. 端点が異なった符号でなはい

## 'extendInt="yes"' なら単に探索区間を拡大する：
u1 <- uniroot(f1, c(0,10),extendInt="yes", trace=1)
u2 <- uniroot(f2, c(0,2), extendInt="yes", trace=2)
stopifnot(all.equal(u1$root, 11, tolerance = 1e-5),
          all.equal(u2$root, 12, tolerance = 6e-6))

## 区間拡大の*危険性*：
## 正値関数の根を見つける方法はないが
## 数値的に f(-|M|) はゼロになる：
u3 <- uniroot(exp, c(0,2), extendInt="yes", trace=TRUE)

## ナンセンスな例 (エラーを与えるべきである)：
tools::assertCondition( uniroot(function(x) 1, 0:1, extendInt="yes"),
                       "error", verbose=TRUE)

## 収束チェック：
sinc <- function(x) ifelse(x == 0, 1, sin(x)/x)
curve(sinc, -6,18); abline(h=0,v=0, lty=3, col=adjustcolor("gray", 0.8))
\dontshow{tools::assertWarning(}
uniroot(sinc, c(0,5), extendInt="yes", maxiter=4) #-> "単に"警告
\dontshow{ , verbose=TRUE)}

## now with  check.conv=TRUE, must signal a convergence error :
\dontshow{tools::assertError(}
uniroot(sinc, c(0,5), extendInt="yes", maxiter=4, check.conv=TRUE)
\dontshow{ , verbose=TRUE)}

### Weibull 累積ハザード(元々 Ravi Varadhan の例)：
cumhaz <- function(t, a, b) b * (t/b)^a
froot <- function(x, u, a, b) cumhaz(x, a, b) - u

n <- 1000
u <- -log(runif(n))
a <- 1/2
b <- 1
## 失敗時刻を見つける
ru <- sapply(u, function(x)
   uniroot(froot, u=x, a=a, b=b, interval= c(1.e-14, 1e04),
           extendInt="yes")$root)
ru2 <- sapply(u, function(x)
   uniroot(froot, u=x, a=a, b=b, interval= c(0.01,  10),
           extendInt="yes")$root)
stopifnot(all.equal(ru, ru2, tolerance = 6e-6))

r1 <- uniroot(froot, u= 0.99, a=a, b=b, interval= c(0.01, 10),
             extendInt="up")
stopifnot(all.equal(0.99, cumhaz(r1$root, a=a, b=b)))

## もし 'extendInt' が "wrong zero-crossing direction" を仮定するならエラー
\dontshow{tools::assertError(}
uniroot(froot, u= 0.99, a=a, b=b, interval= c(0.1, 10), extendInt="down")
\dontshow{ , verbose=TRUE)}
}
\keyword{optimize}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/uniroot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{uniroot}
%\title{One Dimensional Root (Zero) Finding}
%\alias{uniroot}
%\usage{
%uniroot(f, interval, \dots,
%        lower = min(interval), upper = max(interval),
%        f.lower = f(lower, \dots), f.upper = f(upper, \dots),
%        extendInt = c("no", "yes", "downX", "upX"), check.conv = FALSE,
%        tol = .Machine$double.eps^0.25, maxiter = 1000, trace = 0)
%}
%\arguments{
%  \item{f}{the function for which the root is sought.}
%  \item{interval}{a vector containing the end-points of the interval
%    to be searched for the root.}
%  \item{\dots}{additional named or unnamed arguments to be passed
%    to \code{f}}
%  \item{lower, upper}{the lower and upper end points of the interval to
%    be searched.}
%  \item{f.lower, f.upper}{the same as \code{f(upper)} and
%    \code{f(lower)}, respectively.  Passing these values from the caller
%    where they are often known is more economical as soon as \code{f()}
%    contains non-trivial computations.}
%  \item{extendInt}{character string specifying if the interval
%    \code{c(lower,upper)} should be extended or directly produce an error
%    when \code{f()} does not have differing signs at the endpoints.  The
%    default, \code{"no"}, keeps the search interval and hence produces
%    an error.  Can be abbreviated.}
%  \item{check.conv}{logical indicating whether a convergence warning of the
%    underlying \code{\link{uniroot}} should be caught as an error and if
%    non-convergence in \code{maxiter} iterations should be an error
%    instead of a warning.}
%  \item{tol}{the desired accuracy (convergence tolerance).}
%  \item{maxiter}{the maximum number of iterations.}
%  \item{trace}{integer number; if positive, tracing information is
%    produced.  Higher values giving more details.}
%}
%\description{
%  The function \code{uniroot} searches the interval from \code{lower}
%  to \code{upper} for a root (i.e., zero) of the function \code{f} with
%  respect to its first argument.
%
%  Setting \code{extendInt} to a non-\code{"no"} string, means searching
%  for the correct \code{interval = c(lower,upper)} if \code{sign(f(x))}
%  does not satisfy the requirements at the interval end points; see the
%  \sQuote{Details} section.
%}
%\details{
%  Note that arguments after \code{\dots} must be matched exactly.
%
%  Either \code{interval} or both \code{lower} and \code{upper} must be
%  specified: the upper endpoint must be strictly larger than the lower
%  endpoint.
%  The function values at the endpoints must be of opposite signs (or
%  zero), for \code{extendInt="no"}, the default.  Otherwise, if
%  \code{extendInt="yes"}, the interval is extended on both sides, in
%  search of a sign change, i.e., until the search interval \eqn{[l,u]}
%  satisfies \eqn{f(l) \cdot f(u) \le 0}{f(l) * f(u) <= 0}.
%
%  If it is \emph{known how} \eqn{f} changes sign at the root
%  \eqn{x_0}{x0}, that is, if the function is increasing or decreasing there,
%  \code{extendInt} can (and typically should) be specified as
%  \code{"upX"} (for \dQuote{upward crossing}) or \code{"downX"},
%  respectively.  Equivalently, define \eqn{S := \pm 1}{S:= +/- 1}, to
%  require \eqn{S = \mathrm{sign}(f(x_0 + \epsilon))}{S = sign(f(x0 +
%    eps))} at the solution.  In that case, the search interval \eqn{[l,u]}
%  possibly is extended to be such that \eqn{S\cdot f(l)\le 0}{%
%    S * f(l) <= 0} and \eqn{S \cdot f(u) \ge 0}{S * f(u) >= 0}.
%
%  \code{uniroot()} uses Fortran subroutine \file{"zeroin"} (from Netlib)
%  based on algorithms given in the reference below.  They assume a
%  continuous function (which then is known to have at least one root in
%  the interval).
%
%  Convergence is declared either if \code{f(x) == 0} or the change in
%  \code{x} for one step of the algorithm is less than \code{tol} (plus an
%  allowance for representation error in \code{x}).
%
%  If the algorithm does not converge in \code{maxiter} steps, a warning
%  is printed and the current approximation is returned.
%
%  \code{f} will be called as \code{f(\var{x}, ...)} for a numeric value
%  of \var{x}.
%
%  The argument passed to \code{f} has special semantics and used to be
%  shared between calls.  The function should not copy it.
%}
%
%\value{
%  A list with at least four components: \code{root} and \code{f.root}
%  give the location of the root and the value of the function evaluated
%  at that point. \code{iter} and \code{estim.prec} give the number of
%  iterations used and an approximate estimated precision for
%  \code{root}.  (If the root occurs at one of the endpoints, the
%  estimated precision is \code{NA}.)
%
%  Further components may be added in future: component \code{init.it}
%  was added in \R 3.1.0.  
%}
%%\author{of \code{extendInt} and \code{check.conv}: Martin Maechler.}% originally as
%% safeUroot() in CRAN packages nor1mix and copula
%\source{
%  Based on \file{zeroin.c} in \url{http://www.netlib.org/c/brent.shar}.
%}
%\references{
%  Brent, R. (1973)
%  \emph{Algorithms for Minimization without Derivatives.}
%  Englewood Cliffs, NJ: Prentice-Hall.
%}
%\seealso{
%  \code{\link{polyroot}} for all complex roots of a polynomial;
%  \code{\link{optimize}}, \code{\link{nlm}}.
%}
%\examples{\donttest{
%require(utils) # for str
%
%## some platforms hit zero exactly on the first step:
%## if so the estimated precision is 2/3.
%f <- function (x, a) x - a
%str(xmin <- uniroot(f, c(0, 1), tol = 0.0001, a = 1/3))
%
%## handheld calculator example: fixed point of cos(.):
%uniroot(function(x) cos(x) - x, lower = -pi, upper = pi, tol = 1e-9)$root
%
%str(uniroot(function(x) x*(x^2-1) + .5, lower = -2, upper = 2,
%            tol = 0.0001))
%str(uniroot(function(x) x*(x^2-1) + .5, lower = -2, upper = 2,
%            tol = 1e-10))
%
%## Find the smallest value x for which exp(x) > 0 (numerically):
%r <- uniroot(function(x) 1e80*exp(x) - 1e-300, c(-1000, 0), tol = 1e-15)
%str(r, digits.d = 15) # around -745, depending on the platform.
%
%exp(r$root)     # = 0, but not for r$root * 0.999...
%minexp <- r$root * (1 - 10*.Machine$double.eps)
%exp(minexp)     # typically denormalized
%}% donttest because printed output is so much platform dependent
%
%##--- uniroot() with new interval extension + checking features: --------------
%
%f1 <- function(x) (121 - x^2)/(x^2+1)
%f2 <- function(x) exp(-x)*(x - 12)
%
%try(uniroot(f1, c(0,10)))
%try(uniroot(f2, c(0, 2)))
%##--> error: f() .. end points not of opposite sign
%
%## where as  'extendInt="yes"'  simply first enlarges the search interval:
%u1 <- uniroot(f1, c(0,10),extendInt="yes", trace=1)
%u2 <- uniroot(f2, c(0,2), extendInt="yes", trace=2)
%stopifnot(all.equal(u1$root, 11, tolerance = 1e-5),
%          all.equal(u2$root, 12, tolerance = 6e-6))
%
%## The *danger* of interval extension:
%## No way to find a zero of a positive function, but
%## numerically, f(-|M|) becomes zero :
%u3 <- uniroot(exp, c(0,2), extendInt="yes", trace=TRUE)
%
%## Nonsense example (must give an error):
%tools::assertCondition( uniroot(function(x) 1, 0:1, extendInt="yes"),
%                       "error", verbose=TRUE)
%
%## Convergence checking :
%sinc <- function(x) ifelse(x == 0, 1, sin(x)/x)
%curve(sinc, -6,18); abline(h=0,v=0, lty=3, col=adjustcolor("gray", 0.8))
%\dontshow{tools::assertWarning(}
%uniroot(sinc, c(0,5), extendInt="yes", maxiter=4) #-> "just" a warning
%\dontshow{ , verbose=TRUE)}
%
%## now with  check.conv=TRUE, must signal a convergence error :
%\dontshow{tools::assertError(}
%uniroot(sinc, c(0,5), extendInt="yes", maxiter=4, check.conv=TRUE)
%\dontshow{ , verbose=TRUE)}
%
%### Weibull cumulative hazard (example origin, Ravi Varadhan):
%cumhaz <- function(t, a, b) b * (t/b)^a
%froot <- function(x, u, a, b) cumhaz(x, a, b) - u
%
%n <- 1000
%u <- -log(runif(n))
%a <- 1/2
%b <- 1
%## Find failure times
%ru <- sapply(u, function(x)
%   uniroot(froot, u=x, a=a, b=b, interval= c(1.e-14, 1e04),
%           extendInt="yes")$root)
%ru2 <- sapply(u, function(x)
%   uniroot(froot, u=x, a=a, b=b, interval= c(0.01,  10),
%           extendInt="yes")$root)
%stopifnot(all.equal(ru, ru2, tolerance = 6e-6))
%
%r1 <- uniroot(froot, u= 0.99, a=a, b=b, interval= c(0.01, 10),
%             extendInt="up")
%stopifnot(all.equal(0.99, cumhaz(r1$root, a=a, b=b)))
%
%## An error if 'extendInt' assumes "wrong zero-crossing direction":
%\dontshow{tools::assertError(}
%uniroot(froot, u= 0.99, a=a, b=b, interval= c(0.1, 10), extendInt="down")
%\dontshow{ , verbose=TRUE)}
%}
%\keyword{optimize}
%
%\encoding{UTF-8}
%
