% File src/library/stats/man/var.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{var.test}
\alias{var.test}%@%\alias{分散比較の F 検定}
\alias{var.test.default}
\alias{var.test.formula}
\title{F Test to Compare Two Variances}
\description{
  正規母集団からの二つの標本の分散を比較する F 検定を実行する．
}
\usage{
var.test(x, \dots)

\method{var.test}{default}(x, y, ratio = 1,
         alternative = c("two.sided", "less", "greater"),
         conf.level = 0.95, \dots)

\method{var.test}{formula}(formula, data, subset, na.action, \dots)
}
\arguments{
  \item{x, y}{データ値の数値ベクトルか，
    当てはめ線形モデルオブジェクト
    (クラス \code{"lm"} を継承する)．}
  \item{ratio}{
    \code{x} と \code{y} の母集団分散の帰無仮説値．}
  \item{alternative}{
    対立仮説を指定する文字列で，
    \code{"two.sided"} (既定)，
    \code{"greater"} 又は \code{"less"} のどれかでなくてはならない．
    頭文字だけを指定すれば良い．}
  \item{conf.level}{返された信頼区間の信頼水準．}
  \item{formula}{
    形式 \code{lhs ~ rhs} の公式で，ここで \code{lhs}
    はデータ値を与える数値変数で，
    \code{rhs} は対応するグループを与える二つの水準を持つ
    因子．}
  \item{data}{
    公式 \code{formula} 中の変数を含む
    オプションの行列かデータフレーム(又は類似のもの：
    \code{\link{model.frame}} を見よ)．
    既定では変数は \code{environment(formula)} から取られる．}
  \item{subset}{使われる観測値の部分集合を指定するオプションのベクトル．}
  \item{na.action}{
    データが \code{NA} を含んでいる時何が起きるべきかを指示する
    関数．既定は \code{getOption("na.action")}．}
  \item{\dots}{メソッドから・から渡される追加引数．}
}
\details{
  帰無仮説は \code{x} と \code{y} が抽出された母集団か，
  線形モデル \code{x} と \code{y} が当てはめられたデータ中の
  分散の比が \code{ratio} に等しいというものである．
}
\value{
  A list with class
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{F 検定統計量の値．}
  \item{parameter}{検定統計量の F 分布の自由度．}
  \item{p.value}{検定の p 値．}
  \item{conf.int}{母集団分散の比に対する信頼区間．}
  \item{estimate}{\code{x} と \code{y} の標本分散の比．}
  \item{null.value}{帰無仮説の下での母集団分散の比．}
  \item{alternative}{対立仮説を記述する文字列．}
  \item{method}{文字列 \code{"F test to compare two variances"}．}
  \item{data.name}{データの名前を与える文字列．}
}
\seealso{
  正規分布からの二つ以上の標本の分散の同一性の検定に対しては
  \code{\link{bartlett.test}}；
  スケールの差に対するランクに基づく(ノンパラメトリック)
  二標本検定には \code{\link{ansari.test}} と \code{\link{mood.test}}．
}
\examples{
x <- rnorm(50, mean = 0, sd = 2)
y <- rnorm(30, mean = 1, sd = 1)
var.test(x, y)                  # x と y は同じ分散を持つか?
var.test(lm(x ~ 1), lm(y ~ 1))  # 同じ．
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/var.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{var.test}
%\alias{var.test}
%\alias{var.test.default}
%\alias{var.test.formula}
%\title{F Test to Compare Two Variances}
%\description{
%  Performs an F test to compare the variances of two samples from normal
%  populations.
%}
%\usage{
%var.test(x, \dots)
%
%\method{var.test}{default}(x, y, ratio = 1,
%         alternative = c("two.sided", "less", "greater"),
%         conf.level = 0.95, \dots)
%
%\method{var.test}{formula}(formula, data, subset, na.action, \dots)
%}
%\arguments{
%  \item{x, y}{numeric vectors of data values, or fitted linear model
%    objects (inheriting from class \code{"lm"}).}
%  \item{ratio}{the hypothesized ratio of the population variances of
%    \code{x} and \code{y}.}
%  \item{alternative}{a character string specifying the alternative
%    hypothesis, must be one of \code{"two.sided"} (default),
%    \code{"greater"} or \code{"less"}.  You can specify just the initial
%    letter.}
%  \item{conf.level}{confidence level for the returned confidence
%    interval.}
%  \item{formula}{a formula of the form \code{lhs ~ rhs} where \code{lhs}
%    is a numeric variable giving the data values and \code{rhs} a factor
%    with two levels giving the corresponding groups.}
%  \item{data}{an optional matrix or data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.}
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.  Defaults to
%    \code{getOption("na.action")}.}
%  \item{\dots}{further arguments to be passed to or from methods.}
%}
%\details{
%  The null hypothesis is that the ratio of the variances of the
%  populations from which \code{x} and \code{y} were drawn, or in the
%  data to which the linear models \code{x} and \code{y} were fitted, is
%  equal to \code{ratio}.
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of the F test statistic.}
%  \item{parameter}{the degrees of the freedom of the F distribution of
%    the test statistic.}
%  \item{p.value}{the p-value of the test.}
%  \item{conf.int}{a confidence interval for the ratio of the population
%    variances.}
%  \item{estimate}{the ratio of the sample variances of \code{x} and
%    \code{y}.}
%  \item{null.value}{the ratio of population variances under the null.}
%  \item{alternative}{a character string describing the alternative
%    hypothesis.}
%  \item{method}{the character string
%    \code{"F test to compare two variances"}.}
%  \item{data.name}{a character string giving the names of the data.}
%}
%\seealso{
%  \code{\link{bartlett.test}} for testing homogeneity of variances in
%  more than two samples from normal distributions;
%  \code{\link{ansari.test}} and \code{\link{mood.test}} for two rank
%  based (nonparametric) two-sample tests for difference in scale.
%}
%\examples{
%x <- rnorm(50, mean = 0, sd = 2)
%y <- rnorm(30, mean = 1, sd = 1)
%var.test(x, y)                  # Do x and y have the same variance?
%var.test(lm(x ~ 1), lm(y ~ 1))  # The same.
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
