% File src/library/stats/man/weighted.mean.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{weighted.mean}
\alias{weighted.mean}%@%\alias{重み付き平均}
\alias{weighted.mean.default}
\title{Weighted Arithmetic Mean}
\description{
  重み付き平均を計算する．
}
\usage{
weighted.mean(x, w, \dots)

\method{weighted.mean}{default}(x, w, \dots, na.rm = FALSE)
}
\arguments{
  \item{x}{重み付き平均が計算されるべき値を含むオブジェクト．}
  \item{w}{
    \code{x} の要素に対して使われる重みを与える
    \code{x} と同じ長さの重みの数値ベクトル．}
  \item{\dots}{メソッドに・から渡される引数．}
  \item{na.rm}{
    \code{x} 中の \code{NA} 値を計算が始まる前に
    取り除くべきかどうかを指示する論理値．}
}
\details{
  これは総称的関数であり
  最初の引数 \code{x} に対して定義されたメソッドを定義できる：
  既定のメソッドを除けば
  日付-時刻クラス \code{"POSIXct"}, \code{"POSIXlt"},
  \code{"difftime"} そして \code{"Date"} に対するメソッドがある．
  既定メソッドは
  \code{[}, 乗算, 除算そして \code{\link{sum}} が適当なメソッドを
  持つ任意の数値風のオブジェクトに対して動作する．

  もし \code{w} が無ければ
  \code{x} の全ての要素は同じ重みを与えられる，さもなければ
  重みは \code{\link{as.numeric}} で数値に強制変換され総和が1に
  正規化される(もし可能なら：もしそれらの和が
  ゼロか無限であれば値は恐らく \code{NaN} になる)．

  \code{w} 中の欠損値は特別に処理されるので，
  欠損値の結果を与える．しかしながら，ゼロの重みは
  特別に処理され，対応する
  \code{x} 値は和から除外される．
}
\value{
  既定メソッドに対しては長さ1の数値ベクトル．
}
\seealso{
  \code{\link{mean}}
}
\examples{
## Siegel 1994 からの GPA
wt <- c(5,  5,  4,  1)/15
x <- c(3.7,3.3,3.5,2.8)
xm <- weighted.mean(x, wt)
}
\keyword{univar}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/weighted.mean.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{weighted.mean}
%\alias{weighted.mean}
%\alias{weighted.mean.default}
%\title{Weighted Arithmetic Mean}
%\description{
%  Compute a weighted mean.
%}
%\usage{
%weighted.mean(x, w, \dots)
%
%\method{weighted.mean}{default}(x, w, \dots, na.rm = FALSE)
%}
%\arguments{
%  \item{x}{an object containing the values whose weighted mean is to be
%    computed.}
%  \item{w}{a numerical vector of weights the same length as \code{x} giving
%    the weights to use for elements of \code{x}.}
%  \item{\dots}{arguments to be passed to or from methods.}
%  \item{na.rm}{a logical value indicating whether \code{NA}
%    values in \code{x} should be stripped before the computation proceeds.}
%}
%\details{
%  This is a generic function and methods can be defined for the first
%  argument \code{x}: apart from the default methods there are methods
%  for the date-time classes \code{"POSIXct"}, \code{"POSIXlt"},
%  \code{"difftime"} and \code{"Date"}.  The default method will work for
%  any numeric-like object for which \code{[}, multiplication, division
%  and \code{\link{sum}} have suitable methods, including complex vectors.
%
%  If \code{w} is missing then all elements of \code{x} are given the
%  same weight, otherwise the weights coerced to numeric by
%  \code{\link{as.numeric}} and normalized to sum to one (if possible: if
%  their sum is zero or infinite the value is likely to be \code{NaN}).
%
%  Missing values in \code{w} are not handled specially and so give a
%  missing value as the result.  However, zero weights \emph{are} handled
%  specially and the corresponding \code{x} values are omitted from the
%  sum.
%}
%\value{
%  For the default method, a length-one numeric vector.
%}
%\seealso{
%  \code{\link{mean}}
%}
%\examples{
%## GPA from Siegel 1994
%wt <- c(5,  5,  4,  1)/15
%x <- c(3.7,3.3,3.5,2.8)
%xm <- weighted.mean(x, wt)
%}
%\keyword{univar}
%
%\encoding{UTF-8}
%
