% File src/library/tools/man/QC.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{QC}
\title{R コードやドキュメントの品質管理チェック}
%\title{QC Checks for R Code and/or Documentation}
%@%\alias{コードやドキュメントの品質管理チェック}
\alias{QC}
\alias{checkDocFiles}
\alias{checkDocStyle}
\alias{checkReplaceFuns}
\alias{checkS3methods}
\alias{nonS3methods}
\alias{langElts}
\alias{print.checkDocFiles}
\alias{print.checkDocStyle}
\alias{print.checkReplaceFuns}
\alias{print.checkS3methods}
\description{
  R コードとドキュメント，特に R パッケージに対して様々な品質管理
  (QC)チェックを実行する関数．
}
\usage{
checkDocFiles(package, dir, lib.loc = NULL)
checkDocStyle(package, dir, lib.loc = NULL)
checkReplaceFuns(package, dir, lib.loc = NULL)
checkS3methods(package, dir, lib.loc = NULL)

langElts
nonS3methods(package)
}
\arguments{
  \item{package}{インストール済みのパッケージ名前の文字列ベクトル．}
  \item{dir}{パッケージのルートソースディレクトリへのパスを指定する文字列．
    これはサブディレクトリ \file{R} (R コード用) と \R ドキュメントのソース
    \file{man} (Rd 書式の)を含まなければならない．
    \code{package} が与えられない時だけ使われる．}
  \item{lib.loc}{
    \R ライブラリのディレクトリ名の文字列，又は
    \code{NULL}.  既定値 \code{NULL} は現在既知の全てのライブラリに対応する．
    指定されたライブラリツリーは \code{package} を探すために使われる．}
}
\details{
  \code{checkDocFiles} はパッケージ中の全ての Rd ファイルに対する
  チェックを行い，Rd ファイルの用法節に示された全ての引数がその引数節中に
  ドキュメント化されているかどうかを示す．
  これは又引数節に重複する項目があるかどうかと
  引数節に与えられているが用法節には無い\sQuote{過剰にドキュメント化}
  された引数を報告する．
  用法は表示されるものであるので，マッチは用法節に対して行われ，
  もしかすると存在するかもしれない一覧節に対してではないことを注意する．

  \code{checkDocStyle} は(S3)メソッドがパッケージ中の
  Rd ファイルの用法節でどのように示されるかを調べる．
  これは S3 メソッドを指示する Rd の \verb{\method} マークアップを使用せず
  それらのフルネームで表示されるメソッドを報告する．
  初期の \R はまたそれらの総称的関数と共に
  示されるメソッドを報告したが，これは典型的に
  総称的関数とそのメソッド中の主要引数のドキュメント化に対して問題を
  引き起こした．
  \verb{\method} は今やクラス情報が保存されるような仕方で展開されるため，
  同時ドキュメント化は最早必ずしも問題にならない．
  (対応する情報は依然 \code{checkDocStyle} が返すオブジェクト中に含まれる．)

  \code{checkReplaceFuns} はパッケージの R コード中の置き換え関数又は
  S3/S4 置き換えメソッドが名前が
  \code{value} の最終引数を持つかどうかをチェックする．

  \code{checkS3methods} はパッケージの R コード中で定義された
  全ての S3 メソッドが対応する総称的関数の全ての引数を，
  メソッドに対して同じ位置の総称的関数の位置引数と共に持つかどうかを
  チェックする．
  一つの例外として，公式メソッドの最初の引数はたとえそれが
  総称て的関数で使われる名前でなくとも
  \code{formula} と呼ばれる\emph{かも}しれない．
  \code{\dots} が含まれる場合の規則は微妙である：
  S3 総称的と認識される関数は本体に
  \code{UseMethod} への呼び出しを持つもの，
  内部 S3 総称的(\link{InternalMethods} を見よ)，そして
  S3 グループ少々的(\code{\link[=S3groupGeneric]{Math}} を見よ)である．
  異なる名前の下での可能な選択適用は考慮されない．
  総称的関数は最初与えられたパッケージ中で探され，それから
  \pkg{base} パッケージ中，そして
  (現在)パッケージ \pkg{graphics}, \pkg{stats}, そして
  以前の \pkg{base} を R 1.9.0 で分割して付け加えられた
  \pkg{utils} パッケージ中，そしてもしインストール済みパッケージが
  テストされていればパッケージの
  \file{DESCRIPTION} 依存欄中にリストされたロードされた名前空間/パッケージ
  中でも探される．

  \code{nonS3methods(package)} は
  \code{package} 中の S3 メソッドに\sQuote{見える}がそうではない関数名を
  持つ文字列ベクトルを返す．
  \code{package = NULL} の使用は全ての既知の例を返す．

  \code{langElts} は \R の
  \dQuote{言語要素}の名前のベクトルである．
  これらは\dQuote{非常にプリミティブ}な関数として実装されている
  (引数リスト無し；\code{.Primitive("<name>")} とプリントされる).

  もしインストール済みのパッケージを使うのなら，
  パッケージの全ての \R オブジェクトにアクセスする必要のある
  チェックは，もしかするとパッケージの既にロードされたバージョンを
  取り外した後で，パッケージをロードする
  (\pkg{base} パッケージでない限り)．
}
\value{
  この関数は検出された問題に関する情報を含むそれぞれの関数名と同じ名前の
  クラスのオブジェクトを返す．
  そうしたオブジェクト中に含まれる情報を見栄え良く表示する
  \code{print} メソッドがある．
}
\keyword{utilities}
\keyword{documentation}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/QC.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{QC}
%\title{QC Checks for R Code and/or Documentation}
%\alias{QC}
%\alias{checkDocFiles}
%\alias{checkDocStyle}
%\alias{checkReplaceFuns}
%\alias{checkS3methods}
%\alias{nonS3methods}
%\alias{langElts}
%\alias{print.checkDocFiles}
%\alias{print.checkDocStyle}
%\alias{print.checkReplaceFuns}
%\alias{print.checkS3methods}
%\description{
%  Functions for performing various quality control (QC) checks on R code
%  and documentation, notably on R packages.
%}
%\usage{
%checkDocFiles(package, dir, lib.loc = NULL)
%checkDocStyle(package, dir, lib.loc = NULL)
%checkReplaceFuns(package, dir, lib.loc = NULL)
%checkS3methods(package, dir, lib.loc = NULL)
%
%langElts
%nonS3methods(package)
%}
%\arguments{
%  \item{package}{a character string naming an installed package.}
%  \item{dir}{a character string specifying the path to a package's root
%    source directory.  This should contain the subdirectories \file{R}
%    (for R code) and \file{man} with \R documentation sources (in Rd
%    format).  Only used if \code{package} is not given.}
%  \item{lib.loc}{a character vector of directory names of \R libraries,
%    or \code{NULL}.  The default value of \code{NULL} corresponds to all
%    libraries currently known.  The specified library trees are used to
%    search for \code{package}.}
%}
%\details{
%  \code{checkDocFiles} checks, for all Rd files in a package, whether all
%  arguments shown in the usage sections of the Rd file are documented in
%  its arguments section.  It also reports duplicated entries in the
%  arguments section, and \sQuote{over-documented} arguments which are
%  given in the arguments section but not in the usage.  Note that the
%  match is for the usage section and not a possibly existing synopsis
%  section, as the usage is what gets displayed.
%
%  \code{checkDocStyle} investigates how (S3) methods are shown in the
%  usages of the Rd files in a package.  It reports the methods shown by
%  their full name rather than using the Rd \verb{\method} markup for
%  indicating S3 methods.  Earlier versions of \R also reported about
%  methods shown along with their generic, which typically caused
%  problems for the documentation of the primary argument in the generic
%  and its methods.  With \verb{\method} now being expanded in a way
%  that class information is preserved, joint documentation is
%  no longer necessarily a problem.  (The corresponding information is
%  still contained in the object returned by \code{checkDocStyle}.)
%
%  \code{checkReplaceFuns} checks whether replacement functions or S3/S4
%  replacement methods in the package R code have their final argument
%  named \code{value}.
%
%  \code{checkS3methods} checks whether all S3 methods defined in the
%  package R code have all arguments of the corresponding generic, with
%  positional arguments of the generics in the same positions for the
%  method.  As an exception, the first argument of a formula method
%  \emph{may} be called \code{formula} even if this is not the name used
%  by the generic.  The rules when \code{\dots} is involved are subtle:
%  see the source code.  Functions recognized as S3 generics are those
%  with a call to \code{UseMethod} in their body, internal S3 generics
%  (see \link{InternalMethods}), and S3 group generics (see
%  \code{\link[=S3groupGeneric]{Math}}).  Possible dispatch under a
%  different name is not taken into account.  The generics are sought
%  first in the given package, then in the \pkg{base} package and
%  (currently) the packages \pkg{graphics}, \pkg{stats}, and \pkg{utils}
%  added in R 1.9.0 by splitting the former \pkg{base}, and, if an
%  installed package is tested, also in the loaded namespaces/packages
%  listed in the package's \file{DESCRIPTION} Depends field.
%
%  \code{nonS3methods(package)} returns a \code{\link{character}} vector with
%  the names of the functions in \code{package} which \sQuote{look} like
%  S3 methods, but are not.  Using \code{package = NULL} returns all
%  known examples.
%
%  \code{langElts} is a character vector of names of \dQuote{language
%    elements} of \R.  These are implemented as \dQuote{very primitive}
%  functions (no argument list; \code{\link{print}()}ing as
%  \code{.Primitive("<name>")}).
%
%  If using an installed package, the checks needing access to all \R
%  objects of the package will load the package (unless it is the
%  \pkg{base} package), after possibly detaching an already loaded
%  version of the package.
%}
%\value{
%  The functions return objects of class the same as the respective
%  function names containing the information about problems detected.
%  There are \code{print} methods for nicely displaying the information
%  contained in such objects.
%}
%\keyword{utilities}
%\keyword{documentation}
%
%\encoding{UTF8}
%