% File src/library/tools/man/Rdutils.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{Rdutils}
%@%\alias{Rd オブジェクトのためのユーティリティ}
\alias{Rd_db}
\title{Rd オブジェクトのためのユーティリティ}
%\title{Rd Utilities}
\description{Rd オブジェクト中の情報について計算するユーティリティ}
\usage{
Rd_db(package, dir, lib.loc = NULL)
}
\arguments{
  \item{package}{インストール済みのパッケージの名前である文字列．}
  \item{dir}{
    パッケージのルートソースディレクトリへのパスを指定する文字列．
    これは \R のドキュメントのソース(Rd 書式の)を含む
    サブディレクトリ \file{man} を含むべきである．
    \code{package} が与えられない時だけ使われる．}
  \item{lib.loc}{\R ライブラリのディレクトリ名の文字列か
    \code{NULL}． 既定値の \code{NULL} は現在知られている全ての
    ライブラリに対応する．指定されたライブラリツリーは
    \code{package} を探すのに使われる．}
}
\details{
  \code{Rd_db} はパッケージ中の全ての Rd オブジェクトの簡単な
  データベースを作る．これはパッケージ中の Rd ソースファイルに
  \code{\link{parse_Rd}} を実行し，プラットホームに対する
  条件を処理した結果のリストである．
}
\seealso{
  \code{\link{parse_Rd}}
}
\examples{\donttest{
## (インストール済みの)基本パッケージの Rd データベースを作る．
db <- Rd_db("base")

## Rd オブジェクト毎のキーワードのメタデータ．
keywords <- lapply(db, tools:::.Rd_get_metadata, "keyword")
## キーワード項目を作表化．
kw_table <- sort(table(unlist(keywords)))
## 最も頻出のもの5つ：
rev(kw_table)[1 : 5]
## "最も内容のある"物：
kw_table[kw_table == 1]

## Rd ファイル毎のコンセプトメタデータ
concepts <- lapply(db, tools:::.Rd_get_metadata, "concept")
## どれだけ多くのファイルが既に \concept メタデータを持つか?
sum(sapply(concepts, length) > 0)
## 全部で幾つの概念項目があるか?
length(unlist(concepts))
}}
\keyword{utilities}
\keyword{documentation}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/Rdutils.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Rdutils}
%\alias{Rd_db}
%\title{Rd Utilities}
%\description{Utilities for computing on the information in Rd objects.}
%\usage{
%Rd_db(package, dir, lib.loc = NULL)
%}
%\arguments{
%  \item{package}{a character string naming an installed package.}
%  \item{dir}{a character string specifying the path to a package's root
%    source directory.  This should contain the subdirectory \file{man}
%    with \R documentation sources (in Rd format).  Only used if
%    \code{package} is not given.}
%  \item{lib.loc}{a character vector of directory names of \R libraries,
%    or \code{NULL}.  The default value of \code{NULL} corresponds to all
%    libraries currently known.  The specified library trees are used to
%    search for \code{package}.}
%}
%\details{
%  \code{Rd_db} builds a simple database of all Rd objects in a package,
%  as a list of the results of running \code{\link{parse_Rd}} on the Rd
%  source files in the package and processing platform conditionals.
%}
%\seealso{
%  \code{\link{parse_Rd}}
%}
%\examples{\donttest{
%## Build the Rd db for the (installed) base package.
%db <- Rd_db("base")
%
%## Keyword metadata per Rd object.
%keywords <- lapply(db, tools:::.Rd_get_metadata, "keyword")
%## Tabulate the keyword entries.
%kw_table <- sort(table(unlist(keywords)))
%## The 5 most frequent ones:
%rev(kw_table)[1 : 5]
%## The "most informative" ones:
%kw_table[kw_table == 1]
%
%## Concept metadata per Rd file.
%concepts <- lapply(db, tools:::.Rd_get_metadata, "concept")
%## How many files already have \concept metadata?
%sum(sapply(concepts, length) > 0)
%## How many concept entries altogether?
%length(unlist(concepts))
%}}
%\keyword{utilities}
%\keyword{documentation}
%
%\encoding{UTF8}
%