% File src/library/tools/man/compactPDF.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2011-2014 R Core Team
% Distributed under GPL 2 or later

\name{compactPDF}
%@%\alias{コンパクトなPDF}
\alias{compactPDF}
\alias{format.compactPDF}
\title{コンパクトな PDF ファイル}
%\title{Compact PDF Files}
\description{
  PDF ファイル(特にビニエット)をよりコンパクトに再セーブする．\cr
  \command{R CMD build --compact-vignettes} に対するサポート関数．
}
\usage{
compactPDF(paths,
           qpdf = Sys.which(Sys.getenv("R_QPDF", "qpdf")),
           gs_cmd = Sys.getenv("R_GSCMD", ""),
           gs_quality = Sys.getenv("GS_QUALITY", "none"),
           gs_extras = character())

\method{format}{compactPDF}(x, ratio = 0.9, diff = 1e4, ...)
}
\arguments{
  \item{paths}{
    PDF ファイルへのパスの文字列ベクトル，または
    そのディレクトリ中の全ての \file{.pdf} ファイルが使われるのなら
    ディレクトリの名前を与える長さ1の文字列ベクトル．}
  \item{qpdf}{
    \command{qpdf} 命令へのパスを与える文字列．もし空ならば，
    \command{qpdf} は使われない．}
  \item{gs_cmd}{
    もしそれが使われるのならば
    GhostScript の実行ファイルへのパスを与える文字列．
    Windows ではこれは
    \file{gswin32c.exe} または \file{gswin64c.exe} へのパス．
    もし \code{""} (既定)ならば必要な場合は
    GhostScript へのプラットホーム固有のパスを見つけようと試みる．}
  \item{gs_quality}{
    必要な品質を指示する文字列：
    オプションは \code{"none"} (従って GhostScript は使われない)，
    \code{"printer"} (300dpi), \code{"ebook"} (150dpi) そして
    \code{"screen"} (72dpi)．短縮化出来る．}
  \item{gs_extras}{
    GhostScript に渡される追加のオプションのオプション文字列．}
  \item{x}{
    クラス \code{"compactPDF"} のオブジェクト．}
  \item{ratio, diff}{
    報告に対する限界：ファイルはそのサイズが
    因子 \code{ratio} と \code{diff} バイトの双方で縮小した時だけ
    報告される．}
  \item{\dots}{他のメソッドに/から渡される追加引数．}
}
\details{
  これは既定では
  \url{http://qpdf.sourceforge.net/} (Windows バイナリを含む)
  から入手でき
  CRAN の \R の OS X ディストリビューションに含まれる
  \command{qpdf} を使用する．
  もし \code{gs_cmd} が空でなく
  \code{gs_quality != "none"} ならば，先ず GhostScript が使われ，
  それから利用できれば \command{qpdf} が使われる．
  もし \code{gs_quality != "none"} で \code{gs_cmd} が \code{""} ならば，
  GhostScript 実行ファイルを見つけようと試みられる．

  \command{qpdf} と/または \command{gs_cmd} は見つかった全ての PDF ファイルに
  対して実行され，サイズで少なくとも
  10\% と 10Kb 減少するものだけが置き換えられる．

  \command{qpdf} を使う戦略は(損失なしに)
  PDF ストリームとオブジェクトの双方を圧縮するというものである．
  GhostScript はストリームとそれ以上を圧縮し
  (ダウンサンプリングと埋め込みイメージの圧縮を含む)そして
  結果としてかなり遅く品質を失うかもしれない(しかしまた
  よりかなり小さな PDF ファイルを作成できる)．
  しかしながら，品位 \code{"ebook"} はスクリーンで眺めたり
  レーザープリンターでプリントするには完全に十分である．

  PDF ファイルが変更される時はそれらはバージョン 1.5 の PDF ファイルになる：
  これらは 2003 年のバージョン6から
  Acrobat Reader でサポートされているので，
  問題を惹き起こすことはまずありそうもない．

  ストリーム圧縮は最もしばしば大きな利得を持つものである．
  殆どの PDF ドキュメントはオブジェクトの圧縮を伴って
  生成されるが，しかしこれは
  MiKTeX の \command{pdflatex} に対しては既定ではないように見える．
  ある種の PDF ファイル
  (そして特にパッケージのビニエット)に対しては，GhostScript の使用は
  埋め込みイメージ(しばしばスクリーンショット)が占めるスペースを
  劇的に減らすことが出来る．
  

  GhostScript と \command{qpdf} の双方が選択された時
  (\code{gs_quality != "none"} で両方の実行ファイルが見つかった場合)，
  それらはその順序で実行されサイズの縮小は
  達成できた総圧縮に適用される．
}

\value{
  クラス \code{c("compactPDF", "data.frame")} のオブジェクト．
  これは変更されたファイルに対するバイト単位のサイズである二つの列を持つ．

  メソッド \code{format} と \code{print} がある：後者は
  \code{\dots} を書式メソッドに渡すので，
  \code{ratio} と \code{diff} 引数を受け入れる．
}

\note{
  使われている外部ツールは将来のリリースで変更される可能性がある．

  GhostScript のバージョン 9.06 とそれ以降は
  CRAN パッケージのビニエットに関して
  バージョン 9.05 よりも数倍良い圧縮比を持つ．
}

\seealso{
  \code{\link{resaveRdaFiles}}.

  Adobe Acrobat (Reader では無い)を含み，PDF ファイルをコンパクト化する
  多くの他の(そしてある場合にはより効率的な)ツールが利用できる．
  マニュアル \sQuote{Writing R Extensions} を見よ．
}

\keyword{ utilities }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/compactPDF.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2011-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{compactPDF}
%\alias{compactPDF}
%\alias{format.compactPDF}
%\title{
%  Compact PDF Files
%}
%\description{
%  Re-save PDF files (especially vignettes) more compactly.
%  Support function for \command{R CMD build --compact-vignettes}.
%}
%\usage{
%compactPDF(paths,
%           qpdf = Sys.which(Sys.getenv("R_QPDF", "qpdf")),
%           gs_cmd = Sys.getenv("R_GSCMD", ""),
%           gs_quality = Sys.getenv("GS_QUALITY", "none"),
%           gs_extras = character())
%
%\method{format}{compactPDF}(x, ratio = 0.9, diff = 1e4, ...)
%}
%\arguments{
%  \item{paths}{A character vector of paths to PDF files, or a length-one
%    character vector naming a directory, when all \file{.pdf} files in
%    that directory will be used.}
%  \item{qpdf}{Character string giving the path to the \command{qpdf}
%    command.  If empty, \command{qpdf} will not be used.}
%  \item{gs_cmd}{Character string giving the path to the GhostScript
%    executable, if that is to be used.  On Windows this is the path to
%    \file{gswin32c.exe} or \file{gswin64c.exe}.  If \code{""} (the
%    default), the function will try to find a platform-specific path to
%    GhostScript where required.}
%  \item{gs_quality}{A character string indicating the quality required:
%    the options are \code{"none"} (so GhostScript is not used),
%    \code{"printer"} (300dpi), \code{"ebook"} (150dpi) and
%    \code{"screen"} (72dpi).  Can be abbreviated.}
%  \item{gs_extras}{An optional character vector of further options to be
%    passed to GhostScript.}
%  \item{x}{An object of class \code{"compactPDF"}.}
%  \item{ratio, diff}{Limits for reporting: files are only reported whose
%    sizes are reduced both by a factor of \code{ratio} and by
%    \code{diff} bytes.}
%  \item{\dots}{Further arguments to be passed to or from other methods.}
%}
%\details{
%  This by default makes use of \command{qpdf}, available from
%  \url{http://qpdf.sourceforge.net/} (including as a Windows binary) and
%  included with the CRAN OS X distribution of \R.  If \code{gs_cmd}
%  is non-empty and \code{gs_quality != "none"}, GhostScript will used
%  first, then \command{qpdf} if it is available.  If \code{gs_quality !=
%  "none"} and \code{gs_cmd} is \code{""}, an attempt will be made to find a
%  GhostScript executable.
%
%  \command{qpdf} and/or \command{gs_cmd} are run on all PDF files found,
%  and those which are reduced in size by at least 10\% and 10Kb are
%  replaced.
%
%  The strategy of our use of \command{qpdf} is to (losslessly) compress
%  both PDF streams and objects.  GhostScript compresses streams and more
%  (including downsampling and compressing embedded images) and
%  consequently is much slower and may lose quality (but can also produce
%  much smaller PDF files).  However, quality \code{"ebook"} is perfectly
%  adequate for screen viewing and printing on laser printers.
%
%  Where PDF files are changed they will become PDF version 1.5 files:
%  these have been supported by Acrobat Reader since version 6 in 2003,
%  so this is very unlikely to cause difficulties.
%
%  Stream compression is what most often has large gains.  Most PDF
%  documents are generated with object compression, but this does not
%  seem to be the default for MiKTeX's \command{pdflatex}.  For some PDF
%  files (and especially package vignettes), using GhostScript can
%  dramatically reduce the space taken by embedded images (often
%  screenshots).
%
%  Where both GhostScript and \command{qpdf} are selected (when
%  \code{gs_quality != "none"} and both executables are found), they are
%  run in that order and the size reductions apply to the total
%  compression achieved.
%}
%
%\value{
%  An object of class \code{c("compactPDF", "data.frame")}.
%  This has two columns, the old and new sizes in bytes for the files
%  that were changed.
%
%  There are \code{format} and \code{print} methods: the latter passes
%  \code{\dots} to the format method, so will accept \code{ratio} and
%  \code{diff} arguments.
%}
%
%\note{
%  The external tools used may change in future releases.
%
%  Versions of GhostScript 9.06 and later give several times better
%  compression than 9.05 on some vignettes in CRAN packages.
%}
%
%\seealso{
%  \code{\link{resaveRdaFiles}}.
%
%  Many other (and sometimes more effective) tools to compact PDF files
%  are available, including Adobe Acrobat (not Reader).
%  See the \sQuote{Writing R Extensions} manual.
%}
%
%\keyword{ utilities }
%
%\encoding{UTF8}
%