% File src/library/tools/man/fileutils.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{fileutils}
\alias{file_ext}
%@%\alias{ファイルユーティリティ}
\alias{file_path_as_absolute}
\alias{file_path_sans_ext}
\alias{list_files_with_exts}
\alias{list_files_with_type}
%\title{File Utilities}
\title{ファイルユーティリティ}
\description{
  ファイルのりストとファイルパス操作のためのユーティリティ．
}
\usage{
file_ext(x)
file_path_as_absolute(x)
file_path_sans_ext(x, compression = FALSE)

list_files_with_exts(dir, exts, all.files = FALSE,
                     full.names = TRUE)
list_files_with_type(dir, type, all.files = FALSE,
                     full.names = TRUE, OS_subdirs = .OStype())
}
\arguments{
  \item{x}{ファイルパスを与える文字列ベクトル．}
  \item{compression}{論理値：
    圧縮拡張子 \file{.gz}, \file{.bz2} または \file{.xz} は最初に取り除くべきか?}
  \item{dir}{ディレクトリへのパス名の文字列．}
  \item{exts}{可能なファイル拡張子の文字列ベクトル(先頭のドットを除く)．}
  \item{all.files}{
    論理値．もし \code{FALSE} (既定)ならば，可視ファイルだけが
    考慮される；もし \code{TRUE} ならば全てのファイルが使われる．}
  \item{full.names}{
    見つかったファイルの完全なパスを返す(既定値)べきかどうか，またはファイル名
    だけかを指示する論理値．}
  \item{type}{
    拡張子で特徴付けられるリストされるファイルの
    \sQuote{タイプ}を与える文字列．現在可能な値は
    \code{"code"} (R コード)，\code{"data"} (データセット)，
    \code{"demo"} (デモ)，\code{"docs"} (R ドキュメント) そして
    \code{"vignette"} (ビニエット)．}
  \item{OS_subdirs}{
    R コードとドキュメントファイルのリストで可能性として含められる
    OS 固有の副ディレクトリの名前の文字列．
    既定では環境変数 \env{R_OSTYPE} の値か，もしくはもしこれが空なら
    \code{\link{.Platform}$OS.type} の値が使われる．}
}
\details{
  \code{file_ext} はファイル(名)拡張子を返す(先頭のドットを除く)．
  (純粋なアルファニューメリックな拡張子だけが認識される．)

  \code{file_path_as_absolute} は相対パスがあれば絶対パスに変更し，
  必要ならチルダ展開を行う．
  これは \code{\link{normalizePath}} に対するラッパである．
  \code{x} は単一の既存のパスでなければならない．

  \code{file_path_sans_ext} は拡張子
  (と先頭のドット)無しのファイルパスを返す．
  (純粋なアルファニューメリックな拡張子だけが認識される．)

  \code{list_files_with_exts} は
  ディレクトリ \code{dir} 中の
  拡張子が \code{exts} の要素の一つにマッチするファイルのパスか
  名前を返す．
  既定では完全なパスが返され，可視ファイルだけが使われることを注意する．

  \code{list_files_with_type} は，\R が認識する拡張子で決まるような，
  \code{dir} 中の与えられた
  \sQuote{タイプ}のファイルのパスを返す．
  R コードとドキュメントファイルをリストするときは，
  もしあれば OS 固有の副ディレクトリ中のファイルが
  \code{OS_subdirs} の値に応じて含められる．
  既定では完全なパスが返され，可視ファイルだけが使われることを注意する．
}
\seealso{
  \code{\link{file.path}},
  \code{\link{file.info}},
  \code{\link{list.files}}
}
\examples{\donttest{
dir <- file.path(R.home(), "library", "stats")
list_files_with_exts(file.path(dir, "demo"), "R")
list_files_with_type(file.path(dir, "demo"), "demo") # 同じ
file_path_sans_ext(list.files(file.path(R.home("modules"))))
}}
\keyword{file}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/fileutils.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{fileutils}
%\alias{file_ext}
%\alias{file_path_as_absolute}
%\alias{file_path_sans_ext}
%\alias{list_files_with_exts}
%\alias{list_files_with_type}
%\title{File Utilities}
%\description{
%  Utilities for listing files, and manipulating file paths.
%}
%\usage{
%file_ext(x)
%file_path_as_absolute(x)
%file_path_sans_ext(x, compression = FALSE)
%
%list_files_with_exts(dir, exts, all.files = FALSE,
%                     full.names = TRUE)
%list_files_with_type(dir, type, all.files = FALSE,
%                     full.names = TRUE, OS_subdirs = .OStype())
%}
%\arguments{
%  \item{x}{character vector giving file paths.}
%  \item{compression}{logical: should compression extension \file{.gz},
%    \file{.bz2} or \file{.xz} be removed first?}
%  \item{dir}{a character string with the path name to a directory.}
%  \item{exts}{a character vector of possible file extensions (excluding
%    the leading dot).}
%  \item{all.files}{a logical.  If \code{FALSE} (default), only visible
%    files are considered; if \code{TRUE}, all files are used.}
%  \item{full.names}{a logical indicating whether the full paths of the
%    files found are returned (default), or just the file names.}
%  \item{type}{a character string giving the \sQuote{type} of the files
%    to be listed, as characterized by their extensions.  Currently,
%    possible values are \code{"code"} (R code), \code{"data"} (data
%    sets), \code{"demo"} (demos), \code{"docs"} (R documentation), and
%    \code{"vignette"} (vignettes).}
%  \item{OS_subdirs}{a character vector with the names of OS-specific
%    subdirectories to possibly include in the listing of R code and
%    documentation files.  By default, the value of the environment
%    variable \env{R_OSTYPE}, or if this is empty, the value of
%    \code{\link{.Platform}$OS.type}, is used.}
%}
%\details{
%  \code{file_ext} returns the file (name) extensions (excluding the
%  leading dot).
%  (Only purely alphanumeric extensions are recognized.)
%
%  \code{file_path_as_absolute} turns a possibly relative file path
%  absolute, performing tilde expansion if necessary.  This is a wrapper
%  for \code{\link{normalizePath}}.  Currently, \code{x} must be a single
%  existing path.
%
%  \code{file_path_sans_ext} returns the file paths without extensions
%  (and the leading dot).
%  (Only purely alphanumeric extensions are recognized.)
%
%  \code{list_files_with_exts} returns the paths or names of the files in
%  directory \code{dir} with extension matching one of the elements of
%  \code{exts}.  Note that by default, full paths are returned, and that
%  only visible files are used.
%
%  \code{list_files_with_type} returns the paths of the files in \code{dir}
%  of the given \sQuote{type}, as determined by the extensions recognized
%  by \R.  When listing R code and documentation files, files in
%  OS-specific subdirectories are included if present according to the
%  value of \code{OS_subdirs}.  Note that by default, full paths are
%  returned, and that only visible files are used.
%}
%\seealso{
%  \code{\link{file.path}},
%  \code{\link{file.info}},
%  \code{\link{list.files}}
%}
%\examples{\donttest{
%dir <- file.path(R.home(), "library", "stats")
%list_files_with_exts(file.path(dir, "demo"), "R")
%list_files_with_type(file.path(dir, "demo"), "demo") # the same
%file_path_sans_ext(list.files(file.path(R.home("modules"))))
%}}
%\keyword{file}
%
%\encoding{UTF8}
%