% File src/library/tools/man/parseLatex.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{parseLatex}
%@%\alias{Latex の構文解析}
\alias{parseLatex}
\alias{deparseLatex}
\alias{latexToUtf8}
%\title{These experimental functions work with a subset of LaTeX code.}
\title{これらの実験的な関数は LaTeX コードのサブセットを扱う}
\description{
  \code{parseLatex} 関数は
  LaTeX のソースを構文解析し，構造化されたオブジェクトを作る；\cr
  \code{deparseLatex} は過程を逆転する．
  \code{latexToUtf8} 関数は
  LaTeX オブジェクトを取り，それらを
  対応する UTF-8 文字に変換する幾つかの異なったマクロを処理する．
}
\usage{
parseLatex(text, filename = deparse(substitute(text)),
           verbose = FALSE,
           verbatim = c("verbatim", "verbatim*",
                        "Sinput", "Soutput"))
deparseLatex(x, dropBraces = FALSE)
latexToUtf8(x)
}
\arguments{
  \item{text}{
LaTeX のソースコードを含む文字列ベクトル．
}
  \item{filename}{
構文エラーのメッセージ中で使われるファイル名．
}
  \item{verbose}{
もし \code{TRUE} なら，デバッグエラーメッセージをプリントする．
}
  \item{verbatim}{
逐語的なテキストを保持する
LaTeX 環境の名前を含む文字列ベクトル．
}
  \item{x}{
\code{"LaTeX"} オブジェクト．
}
  \item{dropBraces}{
\code{"LaTeX"} オブジェクトを表示する時不要な括弧を取り去る．
}
}
\details{

構文解析器は全ての適正な
LaTeX コードを認識すせず，限られた簡単な例だけである．
それは引数にマクロを関連させない，これは
構文解析後に各マクロの定義の知識を使いなされる必要があある．
この関数の意図は完全な
一般的な LaTeX ドキュメントではなく，文献参照で使われる簡単なコードを
処理することである．

注釈の多いテキストは二つの形式で許される：
\verb{\\verb} マクロ(単一の文字区切りを使い)，
そしてその名前が
\code{verbatim} 引数中でリストされる環境である．

}
\value{
\code{parseLatex()} 関数はクラス
\code{"LaTeX"} の再帰的なオブジェクトを返す．このオブジェクト中の項目の各々は
そのシンタックス的な役割を特定する
\code{"latex_tag"} 属性を持つ．

\code{deparseLatex()} 関数は単一要素の文字列ベクトルを返し，
もしかすると埋め込みの新行を含むかもしれない．

\code{latexToUtf8()} 関数はそれに渡される
\code{"LaTeX"} オブジェクトの修正バージョンを返す．
}
\author{
Duncan Murdoch
}
\examples{\donttest{
latex <- parseLatex("fa\\\\c{c}ile")
deparseLatex(latexToUtf8(latex))
}}
\keyword{ utilities }
\keyword{ documentation }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/parseLatex.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{parseLatex}
%\alias{parseLatex}
%\alias{deparseLatex}
%\alias{latexToUtf8}
%\title{
%These experimental functions work with a subset of LaTeX code.
%}
%\description{
%  The \code{parseLatex} function parses LaTeX source, producing a
%  structured object; \code{deparseLatex} reverses the process.  The
%  \code{latexToUtf8} function takes a LaTeX object, and processes a number
%  of different macros to convert them into the corresponding UTF-8
%  characters.
%}
%\usage{
%parseLatex(text, filename = deparse(substitute(text)),
%           verbose = FALSE,
%           verbatim = c("verbatim", "verbatim*",
%                        "Sinput", "Soutput"))
%deparseLatex(x, dropBraces = FALSE)
%latexToUtf8(x)
%}
%\arguments{
%  \item{text}{
%A character vector containing LaTeX source code.
%}
%  \item{filename}{
%A filename to use in syntax error messages.
%}
%  \item{verbose}{
%If \code{TRUE}, print debug error messages.
%}
%  \item{verbatim}{
%A character vector containing the names of LaTeX environments holding verbatim text.
%}
%  \item{x}{
%A \code{"LaTeX"} object.
%}
%  \item{dropBraces}{
%Drop unnecessary braces when displaying a \code{"LaTeX"} object.
%}
%}
%\details{
%
%The parser does not recognize all legal LaTeX code, only relatively
%simple examples.  It does not associate arguments with macros, that
%needs to be done after parsing, with knowledge of the definitions of
%each macro.  The main intention for this function is to process simple
%LaTeX code used in bibliographic references, not fully general LaTeX
%documents.
%
%Verbose text is allowed in two forms:  the \verb{\\verb} macro (with
%single character delimiters), and environments whose names are listed
%in the \code{verbatim} argument.
%
%}
%\value{
%The \code{parseLatex()} function returns a recursive object of class
%\code{"LaTeX"}.  Each of the entries in this object will have a \code{
%"latex_tag"} attribute identifying its syntactic role.
%
%The \code{deparseLatex()} function returns a single element character
%vector, possibly containing embedded newlines.
%
%The \code{latexToUtf8()} function returns a modified version of the
%\code{"LaTeX"} object that was passed to it.
%}
%\author{
%Duncan Murdoch
%}
%\examples{\donttest{
%latex <- parseLatex("fa\\\\c{c}ile")
%deparseLatex(latexToUtf8(latex))
%}}
%\keyword{ utilities }
%\keyword{ documentation }
%
%\encoding{UTF8}
%